"use strict";
exports.__esModule = true;
exports.getParsedExampleData = exports.getParsedComponentData = void 0;
var chalk = require("chalk");
var ts = require("typescript");
var react_docgen_typescript_1 = require("react-docgen-typescript");
var consoleUtil_1 = require("./consoleUtil");
var fileUtils_1 = require("./fileUtils");
var serviceHost_1 = require("./serviceHost");
var lodash_1 = require("lodash");
var componentPathUtils_1 = require("./componentPathUtils");
var parser = react_docgen_typescript_1.withCompilerOptions({
    jsx: ts.JsxEmit.React,
    maxNodeModuleJsDepth: 1,
    module: ts.ModuleKind.CommonJS,
    target: ts.ScriptTarget.Latest
});
var getExampleName = function (content) {
    return content.match(/export default (function )?(\w+)/m)[2];
};
function getParsedComponentData(filePath, componentName) {
    return parser.parseWithProgramProvider(componentPathUtils_1.getComponentPropertyFilePath(filePath, componentName), serviceHost_1.getProgram);
}
exports.getParsedComponentData = getParsedComponentData;
function getParsedExampleData(componentPath, componentName) {
    var relativePath = consoleUtil_1.absToRelative(componentPath);
    var timerOutput = consoleUtil_1.getStatusLine({
        msg: relativePath + "/" + chalk.bold(componentName + ".tsx"),
        status: 'success',
        statusMsg: 'DONE'
    });
    console.time(timerOutput);
    var exampleFiles = fileUtils_1.getExampleFileNames(componentPath, componentName).filter(function (exampleFileName) { return exampleFileName !== 'index.ts'; });
    var exampleBase = componentPathUtils_1.getComponentExampleFilePath(componentPath);
    var examplePaths = exampleFiles.map(function (f) { return exampleBase + "/" + f; });
    var parsedComponentData = getParsedComponentData(examplePaths, componentName);
    var componentExampleData = exampleFiles.map(function (exampleFileName) {
        var content = fileUtils_1.readFile(exampleBase + "/" + exampleFileName);
        var componentData = parsedComponentData.find(function (component) {
            return lodash_1.isEqual(getExampleName(content), component.displayName);
        });
        return {
            exampleName: exampleFileName.replace('.tsx', ''),
            exampleDescription: componentData && componentData.description,
            exampleCode: content
        };
    });
    console.timeEnd(timerOutput);
    return componentExampleData;
}
exports.getParsedExampleData = getParsedExampleData;
