"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
exports.__esModule = true;
exports.getComponentMarkdownFilePath = exports.getComponentExampleFilePath = exports.getComponentPropertyFilePath = exports.getComponentFilePath = exports.convertToParsedComponentPath = exports.getComponentNames = void 0;
var fileUtils_1 = require("./fileUtils");
var path = require("path");
var lodash_1 = require("lodash");
var externalLibraries_1 = require("../externalLibraries");
function getComponentNames(componentGroupPath, componentGroup) {
    if (externalLibraries_1.isExternalLibrary(componentGroupPath)) {
        var componentNames = Object.keys(externalLibraries_1.EXTERNAL_COMPONENTS).reduce(function (acc, key) {
            return externalLibraries_1.EXTERNAL_COMPONENTS[key].componentGroup === componentGroup
                ? __spreadArrays(acc, [key]) : acc;
        }, []);
        return componentNames.length ? componentNames : [componentGroup];
    }
    return fileUtils_1.getDirectories(path.join(componentGroupPath, componentGroup));
}
exports.getComponentNames = getComponentNames;
function convertToParsedComponentPath(componentGroupPath, componentGroup, componentName) {
    if (externalLibraries_1.isExternalLibrary(componentGroupPath)) {
        var base = fileUtils_1.getPathParts(componentGroupPath)[0];
        if (!externalLibraries_1.EXTERNAL_COMPONENTS[componentName]) {
            console.warn('WARN', "External library component named '" +
                componentName +
                "' does not exist in settings (externalLibrary.ts)");
            return null;
        }
        return {
            componentName: componentName,
            componentGroup: lodash_1.camelCase(componentGroup),
            componentPath: path.join(base, externalLibraries_1.EXTERNAL_COMPONENTS[componentName].componentFolder)
        };
    }
    return {
        componentName: componentName,
        componentGroup: componentGroup,
        componentPath: path.join(componentGroupPath, componentGroup, componentName)
    };
}
exports.convertToParsedComponentPath = convertToParsedComponentPath;
function getComponentFilePath(componentPath, componentName) {
    var base = fileUtils_1.getPathParts(componentPath)[0];
    return externalLibraries_1.isExternalLibrary(componentPath)
        ? path.join(base, externalLibraries_1.EXTERNAL_COMPONENTS[componentName].componentFolder, externalLibraries_1.EXTERNAL_COMPONENTS[componentName].componentFilename)
        : path.join(componentPath, componentName + ".tsx");
}
exports.getComponentFilePath = getComponentFilePath;
function getComponentPropertyFilePath(filePath, componentName) {
    if (externalLibraries_1.isExternalLibrary(filePath)) {
        var base = fileUtils_1.getPathParts(filePath)[0];
        var externalComponent = externalLibraries_1.EXTERNAL_COMPONENTS[componentName];
        return path.join(base, externalComponent.componentFolder, externalComponent.componentPropertyFilename);
    }
    return filePath;
}
exports.getComponentPropertyFilePath = getComponentPropertyFilePath;
function getComponentExampleFilePath(componentPath) {
    var _a = fileUtils_1.getPathParts(componentPath), base = _a[0], componentParts = _a[1];
    if (externalLibraries_1.isExternalLibrary(componentParts)) {
        var componentName = componentParts.slice(componentParts.lastIndexOf(path.sep) + 1);
        return path.join(base, externalLibraries_1.EXTERNAL_COMPONENTS[componentName].exampleFolder);
    }
    return path.join(base, 'packages', 'documentation', 'src', componentParts.replace('components', 'examples'));
}
exports.getComponentExampleFilePath = getComponentExampleFilePath;
function getComponentMarkdownFilePath(markdownFilePath, markdownFileName, componentName) {
    if (externalLibraries_1.isExternalLibrary(markdownFilePath)) {
        var base = fileUtils_1.getPathParts(markdownFilePath)[0];
        var filename = externalLibraries_1.EXTERNAL_COMPONENTS[componentName].markdownFilePath;
        if (filename) {
            return path.join(base, filename);
        }
    }
    return path.join(markdownFilePath, markdownFileName);
}
exports.getComponentMarkdownFilePath = getComponentMarkdownFilePath;
