"use strict";
exports.__esModule = true;
exports.readMarkdownFile = exports.getAllComponentFiles = exports.getExampleFileNames = exports.parseComponentPaths = exports.getFileNamesWithExt = exports.readFile = exports.writeFile = exports.getDirectories = exports.getFiles = exports.getPathParts = void 0;
var chalk = require("chalk");
var fs = require("fs");
var lodash_1 = require("lodash");
var path = require("path");
var types_1 = require("../../../types");
var componentPathUtils_1 = require("./componentPathUtils");
var consoleUtil_1 = require("./consoleUtil");
function getPathParts(componentPath) {
    var _a = componentPath.split("packages" + path.sep), base = _a[0], componentParts = _a[1];
    return [base, componentParts];
}
exports.getPathParts = getPathParts;
function getFiles(filepath) {
    return fs
        .readdirSync(filepath)
        .filter(function (file) {
        return fs.statSync(path.join(filepath, file)).isFile();
    });
}
exports.getFiles = getFiles;
function getDirectories(filepath) {
    return fs
        .readdirSync(filepath)
        .filter(function (file) {
        return fs.statSync(path.join(filepath, file)).isDirectory();
    });
}
exports.getDirectories = getDirectories;
function writeFile(filepath, content) {
    fs.writeFile(filepath, content, function (err) {
        if (err) {
            console.log(chalk.red(err));
        }
        else {
            filepath.match(/componentData/)
                ? console.log(chalk.green('Component data saved.'))
                : console.log(chalk.green('Documentation data saved.'));
        }
    });
}
exports.writeFile = writeFile;
function readFile(filePath) {
    return fs.readFileSync(filePath, 'utf-8');
}
exports.readFile = readFile;
function getFileNamesWithExt(directoryPath, fileExt) {
    if (fileExt === void 0) { fileExt = 'md'; }
    var fileNames = [];
    var regex = fileExt === 'md' ? /\.md$/ : /\.tsx$/;
    try {
        fileNames = getFiles(directoryPath).filter(function (fileName) { return regex.test(fileName); });
    }
    catch (error) {
        console.log(chalk.yellow("path " + directoryPath + " does not exist"));
    }
    return fileNames;
}
exports.getFileNamesWithExt = getFileNamesWithExt;
function parseComponentPaths(componentGroupPath) {
    var componentGroups = getDirectories(componentGroupPath);
    return componentGroups.reduce(function (parsedComponentPaths, componentGroup) {
        var componentNames = componentPathUtils_1.getComponentNames(componentGroupPath, componentGroup);
        componentNames.forEach(function (componentName) {
            var parsedComponentPath = componentPathUtils_1.convertToParsedComponentPath(componentGroupPath, componentGroup, componentName);
            if (parsedComponentPath) {
                parsedComponentPaths.push(parsedComponentPath);
            }
        });
        return parsedComponentPaths;
    }, []);
}
exports.parseComponentPaths = parseComponentPaths;
function getExampleFileNames(componentPath, componentName) {
    var exampleFiles = [];
    var examplePath = componentPathUtils_1.getComponentExampleFilePath(componentPath);
    try {
        exampleFiles = getFiles(examplePath);
    }
    catch (error) {
        console.log(consoleUtil_1.getStatusLine({
            msg: chalk.yellow("No examples found for " + chalk.bold(componentName || componentPath) + "."),
            status: 'warn',
            statusMsg: 'WARN'
        }));
    }
    return exampleFiles;
}
exports.getExampleFileNames = getExampleFileNames;
function getAllComponentFiles() {
    return lodash_1.flatten(lodash_1.flatten(types_1.packageDetails.map(function (packageDetail) {
        return parseComponentPaths(packageDetail.packagePath).map(function (_a) {
            var componentPath = _a.componentPath, componentName = _a.componentName;
            var examplePath = componentPathUtils_1.getComponentExampleFilePath(componentPath);
            return getExampleFileNames(componentPath)
                .filter(function (f) { return f !== 'index.ts'; })
                .map(function (f) { return examplePath + "/" + f; })
                .concat(componentPath + "/" + componentName + ".tsx");
        });
    })));
}
exports.getAllComponentFiles = getAllComponentFiles;
function readMarkdownFile(markdownFilePath, markdownFileName, sectionName) {
    try {
        return readFile(componentPathUtils_1.getComponentMarkdownFilePath(markdownFilePath, markdownFileName, sectionName));
    }
    catch (error) {
        console.log(consoleUtil_1.getStatusLine({
            msg: chalk.yellow("No markdown found for " + chalk.bold(sectionName) + "."),
            status: 'warn',
            statusMsg: 'WARN'
        }));
    }
    return '';
}
exports.readMarkdownFile = readMarkdownFile;
