import * as path from 'path';

export enum ExternalLibrary {
    PreampPlus = '@videoamp-private/preamp-plus'
}

export function isExternalLibrary(filePath: string): boolean {
    return Object.values(
        ExternalLibrary
    ).some((externalLibrary: string): boolean =>
        filePath.includes(externalLibrary)
    );
}

// external library: @videoamp-private/preamp-plus
const PREAMPPLUS = {
    components: path.join(
        'packages',
        'documentation',
        'node_modules',
        ExternalLibrary.PreampPlus,
        'src',
        'components'
    ),
    examples: path.join(
        'packages',
        'documentation',
        'src',
        'preamp-plus',
        'examples'
    )
};

// external component settigns

interface ExternalComponentSettings {
    componentFilename: string;
    componentFolder: string;
    componentGroup?: string;
    componentPropertyFilename: string;
    exampleFolder: string;
    markdownFilePath?: string;
}

export const EXTERNAL_COMPONENTS: Record<string, ExternalComponentSettings> = {
    CardTable: {
        componentFilename: 'index.js',
        componentFolder: path.join(PREAMPPLUS.components, 'CardTable'),
        componentPropertyFilename: 'index.d.ts',
        exampleFolder: path.join(PREAMPPLUS.examples, 'cardTable', 'CardTable'),
        markdownFilePath: path.join(
            PREAMPPLUS.examples,
            'cardTable',
            'cardTable.md'
        )
    },
    DataTable: {
        componentFilename: 'DataTable.js',
        componentFolder: path.join(PREAMPPLUS.components, 'DataTable'),
        componentPropertyFilename: 'DataTable.d.ts',
        exampleFolder: path.join(PREAMPPLUS.examples, 'dataTable', 'DataTable'),
        markdownFilePath: path.join(
            PREAMPPLUS.examples,
            'dataTable',
            'dataTable.md'
        )
    },
    Draggable: {
        componentFilename: 'index.js',
        componentFolder: path.join(
            PREAMPPLUS.components,
            'DragNDrop',
            'Draggable'
        ),
        componentGroup: 'DragNDrop',
        componentPropertyFilename: 'index.d.ts',
        exampleFolder: path.join(PREAMPPLUS.examples, 'dragNDrop', 'Draggable'),
        markdownFilePath: path.join(
            PREAMPPLUS.examples,
            'dragNDrop',
            'draggable.md'
        )
    },
    DragNDropContext: {
        componentFilename: 'index.js',
        componentFolder: path.join(
            PREAMPPLUS.components,
            'DragNDrop',
            'DragNDropContext'
        ),
        componentGroup: 'DragNDrop',
        componentPropertyFilename: 'index.d.ts',
        exampleFolder: path.join(
            PREAMPPLUS.examples,
            'dragNDrop',
            'DragNDropContext'
        ),
        markdownFilePath: path.join(
            PREAMPPLUS.examples,
            'dragNDrop',
            'dragNDropContext.md'
        )
    },
    Droppable: {
        componentFilename: 'index.js',
        componentFolder: path.join(
            PREAMPPLUS.components,
            'DragNDrop',
            'Droppable'
        ),
        componentGroup: 'DragNDrop',
        componentPropertyFilename: 'index.d.ts',
        exampleFolder: path.join(PREAMPPLUS.examples, 'dragNDrop', 'Droppable'),
        markdownFilePath: path.join(
            PREAMPPLUS.examples,
            'dragNDrop',
            'droppable.md'
        )
    },
    TreeAmp: {
        componentFilename: 'index.js',
        componentFolder: path.join(PREAMPPLUS.components, 'TreeAmp'),
        componentPropertyFilename: 'index.d.ts',
        exampleFolder: path.join(PREAMPPLUS.examples, 'treeAmp', 'TreeAmp'),
        markdownFilePath: path.join(
            PREAMPPLUS.examples,
            'treeAmp',
            'treeAmp.md'
        )
    }
};
