import { find, propEq } from 'ramda';
import React, { Component } from 'react';
import { Route, Switch } from 'react-router-dom';
import { IComponentData, ITableOfContents } from '../../../../types';
import { tableOfContents } from '../../../compiled-scripts/tableOfContents';
import { componentData } from '../../../config/data';
import { ComponentPage, DocumentationPage } from '../../components';
import { buildDocumentation } from '../../utils';

interface IContentProps {
    currentPath: string;
}

export class Content extends Component<IContentProps> {
    // wrapper components
    ComponentPageWithProps = (
        component: IComponentData,
        path: string
    ): React.ReactNode => {
        return (): React.ReactNode => (
            <ComponentPage
                componentName={component.componentName}
                componentPath={path}
                currentPath={this.props.currentPath}
                key={`${path}-${component.componentName}`}
            />
        );
    };

    DocumentationPageWithProps = (headerSlug: string): React.ReactNode => {
        return (props: any): React.ReactNode => (
            <DocumentationPage
                currentPath={this.props.currentPath}
                headerSlug={headerSlug}
                matchParams={props.match.params}
            />
        );
    };

    HeaderPageWithProps = (headerSlug: string): React.ReactNode => {
        return (): React.ReactNode => buildDocumentation(headerSlug);
    };

    // route builders
    buildComponentRoutes = (components: IComponentData[]): React.ReactNode =>
        components.map(
            (component: IComponentData): React.ReactNode => {
                const path = `/${component.packageName}/${component.componentGroup}/${component.componentName}`;

                return (
                    <Route
                        component={this.ComponentPageWithProps(component, path)}
                        key={path}
                        path={path}
                    />
                );
            }
        );

    buildDocumentationRoutes = (headerSlug: string): React.ReactNode => (
        <Route
            exact
            path={`/${headerSlug}/:primaryGroup/:secondaryGroup?/:tertiaryGroup?/:anchors?`}
            render={this.DocumentationPageWithProps(headerSlug)}
        />
    );

    buildHeaderPageRoutes = (): any =>
        tableOfContents.map(
            (header: ITableOfContents): React.ReactNode => {
                const currentPackage: ITableOfContents =
                    tableOfContents &&
                    find(propEq('slug', header.slug))(tableOfContents);

                const isComponentPackage: boolean =
                    currentPackage &&
                    currentPackage.templateType === 'component';

                return (
                    <Switch key={header.slug}>
                        <Route
                            exact
                            key={header.slug}
                            path={`/${header.slug}`}
                            render={this.HeaderPageWithProps(header.slug)}
                        />
                        {!isComponentPackage &&
                            this.buildDocumentationRoutes(header.slug)}
                    </Switch>
                );
            }
        );

    render(): React.ReactNode {
        return (
            <>
                {this.buildComponentRoutes(componentData)}
                {this.buildHeaderPageRoutes()}
            </>
        );
    }
}
