import React from 'react';

import { RouteComponentProps, withRouter } from 'react-router-dom';

import { Content, Navigation } from '../../components';

import { Select, SelectType, OptionsType, OptionType } from '@preamp/select';

import '@preamp/mixer/dist/mixer.css';
import * as styles from './Docs.scss';

const themeOptions: OptionsType<OptionType> = [
    { label: 'Default', value: 'default' },
    { label: 'Biophilic', value: 'biophilic' }
];

export const Docs: React.FC = (): React.ReactElement => {
    // const [theme, setTheme] = React.useState<string>('Default');
    function componentWithRouter(
        Component: React.ComponentClass<any> | React.SFC<any>
    ): React.SFC {
        return withRouter<RouteComponentProps>(
            (props: RouteComponentProps): React.ReactNode => (
                <Component currentPath={props.location.pathname} />
            )
        );
    }

    const onThemeOptionsChange = (e: any): void => {
        document.body.className = e.value;
    };

    const NavWithRouter: React.SFC = componentWithRouter(Navigation);

    const ContentWithRouter: React.SFC = componentWithRouter(Content);

    return (
        <div className={styles.docsPage}>
            <div className="theme-control">
                <Select
                    className="theme-options"
                    defaultValue={themeOptions[0]}
                    label="Theme"
                    onChange={onThemeOptionsChange}
                    options={themeOptions}
                    selectType={SelectType.Compact}
                    style={{ width: '8rem' }}
                />
            </div>
            <NavWithRouter />
            <ContentWithRouter />
        </div>
    );
};
