import React, { Component, MouseEvent, ReactNode } from 'react';
import cx from 'classnames';

import { IconButton } from '@preamp/core';
import { Code } from '@preamp/signal';

import { IExampleData } from '../../../../types';
import { CodeExample } from '../../components';

import * as styles from './Example.scss';

interface ExampleProps {
    example: IExampleData;
    componentName: string;
    componentGroup: string;
    packageName: string;
}

interface ExampleState {
    showCode: boolean;
}

// List of known packages to validate against
const PACKAGE_NAMES: string[] = [
    'core',
    'datepicker',
    'preamp-plus',
    'rev',
    'select',
    'signal',
    'tables',
    'waveform'
];

export class Example extends Component<ExampleProps, ExampleState> {
    state: ExampleState = {
        showCode: false
    };

    toggleCode = (event: MouseEvent<HTMLElement>): void => {
        event.preventDefault();
        this.setState(
            (prevState): ExampleState => ({
                showCode: !prevState.showCode
            })
        );
    };

    render(): ReactNode {
        const { showCode } = this.state;
        const {
            example,
            componentName,
            componentGroup,
            packageName
        } = this.props;
        const { exampleCode, exampleDescription, exampleName } = example;

        const componentPackage: string = PACKAGE_NAMES.includes(packageName)
            ? packageName
            : 'core';

        const ExampleComponent = require(`../../${componentPackage}/examples/${componentGroup}/${componentName}/${exampleName}`)
            .default;

        return (
            <section className={cx('mb-8', styles.example)}>
                <p className="mb-4">{exampleDescription}</p>
                {componentName && <ExampleComponent />}
                <article>
                    <nav className={cx('p-2 mt-4', styles['example-nav'])}>
                        <IconButton
                            color={showCode ? 'var(--va-teal-400)' : ''}
                            dataUI="code-large"
                            icon={Code}
                            label={`${showCode ? 'Hide' : 'Show'} Code`}
                            onClick={this.toggleCode}
                            size="lg"
                        />
                    </nav>
                    {showCode && <CodeExample code={exampleCode} />}
                </article>
            </section>
        );
    }
}
