import cx from 'classnames';
import React from 'react';
import { NavLink } from 'react-router-dom';
import { INavigationLink } from '../../../../types';
import { scrollToSelectorOnClick } from '../../utils';
import * as styles from './NavigationLink.scss';

export const NavigationLink: React.SFC<INavigationLink> = (
    props: INavigationLink
): React.ReactElement => {
    function isCurrentPath(path: string, currentPath: string): boolean {
        return path === currentPath;
    }

    // replace prop addresses issue with HashRouter throwing errors when selecting the same link twice
    // https://github.com/ReactTraining/react-router/issues/4467
    return (
        <NavLink
            activeClassName={cx(
                styles.navigationLinkActive,
                props.activeClassName
            )}
            className={cx(styles.navigationLink, props.className)}
            data-selector={
                props.scrollToSelector ? props.scrollToSelector : null
            }
            onClick={props.scrollToSelector ? scrollToSelectorOnClick : null}
            replace={isCurrentPath(props.to, props.currentPath)}
            to={props.to}
        >
            {props.children}
        </NavLink>
    );
};
