import React from 'react';

import { IComponentProps } from '../../../../types';

import * as styles from './PropsTable.scss';

interface IPropsTableProps {
    componentProps: IComponentProps;
}

export const PropsTable: React.FC<IPropsTableProps> = ({
    componentProps
}: IPropsTableProps): React.ReactElement => {
    return (
        <table className={styles.props}>
            <thead>
                <tr>
                    <th>Name</th>
                    <th>Description</th>
                    <th>Type</th>
                    <th>Default</th>
                    <th>Required</th>
                </tr>
            </thead>
            <tbody>
                {Object.keys(componentProps).map(
                    (key: string): React.ReactNode => {
                        return (
                            <tr key={key}>
                                <td>{key}</td>
                                <td>{componentProps[key].description}</td>
                                <td>{componentProps[key].type.name}</td>
                                <td>
                                    {componentProps[key].defaultValue &&
                                        String(
                                            componentProps[key].defaultValue
                                                .value
                                        )}
                                </td>
                                <td>{componentProps[key].required && 'X'}</td>
                            </tr>
                        );
                    }
                )}
            </tbody>
        </table>
    );
};
