import React from 'react';

import { Add, Signal } from '@preamp/signal';

import { Button, ButtonTheme } from '@preamp/core';

interface IBasicButtonState {
    count: number;
}

/**
 * Standard button elements and the different options for styles.
 */
class ExampleButton extends React.Component<{}, IBasicButtonState> {
    state: IBasicButtonState = {
        count: 0
    };

    clickButton = (): void => {
        this.setState((prevState: IBasicButtonState): any => ({
            count: prevState.count + 1
        }));
    };

    render(): React.ReactNode {
        return (
            <>
                <div className="va-btn-group">
                    <Button
                        dataUI="primary"
                        onClick={this.clickButton}
                        theme={ButtonTheme.Primary}
                    >
                        Primary
                    </Button>
                    <Button
                        dataUI="secondary"
                        onClick={this.clickButton}
                        theme={ButtonTheme.Secondary}
                    >
                        Secondary
                    </Button>
                    <Button
                        dataUI="success"
                        onClick={this.clickButton}
                        theme={ButtonTheme.Success}
                    >
                        Success
                    </Button>
                    <Button
                        dataUI="destructive"
                        onClick={this.clickButton}
                        theme={ButtonTheme.Destructive}
                    >
                        Destructive
                    </Button>
                    <Button
                        dataUI="link"
                        onClick={this.clickButton}
                        theme={ButtonTheme.Link}
                    >
                        Link
                    </Button>
                    <Button
                        dataUI="dark"
                        onClick={this.clickButton}
                        theme={ButtonTheme.Dark}
                    >
                        Dark
                    </Button>
                    <Button
                        dataUI="disabled"
                        disabled
                        onClick={this.clickButton}
                    >
                        Disabled
                    </Button>
                    <Button
                        dataUI="secondary"
                        isIconButton
                        onClick={this.clickButton}
                        theme={ButtonTheme.Secondary}
                    >
                        <Signal icon={Add} />
                        With Icon
                    </Button>
                </div>
                <br />
                <br />
                <p>Counter: {this.state.count} times</p>
            </>
        );
    }
}

export default ExampleButton;
