import React from 'react';

import { Add, Signal } from '@preamp/signal';

import { Button, ButtonTheme } from '@preamp/core';

interface IBasicButtonState {
    count: number;
}

/**
 * Anchor buttons - if the href prop has a value, the component will render an anchor tag instead of a button tag.
 * Visually it will look the same as the regular button but will allow for the ability to use HTML href functionality.
 */
class ExampleAnchorButton extends React.Component<{}, IBasicButtonState> {
    state: IBasicButtonState = {
        count: 0
    };

    clickButton = (): void => {
        this.setState((prevState: IBasicButtonState): any => ({
            count: prevState.count + 1
        }));
    };

    render(): React.ReactNode {
        return (
            <>
                <div className="va-btn-group">
                    <Button
                        dataUI="primary"
                        href="https://www.videoamp.com"
                        onClick={this.clickButton}
                        openInNewTab={true}
                        theme={ButtonTheme.Primary}
                    >
                        Primary
                    </Button>
                    <Button
                        dataUI="secondary"
                        href="https://www.videoamp.com"
                        onClick={this.clickButton}
                        openInNewTab={true}
                        theme={ButtonTheme.Secondary}
                    >
                        Secondary
                    </Button>
                    <Button
                        dataUI="success"
                        href="https://www.videoamp.com"
                        onClick={this.clickButton}
                        theme={ButtonTheme.Success}
                    >
                        Success
                    </Button>
                    <Button
                        dataUI="destructive"
                        href="https://www.videoamp.com"
                        onClick={this.clickButton}
                        openInNewTab={true}
                        theme={ButtonTheme.Destructive}
                    >
                        Destructive
                    </Button>
                    <Button
                        dataUI="link"
                        href="https://www.videoamp.com"
                        onClick={this.clickButton}
                        openInNewTab={false}
                        theme={ButtonTheme.Link}
                    >
                        Link
                    </Button>
                    <Button
                        dataUI="dark"
                        href="https://www.videoamp.com"
                        onClick={this.clickButton}
                        openInNewTab={true}
                        theme={ButtonTheme.Dark}
                    >
                        Dark
                    </Button>
                    <Button
                        dataUI="disabled"
                        disabled
                        href="https://www.videoamp.com"
                        onClick={this.clickButton}
                    >
                        Disabled
                    </Button>
                    <Button
                        dataUI="secondary"
                        href="https://www.videoamp.com"
                        isIconButton
                        onClick={this.clickButton}
                        openInNewTab={true}
                        theme={ButtonTheme.Secondary}
                    >
                        <Signal icon={Add} />
                        With Icon
                    </Button>
                </div>
                <br />
                <br />
                <p>Counter: {this.state.count} times</p>
            </>
        );
    }
}

export default ExampleAnchorButton;
