import React, { useState } from 'react';
import { Add, Signal } from '@preamp/signal';

import { Button, ButtonTheme } from '@preamp/core';

/**
 * To preserve the alignment in button groups you can use the class va-btn-group.
 */

function ExampleBasicButtonGroup(): React.ReactElement<{}> {
    const [count, setCount] = useState<number>(0);

    function clickButton(): void {
        setCount(count + 1);
    }

    return (
        <>
            <div className="va-btn-group w-1/2">
                <Button
                    dataUI="primary"
                    onClick={clickButton}
                    theme={ButtonTheme.Primary}
                >
                    Primary
                </Button>
                <Button
                    dataUI="secondary"
                    onClick={clickButton}
                    theme={ButtonTheme.Secondary}
                >
                    Secondary
                </Button>
                <Button
                    dataUI="success"
                    onClick={clickButton}
                    theme={ButtonTheme.Success}
                >
                    Success
                </Button>
                <Button
                    dataUI="destructive"
                    onClick={clickButton}
                    theme={ButtonTheme.Destructive}
                >
                    Destructive
                </Button>
                <Button
                    dataUI="link"
                    onClick={clickButton}
                    theme={ButtonTheme.Link}
                >
                    Link
                </Button>
                <Button
                    dataUI="dark"
                    onClick={clickButton}
                    theme={ButtonTheme.Dark}
                >
                    Dark
                </Button>
                <Button dataUI="disabled" disabled onClick={clickButton}>
                    Disabled
                </Button>
                <Button
                    dataUI="secondary"
                    isIconButton
                    onClick={clickButton}
                    theme={ButtonTheme.Secondary}
                >
                    <Signal icon={Add} />
                    With Icon
                </Button>
            </div>
            <div className="mt-2">
                <p>Counter: {count} times</p>
            </div>
        </>
    );
}

export default ExampleBasicButtonGroup;
