import React, { ReactElement, useState } from 'react';

import {
    Account,
    Check,
    Clear,
    Download,
    Link,
    Search,
    Trash
} from '@preamp/signal';

import { IconButton, TextField } from '@preamp/core';

/**
 * The IconButton can use our Signal icon component or any raw SVG.
 */
function ExampleIconButton(): ReactElement {
    const [customIconSize, setCustomSize] = useState('lg');
    const [customIconColor, setCustomColor] = useState(
        'var(--icon-color-default)'
    );
    const svg: React.ReactNode = (
        <svg viewBox="0 0 24 24">
            <defs>
                <path d="M24 24H0V0h24v24z" id="a" />
            </defs>
            <path d="M3 4V1h2v3h3v2H5v3H3V6H0V4h3zm3 6V7h3V4h7l1.83 2H21c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2H5c-1.1 0-2-.9-2-2V10h3zm7 9c2.76 0 5-2.24 5-5s-2.24-5-5-5-5 2.24-5 5 2.24 5 5 5zm-3.2-5c0 1.77 1.43 3.2 3.2 3.2s3.2-1.43 3.2-3.2-1.43-3.2-3.2-3.2-3.2 1.43-3.2 3.2z" />
        </svg>
    );

    function clickIconButton(): void {
        // eslint-disable-next-line no-console
        console.log('clickIconButton');
    }

    function onIconSizeChange(
        event?: React.ChangeEvent<HTMLInputElement>
    ): void {
        setCustomSize(event.currentTarget.value);
    }

    function onIconColorChange(
        event?: React.ChangeEvent<HTMLInputElement>
    ): void {
        setCustomColor(event.currentTarget.value);
    }

    return (
        <>
            <div className="flex items-center">
                <IconButton
                    dataUI="primary"
                    icon={Check}
                    label="Default"
                    onClick={clickIconButton}
                />
            </div>
            <div className="flex items-center">
                <IconButton
                    dataUI="primary"
                    disabled
                    icon={Check}
                    label="Disabled"
                    onClick={clickIconButton}
                />
            </div>
            <div className="flex items-center">
                <IconButton
                    dataUI="primary"
                    href="#/core/buttons/IconButton"
                    icon={Link}
                    label="Anchor Link"
                />
            </div>
            <div className="flex items-center">
                <IconButton
                    dataUI="clear-small"
                    icon={Clear}
                    label="Small"
                    onClick={clickIconButton}
                    size="sm"
                />
            </div>
            <div className="flex items-center">
                <IconButton
                    dataUI="clear-large"
                    icon={Clear}
                    label="Large"
                    onClick={clickIconButton}
                    size="lg"
                />
            </div>
            <div className="flex items-center">
                <IconButton
                    dataUI="custom-svg"
                    icon={svg}
                    label="Raw SVG"
                    onClick={clickIconButton}
                />
            </div>
            <div className="flex items-center">
                <IconButton
                    dataUI="primary"
                    icon={Check}
                    label="Truncated Label Text"
                    labelMaxWidth="7.2rem"
                    onClick={clickIconButton}
                />
            </div>
            <h4 className="mt-6">Size and Color props: </h4>
            <div className="flex items-center mb-6">
                <IconButton
                    color={customIconColor}
                    dataUI="clear"
                    icon={Clear}
                    onClick={clickIconButton}
                    size={customIconSize}
                />
                <IconButton
                    color={customIconColor}
                    dataUI="account"
                    icon={Account}
                    onClick={clickIconButton}
                    size={customIconSize}
                />
                <IconButton
                    color={customIconColor}
                    dataUI="download"
                    icon={Download}
                    onClick={clickIconButton}
                    size={customIconSize}
                />
                <IconButton
                    color={customIconColor}
                    dataUI="trash"
                    icon={Trash}
                    onClick={clickIconButton}
                    size={customIconSize}
                />
                <IconButton
                    color={customIconColor}
                    dataUI="search"
                    icon={Search}
                    onClick={clickIconButton}
                    size={customIconSize}
                />
            </div>
            <div className="va-grid va-columns-default mt-4">
                <div className="mb-6 col-span-3">
                    <TextField
                        helpText="Custom icon size from the size prop - use 'sm', 'lg', or a number with rem or px units"
                        label="Icon Size"
                        onChange={onIconSizeChange}
                        value={customIconSize}
                    />
                </div>
                <div className="mb-6 col-span-3">
                    <TextField
                        helpText="Custom icon color from the color prop"
                        label="Icon Color"
                        onChange={onIconColorChange}
                        value={customIconColor}
                    />
                </div>
            </div>
        </>
    );
}

export default ExampleIconButton;
