import React from 'react';

import { Checkbox } from '@preamp/core';

interface IBasicCheckboxState {
    checked: boolean;
    checkedNoLabel: boolean;
    checkedIndeterminant: number;
    checkedFocus: boolean;
    checkedBlur: boolean;
    optionalChecked: boolean;
}

/**
 * This is a description for the example Checkbox
 */
class ExampleCheckbox extends React.Component<{}, IBasicCheckboxState> {
    state: IBasicCheckboxState = {
        checked: false,
        checkedNoLabel: false,
        checkedIndeterminant: 0,
        checkedFocus: false,
        checkedBlur: false,
        optionalChecked: false
    };

    normalToggle = (checked: boolean): void => this.setState({ checked });
    optionalToggle = (optionalChecked: boolean): void =>
        this.setState({ optionalChecked });
    indeterminantToggle = (): void =>
        this.setState({
            checkedIndeterminant: (this.state.checkedIndeterminant + 1) % 3
        });
    focusToggle = (checkedFocus: boolean = true): void =>
        this.setState({ checkedFocus });
    blurToggle = (checkedBlur: boolean = true): void =>
        this.setState({ checkedBlur });
    noLabelToggle = (checkedNoLabel: boolean): void =>
        this.setState({ checkedNoLabel });
    logFocus = (): void => {
        // eslint-disable-next-line no-console
        console.log('focus');
    };
    logBlur = (): void => {
        // eslint-disable-next-line no-console
        console.log('blur');
    };

    render(): React.ReactNode {
        return (
            <>
                <p className="mb-2">
                    Below are a few various instances of checkboxes
                </p>

                <Checkbox
                    checked={this.state.checked}
                    id="default-checkbox"
                    label="Normal checkbox"
                    name={'checkboxField'}
                    onChange={this.normalToggle}
                />

                <Checkbox
                    checked={this.state.checkedIndeterminant === 1}
                    disabled={false}
                    id="indeterminant-checkbox"
                    indeterminant={this.state.checkedIndeterminant === 0}
                    label="Indeterminant checkbox"
                    name={'checkboxField'}
                    onChange={this.indeterminantToggle}
                />

                <Checkbox
                    checked={false}
                    disabled={true}
                    id="disabled-checkbox"
                    label="Disabled checkbox"
                    name={'checkboxField'}
                    onChange={this.normalToggle}
                />

                <Checkbox
                    checked={true}
                    disabled={true}
                    id="disabled-checked-checkbox"
                    label="Disabled checked checkbox"
                    name={'checkboxField'}
                    onChange={this.normalToggle}
                />

                <Checkbox
                    checked={true}
                    disabled={true}
                    id="indeterminant-disabled-checkbox"
                    indeterminant={true}
                    label="Disabled indeterminant checkbox"
                    name={'checkboxField'}
                    onChange={this.normalToggle}
                />

                <Checkbox
                    checked={this.state.optionalChecked}
                    id="default-checkbox"
                    isOptional={true}
                    label="Optional checkbox"
                    name={'checkboxField'}
                    onChange={this.optionalToggle}
                />

                <Checkbox
                    checked={this.state.checkedFocus}
                    id="no-label-checkbox"
                    label="A checkbox with focus callback"
                    name={'checkboxField'}
                    onChange={this.focusToggle}
                    onFocus={this.logFocus}
                />

                <Checkbox
                    checked={this.state.checkedBlur}
                    id="no-label-checkbox"
                    label="A checkbox with blur callback"
                    name={'checkboxField'}
                    onBlur={this.logBlur}
                    onChange={this.blurToggle}
                />

                <Checkbox
                    checked={this.state.checkedNoLabel}
                    dataUI="test"
                    id="no-label-checkbox"
                    name={'checkboxField'}
                    onChange={this.noLabelToggle}
                />
                <div className="u-body-2">A checkbox with no label</div>
            </>
        );
    }
}

export default ExampleCheckbox;
