import React from 'react';

import { Checkbox, CheckboxGroup, Toggle } from '@preamp/core';

interface IExampleCheckboxState {
    selectedValues: string[];
    selectedValuesGrp2: string[];
    lastChanged: string;
    checked: boolean;
    requiredOptions: number;
    enoughSelected: boolean;
    toggleInline: boolean;
}

/**
 * This is a set of examples for PreAmp's Check Box Group
 */
class ExampleCheckboxGroup extends React.Component<{}, IExampleCheckboxState> {
    state: IExampleCheckboxState = {
        selectedValues: [],
        selectedValuesGrp2: [],
        lastChanged: null,
        checked: false,
        requiredOptions: 3,
        enoughSelected: false,
        toggleInline: false
    };

    onChangeHandlerGrp1 = (selectedValue: string | number): void => {
        const { selectedValues, requiredOptions } = this.state;

        if (selectedValues.indexOf(selectedValue.toString()) > -1) {
            const filteredValues: string[] = selectedValues.filter(
                (x: string): boolean => x !== selectedValue.toString()
            );
            this.setState({
                selectedValues: filteredValues,
                lastChanged: selectedValue.toString(),
                enoughSelected: filteredValues.length >= requiredOptions
            });
        } else {
            selectedValues.push(selectedValue.toString());
            this.setState({
                selectedValues,
                lastChanged: selectedValue.toString(),
                enoughSelected: selectedValues.length >= requiredOptions
            });
        }
    };

    onChangeHandlerGrp2 = (selectedValue: string | number): void => {
        const { selectedValuesGrp2 } = this.state;

        if (selectedValuesGrp2.indexOf(selectedValue.toString()) > -1) {
            const filteredValues: string[] = selectedValuesGrp2.filter(
                (x: string): boolean => x !== selectedValue.toString()
            );
            this.setState({
                selectedValuesGrp2: filteredValues,
                lastChanged: selectedValue.toString()
            });
        } else {
            selectedValuesGrp2.push(selectedValue.toString());
            this.setState({
                selectedValuesGrp2,
                lastChanged: selectedValue.toString()
            });
        }
    };
    onToggle = (checked: boolean): void => {
        this.setState({ toggleInline: checked });
    };

    // tslint:disable-next-line
    normalToggle = (): void => {};
    render(): React.ReactNode {
        return (
            <>
                <h3>Inline layout</h3>

                <div className="mt-2">
                    <Toggle
                        checked={this.state.toggleInline}
                        label="This toggle allows you to see inline options."
                        name="width-toggle"
                        onChange={this.onToggle}
                    />
                </div>
                {this.state.selectedValues && (
                    <>
                        {!this.state.lastChanged && (
                            <p className="mb-4 u-well">No Checkbox changed.</p>
                        )}
                        {this.state.lastChanged && (
                            <p className="mb-4">
                                Checkbox {this.state.lastChanged} has just been
                                changed.
                            </p>
                        )}
                    </>
                )}
                <div
                    className="va-form-group"
                    data-ui={`form-element--1`}
                    id={`form-element-1`}
                    key={`form-element-1`}
                >
                    <CheckboxGroup
                        description={'This is the description.'}
                        isInline={this.state.toggleInline}
                        key={`form-element-1-group`}
                        minOptionsRequired={
                            this.state.enoughSelected
                                ? null
                                : this.state.requiredOptions
                        }
                        name={'checkboxGroup'}
                        onChange={this.onChangeHandlerGrp1}
                        required={true}
                        selectedValues={this.state.selectedValues}
                        title={'Checkbox Group 1:'}
                    >
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-1-1`}
                            label="Checkbox 1"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={1}
                        />
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-1-2`}
                            label="Checkbox 2"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={2}
                        />
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-1-3`}
                            label="Checkbox 3"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={3}
                        />
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-1-4`}
                            label="Checkbox 4"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={4}
                        />
                    </CheckboxGroup>
                </div>
                <div
                    className="va-form-group"
                    data-ui={`form-element--2`}
                    id={`form-element-2`}
                    key={`form-element-2`}
                >
                    <CheckboxGroup
                        description={'This is the description.'}
                        isInline={this.state.toggleInline}
                        isOptional={true}
                        key={`form-element-2-group`}
                        name={'checkboxGroup'}
                        onChange={this.onChangeHandlerGrp2}
                        required={false}
                        selectedValues={this.state.selectedValuesGrp2}
                        title={'Checkbox Group 2:'}
                    >
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-2-1`}
                            label="Checkbox 5"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={5}
                        />
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-2-2`}
                            label="Checkbox 6"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={6}
                        />
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-2-3`}
                            label="Checkbox 7"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={7}
                        />
                        <Checkbox
                            checked={true}
                            disabled={true}
                            id="default-checkbox"
                            key={`form-element-2-4`}
                            label="Checkbox 8"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={8}
                        />
                    </CheckboxGroup>
                </div>
                <div
                    className="va-form-group"
                    data-ui={`form-element--3`}
                    id={`form-element-3`}
                    key={`form-element-3`}
                >
                    <CheckboxGroup
                        isInline={this.state.toggleInline}
                        key={`form-element-3-group`}
                        name={'checkboxGroup'}
                        onChange={this.onChangeHandlerGrp2}
                        required={false}
                        selectedValues={this.state.selectedValuesGrp2}
                        title={'Checkbox no description:'}
                    >
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-3-1`}
                            label="Checkbox 9"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={9}
                        />
                    </CheckboxGroup>
                </div>
                <p>Checkbox group no title.</p>
                <div
                    className="va-form-group"
                    data-ui={`form-element--4`}
                    id={`form-element-4`}
                    key={`form-element-4`}
                >
                    <CheckboxGroup
                        isInline={this.state.toggleInline}
                        key={`form-element-4-group`}
                        name={'checkboxGroup'}
                        onChange={this.onChangeHandlerGrp2}
                        required={false}
                        selectedValues={this.state.selectedValuesGrp2}
                    >
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-4-1`}
                            label="Checkbox 10"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={10}
                        />
                        <Checkbox
                            checked={true}
                            id="default-checkbox"
                            key={`form-element-4-2`}
                            label="Checkbox 11"
                            name={'checkboxField'}
                            onChange={this.normalToggle}
                            value={11}
                        />
                    </CheckboxGroup>
                </div>
            </>
        );
    }
}

export default ExampleCheckboxGroup;
