import React from 'react';

import { FileUpload, LoadingStatus } from '@preamp/core';

interface ExampleFileUploadState {
    fileName: string;
    uploadStatus?: LoadingStatus;
}

class ExampleFileUpload extends React.Component<{}, ExampleFileUploadState> {
    state: ExampleFileUploadState = {
        fileName: null
    };

    exampleTimeoutActions = (): void => {
        this.setState({
            uploadStatus: LoadingStatus.Loading
        });
        setTimeout((): void => {
            this.setState({
                uploadStatus: LoadingStatus.Success
            });
        }, 2000);
    };

    onFileDropped = (file: File): void => {
        this.setState({
            fileName: file.name
        });
        this.exampleTimeoutActions();
    };

    onFileSelected = (e: React.FormEvent<HTMLInputElement>): void => {
        const file: File = e.currentTarget.files[0];
        if (file) {
            this.setState({
                fileName: file.name
            });
            this.exampleTimeoutActions();
        }
    };

    onFileRemoved = (): void => {
        this.setState({
            fileName: null,
            uploadStatus: null
        });
    };

    onMultipleFilesSelected = (e: React.FormEvent<HTMLInputElement>): void => {
        console.log(e.currentTarget.files);
    };

    render(): React.ReactNode {
        const { fileName, uploadStatus } = this.state;

        return (
            <>
                <FileUpload
                    dataUI="fileupload-default"
                    fileName={fileName}
                    id="fileupload-default"
                    isOptional
                    label="Functional example:"
                    onFileDropped={this.onFileDropped}
                    onFileRemoved={this.onFileRemoved}
                    onFileSelected={this.onFileSelected}
                    status={uploadStatus}
                />
                <br />
                <br />
                <FileUpload
                    dataUI="fileupload-multiple"
                    id="fileupload-multiple"
                    label="Multiple:"
                    multiple
                    onFileSelected={this.onMultipleFilesSelected}
                />
                <br />
                <br />
                <FileUpload
                    dataUI="fileupload-failure"
                    errorText="Product codes 189, $2.50 are not recognized"
                    fileName="MO_November_2019.xlsx"
                    id="fileupload-failure"
                    label="Failed Upload:"
                    onFileDropped={this.onFileDropped}
                    status={LoadingStatus.Error}
                />
            </>
        );
    }
}

export default ExampleFileUpload;
