import React, { useState, ReactElement } from 'react';

import { FileUpload, LoadingStatus } from '@preamp/core';

function LoadingFileUpload(): ReactElement<{}> {
    const [fileName, setFileName] = useState('');
    const [uploadStatus, setUploadStatus] = useState(null);
    const [uploadPercentage, setUploadPercentage] = useState(0);

    function onFileDropped(file: File): void {
        setUploadPercentage(0);
        if (file) {
            setFileName(file.name);
            setUploadStatus(LoadingStatus.Loading);

            let timeleft = 20;
            const downloadTimer = setInterval(function(): void {
                if (timeleft === 0) {
                    clearInterval(downloadTimer);
                    setUploadStatus(LoadingStatus.Success);
                }
                setUploadPercentage(
                    (prevProgress: number): number => prevProgress + 0.05
                );
                timeleft -= 1;
            }, 800);
        }
    }

    function onFileSelected(e: React.FormEvent<HTMLInputElement>): void {
        const file: File = e.currentTarget.files.length
            ? e.currentTarget.files[0]
            : null;
        onFileDropped(file);
    }

    function onFileRemoved(): void {
        setFileName('');
        setUploadStatus(null);
        setUploadPercentage(0);
    }

    return (
        <FileUpload
            dataUI="fileupload-default"
            fileName={fileName}
            id="fileupload-default"
            isOptional={true}
            label="Loading Percentage Example:"
            loadingPercentage={uploadPercentage}
            onFileDropped={onFileDropped}
            onFileRemoved={onFileRemoved}
            onFileSelected={onFileSelected}
            status={uploadStatus}
        />
    );
}

export default LoadingFileUpload;
