import React, { useState } from 'react';
import { FileUpload, LoadingStatus } from '@preamp/core';

interface ExampleFileUploadState {
    fileName: string;
    uploadStatus?: LoadingStatus;
}

function ExampleCustomWidthFileUpload() {
    const [state, setstate] = useState<ExampleFileUploadState>({
        fileName: null
    });

    const exampleTimeoutActions = (): void => {
        setstate({
            ...state,
            uploadStatus: LoadingStatus.Loading
        });
        setTimeout((): void => {
            setstate({
                ...state,
                uploadStatus: LoadingStatus.Success
            });
        }, 2000);
    };

    const onFileDropped = (file: File): void => {
        setstate({
            fileName: file.name
        });
        exampleTimeoutActions();
    };

    const onFileSelected = (e: React.FormEvent<HTMLInputElement>): void => {
        const file: File = e.currentTarget.files[0];
        if (file) {
            setstate({
                fileName: file.name
            });
            exampleTimeoutActions();
        }
    };

    const onFileRemoved = (): void => {
        setstate({
            fileName: null,
            uploadStatus: null
        });
    };

    return (
        <>
            <FileUpload
                dataUI="fileupload-default"
                fileName={state.fileName}
                id="fileupload-default"
                isOptional={true}
                label="Functional example: With a custom width."
                onFileDropped={onFileDropped}
                onFileRemoved={onFileRemoved}
                onFileSelected={onFileSelected}
                status={state.uploadStatus}
                width={500}
            />

            <div className="mt-8">
                <FileUpload
                    dataUI="fileupload-failure"
                    errorText="Product codes 189, $2.50 are not recognized"
                    fileName="MO_November_2019.xlsx"
                    id="fileupload-failure"
                    label="Failed Upload: With a custom width."
                    onFileDropped={onFileDropped}
                    status={LoadingStatus.Error}
                    width={500}
                />
            </div>
        </>
    );
}

export default ExampleCustomWidthFileUpload;
