import React, { ReactElement, useState } from 'react';

import {
    Button,
    ButtonTheme,
    ButtonType,
    Checkbox,
    CheckboxGroup,
    Form,
    FormAutoComplete,
    FormMethod,
    FormTarget,
    RadioButton,
    RadioButtonGroup,
    TextField,
    TextFieldType,
    Toggle,
    ToggleGroup
} from '@preamp/core';

/**
 * This is a set of examples for PreAmp's Form Component.
 */
function ExampleRadioButton(): ReactElement<{}> {
    const [formSubmitted, setFormSubmitted] = useState(false);
    const [lastChanged, setlastChanged] = useState(null);
    const [lastChangedToggle, setLastChangedToggle] = useState(null);
    const [onCheckboxChecked, setOnCheckboxChecked] = useState(false);
    const [onToggleChecked, setOnToggleChecked] = useState(false);
    const [selectedValue, setSelectedValue] = useState(2);
    const [selectedValues, setSelectedValues] = useState(['1']);
    const [selectedToggleValues, setSelectedToggleValues] = useState([]);
    const [textFieldValue, setTextFieldValue] = useState('');
    const [buttonClicked, setButtonClicked] = useState(false);

    function onFromTextChange(e: React.FormEvent<HTMLInputElement>): void {
        setTextFieldValue(e.currentTarget.value);
    }

    function onFormSubmitHandler(): void {
        setFormSubmitted(!formSubmitted);
    }

    function onButtonClick(): void {
        setButtonClicked(!buttonClicked);
    }

    function onChangeHandlerGrp1(selectedCheckbox: string | number): void {
        if (selectedValues.indexOf(selectedCheckbox.toString()) > -1) {
            const filteredCheckValues: string[] = selectedValues.filter(
                (x: string): boolean => x !== selectedCheckbox.toString()
            );
            setSelectedValues(filteredCheckValues);
            setlastChanged(selectedCheckbox.toString());
        } else {
            selectedValues.push(selectedCheckbox.toString());
            setSelectedValues(selectedValues);
            setlastChanged(selectedCheckbox.toString());
        }
    }

    function onRadioChangeHandler(value: number): void {
        setSelectedValue(value);
    }

    // tslint:disable-next-line
    function onChangeHandlerGrp2(selectedToggle: string | number): void {
        if (selectedToggleValues.indexOf(selectedToggle.toString()) > -1) {
            const filteredValues: string[] = selectedToggleValues.filter(
                (x: string): boolean => x !== selectedToggle.toString()
            );
            setSelectedToggleValues(filteredValues);
            setLastChangedToggle(selectedToggle.toString());
        } else {
            selectedToggleValues.push(selectedToggle.toString());
            setSelectedToggleValues(selectedToggleValues);
            setLastChangedToggle(selectedToggle.toString());
        }
    }

    function onCheckboxChanged(checkboxChange: boolean): void {
        setOnCheckboxChecked(checkboxChange);
    }

    function onToggleChanged(toggleChange: boolean): void {
        setOnToggleChecked(toggleChange);
    }

    return (
        <>
            <p>PreAmp Form:</p>
            <p>
                <strong>Textbox: </strong> {textFieldValue}
            </p>
            <p>
                <strong>Checkbox: </strong> Checkbox{' '}
                {onCheckboxChecked && lastChanged} selected.
            </p>
            <p>
                <strong>Radio Buttons: </strong> Radio Button {selectedValue}{' '}
                selected.
            </p>
            <p>
                <strong>Toggle: </strong> {onToggleChecked && 'Toggle On'}
                {!onToggleChecked && 'Toggle Off'}{' '}
                {lastChangedToggle && (
                    <> - Last changed is {lastChangedToggle}</>
                )}
            </p>
            <Form
                autocomplete={FormAutoComplete.On}
                description={
                    'Maecenas faucibus mollis interdum. Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Donec ullamcorper nulla non metus auctor fringilla.'
                }
                method={FormMethod.GET}
                onSubmit={onFormSubmitHandler}
                target={FormTarget._BLANK}
                title={'Form Title'}
                validated={true}
            >
                <TextField
                    id={'test'}
                    label="This is a field"
                    name={'Test'}
                    onChange={onFromTextChange}
                    textFieldType={TextFieldType.Text}
                    value={textFieldValue}
                />
                <CheckboxGroup
                    description={'This is the description.'}
                    name={'checkboxGroup'}
                    onChange={onChangeHandlerGrp1}
                    required={true}
                    selectedValues={selectedValues}
                    title={'Checkbox Group 1:'}
                >
                    <Checkbox
                        checked={null}
                        id="default-checkbox"
                        key={0}
                        label="Checkbox 1"
                        name={'checkboxField'}
                        onChange={onCheckboxChanged}
                        value={1}
                    />
                    <Checkbox
                        checked={null}
                        id="default-checkbox"
                        key={1}
                        label="Checkbox 2"
                        name={'checkboxField'}
                        onChange={onCheckboxChanged}
                        value={2}
                    />
                </CheckboxGroup>
                <RadioButtonGroup
                    name={'radioButtonGroup'}
                    onChange={onRadioChangeHandler}
                    required={false}
                    selectedValue={selectedValue.toString()}
                    title={'Radio Group Title:'}
                >
                    <RadioButton
                        key={0}
                        label={'Button 1'}
                        name={'radioButton'}
                        value={'1'}
                    />
                    <RadioButton
                        key={1}
                        label={'Button 2'}
                        name={'radioButton'}
                        value={'2'}
                    />
                    <RadioButton
                        key={2}
                        label={'Button 3'}
                        name={'radioButton'}
                        value={'3'}
                    />
                    <RadioButton
                        disabled={true}
                        key={3}
                        label={'Button 4'}
                        name={'radioButton'}
                        value={'4'}
                    />
                </RadioButtonGroup>

                <ToggleGroup
                    description={
                        'Maecenas faucibus mollis interdum. Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Donec ullamcorper nulla non metus auctor fringilla'
                    }
                    name={'toggleGroup'}
                    onChange={onChangeHandlerGrp2}
                    required={true}
                    selectedValues={selectedToggleValues}
                    title={'Toggle Group 1:'}
                >
                    <Toggle
                        checked={null}
                        id="off-toggle"
                        key={0}
                        label={'Toggle 1'}
                        name="off-toggle"
                        onChange={onToggleChanged}
                        value={'1'}
                    />

                    <Toggle
                        checked={null}
                        id="on-toggle"
                        key={1}
                        label="On"
                        name="on-toggle"
                        onChange={onToggleChanged}
                        value={'2'}
                    />

                    <Toggle
                        checked={false}
                        disabled={true}
                        id="disabled-off-toggle"
                        key={2}
                        label="Disabled Off"
                        name="disabled-off-toggle"
                        onChange={onToggleChanged}
                        value={'3'}
                    />
                </ToggleGroup>

                <Button
                    buttonType={ButtonType.Submit}
                    dataUI="primary"
                    onClick={onButtonClick}
                    theme={ButtonTheme.Primary}
                >
                    Submit
                </Button>
            </Form>
        </>
    );
}

export default ExampleRadioButton;
