import React from 'react';

import { Help, Tv } from '@preamp/signal';

import { Icon, PillButton, PillTheme } from '@preamp/core';

interface IPillButtonExamplesState {
    checked: boolean;
    checkedNoLabel: boolean;
    checkedFocus: boolean;
    checkedBlur: boolean;
}

/**
 * Examples of the PillButton which are intended to be used as a radio button
 */
class PillButtonExample extends React.Component<{}, IPillButtonExamplesState> {
    state: IPillButtonExamplesState = {
        checked: false,
        checkedNoLabel: false,
        checkedFocus: false,
        checkedBlur: false
    };

    normalPillButton = (checked: boolean): void => this.setState({ checked });

    focusPillButton = (checkedFocus: boolean = true): void =>
        this.setState({ checkedFocus });

    blurPillButton = (checkedBlur: boolean = true): void =>
        this.setState({ checkedBlur });

    noLabelPillButton = (checkedNoLabel: boolean): void =>
        this.setState({ checkedNoLabel });

    render(): React.ReactNode {
        return (
            <>
                <h4 className="mt-6 mb-6">Pill Buttons:</h4>
                <section className="mb-6">
                    <div>Active Pill Button</div>
                    <PillButton
                        id="active-pill-button"
                        label="Normal Pill Button"
                        name="pillButtonField"
                        onChange={this.normalPillButton}
                        theme={PillTheme.Active}
                    />
                </section>
                <section className="mb-6">
                    <div>Default Pill Button</div>
                    <PillButton
                        id="default-pill-button"
                        label="Normal Pill Button"
                        name="pillButtonField"
                        onChange={this.normalPillButton}
                    />
                </section>
                <section className="mb-6">
                    <div>Disabled Pill Button</div>
                    <PillButton
                        disabled
                        id="disabled-pill-button"
                        label="Normal Pill Button"
                        name="pillButtonField"
                        onChange={this.normalPillButton}
                    />
                </section>
                <section className="mb-6">
                    <div>Excluded Pill Button</div>
                    <PillButton
                        excluded
                        id="excluded-pill-button"
                        label="Normal Pill Button"
                        name="pillButtonField"
                        onChange={this.normalPillButton}
                    />
                </section>
                <section className="mb-6">
                    <div>Icon w/ Description Pill Button</div>
                    <PillButton
                        description="This is a description of the item to help the user which item to choose."
                        icon={Help}
                        id="icon-desc-pill-button"
                        label="Normal Pill Button"
                        name="pillButtonField"
                        onChange={this.normalPillButton}
                    />
                </section>
                <section className="mb-6">
                    <div>Custom Pill Button</div>
                    <PillButton
                        id="custom-pill-button"
                        label={
                            <div className="flex flex-row items-center">
                                <Icon
                                    className="mr-2 va-custom-icon"
                                    icon={Tv}
                                />
                                <span>Custom Pill Button</span>
                            </div>
                        }
                        name="pillButtonField"
                        onChange={this.normalPillButton}
                    />
                </section>
            </>
        );
    }
}

export default PillButtonExample;
