import React from 'react';

import { PillButton, PillButtonGroup, PillTheme } from '@preamp/core';

interface PillButtonGroupState {
    selectedValues: (string | number)[];
    lastChanged: string;
}

/**
 * Example of the PillButtonGroup with left label and single select
 */
class PillButtonGroupSingle extends React.Component<{}, PillButtonGroupState> {
    state: PillButtonGroupState = {
        selectedValues: [],
        lastChanged: null
    };

    onChange = (selectedValues: (string | number)[]): void => {
        const lastChanged = String(selectedValues[0]);
        this.setState({ selectedValues, lastChanged });
    };

    buttonTheme = (id: string | number): PillTheme => {
        const { selectedValues } = this.state;
        if (selectedValues.indexOf(id) !== -1) {
            return PillTheme.Active;
        } else {
            return PillTheme.Default;
        }
    };

    render(): React.ReactNode {
        const { lastChanged, selectedValues } = this.state;

        return (
            <>
                <div
                    className="va-form-group"
                    data-ui="form-element--1"
                    id="form-element-1"
                    key="form-element-1"
                >
                    <PillButtonGroup
                        isOptional={true}
                        multiselect={false}
                        name="pillButtonGroup"
                        onChange={this.onChange}
                        selectedValues={selectedValues}
                        title="PillButton Single Select:"
                    >
                        <PillButton
                            id="pb-1"
                            key={1}
                            label="PillButton 1"
                            name="pillButtonField"
                            theme={this.buttonTheme(1)}
                            value={1}
                        />
                        <PillButton
                            id="pb-2"
                            key={2}
                            label="PillButton 2"
                            name="pillButtonField"
                            theme={this.buttonTheme(2)}
                            value={2}
                        />
                        <PillButton
                            disabled={true}
                            id="pb-3"
                            key={3}
                            label="PillButton 3"
                            name="pillButtonField"
                            theme={this.buttonTheme(3)}
                            value={3}
                        />
                        <PillButton
                            excluded
                            id="pb-3b"
                            key="3b"
                            label="PillButton 3b"
                            name="pillButtonField"
                            theme={this.buttonTheme('3b')}
                            value="3b"
                        />
                        <PillButton
                            id="pb-4"
                            key={5}
                            label="PillButton 4"
                            name="pillButtonField"
                            theme={this.buttonTheme(4)}
                            value={4}
                        />
                    </PillButtonGroup>
                </div>
                {selectedValues.length > 0 && (
                    <p className="u-body-2">
                        PillButton {lastChanged} is active.
                    </p>
                )}
            </>
        );
    }
}

export default PillButtonGroupSingle;
