import React from 'react';

import { PillButton, PillButtonGroup, PillTheme } from '@preamp/core';

interface PillButtonGroupState {
    selectedValues: (string | number)[];
}

/**
 * Example of the PillButtonGroup with left label and multi select
 */
class PillButtonGroupMultiple extends React.Component<
    {},
    PillButtonGroupState
> {
    state: PillButtonGroupState = {
        selectedValues: []
    };

    onChange = (selectedValues: (string | number)[]): void => {
        this.setState({ selectedValues });
    };

    buttonTheme = (id: string | number): PillTheme => {
        const { selectedValues } = this.state;
        if (selectedValues.indexOf(id) !== -1) {
            return PillTheme.Active;
        } else {
            return PillTheme.Default;
        }
    };

    render(): React.ReactNode {
        const { selectedValues } = this.state;

        return (
            <>
                <div
                    className="va-form-group"
                    data-ui="form-element--2"
                    id="form-element-2"
                    key="form-element-2"
                >
                    <PillButtonGroup
                        multiselect={true}
                        name="pillButtonGroup"
                        onChange={this.onChange}
                        selectedValues={selectedValues}
                        title="PillButton Multi Select"
                    >
                        <PillButton
                            id="pb-1"
                            key={1}
                            label="PillButton 1"
                            name="pillButtonField"
                            theme={this.buttonTheme(1)}
                            value={1}
                        />
                        <PillButton
                            disabled
                            id="pb-2"
                            key={2}
                            label="PillButton 2"
                            name="pillButtonField"
                            theme={this.buttonTheme(2)}
                            value={2}
                        />
                        <PillButton
                            id="pb-3"
                            key={3}
                            label="PillButton 3"
                            name="pillButtonField"
                            theme={this.buttonTheme(3)}
                            value={3}
                        />
                        <PillButton
                            id="pb-4"
                            key={4}
                            label="PillButton 4"
                            name="pillButtonField"
                            theme={this.buttonTheme(4)}
                            value={4}
                        />
                    </PillButtonGroup>
                </div>
                {selectedValues.length === 1 && (
                    <p className="u-body-2">
                        PillButton {selectedValues[0]} is active.
                    </p>
                )}
                {selectedValues.length > 1 && (
                    <p className="u-body-2">
                        PillButtons {String(selectedValues)} are active.
                    </p>
                )}
            </>
        );
    }
}

export default PillButtonGroupMultiple;
