import React from 'react';

import { PillButton, PillButtonGroup, PillTheme } from '@preamp/core';

import { Coverage, Devices, TvLg } from '@preamp/signal';

interface PillButtonGroupState {
    selectedValues: (string | number)[];
    lastChanged: string;
}

/**
 * Example of the Pill Button Group with Icons and Descriptions and a single selection
 */
class PillButtonGroupIconDescription extends React.Component<
    {},
    PillButtonGroupState
> {
    state: PillButtonGroupState = {
        selectedValues: [],
        lastChanged: null
    };

    onChange = (selectedValues: (string | number)[]): void => {
        const lastChanged = String(selectedValues[0]);
        this.setState({ selectedValues, lastChanged });
    };

    buttonTheme = (id: string | number): PillTheme => {
        const { selectedValues } = this.state;
        if (selectedValues.indexOf(id) !== -1) {
            return PillTheme.Active;
        } else {
            return PillTheme.Default;
        }
    };

    render(): React.ReactNode {
        const { lastChanged, selectedValues } = this.state;

        return (
            <>
                <div
                    className="va-form-group"
                    data-ui="form-element--3"
                    id="form-element-1"
                    key="form-element-1"
                >
                    <PillButtonGroup
                        maxWidth="920px"
                        multiselect={false}
                        name="pillButtonGroup"
                        onChange={this.onChange}
                        selectedValues={selectedValues}
                    >
                        <PillButton
                            description="This is a description of the item to help the user which item to choose."
                            icon={Coverage}
                            id="pb-1"
                            key={1}
                            label="Option One"
                            name="pillButtonField"
                            theme={this.buttonTheme(1)}
                            value={1}
                        />
                        <PillButton
                            description="This is a description of the item to help the user which item to choose."
                            icon={TvLg}
                            id="pb-2"
                            key={2}
                            label="Option Two"
                            name="pillButtonField"
                            theme={this.buttonTheme(2)}
                            value={2}
                        />
                        <PillButton
                            description="This is a description of the item to help the user which item to choose."
                            disabled={true}
                            icon={Devices}
                            id="pb-3"
                            key={3}
                            label="Option Three"
                            name="pillButtonField"
                            theme={this.buttonTheme(3)}
                            value={3}
                        />
                        <PillButton
                            description="This is a description of the item to help the user which item to choose."
                            icon={Coverage}
                            id="pb-4"
                            key={4}
                            label="Option Four"
                            name="pillButtonField"
                            theme={this.buttonTheme(4)}
                            value={4}
                        />
                        <PillButton
                            description="This is a description of the item to help the user which item to choose."
                            disabled={true}
                            icon={Coverage}
                            id="pb-5"
                            key={5}
                            label="Option Five"
                            name="pillButtonField"
                            theme={this.buttonTheme(5)}
                            value={5}
                        />
                    </PillButtonGroup>
                </div>
                {selectedValues.length > 0 && (
                    <p className="u-body-2">
                        PillButton {lastChanged} is active.
                    </p>
                )}
            </>
        );
    }
}

export default PillButtonGroupIconDescription;
