import React from 'react';

import { Coverage, Devices, TvLg } from '@preamp/signal';

import { PillButton, PillButtonGroup, PillTheme } from '@preamp/core';

interface PillButtonGroupState {
    selectedValues: (string | number)[];
}

/**
 * Example of the Pill Button Group with Icons and Descriptions and multi selection
 */
class PillButtonGroupIconDescriptionMulti extends React.Component<
    {},
    PillButtonGroupState
> {
    state: PillButtonGroupState = {
        selectedValues: []
    };

    onChange = (selectedValues: (string | number)[]): void => {
        this.setState({ selectedValues });
    };

    buttonTheme = (id: string | number): PillTheme => {
        const { selectedValues } = this.state;
        if (selectedValues.indexOf(id) !== -1) {
            return PillTheme.Active;
        } else {
            return PillTheme.Default;
        }
    };

    render(): React.ReactNode {
        const { selectedValues } = this.state;

        return (
            <>
                <div
                    className="va-form-group"
                    data-ui="form-element--4"
                    id="form-element-1"
                    key="form-element-1"
                >
                    <PillButtonGroup
                        maxWidth="690px"
                        multiselect={true}
                        name="pillButtonGroup"
                        onChange={this.onChange}
                        selectedValues={selectedValues}
                    >
                        <PillButton
                            autoHideDescription
                            description="This is a description of the item to help the user which item to choose."
                            icon={Coverage}
                            id="pb-1"
                            key={1}
                            label="Help"
                            name="pillButtonField"
                            theme={this.buttonTheme(1)}
                            value={1}
                        />
                        <PillButton
                            autoHideDescription
                            description="This is a description of the item to help the user which item to choose."
                            icon={Devices}
                            id="pb-2"
                            key={2}
                            label="Account"
                            name="pillButtonField"
                            theme={this.buttonTheme(2)}
                            value={2}
                        />
                        <PillButton
                            autoHideDescription
                            description="This is a description of the item to help the user which item to choose."
                            icon={TvLg}
                            id="pb-3"
                            key={3}
                            label="Schedule"
                            name="pillButtonField"
                            theme={this.buttonTheme(3)}
                            value={3}
                        />
                        <PillButton
                            autoHideDescription
                            description="This is a description of the item to help the user which item to choose."
                            icon={Coverage}
                            id="pb-4"
                            key={4}
                            label="Information"
                            name="pillButtonField"
                            theme={this.buttonTheme(4)}
                            value={4}
                        />
                        <PillButton
                            autoHideDescription
                            description="This is a description of the item to help the user which item to choose."
                            icon={Devices}
                            id="pb-5"
                            key={5}
                            label="Explore"
                            name="pillButtonField"
                            theme={this.buttonTheme(5)}
                            value={5}
                        />
                        <PillButton
                            autoHideDescription
                            description="This is a description of the item to help the user which item to choose."
                            icon={TvLg}
                            id="pb-6"
                            key={6}
                            label="Favorites"
                            name="pillButtonField"
                            theme={this.buttonTheme(6)}
                            value={6}
                        />
                        <PillButton
                            autoHideDescription
                            description="This is a description of the item to help the user which item to choose."
                            icon={Coverage}
                            id="pb-7"
                            key={7}
                            label="Frequency"
                            name="pillButtonField"
                            theme={this.buttonTheme(7)}
                            value={7}
                        />
                    </PillButtonGroup>
                </div>
                {selectedValues.length === 1 && (
                    <p className="u-body-2">
                        PillButton {selectedValues[0]} is active.
                    </p>
                )}
                {selectedValues.length > 1 && (
                    <p className="u-body-2">
                        PillButtons {String(selectedValues)} are active.
                    </p>
                )}
            </>
        );
    }
}

export default PillButtonGroupIconDescriptionMulti;
