import React, { ReactElement, useState } from 'react';

import { PillButton, PillButtonGroup, PillTheme } from '@preamp/core';

/**
 * Example of the PillButtonGroup with top label and single select
 */
function PillButtonGroupTopLabelSingle(): ReactElement<{}> {
    const [selectedValues, setSelectedValues] = useState([]);
    const [lastChanged, SetLastChanged] = useState(null);

    function onChange(selectedValue: (string | number)[]): void {
        setSelectedValues(selectedValue);
        SetLastChanged(String(selectedValue[0]));
    }

    function buttonTheme(id: string | number): PillTheme {
        if (selectedValues.indexOf(id) !== -1) {
            return PillTheme.Active;
        } else {
            return PillTheme.Default;
        }
    }

    return (
        <>
            <div
                className="va-form-group"
                data-ui="form-element--1"
                id="form-element-1"
                key="form-element-1"
            >
                <PillButtonGroup
                    isOptional
                    labelPosition="top"
                    multiselect={false}
                    name="pillButtonGroup"
                    onChange={onChange}
                    selectedValues={selectedValues}
                    title="PillButton Single Select:"
                >
                    <PillButton
                        id="pb-1"
                        key={1}
                        label="PillButton 1"
                        name="pillButtonField"
                        theme={buttonTheme(1)}
                        value={1}
                    />
                    <PillButton
                        id="pb-2"
                        key={2}
                        label="PillButton 2"
                        name="pillButtonField"
                        theme={buttonTheme(2)}
                        value={2}
                    />
                    <PillButton
                        disabled={true}
                        id="pb-3"
                        key={3}
                        label="PillButton 3"
                        name="pillButtonField"
                        theme={buttonTheme(3)}
                        value={3}
                    />
                    <PillButton
                        excluded
                        id="pb-3b"
                        key="3b"
                        label="PillButton 3b"
                        name="pillButtonField"
                        theme={buttonTheme('3b')}
                        value="3b"
                    />
                    <PillButton
                        id="pb-4"
                        key={5}
                        label="PillButton 4"
                        name="pillButtonField"
                        theme={buttonTheme(4)}
                        value={4}
                    />
                </PillButtonGroup>
            </div>
            {selectedValues.length > 0 && (
                <p className="va-caption">
                    PillButton {lastChanged} is active.
                </p>
            )}
        </>
    );
}

export default PillButtonGroupTopLabelSingle;
