import React, { ReactElement, useState } from 'react';

import { PillButton, PillButtonGroup, PillTheme } from '@preamp/core';

/**
 * Example of the PillButtonGroup with top label and multi select
 */

function PillButtonGroupTopLabelMultiple(): ReactElement<{}> {
    const [selectedValues, setSelectedValues] = useState([]);

    function onChange(selectedValue: (string | number)[]): void {
        setSelectedValues(selectedValue);
    }

    function buttonTheme(id: string | number): PillTheme {
        if (selectedValues.indexOf(id) !== -1) {
            return PillTheme.Active;
        } else {
            return PillTheme.Default;
        }
    }

    return (
        <>
            <div
                className="va-form-group"
                data-ui="form-element--2"
                id="form-element-2"
                key="form-element-2"
            >
                <PillButtonGroup
                    labelPosition="top"
                    multiselect
                    name="pillButtonGroup"
                    onChange={onChange}
                    selectedValues={selectedValues}
                    title="PillButton Multi Select"
                >
                    <PillButton
                        id="pb-1"
                        key={1}
                        label="PillButton 1"
                        name="pillButtonField"
                        theme={buttonTheme(1)}
                        value={1}
                    />
                    <PillButton
                        disabled
                        id="pb-2"
                        key={2}
                        label="PillButton 2"
                        name="pillButtonField"
                        theme={buttonTheme(2)}
                        value={2}
                    />
                    <PillButton
                        id="pb-3"
                        key={3}
                        label="PillButton 3"
                        name="pillButtonField"
                        theme={buttonTheme(3)}
                        value={3}
                    />
                    <PillButton
                        id="pb-4"
                        key={4}
                        label="PillButton 4"
                        name="pillButtonField"
                        theme={buttonTheme(4)}
                        value={4}
                    />
                </PillButtonGroup>
            </div>
            {selectedValues.length === 1 && (
                <p className="va-caption">
                    PillButton {selectedValues[0]} is active.
                </p>
            )}
            {selectedValues.length > 1 && (
                <p className="va-caption">
                    PillButtons {String(selectedValues)} are active.
                </p>
            )}
        </>
    );
}

export default PillButtonGroupTopLabelMultiple;
