import React, { ReactElement, useState } from 'react';

import { PillButton, PillButtonGroup, PillTheme } from '@preamp/core';

/**
 * Example of the Optional PillButtonGroup with left-oriented label with no title
 */

function PillButtonGroupOptionalNoTitle(): ReactElement<{}> {
    const [selectedValues, setSelectedValues] = useState([]);

    function onChange(selectedValue: (string | number)[]): void {
        setSelectedValues(selectedValue);
    }

    function buttonTheme(id: string | number): PillTheme {
        return selectedValues.includes(id)
            ? PillTheme.Active
            : PillTheme.Default;
    }

    return (
        <>
            <div
                className="va-form-group"
                data-ui="form-element--2"
                id="form-element-2"
                key="form-element-2"
            >
                <PillButtonGroup
                    isOptional
                    name="pillButtonGroup"
                    onChange={onChange}
                    selectedValues={selectedValues}
                >
                    <PillButton
                        id="pb-1"
                        key={1}
                        label="PillButton 1"
                        name="pillButtonField"
                        theme={buttonTheme(1)}
                        value={1}
                    />
                    <PillButton
                        id="pb-2"
                        key={2}
                        label="PillButton 2"
                        name="pillButtonField"
                        theme={buttonTheme(2)}
                        value={2}
                    />
                </PillButtonGroup>
            </div>
        </>
    );
}

export default PillButtonGroupOptionalNoTitle;
