import React from 'react';

import { RadioButton } from '@preamp/core';

interface IRadioButtonExamplesState {
    checked: boolean;
    checkedNoLabel: boolean;
    checkedFocus: boolean;
    checkedBlur: boolean;
}

/**
 * This is a set of examples for PreAmp's radio button.
 */
class ExampleRadioButton extends React.Component<
    {},
    IRadioButtonExamplesState
> {
    state: IRadioButtonExamplesState = {
        checked: false,
        checkedNoLabel: false,
        checkedFocus: false,
        checkedBlur: false
    };

    normalRadioButton = (checked: boolean): void => this.setState({ checked });
    focusRadioButton = (checkedFocus: boolean = true): void =>
        this.setState({ checkedFocus });
    blurRadioButton = (checkedBlur: boolean = true): void =>
        this.setState({ checkedBlur });
    noLabelRadioButton = (checkedNoLabel: boolean): void =>
        this.setState({ checkedNoLabel });

    render(): React.ReactNode {
        return (
            <>
                <p className="mb-2">Radio Buttons:</p>

                <RadioButton
                    checked={this.state.checked}
                    id={'normal-radio-button'}
                    isOptional={true}
                    label={'Normal Radio Button'}
                    name={'radioButtonField'}
                    onChange={this.normalRadioButton}
                />

                <RadioButton
                    checked={false}
                    disabled={true}
                    id={'disabled-radio-button'}
                    label={'Disabled Radio Button'}
                    name={'radioButtonField'}
                    onChange={this.normalRadioButton}
                />

                <RadioButton
                    checked={true}
                    disabled={true}
                    id={'disabled-checked-radio-button'}
                    label={'Disabled Checked Radio Button'}
                    name={'radioButtonField'}
                    onChange={this.normalRadioButton}
                />

                <RadioButton
                    checked={this.state.checkedFocus}
                    id={'normal-radio-button'}
                    label={'Radio Button With onFocus'}
                    name={'radioButtonField'}
                    onChange={this.focusRadioButton}
                    onFocus={this.focusRadioButton}
                />

                <RadioButton
                    checked={this.state.checkedBlur}
                    id={'normal-radio-button'}
                    label={'Radio Button With onBlur'}
                    name={'radioButtonField'}
                    onBlur={this.blurRadioButton}
                    onChange={this.blurRadioButton}
                />

                <RadioButton
                    checked={this.state.checkedNoLabel}
                    id={'normal-radio-button'}
                    name={'radioButtonField'}
                    onChange={this.noLabelRadioButton}
                />
                <p className="u-body-2">Radio button with no label.</p>
            </>
        );
    }
}

export default ExampleRadioButton;
