import React from 'react';

import { RadioButton, RadioButtonGroup, Toggle } from '@preamp/core';

interface IExampleRadioButtonState {
    selectedValue: string | number;
    toggleInline: boolean;
}

/**
 * This is a set of examples for PreAmp's Radio Button Group.
 */
class ExampleRadioButton extends React.Component<{}, IExampleRadioButtonState> {
    state: IExampleRadioButtonState = {
        selectedValue: null,
        toggleInline: false
    };

    onChangeHandler = (selectedValue: string | number): void => {
        this.setState({ selectedValue });
    };
    onToggle = (checked: boolean): void => {
        this.setState({ toggleInline: checked });
    };

    render(): React.ReactNode {
        return (
            <>
                <h3>Inline layout</h3>

                <div className="mt-2">
                    <Toggle
                        checked={this.state.toggleInline}
                        label="This toggle allows you to see inline options."
                        name="width-toggle"
                        onChange={this.onToggle}
                    />
                </div>

                <p className="mb-4 u-well">
                    {this.state.selectedValue && (
                        <span>
                            Radio Button {this.state.selectedValue} is selected.
                        </span>
                    )}

                    {!this.state.selectedValue && (
                        <span>No Radio Button is selected.</span>
                    )}
                </p>
                <div
                    className="va-form-group"
                    data-ui={`form-element--1`}
                    id={`form-element-1`}
                    key={`form-element-1`}
                >
                    <RadioButtonGroup
                        isInline={this.state.toggleInline}
                        isOptional={true}
                        key={`form-element-1-group`}
                        name={'radioButtonGroup'}
                        onChange={this.onChangeHandler}
                        required={false}
                        selectedValue={this.state.selectedValue}
                        title={'Radio Group Title:'}
                    >
                        <RadioButton
                            key={`form-element-1-1`}
                            label={'Button 1'}
                            name={'radioButton'}
                            value={'1'}
                        />
                        <RadioButton
                            key={`form-element-1-2`}
                            label={'Button 2'}
                            name={'radioButton'}
                            value={'2'}
                        />
                        <RadioButton
                            key={`form-element-1-3`}
                            label={'Button 3'}
                            name={'radioButton'}
                            value={'3'}
                        />
                        <RadioButton
                            key={`form-element-1-4`}
                            label={'Button 4'}
                            name={'radioButton'}
                            value={'4'}
                        />
                    </RadioButtonGroup>
                </div>
                <div
                    className="va-form-group"
                    data-ui={`form-element--2`}
                    id={`form-element-2`}
                    key={`form-element-2`}
                >
                    <RadioButtonGroup
                        isInline={this.state.toggleInline}
                        key={`form-element-2-group`}
                        name={'radioButtonGroup'}
                        onChange={this.onChangeHandler}
                        required={true}
                        selectedValue={this.state.selectedValue}
                        title={'Radio Group 2 Title:'}
                    >
                        <RadioButton
                            key={`form-element-2-1`}
                            label={'Button 5'}
                            name={'radioButton'}
                            value={'5'}
                        />
                        <RadioButton
                            key={`form-element-2-2`}
                            label={'Button 6'}
                            name={'radioButton'}
                            value={'6'}
                        />
                        <RadioButton
                            key={`form-element-2-3`}
                            label={'Button 7'}
                            name={'radioButton'}
                            value={'7'}
                        />
                        <RadioButton
                            key={`form-element-2-4`}
                            label={'Button 8'}
                            name={'radioButton'}
                            value={'8'}
                        />
                    </RadioButtonGroup>
                </div>
                <div
                    className="va-form-group"
                    data-ui={`form-element--3`}
                    id={`form-element-3`}
                    key={`form-element-3`}
                >
                    <RadioButtonGroup
                        isInline={this.state.toggleInline}
                        key={`form-element-3-group`}
                        name={'radioButtonGroup'}
                        onChange={this.onChangeHandler}
                        required={true}
                        selectedValue={this.state.selectedValue}
                        title={'Radio Group 3 Title:'}
                    >
                        <RadioButton
                            key={`form-element-3-1`}
                            label={'Button 9'}
                            name={'radioButton'}
                            value={'9'}
                        />
                    </RadioButtonGroup>
                </div>
            </>
        );
    }
}

export default ExampleRadioButton;
