import React from 'react';

import cx from 'classnames';

import { Search, SearchTheme, Toggle } from '@preamp/core';

/**
 * Basic example of Search.
 */
const ExampleSearch: React.FC = (): React.ReactElement => {
    const [searchValue, setSearchValue] = React.useState<string>('');
    const [toggle, setToggle] = React.useState<boolean>(false);

    const onBlurInteraction = React.useCallback((): void => {
        // eslint-disable-next-line no-console
        console.log('the text field is no longer focused');
    }, []);

    const onFocus = React.useCallback((): void => {
        // eslint-disable-next-line no-console
        console.log('the text field is focused');
    }, []);

    const onClear = React.useCallback((): void => {
        setSearchValue('');
    }, [setSearchValue]);

    const onSearch = React.useCallback(
        (value: string): void => {
            setSearchValue(value);
        },
        [setSearchValue]
    );

    const onToggle = React.useCallback(
        (checked: boolean): void => {
            setToggle(checked);
        },
        [setToggle]
    );

    return (
        <>
            <p>
                Search term: <b>{searchValue}</b>
            </p>
            <div
                className={cx('va-form-group p-4', {
                    'bg-va-grey-200': !toggle
                })}
            >
                <Toggle
                    checked={toggle}
                    label="Light Theme"
                    name="theme-toggle"
                    onChange={onToggle}
                />
                <Search
                    id="basic-search"
                    name="basic-search"
                    onBlur={onBlurInteraction}
                    onClear={onClear}
                    onFocus={onFocus}
                    onSearch={onSearch}
                    placeholder="Search"
                    theme={toggle ? SearchTheme.Light : SearchTheme.Default}
                />
            </div>
        </>
    );
};

export default ExampleSearch;
