import React from 'react';

import { Search } from '@preamp/core';

/**
 * Search with managed state using the value prop.
 */
const ExampleSearchWithState: React.FC = (): React.ReactElement => {
    const [inputValue, setInputValue] = React.useState<string>('');
    const [searchValue, setSearchValue] = React.useState<string>('');

    const onBlurInteraction = React.useCallback((): void => {
        // eslint-disable-next-line no-console
        console.log('the text field is no longer focused');
    }, []);

    const onFocus = React.useCallback((): void => {
        // eslint-disable-next-line no-console
        console.log('the text field is focused');
    }, []);

    const onClear = React.useCallback((): void => {
        setInputValue('');
        setSearchValue('');
    }, [setSearchValue]);

    const onChange = React.useCallback(
        (e: React.ChangeEvent<HTMLInputElement>): void => {
            const { value } = e.currentTarget;

            setInputValue(value);
        },
        [setInputValue]
    );

    const onSearch = React.useCallback(
        (value: string): void => {
            setSearchValue(value);
        },
        [setSearchValue]
    );

    return (
        <>
            <p>
                Input value: <b>{inputValue}</b>
            </p>
            <p>
                Search term: <b>{searchValue}</b>
            </p>
            <div className="va-form-group p-4 bg-va-grey-200">
                <Search
                    id="search-with-state"
                    name="search-with-state"
                    onBlur={onBlurInteraction}
                    onChange={onChange}
                    onClear={onClear}
                    onFocus={onFocus}
                    onSearch={onSearch}
                    placeholder="Search"
                    value={inputValue}
                />
            </div>
        </>
    );
};

export default ExampleSearchWithState;
