import * as React from 'react';

import { Slider, TextFieldType, TextField } from '@preamp/core';

/**
 *  Basic Range Slider.
 */
const BasicRangeSlider: React.FC = (): React.ReactElement => {
    const fixedArray = [9, 14, 24, 39, 44, 54, 65];
    const [currentValue, setCurrentValue] = React.useState<number>(
        fixedArray[3]
    );

    function handleOnChange(value: number): void {
        console.info('Current Value: ', value);
    }

    function onChange(value: number): void {
        console.log('current Value: ', value);
        setCurrentValue(value);
    }

    function onChangeTextField(
        event: React.ChangeEvent<HTMLInputElement>
    ): void {
        event.persist();
        const value = Number(event.target.value);
        setCurrentValue(value);
    }

    return (
        <div className="mt-5">
            <div className="va-form-group">
                <h5>Basic Single Slider</h5>
                <Slider isSingleThumb max={90} min={15} />
            </div>
            <div className="va-form-group">
                <h5>
                    Basic Single Slider with a smaller width and bottom text
                    input
                </h5>
                <Slider
                    isSingleThumb
                    isTextInputBottom
                    max={90}
                    min={15}
                    width={450}
                />
            </div>

            <div className="va-form-group">
                <h5>Single Slider with Full Width</h5>
                <Slider fullWidth isSingleThumb max={90} min={15} />
            </div>

            <div className="va-form-group">
                <h5>Single Slider with Full Width & Steps</h5>
                <Slider fullWidth isSingleThumb max={50} min={0} step={5} />
            </div>

            <div className="va-form-group">
                <h5>Single Slider with Decimals</h5>
                <Slider fullWidth isSingleThumb max={1} min={0} step={0.1} />
                <Slider fullWidth isSingleThumb max={1} min={0} step={0.25} />
            </div>

            <div className="va-form-group">
                <h5>Single Slider with Percentage Number Format</h5>
                <Slider
                    fullWidth
                    isSingleThumb
                    max={1}
                    min={0}
                    numberFormat="0,0[.][00]%"
                    step={0.1}
                />
            </div>

            <div className="va-form-group">
                <h5>Single Slider with Currency Number Format</h5>
                <Slider
                    fullWidth
                    isSingleThumb
                    max={10000}
                    min={1000}
                    numberFormat="$0.0a"
                    step={1500}
                />
            </div>

            <div className="va-form-group">
                <h5>Single Slider with Label, Step and Bottom Text Input</h5>
                <Slider
                    isSingleThumb
                    isTextInputBottom
                    label="This is a label"
                    max={50}
                    min={0}
                    step={5}
                />
            </div>
            <div className="va-form-group">
                <h5>Single Slider without Text Input</h5>
                <Slider
                    currentValue={50}
                    isSingleThumb
                    max={80}
                    min={20}
                    showTextInput={false}
                />
            </div>
            <div className="va-form-group">
                <h5>Controlled Single Slider</h5>
                <div className="flex flex-wrap w-32 mb-5">
                    <div className="w-1/2">
                        <TextField
                            dataUI="textfield--1"
                            defaultValue={String(currentValue)}
                            disabled={false}
                            id="myTextField"
                            label="Current Value"
                            name="currentValue"
                            onChange={onChangeTextField}
                            placeholder="Number"
                            required={false}
                            textFieldType={TextFieldType.Number}
                        />
                    </div>
                </div>
                <Slider
                    currentValue={currentValue}
                    isSingleThumb
                    max={90}
                    min={15}
                    onChange={onChange}
                />
            </div>
            <div className="va-form-group">
                <h5>Single Slider with Fixed Values</h5>
                <Slider
                    fixedValues={fixedArray}
                    isOptional
                    isSingleThumb
                    isTextInputBottom
                    label="Fixed Values"
                    max={fixedArray[6]}
                    min={fixedArray[0]}
                    onChange={handleOnChange}
                />
            </div>
        </div>
    );
};

export default BasicRangeSlider;
