import * as React from 'react';

import { Slider, TextFieldType, TextField } from '@preamp/core';
/**
 *  Basic Range Slider.
 */
const BasicRangeSlider: React.FC = (): React.ReactElement => {
    const fixedArray = [9, 14, 24, 39, 44, 54, 65];
    const [currentMin, setCurrentMin] = React.useState<number>(fixedArray[1]);
    const [currentMax, setCurrentMax] = React.useState<number>(fixedArray[5]);

    function handleOnChange(min: number, max: number): void {
        console.info(`Min: ${min}, Max: ${max}`);
    }

    function handleOnChangeFixedValues(min: number, max: number): void {
        console.info(`Min: ${min}, Max: ${max}`);
        setCurrentMin(min);
        setCurrentMax(max);
    }

    function onChangeTextField(
        event: React.ChangeEvent<HTMLInputElement>
    ): void {
        event.persist();
        const { name } = event.target;
        const value = Number(event.target.value);
        const setValues = {
            min: setCurrentMin,
            max: setCurrentMax
        };
        setValues[name](value);
    }

    return (
        <div className="mt-5">
            <div className="va-form-group">
                <h5>Basic Dual Slider</h5>
                <Slider max={90} min={15} />
            </div>
            <div className="va-form-group">
                <h5>Dual Slider with Label, Step and Bottom Text Input</h5>
                <Slider
                    isTextInputBottom
                    label="This is a label"
                    max={40}
                    min={4}
                    step={4}
                />
            </div>
            <div className="va-form-group">
                <h5>Dual Slider without Text Input</h5>
                <Slider
                    currentValue={[30, 60]}
                    max={80}
                    min={20}
                    showTextInput={false}
                />
            </div>
            <div className="va-form-group">
                <h5>Controlled Dual Slider</h5>
                <div className="flex flex-wrap w-64 mb-5">
                    <div className="w-1/2 pr-2">
                        <TextField
                            dataUI="textfield--1"
                            disabled={false}
                            id="myTextField"
                            label="Min"
                            name="min"
                            onChange={onChangeTextField}
                            placeholder="Number"
                            required={false}
                            textFieldType={TextFieldType.Number}
                            value={String(currentMin)}
                        />
                    </div>
                    <div className="w-1/2 pl-2">
                        <TextField
                            dataUI="textfield--2"
                            disabled={false}
                            id="myTextField"
                            label="Max"
                            name="max"
                            onChange={onChangeTextField}
                            placeholder="Number"
                            required={false}
                            textFieldType={TextFieldType.Number}
                            value={String(currentMax)}
                        />
                    </div>
                </div>
                <Slider
                    currentValue={[currentMin, currentMax]}
                    label="This is a label"
                    max={fixedArray[6]}
                    min={fixedArray[0]}
                    onChange={handleOnChangeFixedValues}
                />
            </div>
            <div className="va-form-group">
                <h5>Dual Slider with Fixed Values</h5>
                <Slider
                    fixedValues={fixedArray}
                    label="Range Slider with fixed Values"
                    max={fixedArray[6]}
                    min={fixedArray[0]}
                    onChange={handleOnChange}
                    showTextInput={true}
                />
            </div>
            <div className="va-form-group">
                <h5>Dual Slider with Full Width</h5>
                <Slider fullWidth max={90} min={15} />
            </div>
            <div className="va-form-group">
                <h5>Dual Slider with Full Width & Steps</h5>
                <Slider
                    fullWidth
                    label="This is a label"
                    max={40}
                    min={4}
                    step={4}
                />
            </div>
            <div className="va-form-group">
                <h5>Dual Slider with Percentage Number Format</h5>
                <Slider
                    fullWidth
                    label="This is a label"
                    max={0.5}
                    min={0}
                    numberFormat="0,0[.][00]%"
                    step={0.05}
                />
            </div>
            <div className="va-form-group">
                <h5>Dual Slider with Currency Number Format</h5>
                <Slider
                    fullWidth
                    label="This is a label"
                    max={1000000000}
                    min={0}
                    numberFormat="$0a"
                    step={100000000}
                />
            </div>
        </div>
    );
};

export default BasicRangeSlider;
