import React from 'react';

import { Clear } from '@preamp/signal';

import { IconButton, TextArea } from '@preamp/core';

interface ExampleTextAreaState {
    value: string;
}

class ExampleTextArea extends React.Component<{}, ExampleTextAreaState> {
    state: ExampleTextAreaState = {
        value: ''
    };
    onBlurInteraction = (
        event?: React.FocusEvent<HTMLTextAreaElement>
    ): void => {
        // eslint-disable-next-line no-console
        console.log('the textarea is no longer focused', event);
    };
    onChange = (event?: React.ChangeEvent<HTMLTextAreaElement>): void => {
        this.setState({
            value: event.currentTarget.value
        });
    };
    clearInput = (): void => {
        this.setState({
            value: ''
        });
    };
    render(): React.ReactNode {
        return (
            <>
                <p>Default:</p>
                <div className="va-form-group">
                    <TextArea
                        className="myClass myOtherClass"
                        dataUI="text-area"
                        disabled={false}
                        helpText="This is helper text"
                        id="myTextArea"
                        label="This is a Label"
                        name="fieldName"
                        onBlur={this.onBlurInteraction}
                        onChange={this.onChange}
                        onFocus={null}
                        placeholder="Enter text..."
                        required={false}
                        tabIndex={0}
                        value={this.state.value}
                    />
                    {this.state.value !== '' && (
                        <div className="flex items-center">
                            <span className="u-body-2 mr-2">
                                TextArea Value: {this.state.value}
                            </span>
                            <IconButton icon={Clear} onClick={this.clearInput}>
                                Clear input
                            </IconButton>
                        </div>
                    )}
                </div>
                <p>Disabled:</p>
                <div className="va-form-group">
                    <TextArea
                        disabled={true}
                        id="myDisabledField"
                        label="This textarea is disabled"
                        name="anotherField"
                        onChange={null}
                        onFocus={null}
                        placeholder="You can't enter text here."
                        value="This textarea is disabled."
                    />
                </div>
            </>
        );
    }
}

export default ExampleTextArea;
