import React from 'react';

import { Clear } from '@preamp/signal';

import {
    IconButton,
    TextField,
    TextFieldType,
    TextFieldVariant
} from '@preamp/core';

interface ExampleTextFieldState {
    value: string;
}

class ExampleTextField extends React.Component<{}, ExampleTextFieldState> {
    state: ExampleTextFieldState = {
        value: ''
    };
    onBlurInteraction = (event?: React.FocusEvent<HTMLInputElement>): void => {
        // eslint-disable-next-line no-console
        console.log('the textfield is no longer focused', event);
    };
    onChange = (event?: React.ChangeEvent<HTMLInputElement>): void => {
        this.setState({
            value: event.currentTarget.value
        });
    };
    clearInput = (): void => {
        this.setState({
            value: ''
        });
    };
    render(): React.ReactNode {
        return (
            <>
                <div className="va-form-group">
                    <TextField
                        className="myClass myOtherClass"
                        dataUI="textfield--1"
                        disabled={false}
                        helpText="This is helper text"
                        id="myTextField"
                        label="This is a Label"
                        name="fieldName"
                        onBlur={this.onBlurInteraction}
                        onChange={this.onChange}
                        onFocus={null}
                        placeholder="Enter text..."
                        required={false}
                        tabIndex={0}
                        textFieldType={TextFieldType.Text}
                        value={this.state.value}
                    />
                    {this.state.value !== '' && (
                        <div className="flex items-center">
                            <span className="u-body-2 mr-2">
                                TextField Value: {this.state.value}
                            </span>
                            <IconButton icon={Clear} onClick={this.clearInput}>
                                Clear input
                            </IconButton>
                        </div>
                    )}
                </div>

                <div className="va-form-group">
                    <TextField
                        dataUI="textfield--2"
                        disabled={true}
                        id="myDisabledField"
                        label="This field is disabled"
                        name="anotherField"
                        onChange={null}
                        onFocus={null}
                        placeholder="You can't enter text here."
                        textFieldType={TextFieldType.Text}
                    />
                </div>
                <div className="va-form-group">
                    <TextField
                        dataUI="textfield--3"
                        helpText="This field has no label."
                        id="myPasswordField"
                        name="anotherField"
                        onBlur={null}
                        onChange={null}
                        onFocus={null}
                        placeholder="Password"
                        textFieldType={TextFieldType.Password}
                    />
                </div>
                <div className="va-form-group">
                    <TextField
                        dataUI="textfield--4"
                        id="myNumberField"
                        label="This is a required number field"
                        max={'50'}
                        min={'0'}
                        name="anotherField"
                        placeholder="Enter a number between 0 and 50"
                        required={true}
                        textFieldType={TextFieldType.Number}
                    />
                </div>
                <div className="va-form-group">
                    <TextField
                        append="USD"
                        dataUI="textfield--5"
                        id="myCurrencyField"
                        label="This field has Prepend and Append"
                        name="prependField"
                        prepend="$"
                        textFieldType={TextFieldType.Number}
                    />
                </div>
                <div className="va-form-group">
                    <TextField
                        dataUI="textfield--6"
                        id="jumboTextfield"
                        isOptional={true}
                        label="Textfield with the jumbo theme"
                        name="jumboTextfield"
                        onBlur={null}
                        onChange={null}
                        onFocus={null}
                        placeholder="Enter text..."
                        variant={TextFieldVariant.Jumbo}
                    />
                </div>
            </>
        );
    }
}

export default ExampleTextField;
