import React from 'react';

import { Toggle } from '@preamp/core';

interface IBasicToggleState {
    offToggleChecked: boolean;
    onToggleChecked: boolean;
    offToggleState?: string;
}

/**
 * Examples of the Toggle component in different states
 */
class ExampleToggle extends React.Component<{}, IBasicToggleState> {
    state: IBasicToggleState = {
        offToggleChecked: false,
        onToggleChecked: true
    };

    handleInteraction = (evt: any): void => {
        this.setState({ offToggleState: evt.type });
    };

    offToggleChanged = (offToggleChecked: boolean): void =>
        this.setState({ offToggleChecked });
    onToggleChanged = (onToggleChecked: boolean): void =>
        this.setState({ onToggleChecked });

    render(): React.ReactNode {
        const { offToggleChecked, offToggleState } = this.state;

        return (
            <>
                <p className="mb-4">Toggle states</p>

                <Toggle
                    checked={offToggleChecked}
                    id="off-toggle"
                    isOptional={true}
                    label={`Off ${
                        offToggleState === 'focus' ? '(focused)' : ''
                    }`}
                    name="off-toggle"
                    onBlur={this.handleInteraction}
                    onChange={this.offToggleChanged}
                    onFocus={this.handleInteraction}
                />

                <Toggle
                    checked={this.state.onToggleChecked}
                    id="on-toggle"
                    label="On"
                    name="on-toggle"
                    onChange={this.onToggleChanged}
                />

                <Toggle
                    checked={false}
                    disabled={true}
                    id="disabled-off-toggle"
                    label="Disabled Off"
                    name="disabled-off-toggle"
                    onChange={this.offToggleChanged}
                />

                <Toggle
                    checked={true}
                    disabled={true}
                    id="disabled-on-toggle"
                    label="Disabled On"
                    name="disabled-on-toggle"
                    onChange={this.offToggleChanged}
                />
            </>
        );
    }
}

export default ExampleToggle;
