import React from 'react';

import { Toggle, ToggleGroup } from '@preamp/core';

interface IBasicToggleGroupState {
    selectedValues: string[];
    selectedValues2: string[];
    offToggleChecked: boolean;
    onToggleChecked2: boolean;
    onToggleChecked: boolean;
    offToggleState?: string;
    lastChanged: string;
    toggleInline: boolean;
}

/**
 * This is a set of examples for PreAmp's Toggle Group.
 */
class ExampleToggleGroup extends React.Component<{}, IBasicToggleGroupState> {
    state: IBasicToggleGroupState = {
        offToggleChecked: false,
        onToggleChecked2: false,
        onToggleChecked: true,
        selectedValues: [],
        selectedValues2: [],
        lastChanged: null,
        toggleInline: false
    };

    // tslint:disable-next-line
    onChangeHandlerGrp1 = (selectedValue: string | number): void => {
        const { selectedValues } = this.state;

        if (selectedValues.indexOf(selectedValue.toString()) > -1) {
            const filteredValues: string[] = selectedValues.filter(
                (x: string): boolean => x !== selectedValue.toString()
            );
            this.setState({
                selectedValues: filteredValues,
                lastChanged: selectedValue.toString()
            });
        } else {
            selectedValues.push(selectedValue.toString());
            this.setState({
                selectedValues,
                lastChanged: selectedValue.toString()
            });
        }
    };

    // tslint:disable-next-line
    onChangeHandlerGrp2 = (selectedValue: string | number): void => {
        const { selectedValues2 } = this.state;

        if (selectedValues2.indexOf(selectedValue.toString()) > -1) {
            const filteredValues: string[] = selectedValues2.filter(
                (x: string): boolean => x !== selectedValue.toString()
            );
            this.setState({
                selectedValues2: filteredValues,
                lastChanged: selectedValue.toString(),
                onToggleChecked2: false
            });
        } else {
            selectedValues2.push(selectedValue.toString());
            this.setState({
                selectedValues2,
                lastChanged: selectedValue.toString(),
                onToggleChecked2: true
            });
        }
    };

    // tslint:disable-next-line
    normalToggle = (): void => {};

    offToggleChanged = (offToggleChecked: boolean): void => {
        this.setState({ offToggleChecked });
    };

    onToggleChanged = (onToggleChecked: boolean): void => {
        this.setState({ onToggleChecked });
    };
    onToggleChanged2 = (onToggleChecked2: boolean): void => {
        this.setState({ onToggleChecked2 });
    };
    onToggle = (checked: boolean): void => {
        this.setState({ toggleInline: checked });
    };

    render(): React.ReactNode {
        const {
            offToggleChecked,
            offToggleState,
            onToggleChecked2,
            onToggleChecked
        } = this.state;

        return (
            <>
                <h3>Inline layout</h3>

                <div className="mt-2">
                    <Toggle
                        checked={this.state.toggleInline}
                        label="This toggle allows you to see inline options."
                        name="width-toggle"
                        onChange={this.onToggle}
                    />
                </div>
                <div
                    className="va-form-group"
                    data-ui={`form-element--1`}
                    id={`form-element-1`}
                    key={`form-element-1`}
                >
                    <ToggleGroup
                        description={
                            'Maecenas faucibus mollis interdum. Praesent commodo cursus magna, vel scelerisque nisl consectetur et. Donec ullamcorper nulla non metus auctor fringilla'
                        }
                        isInline={this.state.toggleInline}
                        name={'toggleGroup'}
                        onChange={this.onChangeHandlerGrp1}
                        required={true}
                        selectedValues={this.state.selectedValues}
                        title={'Toggle Group 1:'}
                    >
                        <Toggle
                            checked={offToggleChecked}
                            id="off-toggle"
                            key={0}
                            label={`Off ${
                                offToggleState === 'focus' ? '(focused)' : ''
                            }`}
                            name="off-toggle"
                            onChange={this.offToggleChanged}
                            value={'5'}
                        />

                        <Toggle
                            checked={onToggleChecked}
                            id="on-toggle"
                            key={1}
                            label="On"
                            name="on-toggle"
                            onChange={this.onToggleChanged}
                            value={'6'}
                        />

                        <Toggle
                            checked={false}
                            disabled={true}
                            id="disabled-off-toggle"
                            key={2}
                            label="Disabled Off"
                            name="disabled-off-toggle"
                            onChange={this.offToggleChanged}
                            value={'7'}
                        />
                    </ToggleGroup>
                </div>
                <div
                    className="va-form-group"
                    data-ui={`form-element--2`}
                    id={`form-element-1`}
                    key={`form-element-1`}
                >
                    <ToggleGroup
                        isOptional={true}
                        name={'toggleGroup2'}
                        onChange={this.onChangeHandlerGrp2}
                        required={false}
                        selectedValues={this.state.selectedValues2}
                        title={'Toggle Group 2:'}
                    >
                        <Toggle
                            checked={onToggleChecked2}
                            id="on-toggle2"
                            key={0}
                            label="Toggle Sample"
                            name="on-toggle2"
                            onChange={this.onToggleChanged2}
                            value={'6'}
                        />
                    </ToggleGroup>
                </div>
            </>
        );
    }
}

export default ExampleToggleGroup;
