import React from 'react';

import { Button, ButtonTheme, ContentPadding, Modal } from '@preamp/core';

interface IBasicModalState {
    isModalOpen: boolean;
}

/**
 * This is a slim modal. Reduces the padding of content to 1.5rem
 */
class ExampleSlimModal extends React.Component<{}, IBasicModalState> {
    state: IBasicModalState = {
        isModalOpen: false
    };

    toggleModal = (): void => {
        this.setState((prevState: IBasicModalState): any => ({
            isModalOpen: !prevState.isModalOpen
        }));
    };

    renderFooter = (): React.ReactNode => (
        <>
            <Button onClick={this.toggleModal} theme={ButtonTheme.Secondary}>
                Discard Changes
            </Button>
            <Button onClick={this.toggleModal}>Save Changes</Button>
        </>
    );

    render(): React.ReactNode {
        return (
            <>
                <Button onClick={this.toggleModal}>Open Modal</Button>
                <Modal
                    actions={this.renderFooter()}
                    contentPadding={ContentPadding.Slim}
                    description="Lorem ipsum dolor sit amet"
                    isOpen={this.state.isModalOpen}
                    onHide={this.toggleModal}
                    title="Sample Slim Modal"
                >
                    Some Content With 1.5rem padding
                </Modal>
            </>
        );
    }
}

export default ExampleSlimModal;
