import React from 'react';

import { Button, ButtonTheme, Modal } from '@preamp/core';

interface BasicModalState {
    isModalOpen: boolean;
}

/**
 * This is a custom Modal setting maxWidth and maxHeight props
 */
class CustomHeightWidthModal extends React.Component<{}, BasicModalState> {
    state: BasicModalState = {
        isModalOpen: false
    };

    toggleModal = (): void => {
        this.setState(
            (prevState: BasicModalState): BasicModalState => ({
                isModalOpen: !prevState.isModalOpen
            })
        );
    };

    renderFooter = (): React.ReactNode => (
        <>
            <Button onClick={this.toggleModal} theme={ButtonTheme.Secondary}>
                Discard Changes
            </Button>
            <Button onClick={this.toggleModal}>Save Changes</Button>
        </>
    );

    render(): React.ReactNode {
        return (
            <>
                <Button onClick={this.toggleModal}>Open Modal</Button>
                <Modal
                    actions={this.renderFooter()}
                    description="Lorem ipsum dolor sit amet"
                    isOpen={this.state.isModalOpen}
                    maxHeight={'600px'}
                    maxWidth={'1200px'}
                    onHide={this.toggleModal}
                    title="Custom Width"
                >
                    Some Content
                </Modal>
            </>
        );
    }
}

export default CustomHeightWidthModal;
