import React from 'react';

import { Button, ButtonTheme, Modal, ContentPadding } from '@preamp/core';

/**
 * This is a Modal for confirmations
 */
const ContentCenteredModal = (): React.ReactNode => {
    const [isModalOpen, setIsOpenModal] = React.useState<boolean>(false);

    const maxHeight = '222px';
    const maxWidth = '500px';

    const toggleModal = (): void => {
        setIsOpenModal(!isModalOpen);
    };

    const renderFooter = (): React.ReactNode => (
        <>
            <Button onClick={toggleModal} theme={ButtonTheme.Secondary}>
                Discard Changes
            </Button>
            <Button onClick={toggleModal}>Save Changes</Button>
        </>
    );

    return (
        <>
            <Button onClick={toggleModal}>Open Modal</Button>
            <Modal
                actions={renderFooter()}
                contentPadding={ContentPadding.Slim}
                description="Lorem ipsum dolor sit amet"
                isLightContent
                isOpen={isModalOpen}
                maxHeight={maxHeight}
                maxWidth={maxWidth}
                onHide={toggleModal}
                title="Sample Modal"
            >
                <p>
                    Lorem ipsum dolor sit amet, consectetur adipiscing elit,
                    <br />
                    sed eiusmod tempor incidunt ut labore et dolore magna
                    aliqua.
                </p>
            </Modal>
        </>
    );
};

export default ContentCenteredModal;
