import React, { ReactElement, ReactNode, ReactText, useState } from 'react';

import { Button, ButtonTheme, IconButton, Modal } from '@preamp/core';
import {
    Account,
    Check,
    Clear,
    Download,
    Link,
    Search,
    Trash
} from '@preamp/signal';

interface MetricData {
    label: ReactText;
    value: ReactText;
}

/**
 * This is a Modal with Header Actions
 */
function ExampleHeaderActionsModal(): ReactElement<{}> {
    const HeaderMetrics = [
        {
            label: 'Frequency of Usage',
            value: '6x'
        },
        {
            label: 'Type of Item',
            value: 'Toilet Paper'
        },
        {
            label: 'Date Range',
            value: '12/09/2019 - 01/11/2020'
        }
    ];

    const [isModalOpen, setModalOpen] = useState(false);
    const [isSecondModalOpen, setSecondModalOpen] = useState(false);

    function toggleModal(): void {
        setModalOpen(!isModalOpen);
    }

    function toggleSecondModal(): void {
        setSecondModalOpen(!isSecondModalOpen);
    }

    const renderFooter = (): ReactNode => (
        <>
            <Button onClick={toggleModal} theme={ButtonTheme.Secondary}>
                Discard Changes
            </Button>
            <Button onClick={toggleModal}>Save Changes</Button>
        </>
    );

    const renderHeaderActions = (): ReactNode => (
        <>
            <ol className="flex">
                {HeaderMetrics.map(
                    (item: MetricData, idx): ReactNode => (
                        <dl className="mr-4" key={idx}>
                            <dt className="u-body-3 u-font-normal uppercase">
                                {item.label}
                            </dt>
                            <dd className="u-body-2 u-font-light mt-1">
                                {item.value}
                            </dd>
                        </dl>
                    )
                )}
            </ol>
        </>
    );

    const renderSecondHeaderActions = (): ReactNode => (
        <div className="flex flex-shrink-0">
            <IconButton
                dataUI="account"
                icon={Account}
                onClick={toggleSecondModal}
                size="lg"
            />
            <IconButton
                dataUI="check"
                icon={Check}
                onClick={toggleSecondModal}
                size="lg"
            />
            <IconButton
                dataUI="clear"
                icon={Clear}
                onClick={toggleSecondModal}
                size="lg"
            />
            <IconButton
                dataUI="download"
                icon={Download}
                onClick={toggleSecondModal}
                size="lg"
            />
            <IconButton
                dataUI="link"
                icon={Link}
                onClick={toggleSecondModal}
                size="lg"
            />
            <IconButton
                dataUI="search"
                icon={Search}
                onClick={toggleSecondModal}
                size="lg"
            />
            <IconButton
                dataUI="trash"
                icon={Trash}
                onClick={toggleSecondModal}
                size="lg"
            />
        </div>
    );

    return (
        <>
            <Button onClick={toggleModal}>Open Modal</Button>
            <Modal
                actions={renderFooter()}
                description="Lorem ipsum, dolor sit amet consectetur adipisicing elit. Repellat
        laboriosam facilis inventore reprehenderit quia ullam officiis,
        adipisci dignissimos. Vitae quae ab, optio possimus laudantium
        impedit voluptates labore expedita eum. Aperiam?"
                headerActions={renderHeaderActions()}
                isOpen={isModalOpen}
                onHide={toggleModal}
                title="Modal with Header Actions"
            >
                Content goes here
            </Modal>
            <Button onClick={toggleSecondModal}>Open Modal 2</Button>
            <Modal
                description="Lorem ipsum, dolor sit amet consectetur adipisicing elit. Repellat
        laboriosam facilis inventore reprehenderit quia ullam officiis,
        adipisci dignissimos. Vitae quae ab, optio possimus laudantium
        impedit voluptates labore expedita eum. Aperiam?"
                headerActions={renderSecondHeaderActions()}
                isOpen={isSecondModalOpen}
                onHide={toggleSecondModal}
                title="Modal with Text Header Actions"
            >
                Content goes here
            </Modal>
        </>
    );
}

export default ExampleHeaderActionsModal;
