import React, { ReactElement, useState } from 'react';

import {
    Button,
    ButtonTheme,
    Notification,
    NotificationTheme
} from '@preamp/core';

interface InlineNotificationState {
    notificationOpen: boolean;
    errorNotificationOpen: boolean;
    notificationThemeValue: NotificationTheme;
    notificationTitle: string;
}

/**
 * Basic notification component.
 */
function ExampleNotification(): ReactElement<{}> {
    const [inlineState, setInlineState] = useState<InlineNotificationState>({
        notificationOpen: false,
        errorNotificationOpen: false,
        notificationThemeValue: NotificationTheme.Default,
        notificationTitle: 'Your Report is Ready for Review.'
    });

    function inlineNotificationHide(): void {
        setInlineState({
            ...inlineState,
            notificationOpen: false
        });
    }
    function errorNotificationHide(): void {
        setInlineState({
            ...inlineState,
            errorNotificationOpen: false
        });
    }
    function openErrorNotification(): void {
        setInlineState({
            ...inlineState,
            errorNotificationOpen: true
        });
    }
    function openNotification(): void {
        setInlineState({
            ...inlineState,
            notificationThemeValue: NotificationTheme.Default,
            notificationOpen: true,
            notificationTitle: 'Your Report is Ready for Review.'
        });
    }

    return (
        <>
            <h4 className="py-4">Inline Notification</h4>
            <Notification
                isInline
                isOpen={inlineState.errorNotificationOpen}
                onHide={errorNotificationHide}
                theme={NotificationTheme.Error}
                title="One or more of your 3rd Party Tag URLs didn't process."
            >
                Please check your 3rd Party Tag URLs for accuracy, make any
                necessary edits, and try again
            </Notification>
            <Notification
                actions={
                    <Button
                        onClick={inlineNotificationHide}
                        theme={ButtonTheme.Link}
                    >
                        Close
                    </Button>
                }
                isInline
                isOpen={inlineState.notificationOpen}
                onHide={inlineNotificationHide}
                theme={inlineState.notificationThemeValue}
                title={inlineState.notificationTitle}
            >
                Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec
                pharetra nibh id enim elementum congue. Ut neque sem, imperdiet
                sit amet leo vel, tincidunt tincidunt dolor. Vestibulum rhoncus,
                odio ac viverra egestas, neque metus pellentesque enim, at
                cursus libero magna ut massa. Pellentesque accumsan arcu ac
                lacinia viverra. Sed malesuada nisl accumsan, mattis velit ut,
                euismod sem. Sed egestas nibh a dignissim fringilla.
            </Notification>
            <div className="mb-8">
                <p>
                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                    Donec pharetra nibh id enim elementum congue. Ut neque sem,
                    imperdiet sit amet leo vel, tincidunt tincidunt dolor.
                    Vestibulum rhoncus, odio ac viverra egestas, neque metus
                    pellentesque enim, at cursus libero magna ut massa.
                    Pellentesque accumsan arcu ac lacinia viverra. Sed malesuada
                    nisl accumsan, mattis velit ut, euismod sem. Sed egestas
                    nibh a dignissim fringilla.
                </p>
            </div>
            {inlineState.notificationOpen && (
                <Button
                    onClick={inlineNotificationHide}
                    theme={ButtonTheme.Primary}
                >
                    Close the Inline Notification
                </Button>
            )}
            {!inlineState.notificationOpen && (
                <Button onClick={openNotification} theme={ButtonTheme.Primary}>
                    Open the Inline Notification
                </Button>
            )}
            {inlineState.errorNotificationOpen && (
                <Button
                    onClick={errorNotificationHide}
                    theme={ButtonTheme.Secondary}
                >
                    Fix the Errors!
                </Button>
            )}
            {!inlineState.errorNotificationOpen && (
                <Button
                    onClick={openErrorNotification}
                    theme={ButtonTheme.Destructive}
                >
                    Error Notification
                </Button>
            )}
        </>
    );
}

export default ExampleNotification;
