import * as React from 'react';

import { AppBar, AppBarItem, AppBarItemProps } from '@preamp/core';
import {
    AppSelect,
    Build,
    Code,
    Equalizer,
    Notification,
    Signal
} from '@preamp/signal';

interface ButtonAppBarState {
    selectedId: number;
}

/**
 * Basic example of the AppBar with buttons for nav items
 */
class ButtonAppBar extends React.Component<{}, ButtonAppBarState> {
    state: ButtonAppBarState = {
        selectedId: 0
    };

    onClickItem = (index: number): (() => void) => (): void => {
        this.setState({ selectedId: index });
    };

    renderNavigation(data: AppBarItemProps[]): React.ReactNode {
        return data.map(
            (item: AppBarItemProps, index: number): React.ReactNode => (
                <li key={index}>
                    <AppBarItem
                        className={item.className}
                        currentItem={
                            this.state.selectedId === index ? true : false
                        }
                        onClick={this.onClickItem(index)}
                        tooltipDescription={item.tooltipDescription}
                        tooltipTitle={item.tooltipTitle}
                    >
                        {item.children}
                    </AppBarItem>
                </li>
            )
        );
    }

    render(): React.ReactNode {
        const navItemsData: AppBarItemProps[] = [
            {
                className: 'appbar-item-custom-class',
                tooltipTitle: 'Title One',
                tooltipDescription:
                    'Description text to be displayed in the AppBarItem tooltip on hover or focus',
                children: <Signal icon={Build} size={1.5} />
            },
            {
                className: 'appbar-item-custom-class',
                tooltipTitle: 'Title Two',
                tooltipDescription:
                    'Description text to be displayed in the AppBarItem tooltip on hover or focus',
                children: <Signal icon={Code} size={1.5} />
            },
            {
                className: 'appbar-item-custom-class',
                tooltipTitle: 'Title Three',
                tooltipDescription:
                    'Description text to be displayed in the AppBarItem tooltip on hover or focus',
                children: <Signal icon={Equalizer} size={1.5} />
            },
            {
                className: 'appbar-item-custom-class',
                tooltipTitle: 'Title Four',
                tooltipDescription:
                    'Description text to be displayed in the AppBarItem tooltip on hover or focus',
                children: <Signal icon={Notification} size={1.5} />
            }
        ];

        return (
            <div style={{ height: '500px' }}>
                <AppBar
                    header={
                        <AppBarItem
                            className="appbar-header-custom-class"
                            currentItem={false}
                            onClick={this.onClickItem(-1)}
                        >
                            <Signal icon={AppSelect} size={1.5} />
                        </AppBarItem>
                    }
                >
                    <ul>{this.renderNavigation(navItemsData)}</ul>
                </AppBar>
            </div>
        );
    }
}

export default ButtonAppBar;
