import React, { ReactElement, useState } from 'react';

import { AppBar, AppBarItem } from '@preamp/core';
import {
    AccountCircle,
    AppSelect,
    Build,
    Code,
    Equalizer,
    Help,
    Notification,
    Power,
    Search,
    Signal
} from '@preamp/signal';

/**
 * Basic example of the AppBar with nav items and actions
 */
function ActionsAppBar(): ReactElement {
    const [selectedId, setSelectedId] = useState<string>(null);

    function onClickItem(id: string): () => void {
        return (): void => {
            setSelectedId(id);
        };
    }

    return (
        <div style={{ height: 600 }}>
            <AppBar
                actions={
                    <ul className="mb-0">
                        <li>
                            <AppBarItem>
                                <Signal icon={Search} size={1.5} />
                            </AppBarItem>
                        </li>
                        <li>
                            <AppBarItem>
                                <Signal icon={AccountCircle} size={1.5} />
                            </AppBarItem>
                        </li>
                        <li>
                            <AppBarItem>
                                <Signal icon={Help} size={1.5} />
                            </AppBarItem>
                        </li>
                        <li>
                            <AppBarItem>
                                <Signal icon={Power} size={1.5} />
                            </AppBarItem>
                        </li>
                    </ul>
                }
                header={
                    <AppBarItem onClick={onClickItem(null)}>
                        <Signal icon={AppSelect} size={1.5} />
                    </AppBarItem>
                }
            >
                <ul className="mb-0">
                    <li>
                        <AppBarItem
                            currentItem={selectedId === 'id-1'}
                            onClick={onClickItem('id-1')}
                            tooltipDescription="Description text to be displayed in the AppBarItem tooltip on hover or focus"
                            tooltipTitle="Title One"
                        >
                            <Signal icon={Build} size={1.5} />
                        </AppBarItem>
                    </li>
                    <li>
                        <AppBarItem
                            currentItem={selectedId === 'id-2'}
                            onClick={onClickItem('id-2')}
                            tooltipDescription="Description text to be displayed in the AppBarItem tooltip on hover or focus"
                            tooltipTitle="Title Two"
                        >
                            <Signal icon={Code} size={1.5} />
                        </AppBarItem>
                    </li>
                    <li>
                        <AppBarItem
                            currentItem={selectedId === 'id-3'}
                            onClick={onClickItem('id-3')}
                            tooltipDescription="Description text to be displayed in the AppBarItem tooltip on hover or focus"
                            tooltipTitle="Title Three"
                        >
                            <Signal icon={Equalizer} size={1.5} />
                        </AppBarItem>
                    </li>
                    <li>
                        <AppBarItem
                            currentItem={selectedId === 'id-4'}
                            onClick={onClickItem('id-4')}
                            tooltipDescription="Description text to be displayed in the AppBarItem tooltip on hover or focus"
                            tooltipTitle="Title Four"
                        >
                            <Signal icon={Notification} size={1.5} />
                        </AppBarItem>
                    </li>
                </ul>
            </AppBar>
        </div>
    );
}

export default ActionsAppBar;
