import * as React from 'react';

import { uniq, without } from 'lodash';

import { Drilldown, DrilldownItemType } from '@preamp/core';

interface ExampleDrilldownState {
    activeItem: DrilldownItemType;
    selectedItemIds: string[];
}

const sampleData: DrilldownItemType[] = [
    {
        id: 'grandparent-1',
        items: [
            {
                id: 'parent-1',
                items: [
                    {
                        id: 'child-1',
                        title: 'Child',
                        subtitle: 'Item has no children'
                    }
                ],
                title: 'Parent'
            }
        ],
        title: 'Grandparent'
    }
];

/**
 * The component should be able to recover from a loaded state. This example mounts the component
 * with items pre-selected and with the `activeItem`
 */
class ExampleRecoverStateDrilldown extends React.Component<
    {},
    ExampleDrilldownState
> {
    state: ExampleDrilldownState = {
        activeItem: sampleData[0].items[0],
        selectedItemIds: ['child-1']
    };

    onNavigate = (activeItem?: DrilldownItemType): void => {
        this.setState({ activeItem });
    };

    onSelect = (selectedItem: DrilldownItemType): void => {
        const { selectedItemIds } = this.state;
        const isItemSelected: boolean = selectedItemIds.includes(
            selectedItem.id
        );
        let selectedIds: string[];

        if (isItemSelected) {
            selectedIds = without(selectedItemIds, selectedItem.id);
        } else {
            selectedIds = selectedItemIds.concat(selectedItem.id);
        }

        this.setState({ selectedItemIds: uniq(selectedIds) });
    };

    render(): React.ReactNode {
        const { activeItem, selectedItemIds } = this.state;

        return (
            <Drilldown
                activeItem={activeItem}
                dataUI="drilldown-example-recover-state"
                items={sampleData}
                onNavigate={this.onNavigate}
                onSelect={this.onSelect}
                selectedItemIds={selectedItemIds}
            />
        );
    }
}

export default ExampleRecoverStateDrilldown;
