import React, { useState } from 'react';

import { Drilldown, DrilldownItemType } from '@preamp/core';

interface CustomTrailingBreadcrumbsExampleState {
    activeItem?: DrilldownItemType;
    selectedItem?: DrilldownItemType;
    selectedItemIds: string[];
    filteredItems: DrilldownItemType[];
}

const sampleData: DrilldownItemType[] = [
    {
        id: 'level-1',
        title: 'Level 1',
        items: [
            {
                id: 'level-2',
                title: 'Level 2',
                items: [
                    {
                        id: 'level-3',
                        title: 'Level 3',
                        items: [
                            {
                                id: 'level-4',
                                title: 'Level 4',
                                items: [
                                    {
                                        id: 'level-5',
                                        title: 'Level 5',
                                        items: [
                                            {
                                                id: 'level-6',
                                                title: 'Level 6'
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                ]
            }
        ]
    }
];

function useCustomState(): [
    CustomTrailingBreadcrumbsExampleState,
    (state: Partial<CustomTrailingBreadcrumbsExampleState>) => void
] {
    const [state, setState] = useState<CustomTrailingBreadcrumbsExampleState>({
        filteredItems: sampleData,
        selectedItemIds: [sampleData[0].id],
        selectedItem: sampleData[0]
    });

    function updateState(
        newState: CustomTrailingBreadcrumbsExampleState
    ): void {
        setState({
            ...state,
            ...newState
        });
    }

    return [state, updateState];
}

/**
 * Custom trailing breadcrumbs can be set by passing an array of strings into the
 * "customTrailingBreadcrumbs" prop. This will override the use of drilldown item titles as the
 * source for breadcrumbs.
 *
 * If data has more levels than strings defined in "customBreadcrumbs", the breadcrumb name will
 * default to the title of the drilldown item.
 */
export default function CustomTrailingBreadcrumbsExample(): React.ReactNode {
    const [state, setState] = useCustomState();

    function onNavigate(activeItem: DrilldownItemType): void {
        setState({ activeItem });
    }

    function onSelect(selectedItem: DrilldownItemType): void {
        if (selectedItem.id !== state.selectedItemIds[0]) {
            setState({ selectedItemIds: [selectedItem.id], selectedItem });
        }
    }

    return (
        <Drilldown
            activeItem={state.activeItem}
            customTrailingBreadcrumbs={['A', 'B', 'C', 'D']}
            dataUI="drilldown-custom-breadcrumbs-example"
            isParentSelectable
            items={state.filteredItems}
            onNavigate={onNavigate}
            onSelect={onSelect}
            selectedItemIds={state.selectedItemIds}
        />
    );
}
