import React, { useState } from 'react';

import { Drilldown, DrilldownItemType } from '@preamp/core';

interface AlwaysDisplayBreadcrumbsExampleState {
    activeItem?: DrilldownItemType;
    selectedItem?: DrilldownItemType;
    selectedItemIds: string[];
    filteredItems: DrilldownItemType[];
}

const sampleData: DrilldownItemType[] = [
    {
        id: 'level-1',
        title: 'Level 1',
        items: [
            {
                id: 'level-2',
                title: 'Level 2',
                items: [
                    {
                        id: 'level-3',
                        title: 'Level 3',
                        items: [
                            {
                                id: 'level-4',
                                title: 'Level 4',
                                items: [
                                    {
                                        id: 'level-5',
                                        title: 'Level 5',
                                        items: [
                                            {
                                                id: 'level-6',
                                                title: 'Level 6'
                                            }
                                        ]
                                    }
                                ]
                            }
                        ]
                    }
                ]
            }
        ]
    }
];

function useCustomState(): [
    AlwaysDisplayBreadcrumbsExampleState,
    (state: Partial<AlwaysDisplayBreadcrumbsExampleState>) => void
] {
    const [state, setState] = useState<AlwaysDisplayBreadcrumbsExampleState>({
        filteredItems: sampleData,
        selectedItemIds: [sampleData[0].id],
        selectedItem: sampleData[0]
    });

    function updateState(newState: AlwaysDisplayBreadcrumbsExampleState): void {
        setState({
            ...state,
            ...newState
        });
    }

    return [state, updateState];
}

/**
 * Breadcrumbs can be configured so it is always visible, even in the top level.
 */
export default function AlwaysDisplayBreadcrumbsExample(): React.ReactNode {
    const [state, setState] = useCustomState();

    function onNavigate(activeItem: DrilldownItemType): void {
        setState({ activeItem });
    }

    function onSelect(selectedItem: DrilldownItemType): void {
        if (selectedItem.id !== state.selectedItemIds[0]) {
            setState({ selectedItemIds: [selectedItem.id], selectedItem });
        }
    }

    return (
        <Drilldown
            activeItem={state.activeItem}
            dataUI="drilldown-always-display-breadcrumbs-example"
            isBreadcrumbsVisibleInRoot
            isParentSelectable
            items={state.filteredItems}
            onNavigate={onNavigate}
            onSelect={onSelect}
            selectedItemIds={state.selectedItemIds}
        />
    );
}
