import React, { ReactNode, useState } from 'react';

import { Drilldown, DrilldownItemType } from '@preamp/core';
import { without } from 'lodash';

const sampleData: DrilldownItemType[] = [
    {
        id: 'level-1',
        title: 'Level 1'
    },
    {
        id: 'level-2',
        title: 'Level 2'
    }
];

/**
 * Drilldown with customToolbarContent prop.
 */
export default function DrilldownCustomToolbarContent(): ReactNode {
    const [selectedItemIds, setSelectedItemIds] = useState([]);

    function onSelect(selectedItem: DrilldownItemType): void {
        const isItemSelected: boolean = selectedItemIds.includes(
            selectedItem.id
        );

        let selectedIds: string[];

        if (isItemSelected) {
            selectedIds = without(selectedItemIds, selectedItem.id);
        } else {
            selectedIds = selectedItemIds.concat(selectedItem.id);
        }
        setSelectedItemIds(selectedIds);
    }

    function onSelectAll(): void {
        if (selectedItemIds.length === sampleData.length) {
            return setSelectedItemIds([]);
        }
        return setSelectedItemIds(sampleData.map((data): string => data.id));
    }

    return (
        <>
            <Drilldown
                customToolbarContent={
                    <a className="text-xs" onClick={onSelectAll} role="button">
                        Select All
                    </a>
                }
                dataUI="drilldown-list-table-example"
                items={sampleData}
                onSelect={onSelect}
                selectedItemIds={selectedItemIds}
            />
            <div className="mt-1">Selected Item: {selectedItemIds}</div>
        </>
    );
}
