import React from 'react';

import {
    Button,
    Drilldown,
    DrilldownEditItem,
    DrilldownItemProps,
    DrilldownItemType
} from '@preamp/core';

interface BasicDrilldownEditItemState {
    selectedItems: string[];
    activeItem?: DrilldownItemType;
    isSuccess?: boolean;
}

const sampleData: DrilldownItemType[] = [
    {
        id: 'example-1',
        title: 'Parent Item 1',
        items: [
            {
                id: 'child-example-1',
                title: 'Child Item 1'
            }
        ]
    },
    {
        id: 'example-2',
        title: 'Top Level Child'
    }
];

/** An editable Drilldown Item component */
class BasicDrilldownEditItemExample extends React.Component {
    state: BasicDrilldownEditItemState = {
        selectedItems: []
    };

    handleSelect = (item: DrilldownItemType): void => {
        this.setState({
            selectedItems: [item.id]
        });
    };

    handleNavigate = (activeItem: DrilldownItemType): void => {
        this.setState({ activeItem });
    };

    triggerSuccess = (): void => {
        const { isSuccess } = this.state;
        if (!isSuccess) {
            this.setState({ isSuccess: true });
        }
    };

    handleSuccessComplete = (): void => {
        this.setState({ isSuccess: false });
    };

    itemFunction = (props: DrilldownItemProps): React.ReactNode => (
        <DrilldownEditItem
            {...props}
            isSuccess={this.state.isSuccess}
            onSuccessComplete={this.handleSuccessComplete}
        >
            {props.item.title}
        </DrilldownEditItem>
    );

    render(): React.ReactNode {
        const { activeItem, selectedItems } = this.state;
        const { handleNavigate, handleSelect, triggerSuccess } = this;

        return (
            <>
                <Drilldown
                    activeItem={activeItem}
                    isParentSelectable
                    itemFunction={this.itemFunction}
                    items={sampleData}
                    onNavigate={handleNavigate}
                    onSelect={handleSelect}
                    selectedItemIds={selectedItems}
                />
                <div className="mt-8">
                    <Button onClick={triggerSuccess}>Trigger Success</Button>
                </div>
            </>
        );
    }
}

export default BasicDrilldownEditItemExample;
