import React from 'react';

import { findIndex } from 'lodash';

import { Button, ButtonTheme, IStep, Stepper } from '@preamp/core';

const steps: IStep[] = [
    {
        id: 1,
        label: 'Label 1',
        title: 1
    },
    {
        id: 2,
        label: 'Label 2',
        title: 2
    },
    {
        id: 3,
        label: 'Label 3',
        title: 3
    },
    {
        id: 4,
        label: 'Label 4',
        title: 4
    },
    {
        id: 5,
        label: 'Label 5',
        title: 5
    }
];

const defaultDisabledSteps: IStep[] = steps.filter(
    (_: IStep, index: number): React.ReactNode => {
        return index > 0;
    }
);

interface SimpleStepperState {
    currentStep: IStep;
    disabledSteps: IStep[];
    numberOfCompletedSteps: number;
}

/**
 * Simple example of the Stepper component
 */
class SimpleStepper extends React.Component<{}, SimpleStepperState> {
    state: SimpleStepperState = {
        currentStep: steps[0],
        disabledSteps: defaultDisabledSteps,
        numberOfCompletedSteps: 0
    };

    onClickHandler = (
        step: IStep,
        event: React.MouseEvent<HTMLButtonElement>
    ): void => {
        // eslint-disable-next-line no-console
        console.groupCollapsed('onClickHandler');
        // eslint-disable-next-line no-console
        console.log('step\n', step);
        // eslint-disable-next-line no-console
        console.log('event\n', event);
        // eslint-disable-next-line no-console
        console.groupEnd();

        const { numberOfCompletedSteps } = this.state;
        const stepIndex: number = findIndex(steps, step);
        this.setState({
            currentStep: step,
            numberOfCompletedSteps:
                stepIndex > numberOfCompletedSteps
                    ? stepIndex
                    : numberOfCompletedSteps
        });
    };

    incrementClickHandler = (): void => {
        const { numberOfCompletedSteps, currentStep } = this.state;
        const nextStep: number =
            findIndex(steps, currentStep) === steps.length - 1
                ? steps.length - 1
                : (findIndex(steps, currentStep) as number) + 1;
        const completedSteps: number =
            nextStep > numberOfCompletedSteps
                ? nextStep
                : numberOfCompletedSteps;
        this.setState({
            currentStep: steps[nextStep],
            disabledSteps: steps.filter(
                (_: IStep, index: number): React.ReactNode => {
                    return index > completedSteps;
                }
            ),
            numberOfCompletedSteps: completedSteps
        });
    };

    resetHandler = (): void => {
        this.setState({
            currentStep: steps[0],
            disabledSteps: defaultDisabledSteps,
            numberOfCompletedSteps: 0
        });
    };

    render(): React.ReactNode {
        const {
            currentStep,
            disabledSteps,
            numberOfCompletedSteps
        } = this.state;

        return (
            <>
                <section className="mt-6 mb-9">
                    <Stepper
                        currentStep={currentStep}
                        disabledSteps={disabledSteps}
                        minWidth={300}
                        numberOfCompletedSteps={numberOfCompletedSteps}
                        onClick={this.onClickHandler}
                        steps={steps}
                    />
                    <div className="pt-4 pb-4">
                        <Button
                            dataUI="incriment-step"
                            onClick={this.resetHandler}
                            theme={ButtonTheme.Secondary}
                        >
                            Reset Steps
                        </Button>
                        <Button
                            dataUI="incriment-step"
                            onClick={this.incrementClickHandler}
                            theme={ButtonTheme.Primary}
                        >
                            Complete Step
                        </Button>
                    </div>
                </section>
            </>
        );
    }
}

export default SimpleStepper;
