import React, { useState, FC } from 'react';

import { ITabItem, Tabs } from '@preamp/core';

interface Section {
    [key: string]: {
        identifier: string;
        content?: string;
    };
}

const tabs: ITabItem[] = [
    {
        href: '#section-1',
        identifier: 'section-1',
        label: 'Tab 1'
    },
    {
        href: '#section-2',
        identifier: 'section-2',
        label: 'Tab 2'
    },
    {
        href: '#section-3',
        identifier: 'section-3',
        label: 'Tab 3'
    },
    {
        href: '#section-4',
        identifier: 'section-4',
        label: 'Tab 4'
    },
    {
        disabled: true,
        href: '#section-5',
        identifier: 'section-5',
        label: 'Tab 5'
    }
];

const sections: Section = {
    'section-1': {
        content:
            'Ancient alien pyramids King Soloman foo fighter ancient god, legendary times mystery I know it sounds crazy.... Cover up burmuta triangle anti-gravity space travel worm hole spaceships, I know it sounds crazy... The vedas King Soloman gods. Magnetic current mystery kachina doll, NASA Vymaanika-Shaastra kachina doll, ancient civilization DNA manipulation.\n',
        identifier: 'section-1'
    },
    'section-2': {
        content:
            'Vimana star people crystal skull SETI extraterrestrial origin, choral castle gods grey Mahabharata space time, extraterrestrial origin Indian texts otherworldly visitors grey clearly weightless. Kachina doll extraterrestrial origin Mayan vortex pyramids grey, von Daniken SETI sky people burmuta triangle magnetic current, aircraft the vedas electromagnetic helicopter heiroglyph.\n',
        identifier: 'section-2'
    },
    'section-3': {
        content:
            'Space time petroglyph ancient god cover up, I know it sounds crazy... Earth mound cover up aircraft portal, golden disk flying vessels astronaut worm hole extraterrestrial Ezekiel. Electromagnetic weightless sanskrit von Daniken Indian texts mainstream archaelogy sun disc, sun disc pre-colonial aerodynamics otherworldly visitors crystal skull extraterrestrial origin.\n',
        identifier: 'section-3'
    },
    'section-4': {
        content:
            'Clearly earth mound sanskrit stonehenge choral castle magnetic current flying vessels, magnetic current grey helicopter heiroglyph Nazca lines ancient alien theorists. Foo fighter Nazca lines electromagnetic kachina doll kachina doll, ancient alien theorists the vedas vimana weightless Ezekiel extraterrestrial origin, inter-dimensional weightless sightings aircraft worm hole mercury megoliths.\n',
        identifier: 'section-4'
    },
    'section-5': {
        content:
            'Elongated skull Vymaanika-Shaastra UFO King Soloman alien SETI cover up, portal weightless megoliths aircraft megoliths Giorgio space brothers star people. Sky people stonehenge NASA ancient civilization space time foo fighter, golden disk mainstream archaelogy Vymaanika-Shaastra UFO Mayan UFO petroglyph technology, electromagnetic legendary times pre-colonial aerodynamics earth mound weightless.\n',
        identifier: 'section-5'
    }
};

/**
 * An example of the Tabs component using the `shouldChildrenFill` prop
 */
export const SimpleTabsWithFilledChildren: FC = (): JSX.Element => {
    const [tabState, setTabState] = useState<string>(tabs[0].identifier);

    const onClick = (tab: ITabItem): void => {
        setTabState(tab.identifier);
    };

    const currentTab = tabState;

    return (
        <div className="mt-6 mb-9">
            <Tabs onClick={onClick} shouldChildrenFill tabs={tabs} />
            <div className="mt-3 mb-9">
                {tabs.map(
                    (tab: ITabItem): React.ReactNode => (
                        <section
                            aria-labelledby={`${tab.identifier}-tab`}
                            className="mt-3 mb-6"
                            id={tab.identifier}
                            key={tab.identifier}
                            role="tabpanel"
                            style={{
                                display:
                                    currentTab === tab.identifier
                                        ? 'block'
                                        : 'none'
                            }}
                        >
                            {sections[tab.identifier].content}
                        </section>
                    )
                )}
            </div>
        </div>
    );
};

export default SimpleTabsWithFilledChildren;
