import React, { useState, FC } from 'react';

import { ITabItem, Tabs } from '@preamp/core';
import { Alert, Check, Signal } from '@preamp/signal';

interface Section {
    [key: string]: {
        identifier: string;
        content?: string;
    };
}

const tabs: ITabItem[] = [
    {
        href: '#section-1',
        identifier: 'section-1',
        label: (
            <>
                Tab 1
                <Signal className={'m-1'} icon={Check} />
            </>
        )
    },
    {
        href: '#section-2',
        identifier: 'section-2',
        label: (
            <>
                Tab 2
                <Signal className={'m-1'} icon={Check} />
            </>
        )
    },
    {
        disabled: true,
        href: '#section-3',
        identifier: 'section-3',
        label: <Signal icon={Alert} size="Medium" />
    }
];

const sections: Section = {
    'section-1': {
        content:
            'Ancient alien technology Chariot of the Gods Puma Punku megoliths Mahabharata crystal skull, legendary times choral castle Indian texts clearly sanskrit cover up. Gods the vedas anti-gravity Indian texts ancient religions inter-dimensional, cover up ancient alien theorists, the answer is a resounding YES... Foo fighter star gates flying vessels electromagnetic.\n',
        identifier: 'section-1'
    },
    'section-2': {
        content:
            'Mayan Ezekiel Nazca lines stonehenge spaceships Annunaki, Easter island sky people flying vessels helicopter heiroglyph, ancient alien crystal skull UFO astronaut ancient alien. Anti-gravity Vymaanika-Shaastra petroglyph mainstream archaelogy otherworldly visitors ancient religions, alien ancient alien theorists mystery star people gods, ancient god Annunaki clearly gods extraterrestrial origin.',
        identifier: 'section-2'
    },
    'section-3': {
        content:
            'Portal foo fighter burmuta triangle magnetic current, burmuta triangle the answer is a resounding YES.... Ancient god evidence Easter island ancient god astronaut vimana pyramids anti-gravity flying vessels space brothers, the answer is a resounding YES... Gods spaceships earth mound ancient god. Mystery extraterrestrial origin astronaut, Vymaanika-Shaastra.\n',
        identifier: 'section-3'
    }
};

/**
 * An example of the Tabs component using the `icon` prop
 */
export const SimpleTabsWithIcons: FC = (): JSX.Element => {
    const [tabState, setTabState] = useState<string>(tabs[0].identifier);

    const onClick = (tab: ITabItem): void => {
        setTabState(tab.identifier);
    };

    const currentTab = tabState;

    return (
        <div className="mt-6 mb-9">
            <Tabs onClick={onClick} tabs={tabs} />
            <div className="mt-3 mb-9">
                {tabs.map(
                    (tab: ITabItem): React.ReactNode => (
                        <section
                            aria-labelledby={`${tab.identifier}-tab`}
                            className="mt-3 mb-6"
                            id={tab.identifier}
                            key={tab.identifier}
                            role="tabpanel"
                            style={{
                                display:
                                    currentTab === tab.identifier
                                        ? 'block'
                                        : 'none'
                            }}
                        >
                            {sections[tab.identifier].content}
                        </section>
                    )
                )}
            </div>
        </div>
    );
};

export default SimpleTabsWithIcons;
