import * as React from 'react';

import {
    Status,
    VerticalNav,
    VerticalNavChildItem,
    VerticalNavHeader,
    VerticalNavItem
} from '@preamp/core';
import { CloudUpload } from '@preamp/signal';

interface VerticalNavState {
    selectedItemId: number;
}

function unprintableMessage(): void {
    // eslint-disable-next-line no-console
    console.log('This message should not fire because item is disabled');
}

/**
 * Basic example of the VerticalNav with normal VerticalNavItems, as well as
 * VerticalNavItems containing child VerticalNavChildItems.
 */
class BasicVerticalNav extends React.Component<{}, VerticalNavState> {
    state: VerticalNavState = {
        selectedItemId: 10
    };

    setSelectedNavItem = (id: number): void =>
        this.setState({ selectedItemId: id });

    render(): React.ReactNode {
        const { selectedItemId } = this.state;

        return (
            <div
                style={{
                    height: '600px',
                    backgroundColor: 'var(--va-base-bg)'
                }}
            >
                <VerticalNav
                    header={<VerticalNavHeader primaryText="Measurement" />}
                >
                    <VerticalNavChildItem
                        id={10}
                        isSelected={selectedItemId === 10}
                        onClick={this.setSelectedNavItem}
                        primaryText="Databases"
                    />
                    <VerticalNavChildItem
                        icon={CloudUpload}
                        id={11}
                        isSelected={selectedItemId === 11}
                        onClick={this.setSelectedNavItem}
                        primaryText="Upload CSV"
                    />
                    <VerticalNavChildItem
                        href="https://example.org"
                        id={12}
                        isSelected={selectedItemId === 12}
                        primaryText="Tables"
                    />
                    <VerticalNavChildItem
                        href="https://example.org"
                        id={13}
                        isSelected={selectedItemId === 13}
                        primaryText="Druid Clusters"
                        shouldOpenNewTab
                    />
                    <VerticalNavChildItem
                        id={14}
                        isSelected={selectedItemId === 14}
                        onClick={this.setSelectedNavItem}
                        primaryText="Scan New Datasources"
                    />
                    <VerticalNavChildItem
                        disabled
                        id={15}
                        isSelected={selectedItemId === 15}
                        onClick={unprintableMessage}
                        primaryText="Refresh Druid Metadata"
                    />

                    <VerticalNavItem
                        id={'1'}
                        isSelected={selectedItemId === 1}
                        onClick={this.setSelectedNavItem}
                        primaryText="Chart Builder"
                    />
                    <VerticalNavItem
                        disabled
                        expanded
                        onClick={unprintableMessage}
                        primaryText="SQL Lab"
                    >
                        <VerticalNavChildItem
                            id={20}
                            isSelected={selectedItemId === 20}
                            onClick={this.setSelectedNavItem}
                            primaryText="SQL Injection"
                        />
                        <VerticalNavChildItem
                            id={21}
                            isSelected={selectedItemId === 21}
                            onClick={this.setSelectedNavItem}
                            primaryText="Drop Tables"
                        />
                    </VerticalNavItem>
                    <VerticalNavItem
                        expanded
                        isCollapsible
                        primaryText="Statuses"
                    >
                        <VerticalNavChildItem
                            id={22}
                            isIndicatorShown={true}
                            isSelected={selectedItemId === 22}
                            onClick={this.setSelectedNavItem}
                            primaryText="Processing"
                            status={Status.Pending}
                        />
                        <VerticalNavChildItem
                            className="font-bold"
                            id={23}
                            isIndicatorShown={true}
                            isSelected={selectedItemId === 23}
                            onClick={this.setSelectedNavItem}
                            primaryText="Failed"
                            status={Status.Failing}
                        />
                        <VerticalNavChildItem
                            id={24}
                            indicatorColor={'green'}
                            isIndicatorShown={true}
                            isSelected={selectedItemId === 24}
                            onClick={this.setSelectedNavItem}
                            primaryText="Go go go"
                        />
                        <VerticalNavChildItem
                            id={25}
                            isIndicatorShown={true}
                            isSelected={selectedItemId === 25}
                            onClick={this.setSelectedNavItem}
                            primaryText="Notification"
                            status={Status.Notification}
                        />
                    </VerticalNavItem>
                </VerticalNav>
            </div>
        );
    }
}

export default BasicVerticalNav;
