import * as React from 'react';

import {
    Button,
    ButtonTheme,
    VerticalNav,
    VerticalNavChildItem,
    VerticalNavItem
} from '@preamp/core';

interface VerticalNavState {
    selectedItemId: number;
}

/**
 * A VerticalNav example with an additional Button component that is not a Child item.
 */
class VerticalNavWithButton extends React.Component<{}, VerticalNavState> {
    state: VerticalNavState = {
        selectedItemId: 0
    };

    setSelectedNavItem = (id: number): void =>
        this.setState({ selectedItemId: id });

    clickButton = (): void => {
        // eslint-disable-next-line no-console
        console.log('the button was clicked');
    };

    render(): React.ReactNode {
        const { selectedItemId } = this.state;

        return (
            <div style={{ height: '320px' }}>
                <VerticalNav>
                    <VerticalNavItem expanded={true} primaryText="Parent">
                        <VerticalNavChildItem
                            id={10}
                            isSelected={selectedItemId === 10}
                            onClick={this.setSelectedNavItem}
                            primaryText="Databases"
                        />
                        <VerticalNavChildItem
                            id={11}
                            isSelected={selectedItemId === 11}
                            onClick={this.setSelectedNavItem}
                            primaryText="Upload CSV"
                        />
                        <VerticalNavChildItem
                            id={12}
                            isSelected={selectedItemId === 12}
                            onClick={this.setSelectedNavItem}
                            primaryText="Tables"
                        />
                        <VerticalNavChildItem
                            id={13}
                            isSelected={selectedItemId === 13}
                            onClick={this.setSelectedNavItem}
                            primaryText="Druid Clusters"
                        />
                        <VerticalNavChildItem
                            id={14}
                            isSelected={selectedItemId === 14}
                            onClick={this.setSelectedNavItem}
                            primaryText="Scan New Datasources"
                        />
                    </VerticalNavItem>

                    <Button
                        dataUI="nav-button"
                        isFullWidth={true}
                        onClick={this.clickButton}
                        theme={ButtonTheme.Secondary}
                    >
                        Example Button
                    </Button>
                </VerticalNav>
            </div>
        );
    }
}

export default VerticalNavWithButton;
