import * as React from 'react';

import {
    VerticalNav,
    VerticalNavChildItem,
    VerticalNavHeader,
    VerticalNavItem
} from '@preamp/core';

interface HrefVerticalNavState {
    selectedItemId: number;
}

function unprintableMessage(): void {
    // eslint-disable-next-line no-console
    console.log('This message should not fire because item is disabled');
}

/**
 * Example of the VerticalNav with href VerticalNavItems, as well as
 * VerticalNavItems containing child href VerticalNavChildItems.
 */
class HrefVerticalNav extends React.Component<{}, HrefVerticalNavState> {
    state: HrefVerticalNavState = {
        selectedItemId: 0
    };

    setSelectedNavItem = (id: number): void =>
        this.setState({ selectedItemId: id });

    render(): React.ReactNode {
        const { selectedItemId } = this.state;

        return (
            <div style={{ height: '330px' }}>
                <VerticalNav
                    header={<VerticalNavHeader primaryText="Href Navigation" />}
                >
                    <VerticalNavItem
                        href="#"
                        id={'0'}
                        isSelected={selectedItemId === 0}
                        onClick={this.setSelectedNavItem}
                        primaryText="Top Level"
                        shouldOpenNewTab
                    />
                    <VerticalNavItem
                        expanded={true}
                        href="#"
                        primaryText="Parent Link"
                    >
                        <VerticalNavChildItem
                            href="#"
                            id={10}
                            isSelected={selectedItemId === 10}
                            onClick={this.setSelectedNavItem}
                            primaryText="Child 1"
                        />
                        <VerticalNavChildItem
                            href="#"
                            id={11}
                            isSelected={selectedItemId === 11}
                            onClick={this.setSelectedNavItem}
                            primaryText="Child 2"
                        />
                        <VerticalNavChildItem
                            href="#"
                            id={12}
                            isSelected={selectedItemId === 12}
                            onClick={this.setSelectedNavItem}
                            primaryText="Child 3"
                        />
                        <VerticalNavChildItem
                            disabled
                            href="#"
                            id={13}
                            isSelected={selectedItemId === 13}
                            onClick={unprintableMessage}
                            primaryText="Disabled Child"
                        />
                    </VerticalNavItem>
                    <VerticalNavItem
                        disabled
                        href="#"
                        id={'1'}
                        isSelected={selectedItemId === 1}
                        onClick={this.setSelectedNavItem}
                        primaryText="Disabled Top Level"
                    />
                </VerticalNav>
            </div>
        );
    }
}

export default HrefVerticalNav;
