import * as React from 'react';

import {
    Button,
    ButtonTheme,
    VerticalNav,
    VerticalNavChildItem,
    VerticalNavHeader,
    VerticalNavItem
} from '@preamp/core';

/**
Example of the VerticalNav with a width set to 500px
 */
function VerticalNavWidthSet(): React.ReactNode {
    const [state, setState] = React.useState<number>(10);

    const clickButton = (): void => {
        // eslint-disable-next-line no-console
        console.log('the button was clicked');
    };

    const setSelectedNavItem = (id: number): void => setState(id);

    return (
        <div style={{ height: '330px' }}>
            <VerticalNav
                header={<VerticalNavHeader primaryText="Href Navigation" />}
                width={500}
            >
                <VerticalNavItem
                    href="#"
                    id="0"
                    isSelected={state === 0}
                    onClick={setSelectedNavItem}
                    primaryText="Top Level"
                    shouldOpenNewTab
                />
                <VerticalNavItem expanded href="#" primaryText="Parent Link">
                    <VerticalNavChildItem
                        href="#"
                        id={10}
                        isSelected={state === 10}
                        onClick={setSelectedNavItem}
                        primaryText="Child 1"
                    />
                    <VerticalNavChildItem
                        href="#"
                        id={11}
                        isSelected={state === 11}
                        onClick={setSelectedNavItem}
                        primaryText="Child 2"
                    />
                </VerticalNavItem>
                <VerticalNavItem
                    disabled
                    href="#"
                    id="1"
                    isSelected={state === 1}
                    onClick={setSelectedNavItem}
                    primaryText="Disabled Top Level"
                />
                <Button
                    dataUI="nav-button"
                    isFullWidth
                    onClick={clickButton}
                    theme={ButtonTheme.Secondary}
                >
                    Example Button
                </Button>
            </VerticalNav>
        </div>
    );
}

export default VerticalNavWidthSet;
