import * as React from 'react';

import { Card, CardTheme, IconButton } from '@preamp/core';
import { Trash } from '@preamp/signal';

interface IActionState {
    count: number;
}

/**
 * Examples of the Card component
 */
class ExampleCard extends React.Component<{}, IActionState> {
    state: IActionState = {
        count: 0
    };

    clickButton = (): void => {
        this.setState((prevState: IActionState): any => ({
            count: prevState.count + 1
        }));
    };
    render(): React.ReactNode {
        return (
            <>
                <p className="my-4">Default card:</p>
                <Card
                    action={
                        <>
                            <IconButton
                                dataUI="primary"
                                icon={Trash}
                                onClick={this.clickButton}
                                size="lg"
                            >
                                Button
                            </IconButton>
                        </>
                    }
                    title="Example 2: Content with button"
                >
                    <p>
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                    Action Clicks: {this.state.count}
                </Card>
                <p className="my-4">Card with white theme:</p>
                <Card
                    action={
                        <>
                            <IconButton
                                dataUI="primary"
                                icon={Trash}
                                onClick={this.clickButton}
                                size="lg"
                            >
                                Button
                            </IconButton>
                        </>
                    }
                    theme={CardTheme.White}
                    title="White theme example"
                >
                    <p>
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                    Action Clicks: {this.state.count}
                </Card>
                <p className="my-4">Card with no title:</p>
                <Card
                    action={
                        <>
                            <IconButton
                                dataUI="primary"
                                icon={Trash}
                                onClick={this.clickButton}
                                size="lg"
                            >
                                Button
                            </IconButton>
                        </>
                    }
                >
                    <p>
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                    Action Clicks: {this.state.count}
                </Card>
                <p className="my-4">Card in selected state:</p>
                <Card
                    action={
                        <>
                            <IconButton
                                dataUI="primary"
                                icon={Trash}
                                onClick={this.clickButton}
                                size="lg"
                            >
                                Button
                            </IconButton>
                        </>
                    }
                    isSelected
                    title="Example 2: Content with button"
                >
                    <p>
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna.{' '}
                    </p>
                </Card>
            </>
        );
    }
}

export default ExampleCard;
