import React, { ReactElement, useState } from 'react';
import { noop } from 'lodash';

import { ExpandableCard, Button, ButtonTheme } from '@preamp/core';
import { IDataTableColumn, DataTable } from '@preamp/tables';

enum columnEnum {
    FirstName = 'firstName',
    LastName = 'lastName',
    Location = 'location',
    Date = 'date'
}

interface BasicDataTableRow {
    identifier: number;
    [columnEnum.FirstName]: string;
    [columnEnum.LastName]: string;
    [columnEnum.Location]: string;
    [columnEnum.Date]: string;
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.FirstName,
        header: 'First Name'
    },
    {
        identifier: columnEnum.LastName,
        header: 'Last Name'
    },
    {
        identifier: columnEnum.Location,
        header: 'Location'
    },
    {
        identifier: columnEnum.Date,
        header: 'Date'
    }
];

const rows: BasicDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 2,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    }
];

const firstLevelData = {
    name: 'AMC',
    data: [
        { label: 'Total Impressions', value: '38,109,305' },
        { label: 'Total HH Reach', value: '137,457' },
        { label: 'Total Units', value: '9,362' },
        { label: 'Avg. CPM', value: '$163' },
        { label: 'Total Cost', value: '$886,555' }
    ]
};

const expandedData = {
    name: 'WeTV',
    data: [
        { label: 'Total Impressions', value: '38,109,305' },
        { label: 'Total Units', value: '9,362' },
        { label: 'Total Cost', value: '$886,555' }
    ]
};

/**
 * Example of the ExpandableCard component with summary data
 */
function SummaryDataExpandableCards(): ReactElement<{}> {
    const [expanded, setExpanded] = useState(false);

    return (
        <ExpandableCard
            action={
                <div className="ml-8 flex items-center">
                    <Button onClick={noop}>Reject</Button>
                    <Button onClick={noop} theme={ButtonTheme.Primary}>
                        Confirm
                    </Button>
                </div>
            }
            className="va-grey-200--background"
            expandableContent={
                <div className="-mt-10">
                    <ExpandableCard
                        className={`bg-white mt-10`}
                        expandableContent={
                            <DataTable
                                columns={columns}
                                dataUI="basic-data-table"
                                rows={rows}
                                showPagination={false}
                            />
                        }
                        isExpanded={false}
                        key={String(expanded)}
                        summaryData={expandedData.data}
                    >
                        <div className="flex justify-between ml-2 items-center">
                            <div>{expandedData.name}</div>
                        </div>
                    </ExpandableCard>
                </div>
            }
            isExpanded={expanded}
            onExpand={setExpanded}
            summaryData={firstLevelData.data}
        >
            <div className="flex justify-between ml-2 items-center">
                <div>{firstLevelData.name}</div>
            </div>
        </ExpandableCard>
    );
}

export default SummaryDataExpandableCards;
