import React, { ReactElement, useState } from 'react';

import { Button, ExpandableCard } from '@preamp/core';
import {
    IListTableColumn,
    ITableRow,
    ListTable,
    ListTableTheme
} from '@preamp/tables';

const COLUMNS: IListTableColumn[] = [
    {
        header: 'Title',
        identifier: 'title'
    },
    {
        header: 'Description',
        identifier: 'description'
    }
];
const ROWS: ITableRow[] = [
    {
        description:
            'Consectetur adipiscing elit. Duis consectetur tristique ipsum a venenatis.',
        identifier: 1,
        title: 'Lorem Ipsum Dolor Sit Amet'
    },
    {
        description:
            'A odio semper, ac semper mi varius. Donec efficitur egestas finibus. Nullam rhoncus, tortor quis viverra molestie.',
        identifier: 2,
        title: 'Curabitur Tempus Nunc'
    },
    {
        description:
            'Eu semper est dolor a purus. Aenean at aliquam tortor, vitae commodo urna.',
        identifier: 3,
        title: 'Libero Nisi Hendrerit Mauris'
    },
    {
        description:
            'In tempus nisl at nulla interdum gravida. Praesent sit amet vulputate lorem, quis consequat massa. Aliquam ligula dui, commodo ut porta vel, lacinia sit amet magna.',
        identifier: 4,
        title: 'Sed Sit Amet Ultricies Mauris'
    },
    {
        description: 'Commodo iaculis nibh, a ultricies augue semper ut.',
        identifier: 5,
        title: 'Vestibulum'
    },
    {
        description:
            'Pellentesque eu dolor nec urna pharetra consequat. Mauris ultrices, elit quis consectetur pretium, purus nisl tincidunt orci, at sagittis felis arcu sed erat.',
        identifier: 6,
        title: 'Nam Metus Libero Dictum eu Lobortis Quis Luctus Sed Nibh'
    }
];

/**
 * Example of the ExpandableCard component with dymanic ListTable rows
 */
function DynamicListTableExpandableCard(): ReactElement<{}> {
    const [expanded, setExpanded] = useState<boolean>(true);
    const [rows, setRows] = useState<ITableRow[]>(ROWS.slice(0, 3));

    return (
        <>
            <Button
                className="mb-3"
                onClick={(): void => {
                    setRows((prevState): ITableRow[] => [
                        ...prevState,
                        {
                            ...ROWS[prevState.length % ROWS.length],
                            identifier: prevState.length + 1
                        }
                    ]);
                }}
            >
                Add Item
            </Button>
            <Button
                className="mb-3"
                disabled={rows.length === 0}
                onClick={(): void => {
                    setRows((prevState): ITableRow[] => prevState.slice(0, -1));
                }}
            >
                Remove Item
            </Button>
            <ExpandableCard
                dataUI="dynamic-content-expandable-card"
                expandableContent={
                    <ListTable
                        columns={COLUMNS}
                        rows={rows}
                        theme={ListTableTheme.Simple}
                    />
                }
                isExpanded={expanded}
                onExpand={setExpanded}
            >
                <h3>List of Items</h3>
            </ExpandableCard>
        </>
    );
}

export default DynamicListTableExpandableCard;
