import React from 'react';

import {
    LoadingIndicator,
    LoadingTheme,
    TextField,
    TextFieldType
} from '@preamp/core';

interface LoadingExample {
    determinateScaleNumber: string;
    determinateColorPrimary: string;
    determinateColorSecondary: string;
}

class IndeterminateLoadingIndicator extends React.Component<
    {},
    LoadingExample
> {
    state: LoadingExample = {
        determinateScaleNumber: '2',
        determinateColorPrimary: 'var(--va-loading-default-color)',
        determinateColorSecondary: 'var(--va-loading-default-color-secondary)'
    };
    onDeterminateScaleChange = (
        event?: React.ChangeEvent<HTMLInputElement>
    ): void => {
        this.setState({
            determinateScaleNumber: event.currentTarget.value
        });
    };
    onDeterminatePrimaryColorChange = (
        event?: React.ChangeEvent<HTMLInputElement>
    ): void => {
        this.setState({
            determinateColorPrimary: event.currentTarget.value
        });
    };
    onDeterminateSecondaryColorChange = (
        event?: React.ChangeEvent<HTMLInputElement>
    ): void => {
        this.setState({
            determinateColorSecondary: event.currentTarget.value
        });
    };

    render(): React.ReactNode {
        return (
            <>
                <div>Indeterminate Loading Indicator</div>
                <h4>Large</h4>
                <LoadingIndicator
                    color={this.state.determinateColorPrimary}
                    colorSecondary={this.state.determinateColorSecondary}
                    scale={parseFloat(this.state.determinateScaleNumber)}
                    theme={LoadingTheme.Large}
                />
                <h4 className="mt-4">Small</h4>
                <LoadingIndicator
                    color={this.state.determinateColorPrimary}
                    colorSecondary={this.state.determinateColorSecondary}
                    scale={parseFloat(this.state.determinateScaleNumber)}
                    theme={LoadingTheme.Small}
                />
                <div className="va-grid va-columns-default mt-4">
                    <div className="col-span-3">
                        <TextField
                            helpText="Base 100px for Large, 10px for Small"
                            label="Scale"
                            onChange={this.onDeterminateScaleChange}
                            textFieldType={TextFieldType.Number}
                            value={this.state.determinateScaleNumber}
                        />
                    </div>
                    <div className="col-span-3">
                        <TextField
                            helpText="Enter CSS Custom Property or hex value"
                            label="Color"
                            onChange={this.onDeterminatePrimaryColorChange}
                            textFieldType={TextFieldType.Text}
                            value={this.state.determinateColorPrimary}
                        />
                    </div>
                    <div className="col-span-3">
                        <TextField
                            helpText="Enter CSS Custom Property or hex value"
                            label="Secondary Color"
                            onChange={this.onDeterminateSecondaryColorChange}
                            textFieldType={TextFieldType.Text}
                            value={this.state.determinateColorSecondary}
                        />
                    </div>
                </div>
            </>
        );
    }
}

export default IndeterminateLoadingIndicator;
