import React from 'react';

import {
    Button,
    ButtonTheme,
    LoadingIndicator,
    LoadingStatus,
    LoadingTheme
} from '@preamp/core';

interface LoadingExample {
    status: LoadingStatus;
}

class IndeterminateLoadingIndicator extends React.Component<
    {},
    LoadingExample
> {
    state: LoadingExample = {
        status: LoadingStatus.Loading
    };

    progressSuccess = (): void => {
        this.setState({ status: LoadingStatus.Success });
    };
    progressError = (): void => {
        this.setState({ status: LoadingStatus.Error });
    };
    setIndeterminate = (): void => {
        this.setState({ status: LoadingStatus.Loading });
    };
    afterSuccess = (): void => {
        alert('Woohoo! Success event!');
    };
    afterError = (): void => {
        alert('Oh no! Error event!');
    };

    render(): React.ReactNode {
        return (
            <>
                <div>Determinate Loading Indicator - Status</div>
                <h4>Large</h4>
                <LoadingIndicator
                    errorEvent={this.afterError}
                    scale={2}
                    status={this.state.status}
                    successEvent={this.afterSuccess}
                    theme={LoadingTheme.Large}
                />
                <h4 className="mt-4">Small</h4>
                <LoadingIndicator
                    scale={3.6}
                    status={this.state.status}
                    theme={LoadingTheme.Small}
                />
                <div className="va-grid va-columns-default mt-4">
                    <div className="col-span-12">
                        <Button
                            onClick={this.progressSuccess}
                            theme={ButtonTheme.Success}
                        >
                            Click for Success
                        </Button>
                        <Button
                            onClick={this.progressError}
                            theme={ButtonTheme.Destructive}
                        >
                            Click for Error
                        </Button>
                        <Button
                            onClick={this.setIndeterminate}
                            theme={ButtonTheme.Secondary}
                        >
                            Indeterminate
                        </Button>
                    </div>
                </div>
            </>
        );
    }
}

export default IndeterminateLoadingIndicator;
