import React from 'react';

import {
    LoadingIndicator,
    LoadingStatus,
    LoadingTheme,
    TextField,
    TextFieldType
} from '@preamp/core';

interface LoadingExample {
    determinateProgressNumber: number;
    status: LoadingStatus;
}

class IndeterminateLoadingIndicator extends React.Component<
    {},
    LoadingExample
> {
    state: LoadingExample = {
        determinateProgressNumber: 0,
        status: LoadingStatus.Loading
    };

    onDeterminateProgressChange = (
        event?: React.ChangeEvent<HTMLInputElement>
    ): void => {
        this.setState({
            determinateProgressNumber: parseFloat(event.currentTarget.value)
        });
        if (parseFloat(event.currentTarget.value) >= 100) {
            this.setState({ determinateProgressNumber: 100 });
            this.setState({ status: LoadingStatus.Success });
        } else {
            this.setState({ status: LoadingStatus.Loading });
        }
    };

    render(): React.ReactNode {
        return (
            <>
                <div>Determinate Loading Indicator - Progress Demo</div>
                <h4>Large</h4>
                <LoadingIndicator
                    progress={this.state.determinateProgressNumber}
                    scale={1.5}
                    status={this.state.status}
                    theme={LoadingTheme.Large}
                />
                <h4 className="mt-4">Small</h4>
                <LoadingIndicator
                    progress={this.state.determinateProgressNumber}
                    scale={3.6}
                    status={this.state.status}
                    theme={LoadingTheme.Small}
                />
                <div className="va-grid va-columns-default mt-4">
                    <div className="col-span-3">
                        <TextField
                            helpText="Enter a value for the progress prop"
                            label="Progress"
                            max={'100'}
                            min={'0'}
                            onChange={this.onDeterminateProgressChange}
                            textFieldType={TextFieldType.Number}
                        />
                    </div>
                </div>
            </>
        );
    }
}

export default IndeterminateLoadingIndicator;
