import React, { ReactElement, useState } from 'react';

import { Checkbox, Meter, Slider } from '@preamp/core';

/**
 * Basic example of the Meter component
 */
function BasicMeter(): ReactElement {
    const [max, setMax] = useState<number>(100);
    const [min, setMin] = useState<number>(0);
    const [optimum, setOptimum] = useState<number>(60);
    const [shouldShowLabels, setShouldShowLabels] = useState<boolean>(true);
    const [
        shouldShowTooltipPercentage,
        setShouldShowTooltipPercentage
    ] = useState<boolean>(true);
    const [shouldShowTooltipValue, setShouldShowTooltipValue] = useState<
        boolean
    >(true);
    const [value, setValue] = useState<number>(40);

    return (
        <>
            <div className="flex my-4">
                <Checkbox
                    checked={shouldShowLabels}
                    label="Show Labels"
                    name="shouldShowLabels"
                    onChange={(isChecked: boolean): void => {
                        setShouldShowLabels(isChecked);
                    }}
                />
                <Checkbox
                    checked={shouldShowTooltipPercentage}
                    className="ml-8"
                    label="Show Percentage in Tooltip"
                    name="shouldShowLabels"
                    onChange={(isChecked: boolean): void => {
                        setShouldShowTooltipPercentage(isChecked);
                    }}
                />
                <Checkbox
                    checked={shouldShowTooltipValue}
                    className="ml-8"
                    label="Show Value in Tooltip"
                    name="shouldShowLabels"
                    onChange={(isChecked: boolean): void => {
                        setShouldShowTooltipValue(isChecked);
                    }}
                />
            </div>
            <Meter
                label="Blue"
                max={max}
                min={min}
                optimum={optimum}
                shouldShowLabels={shouldShowLabels}
                shouldShowTooltipPercentage={shouldShowTooltipPercentage}
                shouldShowTooltipValue={shouldShowTooltipValue}
                tooltipTitle="Totals"
                value={value}
            />
            <div className="mt-4">
                <Slider
                    className="mt-4"
                    currentValue={min}
                    isSingleThumb
                    label="Min"
                    max={100}
                    min={0}
                    onChange={setMin}
                    step={10}
                />
                <Slider
                    className="mt-4"
                    currentValue={max}
                    isSingleThumb
                    label="Max"
                    max={100}
                    min={0}
                    onChange={setMax}
                    step={10}
                />
                <Slider
                    className="mt-4"
                    currentValue={value}
                    isSingleThumb
                    label="Value"
                    max={100}
                    min={0}
                    onChange={setValue}
                    step={10}
                />
                <Slider
                    className="mt-4"
                    currentValue={optimum}
                    isSingleThumb
                    label="Optimum"
                    max={100}
                    min={0}
                    onChange={setOptimum}
                    step={10}
                />
            </div>
        </>
    );
}

export default BasicMeter;
