import React, { ReactElement, useState } from 'react';

import {
    MetricGrid,
    MetricTypes,
    TextField,
    TextFieldType,
    Toggle
} from '@preamp/core';

const EXAMPLE_METRICS: MetricTypes[] = [
    {
        items: [
            {
                id: '1',
                metric: '2.475M',
                label: 'Impressions'
            },
            {
                id: '2',
                metric: '1.123M',
                label: 'HH Reach'
            },
            {
                id: '3',
                metric: '85%',
                label: 'HH Reach %'
            },
            {
                id: '4',
                metric: '$2.456M',
                label: 'Estimated Spend'
            },
            {
                id: '5',
                metric: '$999',
                label: 'Impression CPM'
            },
            {
                id: '6',
                metric: '85%',
                label: 'HH Reach %'
            },
            {
                id: '7',
                metric: '$2.456M',
                label: 'Estimated Spend'
            },
            {
                id: '8',
                metric: '$999',
                label: 'Impression CPM'
            }
        ]
    },
    {
        group: 'Group Titles will span the entire row',
        items: [
            {
                id: '9',
                metric: '2.075M',
                label: 'On-Target Impressions'
            },
            {
                id: '10',
                metric: '923.2K',
                secondaryMetric: '84%',
                label: 'On-Target HH Reach'
            },
            {
                id: '1',
                metric: '67%',
                label: 'On-Target HH Reach %'
            },
            {
                id: '11',
                metric: '$2.255M',
                label: 'Estimated Spend'
            },
            {
                id: '12',
                metric: '$1,300',
                label: 'On-Target Impression CPM'
            }
        ]
    }
];

const emptyMetricList: MetricTypes[] = [];

/**
 * Basic example of the Metric Grid component
 */
function BasicMetricGrid(): ReactElement {
    const [columnGutterValue, setColumnGutterValue] = useState('3.5rem');
    const [labelMaxWidthValue, setLabelMaxWidthValue] = useState('100%');
    const [maxWidthValue, setMaxWidthValue] = useState('768px');
    const [isLoading, setLoading] = useState(false);

    function onMaxWidthChange(
        event?: React.ChangeEvent<HTMLInputElement>
    ): void {
        setMaxWidthValue(event.currentTarget.value);
    }
    function onLabelMaxWidthChange(
        event?: React.ChangeEvent<HTMLInputElement>
    ): void {
        setLabelMaxWidthValue(event.currentTarget.value);
    }
    function onColumnGutterhange(
        event?: React.ChangeEvent<HTMLInputElement>
    ): void {
        setColumnGutterValue(event.currentTarget.value);
    }

    function toggleLoading(): void {
        setLoading(!isLoading);
    }

    return (
        <div className="py-8">
            <div className="mb-6">
                <Toggle
                    checked={isLoading}
                    label="Simulate Loading State"
                    name="loading-state"
                    onChange={toggleLoading}
                />
            </div>
            <MetricGrid
                className="metric-grid-class"
                columnGutter={columnGutterValue}
                isLoading={isLoading}
                labelMaxWidth={labelMaxWidthValue}
                maxWidth={maxWidthValue}
                metricList={EXAMPLE_METRICS}
            />
            <div className="va-grid va-columns-default mt-4">
                <div className="col-span-3">
                    <div className="mb-6">
                        <TextField
                            helpText="The maxWidth prop adjusts the 'max-width' style value - default is 768px"
                            label="Max-Width"
                            onChange={onMaxWidthChange}
                            textFieldType={TextFieldType.Text}
                            value={maxWidthValue}
                        />
                    </div>
                </div>
                <div className="col-span-3">
                    <div className="mb-6">
                        <TextField
                            helpText="The columnGutter prop adjusts the 'grid-column-gap' style value - default is 3.5rem"
                            label="Gutter Width"
                            onChange={onColumnGutterhange}
                            textFieldType={TextFieldType.Text}
                            value={columnGutterValue}
                        />
                    </div>
                </div>
                <div className="col-span-3">
                    <div className="mb-6">
                        <TextField
                            helpText="The labelMaxWidth prop adjusts the 'max-width' style value of the lables - default is 100%"
                            label="Label max width"
                            onChange={onLabelMaxWidthChange}
                            textFieldType={TextFieldType.Text}
                            value={labelMaxWidthValue}
                        />
                    </div>
                </div>
            </div>
            <h3 className="py-6">
                If the list has no items, the emptyMessage will display:
            </h3>
            <MetricGrid
                emptyMessage="Sorry, there are no metrics available."
                metricList={emptyMetricList}
            />
        </div>
    );
}

export default BasicMetricGrid;
