import React, { ReactElement } from 'react';

import { MetricGrid, MetricItemTypes } from '@preamp/core';
import { CheckCircle, Error, Information, Signal } from '@preamp/signal';

/**
 * Example of the Metric Grid component with custom labels
 */
function MetricGridCustomLabelsExample(): ReactElement {
    const simpleLabel = 'simple label';
    const iconLabel = (
        <div className="flex items-center">
            <Signal className="mr-1" icon={Information} size={1.5} />
            <span>label with an icon</span>
        </div>
    );

    const longIconLabel = (
        <div className="flex items-center u-border-default p-1">
            <Signal className="mr-1" icon={CheckCircle} size={1} />
            <span>a very long label with an icon</span>
        </div>
    );

    const borderedLabel = (
        <div className="u-border-default text-center">
            label in a bordered container
        </div>
    );

    const complexLabel = (
        <div className="flex items-center p-1">
            <Signal
                className="mr-1"
                color="var(--va-teal-300)"
                colorSecondary="red"
                icon={Error}
                size={1.5}
            />
            <div
                style={{
                    textTransform: 'none',
                    fontSize: 12,
                    fontFamily: 'var(font-semibold)'
                }}
            >
                Another Label
            </div>
        </div>
    );

    const metricItems: MetricItemTypes[] = [
        simpleLabel,
        iconLabel,
        longIconLabel,
        borderedLabel,
        complexLabel
    ].map(
        (label: React.ReactChild, index: number): MetricItemTypes => ({
            id: `${index}`,
            label,
            metric: '1.234K',
            secondaryMetric: index === 4 ? '/ 87%' : undefined
        })
    );

    return (
        <MetricGrid
            labelMaxWidth={'150px'}
            maxWidth="100%"
            metricList={[{ items: metricItems }]}
        />
    );
}

export default MetricGridCustomLabelsExample;
