import * as React from 'react';

import { OverflowShadow } from '@preamp/core';

const CONTENT_WITH_X_OVERFLOW = (
    <div className="u-body-2" style={{ width: '200%' }}>
        This content is overflowing parent
    </div>
);

const CONTENT_WITH_XY_OVERFLOW = (
    <div className="u-body-2" style={{ width: '200%', height: '200%' }}>
        This content is overflowing parent
    </div>
);

/**
 * Set horizontal shadows to a scrollable HTML element
 */
function BasicOverflowShadowExample(): React.ReactElement {
    const xOverflowContainerRef = React.useRef<HTMLDivElement>();
    const colorContainerRef = React.useRef<HTMLDivElement>();
    const xyOverflowContainerRef = React.useRef<HTMLDivElement>();

    return (
        <>
            <div className="font-bold mb-2 mt-12">
                Example 1: Horizontal overflow shadows
            </div>
            <OverflowShadow scrollableContainer={xOverflowContainerRef}>
                <div
                    className="w-full overflow-auto px-4 h-24 u-border-default"
                    ref={xOverflowContainerRef}
                >
                    {CONTENT_WITH_X_OVERFLOW}
                </div>
            </OverflowShadow>

            <div className="font-bold mb-2 mt-12">
                Example 2: Horizontal overflow shadows for a container with
                background color
            </div>
            <OverflowShadow scrollableContainer={colorContainerRef}>
                <div
                    className="w-full overflow-auto px-4 h-24 u-border-default"
                    ref={colorContainerRef}
                    style={{
                        backgroundColor: '#d3d3d3'
                    }}
                >
                    {CONTENT_WITH_X_OVERFLOW}
                </div>
            </OverflowShadow>

            <div className="font-bold mb-2 mt-12">
                Example 3: Horizontal overflow shadows for a container with
                vertical scrollbar
            </div>
            <OverflowShadow scrollableContainer={xyOverflowContainerRef}>
                <div
                    className="w-full overflow-auto px-4 h-24 u-border-default"
                    ref={xyOverflowContainerRef}
                >
                    {CONTENT_WITH_XY_OVERFLOW}
                </div>
            </OverflowShadow>
        </>
    );
}

export default BasicOverflowShadowExample;
