import React, { ReactElement, useState } from 'react';

import { Button, ButtonTheme, Panel } from '@preamp/core';

/**
 * Examples of the Panel component in different states
 */
function ExamplePanel(): ReactElement<{}> {
    const [count, setCount] = useState(0);

    function clickButton(): void {
        setCount(count + 1);
    }

    return (
        <>
            <Panel header="Panel with header and no content" />
            <Panel>
                <p className="va-body-1 mb-4">
                    Panel with only content. Lorem ipsum dolor sit amet,
                    consectetur adipiscing elit.
                </p>
                <p className="va-body-1">
                    Suspendisse dolor arcu, luctus et nibh vel, consequat
                    feugiat diam. Aenean rutrum, est eu rhoncus gravida, nulla
                    eros finibus turpis, in fermentum dolor leo nec magna. Morbi
                    vel ex at eros commodo fringilla a at sapien. Vestibulum
                    fermentum nisi nisi, ac dictum turpis placerat at. In
                    facilisis facilisis ipsum non euismod. Duis non mauris
                    pretium, pretium ante sed, molestie dolor. Nulla facilisi.
                </p>
            </Panel>
            <Panel
                action={
                    <Button
                        dataUI="primary"
                        onClick={clickButton}
                        theme={ButtonTheme.Primary}
                    >
                        Button
                    </Button>
                }
                header="Panel with header, action and content"
            >
                <p className="va-body-1 mb-4">
                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                    Suspendisse dolor arcu, luctus et nibh vel, consequat
                    feugiat diam. Aenean rutrum, est eu rhoncus gravida, nulla
                    eros finibus turpis, in fermentum dolor leo nec magna. Morbi
                    vel ex at eros commodo fringilla a at sapien. Vestibulum
                    fermentum nisi nisi, ac dictum turpis placerat at. In
                    facilisis facilisis ipsum non euismod. Duis non mauris
                    pretium, pretium ante sed, molestie dolor. Nulla facilisi.
                    Integer non iaculis arcu. Donec faucibus nulla ut nunc
                    euismod dictum.
                </p>
                <p className="va-body-2">Button Clicks: {count}</p>
            </Panel>
            <Panel
                footer={
                    <>
                        <Button className="mr-2" theme={ButtonTheme.Link}>
                            Footer Link 1
                        </Button>
                        <Button theme={ButtonTheme.Link}>Footer Link 2</Button>
                    </>
                }
                header="Panel with footer"
            >
                <p className="va-body-1">
                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                    Suspendisse dolor arcu, luctus et nibh vel, consequat
                    feugiat diam. Aenean rutrum, est eu rhoncus gravida, nulla
                    eros finibus turpis, in fermentum dolor leo nec magna. Morbi
                    vel ex at eros commodo fringilla a at sapien. Vestibulum
                    fermentum nisi nisi, ac dictum turpis placerat at. In
                    facilisis facilisis ipsum non euismod. Duis non mauris
                    pretium, pretium ante sed, molestie dolor. Nulla facilisi.
                    Integer non iaculis arcu. Donec faucibus nulla ut nunc
                    euismod dictum.
                </p>
            </Panel>
        </>
    );
}

export default ExamplePanel;
