import React from 'react';

import { Button, ButtonTheme, Panel } from '@preamp/core';

/**
 * Examples of the Panel component with fullBleed
 */
export const FullBleedPanelExample: React.FC = (): React.ReactElement => {
    return (
        <>
            <div className="bg-va-grey-200 p-8">
                <Panel fullBleed>
                    <div className="va-body-1 text-justify">
                        Panel with fullBleed and only content.
                    </div>
                    <p className="va-body-1 text-justify">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                </Panel>
            </div>

            <div className="bg-va-grey-200 p-8 mt-4">
                <Panel
                    action={
                        <Button
                            dataUI="primary"
                            onClick={(): void => {}}
                            theme={ButtonTheme.Primary}
                        >
                            Action
                        </Button>
                    }
                    footer={
                        <Button theme={ButtonTheme.Link}>Footer Link</Button>
                    }
                    fullBleed
                    header="Panel with fullBleed. Also header, actions and footer."
                >
                    <p className="va-body-1 text-justify">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                </Panel>
            </div>

            <div className="bg-va-grey-200 p-8 mt-4">
                <Panel
                    action={
                        <Button
                            className="m-4"
                            dataUI="primary"
                            onClick={(): void => {}}
                            theme={ButtonTheme.Primary}
                        >
                            Action
                        </Button>
                    }
                    fillHeight
                    footer={
                        <Button className="m-2 mr-4" theme={ButtonTheme.Link}>
                            Footer Link
                        </Button>
                    }
                    fullBleed
                    header={
                        <div className="m-4">
                            Panel with fullBleed with custom alignments.
                        </div>
                    }
                >
                    <p className="va-body-1 text-justify mb-4">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                </Panel>
            </div>

            <div className="bg-va-grey-200 p-8 mt-4" style={{ height: 250 }}>
                <Panel
                    fillHeight
                    fullBleed
                    header="Panel with fullBleed and overflow scrolling"
                >
                    <p className="va-body-1 text-justify">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                    <p className="va-body-1 text-justify pt-8">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                    <p className="va-body-1 text-justify pt-8">
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                        Suspendisse dolor arcu, luctus et nibh vel, consequat
                        feugiat diam. Aenean rutrum, est eu rhoncus gravida,
                        nulla eros finibus turpis, in fermentum dolor leo nec
                        magna. Morbi vel ex at eros commodo fringilla a at
                        sapien. Vestibulum fermentum nisi nisi, ac dictum turpis
                        placerat at. In facilisis facilisis ipsum non euismod.
                        Duis non mauris pretium, pretium ante sed, molestie
                        dolor. Nulla facilisi. Integer non iaculis arcu. Donec
                        faucibus nulla ut nunc euismod dictum.
                    </p>
                </Panel>
            </div>
        </>
    );
};

export default FullBleedPanelExample;
