import React from 'react';

import { Checkbox, IconButton, Pill } from '@preamp/core';
import { Add, Clear } from '@preamp/signal';

interface ExamplePillState {
    shouldAppend: boolean;
    shouldPrepend: boolean;
}

/**
 * Examples of the Pill component in different states
 */
class ExamplePill extends React.Component<{}, ExamplePillState> {
    state: ExamplePillState = {
        shouldAppend: true,
        shouldPrepend: true
    };

    onClickHandler(event: React.MouseEvent<HTMLElement>): void {
        // eslint-disable-next-line no-console
        console.log('onClickHandler', event);
    }

    onMouseDownHandler(event: React.MouseEvent<HTMLElement>): void {
        // eslint-disable-next-line no-console
        console.log('onMouseDownHandler', event);
    }

    toggleAppend = (): void => {
        this.setState((prevState: ExamplePillState): any => ({
            shouldAppend: !prevState.shouldAppend
        }));
    };

    togglePrepend = (): void => {
        this.setState((prevState: ExamplePillState): any => ({
            shouldPrepend: !prevState.shouldPrepend
        }));
    };

    render(): React.ReactNode {
        const append: React.ReactNode = (
            <IconButton icon={Clear} onClick={this.onClickHandler} />
        );
        const prepend: React.ReactNode = (
            <IconButton icon={Add} onClick={this.onClickHandler} />
        );

        return (
            <>
                <p>Pill</p>
                <Pill
                    append={this.state.shouldAppend ? append : null}
                    onClick={this.onClickHandler}
                    onMouseDown={this.onMouseDownHandler}
                    prepend={this.state.shouldPrepend ? prepend : null}
                    tabIndex={0}
                >
                    A Pill
                </Pill>
                <br />
                <br />
                <Checkbox
                    checked={this.state.shouldPrepend}
                    label="Show prepend"
                    name="prepend"
                    onChange={this.togglePrepend}
                />
                <Checkbox
                    checked={this.state.shouldAppend}
                    label="Show append"
                    name="append"
                    onChange={this.toggleAppend}
                />
            </>
        );
    }
}

export default ExamplePill;
