import React, { ReactElement, useState } from 'react';

import { Button, ButtonTheme, ProcessGauge } from '@preamp/core';

/**
 * Examples of the Process Gauge component in different states
 */
function ExampleProcessGauge(): ReactElement<{}> {
    const [isLoading, setIsLoading] = useState(true);

    React.useEffect((): (() => void) => {
        if (isLoading) {
            const timer: any = setTimeout((): void => {
                setIsLoading(false);
            }, 500);

            return (): void => clearTimeout(timer);
        }
    }, [isLoading]);

    function simulateLoad(): void {
        setIsLoading(true);
    }

    return (
        <>
            <div className="va-grid va-columns-default my-4">
                <div className="col-span-3">
                    <ProcessGauge
                        label="Under pacing"
                        status={!isLoading && 25}
                    />
                </div>
                <div className="col-span-3">
                    <ProcessGauge label="On pace" status={!isLoading && 50} />
                </div>
                <div className="col-span-3">
                    <ProcessGauge
                        label="Over pacing"
                        status={!isLoading && 75}
                    />
                </div>
            </div>
            <Button onClick={simulateLoad} theme={ButtonTheme.Primary}>
                Simulate Loading
            </Button>
        </>
    );
}

export default ExampleProcessGauge;
