import React, { useState } from 'react';

import {
    IconButtonProps,
    RightRail,
    RightRailTheme,
    Button,
    ButtonTheme
} from '@preamp/core';
import { Edit, Trash } from '@preamp/signal';

function onClick(): void {
    // eslint-disable-next-line no-console
    console.log('Header Action Clicked');
}

const headerActions: IconButtonProps[] = [
    {
        icon: Trash,
        onClick: onClick
    },
    {
        icon: Edit,
        onClick: onClick
    }
];

/**
 * Examples of the RightRail
 */
function ExampleRightRail(): React.ReactNode {
    const [active, setActive] = useState(true);

    function activeToggle(): void {
        setActive(!active);
    }

    function handleClick(): void {
        // eslint-disable-next-line no-console
        console.log('Action Clicked');
    }

    return (
        <>
            <section className="mb-6" style={{ maxWidth: '256px' }}>
                <RightRail
                    isActive={active}
                    title="A Title with an extremely really really really long name"
                    titleToolTip
                >
                    <div className="mb-6">
                        <h3 className="subtitle">Subtitle</h3>
                        <div>Page without action</div>
                    </div>
                    <div className="mb-6">
                        <h3 className="subtitle">Another Subtitle</h3>
                        <div className="mb-1">Content of this section</div>
                        <div className="description">
                            .va-border and .va-border--left are applied to this
                            RightRail
                        </div>
                    </div>
                    <div>
                        <h3 className="subtitle">Another Subtitle</h3>
                        <ul>
                            <li>An item in a list</li>
                            <li>An item in a list</li>
                            <li>An item in a list</li>
                        </ul>
                    </div>
                </RightRail>
                <Button
                    className="mt-4"
                    dataUI="active-toggle"
                    onClick={activeToggle}
                    theme={ButtonTheme.Link}
                >
                    Set isActive to {active ? `false` : `true`}
                </Button>
            </section>
            <section className="mb-6" style={{ maxWidth: '256px' }}>
                <RightRail
                    action={{
                        title: 'An Action',
                        onClick: handleClick
                    }}
                    title="A Page Title"
                >
                    Page with action
                </RightRail>
            </section>
            <section className="mb-6" style={{ maxWidth: '256px' }}>
                <RightRail
                    action={{
                        title: 'An Action',
                        onClick: handleClick
                    }}
                    headerActions={headerActions}
                    title="A Page Title with Truncated Text"
                    titleToolTip
                >
                    Page with action and header actions
                </RightRail>
            </section>
            <section className="mb-6" style={{ maxWidth: '256px' }}>
                <RightRail theme={RightRailTheme.Item} title="An Item Title">
                    Item without action
                </RightRail>
            </section>
            <section className="mb-6" style={{ maxWidth: '256px' }}>
                <RightRail
                    action={{
                        title: 'An Action',
                        onClick: handleClick
                    }}
                    theme={RightRailTheme.Item}
                    title="An Item Title"
                >
                    Item with action
                </RightRail>
            </section>
            <section className="mb-6" style={{ maxWidth: '256px' }}>
                <RightRail
                    action={{
                        title: 'An Action',
                        onClick: handleClick
                    }}
                    headerActions={headerActions.slice(1, 2)}
                    theme={RightRailTheme.Item}
                    title="An Item Title with Truncated Text"
                    titleToolTip
                >
                    Header and Item with an action
                </RightRail>
            </section>
            <section className="mb-6" style={{ maxWidth: '256px' }}>
                <RightRail
                    action={{
                        title: 'An Action',
                        onClick: handleClick
                    }}
                    headerActions={headerActions}
                    theme={RightRailTheme.Item}
                    title="An Item Title with Truncated Text"
                    titleToolTip
                >
                    Header and Item with two actions
                </RightRail>
            </section>
            <section className="mb-6">
                <RightRail
                    action={{
                        title: 'An Action',
                        onClick: handleClick
                    }}
                    headerActions={headerActions}
                    theme={RightRailTheme.Item}
                    title="An Item Title with Responsive Width"
                >
                    Header and Item with two actions and responsive
                    (unrestricted) width
                </RightRail>
            </section>
        </>
    );
}

export default ExampleRightRail;
