import React from 'react';

import { Button, Pill, Tile, TileTheme } from '@preamp/core';
import { Account, Business, Explore, Poll } from '@preamp/signal';

import Icon1 from './icons/Icon1';

const SingleTile: React.FC = (): React.ReactElement => {
    function onClick(event: React.MouseEvent<HTMLElement>): void {
        // eslint-disable-next-line no-console
        console.log('onClick', event);
    }

    return (
        <div className="max-w-md" style={{ minWidth: '340px' }}>
            <section className="mb-6">
                <h4 className="mb-1">Basic Tile as Default Button</h4>
                <Tile
                    className="example-class"
                    dataUI="button-tile"
                    description="Tile rendered as a button element with the Default theme"
                    icon={Explore}
                    onClick={onClick}
                    title="Default Tile"
                />
            </section>
            <section className="mb-6">
                <h4 className="mb-1">Basic Tile as Anchor Link</h4>
                <Tile
                    className="example-class"
                    dataUI="anchor-tile"
                    description="Tile rendered as an anchor element with the Default theme"
                    href="https://www.videoamp.com"
                    icon={Account}
                    target="_blank"
                    title="Default Tile as Link"
                />
            </section>
            <section className="mb-6">
                <h4 className="mb-1">Tile with a non-text description</h4>
                <Tile
                    className="example-class"
                    dataUI="anchor-tile"
                    description={
                        <>
                            <p className="u-body-2">
                                Tile could be configured with a description to
                                contain HTML, text, or other React components.
                            </p>
                            <div className="flex justify-between mt-4">
                                <div>
                                    <Pill>Tile</Pill>
                                    <Pill>Non-text description</Pill>
                                </div>
                                <Button>Good to know!</Button>
                            </div>
                        </>
                    }
                    href="https://www.videoamp.com"
                    icon={Business}
                    target="_blank"
                    title="Default Tile with a non-text description"
                />
            </section>
            <section className="mb-6">
                <h4 className="mb-1">Tile with Wide theme applied</h4>
                <Tile
                    className="example-class"
                    dataUI="gradient-tile"
                    description="Tile rendered as a button element with the Wide theme, including a larger title and larger max-width for content"
                    icon={Poll}
                    onClick={onClick}
                    theme={TileTheme.Wide}
                    title="Wide Tile"
                />
            </section>
            <section className="mb-6">
                <h4 className="mb-1">Gradient Themed Tile</h4>
                <div className="p-10 bg-va-purple-500">
                    <Tile
                        className="example-class"
                        dataUI="gradient-tile"
                        description="Tile rendered as an anchor element with the Gradient theme"
                        href="https://www.videoamp.com"
                        icon={Icon1}
                        target="_blank"
                        theme={TileTheme.Gradient}
                        title="Gradient Tile"
                    />
                </div>
            </section>
        </div>
    );
};

export default SingleTile;
