import React from 'react';

import { Tile, TileTheme } from '@preamp/core';
import { Account, Business, Explore, Poll } from '@preamp/signal';

import Icon1 from './icons/Icon1';
import Icon2 from './icons/Icon2';
import Icon3 from './icons/Icon3';
import Icon4 from './icons/Icon4';
import Icon5 from './icons/Icon5';
import Icon6 from './icons/Icon6';
import Icon7 from './icons/Icon7';

const GridTiles: React.FC = (): React.ReactElement => {
    function onClick(event: React.MouseEvent<HTMLElement>): void {
        // eslint-disable-next-line no-console
        console.log('onClick', event);
    }

    return (
        <div className="mt-6" style={{ minWidth: '340px' }}>
            <section className="max-w-xl mb-6">
                <h4 className="mb-1">Grid Tile Layout with Default Theme</h4>
                <div className="va-grid va-columns-default">
                    <div className="col-span-12 col-span-lg-6">
                        <Tile
                            className="example-class"
                            dataUI="grid-default--1"
                            description="Tile rendered as a button element with the Default theme in a grid"
                            icon={Explore}
                            onClick={onClick}
                            title="Tile One"
                        />
                    </div>
                    <div className="col-span-12 col-span-lg-6">
                        <Tile
                            className="example-class"
                            dataUI="grid-default--2"
                            description="Tile rendered as a button element with the Default theme in a grid"
                            icon={Business}
                            onClick={onClick}
                            title="Tile Two"
                        />
                    </div>
                    <div className="col-span-12 col-span-lg-6">
                        <Tile
                            className="example-class"
                            dataUI="grid-default--3"
                            description="Tile rendered as a button element with the Default theme in a grid"
                            icon={Account}
                            onClick={onClick}
                            title="Tile Three"
                        />
                    </div>
                    <div className="col-span-12 col-span-lg-6">
                        <Tile
                            className="example-class"
                            dataUI="grid-default--4"
                            description="Tile rendered as a button element with the Default theme in a grid"
                            icon={Poll}
                            onClick={onClick}
                            title="Tile Four"
                        />
                    </div>
                </div>
            </section>
            <section className="mb-6">
                <h4 className="mb-1">
                    Grid Tile Layout with Dark Theme and DarkWide themed tile at
                    the top
                </h4>
                <div className="p-10 bg-va-grey-800">
                    <div className="max-w-xl ml-auto mr-auto va-grid va-columns-default">
                        <div className="col-span-12">
                            <Tile
                                className="example-class"
                                dataUI="grid-gradient--1"
                                description="Tile rendered as an anchor element with the GradientWide theme in a grid, includes larger title and max-width on content"
                                href="https://www.videoamp.com"
                                icon={Icon1}
                                target="_blank"
                                theme={TileTheme.DarkWide}
                                title="Tile One"
                            />
                        </div>
                        <div className="col-span-12 col-span-lg-6">
                            <Tile
                                className="example-class"
                                dataUI="grid-gradient--2"
                                description="Tile rendered as an anchor element with the Gradient theme in a grid"
                                href="https://www.videoamp.com"
                                icon={Icon2}
                                target="_blank"
                                theme={TileTheme.Dark}
                                title="Tile Two"
                            />
                        </div>
                        <div className="col-span-12 col-span-lg-6">
                            <Tile
                                className="example-class"
                                dataUI="grid-gradient--3"
                                description="Tile rendered as an anchor element with the Gradient theme in a grid"
                                href="https://www.videoamp.com"
                                icon={Icon3}
                                target="_blank"
                                theme={TileTheme.Dark}
                                title="Tile Three"
                            />
                        </div>
                        <div className="col-span-12 col-span-lg-6">
                            <Tile
                                className="example-class"
                                dataUI="grid-gradient--4"
                                description="Tile rendered as an anchor element with the Gradient theme in a grid"
                                href="https://www.videoamp.com"
                                icon={Icon4}
                                target="_blank"
                                theme={TileTheme.Dark}
                                title="Tile Four"
                            />
                        </div>
                        <div className="col-span-12 col-span-lg-6">
                            <Tile
                                className="example-class"
                                dataUI="grid-gradient--5"
                                description="Tile rendered as an anchor element with the Gradient theme in a grid"
                                href="https://www.videoamp.com"
                                icon={Icon5}
                                target="_blank"
                                theme={TileTheme.Dark}
                                title="Tile Five"
                            />
                        </div>

                        <div className="col-span-12 col-span-lg-6">
                            <Tile
                                className="example-class"
                                dataUI="grid-gradient--6"
                                description="Tile rendered as an anchor element with the Gradient theme in a grid"
                                href="https://www.videoamp.com"
                                icon={Icon6}
                                target="_blank"
                                theme={TileTheme.Dark}
                                title="Tile Six"
                            />
                        </div>
                        <div className="col-span-12 col-span-lg-6">
                            <Tile
                                className="example-class"
                                dataUI="grid-gradient--7"
                                description="Tile rendered as an anchor element with the Gradient theme in a grid"
                                href="https://www.videoamp.com"
                                icon={Icon7}
                                target="_blank"
                                theme={TileTheme.Dark}
                                title="Tile Seven"
                            />
                        </div>
                    </div>
                </div>
            </section>
        </div>
    );
};

export default GridTiles;
