import * as React from 'react';

import { Placement } from 'popper.js';

import {
    Button,
    Checkbox,
    RadioButton,
    PillButton,
    PillButtonGroup,
    PillTheme,
    Tooltip,
    TooltipTheme
} from '@preamp/core';

/**
 * Examples of the Tooltip placements, themes, and arrows
 */
const MultiDirectionTooltips: React.FunctionComponent<any> = (): React.ReactElement => {
    const [hasArrow, setHasArrow] = React.useState<boolean>(true);
    const [placement, setPlacement] = React.useState<Placement>('top');
    const [theme, setTheme] = React.useState<TooltipTheme>(
        TooltipTheme.Primary
    );

    function getPillButtonTheme(value: string): PillTheme {
        return theme === value ? PillTheme.Active : PillTheme.Default;
    }

    function onThemeChange([selectedTheme]: TooltipTheme[]): void {
        setTheme(selectedTheme);
    }

    function onArrowChange(isChecked: boolean): void {
        setHasArrow(isChecked);
    }

    return (
        <>
            <PillButtonGroup
                name="Theme Select"
                onChange={onThemeChange}
                selectedValues={[theme]}
                title="Theme:"
            >
                <PillButton
                    key={TooltipTheme.Primary}
                    label="Primary"
                    theme={getPillButtonTheme(TooltipTheme.Primary)}
                    value={TooltipTheme.Primary}
                />
                <PillButton
                    key={TooltipTheme.Alert}
                    label="Alert"
                    theme={getPillButtonTheme(TooltipTheme.Alert)}
                    value={TooltipTheme.Alert}
                />
                <PillButton
                    key={TooltipTheme.Error}
                    label="Error"
                    theme={getPillButtonTheme(TooltipTheme.Error)}
                    value={TooltipTheme.Error}
                />
                <PillButton
                    key={TooltipTheme.Light}
                    label="Light"
                    theme={getPillButtonTheme(TooltipTheme.Light)}
                    value={TooltipTheme.Light}
                />
            </PillButtonGroup>
            <div className="mt-4">
                <Checkbox
                    checked={hasArrow}
                    label="Show Arrow"
                    name="hasArrow"
                    onChange={onArrowChange}
                />
            </div>
            <div
                style={{
                    alignItems: 'center',
                    display: 'grid',
                    gridTemplateColumns: '5rem 5rem 5rem 5rem 5rem',
                    gridTemplateRows: '5rem 5rem 5rem 5rem 5rem',
                    justifyItems: 'center'
                }}
            >
                {[
                    'top-start',
                    'top',
                    'top-end',
                    'right-start',
                    'right',
                    'right-end',
                    'bottom-end',
                    'bottom',
                    'bottom-start',
                    'left-end',
                    'left',
                    'left-start'
                ].map(
                    (radioPlacement: Placement): React.ReactElement => {
                        const [position, modifier] = radioPlacement.split('-');

                        function getColumn(
                            position: string,
                            modifier: string
                        ): number {
                            if (position === 'left') {
                                return 1;
                            }
                            if (position === 'right') {
                                return 5;
                            }
                            if (modifier === 'start') {
                                return 2;
                            }
                            if (modifier === 'end') {
                                return 4;
                            }

                            return 3;
                        }

                        function getRow(
                            position: string,
                            modifier: string
                        ): number {
                            if (position === 'top') {
                                return 1;
                            }
                            if (position === 'bottom') {
                                return 5;
                            }
                            if (modifier === 'start') {
                                return 2;
                            }
                            if (modifier === 'end') {
                                return 4;
                            }

                            return 3;
                        }

                        return (
                            <div
                                key={radioPlacement}
                                style={{
                                    gridColumn: getColumn(position, modifier),
                                    gridRow: getRow(position, modifier)
                                }}
                            >
                                <RadioButton
                                    checked={radioPlacement === placement}
                                    name={radioPlacement}
                                    onChange={(): void => {
                                        setPlacement(radioPlacement);
                                    }}
                                    style={{
                                        marginRight: 0
                                    }}
                                />
                            </div>
                        );
                    }
                )}
                <div
                    style={{
                        gridColumn: '2 / span 3',
                        gridRow: '2 / span 3'
                    }}
                >
                    <Tooltip
                        content="Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua."
                        hasArrow={hasArrow}
                        placement={placement}
                        referenceClassName="inline-block"
                        theme={theme}
                    >
                        <Button>Hover over me!</Button>
                    </Tooltip>
                </div>
            </div>
        </>
    );
};

export default MultiDirectionTooltips;
