import * as React from 'react';

import { Tooltip } from '@preamp/core';

interface IFollowingTipState {
    containerRef: HTMLElement;
}

/**
 * Example of a tooltip that's appended to .following-tooltip-container instead of <body>
 */

class FollowingTooltip extends React.Component<IFollowingTipState> {
    container: HTMLDivElement;

    state: IFollowingTipState = {
        containerRef: null
    };

    componentDidMount(): void {
        if (this.container) {
            this.setState({
                containerRef: this.container
            });
        }
    }

    render(): React.ReactElement {
        return (
            <>
                <style>
                    {`
                        .following-tooltip-container::-webkit-scrollbar {
                            -webkit-appearance: none;
                            width: 10px;
                        }
                        .following-tooltip-container::-webkit-scrollbar-thumb {
                            border-radius: 8px;
                            border: 2px solid white;
                            background-color: rgba(0, 0, 0, 0.5);
                        }
                    `}
                </style>
                <div className="m-2">
                    <div className="my-2">
                        <div
                            className="border border-solid overflow-y-auto relative following-tooltip-container"
                            ref={(container: HTMLDivElement): HTMLDivElement =>
                                (this.container = container)
                            }
                            style={{ width: 650, height: 200 }}
                        >
                            <div
                                className="flex items-center"
                                style={{ minHeight: '150%' }}
                            >
                                <div className="m-2">
                                    <Tooltip
                                        className="following-tooltip"
                                        content="Puma Punku vimana King Soloman electromagnetic"
                                        isVisible
                                        placement="right"
                                        shouldHandleEvents={false}
                                        style={{ maxWidth: 200 }}
                                        tooltipParent={this.state.containerRef}
                                    >
                                        <span className="border border-solid max-w-xs my-0 mr-1 p-1 text-xs">
                                            Annunaki Ezekiel, electromagnetic
                                            legendary times ancient civilization
                                        </span>
                                    </Tooltip>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </>
        );
    }
}

export default FollowingTooltip;
