import React, { ReactElement, useRef, useState } from 'react';

import { Tooltip, VirtualRef } from '@preamp/core';

// eslint-disable-next-line react/prop-types
function TableCell({ children, setRef }): ReactElement {
    const ref = useRef(null);

    return (
        <td
            onMouseEnter={(): void => {
                setRef(ref.current);
            }}
            onMouseLeave={(): void => {
                setRef(
                    (prevState: VirtualRef): VirtualRef =>
                        prevState === ref.current ? null : prevState
                );
            }}
            ref={ref}
        >
            {children}
        </td>
    );
}

/**
 * Example of the using the ReferenceElement prop.
 */
function ReferenceElement(): ReactElement {
    const [ref, setRef] = useState<VirtualRef>(null);

    return (
        <>
            <table>
                <tbody>
                    <tr>
                        <TableCell setRef={setRef}>foo</TableCell>
                        <TableCell setRef={setRef}>bar</TableCell>
                    </tr>
                    <tr>
                        <TableCell setRef={setRef}>baz</TableCell>
                        <TableCell setRef={setRef}>qux</TableCell>
                    </tr>
                </tbody>
            </table>
            <Tooltip
                content="Lorem ipsum dolor sit amet"
                hasArrow
                isVisible={Boolean(ref)}
                referenceElement={ref}
            />
        </>
    );
}

export default ReferenceElement;
