import React from 'react';

import dateFnsFormat from 'date-fns/format';

import {
    DateRange,
    DateRangePicker,
    SLASH_DATE_FORMAT
} from '@preamp/datepicker';

interface IDateRangePickerState {
    selectedDates: DateRange;
    confirmedDates: DateRange;
}
/**
 * Date Range Picker Example
 */
class ExampleDateRangePicker extends React.Component<
    {},
    IDateRangePickerState
> {
    state: IDateRangePickerState = {
        selectedDates: {
            from: null,
            to: null
        },
        confirmedDates: {
            from: null,
            to: null
        }
    };

    handleDayClick = (selectedDates: DateRange): void =>
        this.setState({
            selectedDates
        });

    onClearSelectedDates = (selectedDates: DateRange): void =>
        this.setState({
            selectedDates
        });

    onConfirmDates = (confirmedDates: DateRange): void =>
        this.setState({
            confirmedDates
        });

    formatDate = (day: Date): string => {
        if (!day) {
            return '';
        }

        return dateFnsFormat(day, SLASH_DATE_FORMAT);
    };

    render(): React.ReactNode {
        const { selectedDates, confirmedDates } = this.state;

        const fromDate: string = this.formatDate(selectedDates.from);
        const toDate: string = this.formatDate(selectedDates.to);
        const confirmedFromDate: string = this.formatDate(confirmedDates.from);
        const confirmedToDate: string = this.formatDate(confirmedDates.to);

        return (
            <>
                <div className="mt-4 mb-4">
                    <DateRangePicker
                        handleDayClick={this.handleDayClick}
                        id="date-range-picker"
                        initialMonth={new Date(2014, 5, 1)}
                        isOptional
                        label="Select a date range"
                        onClearSelectedDates={this.onClearSelectedDates}
                        onConfirmDates={this.onConfirmDates}
                    />
                </div>
                <div>{`Selected Date Range: ${fromDate} - ${toDate}`}</div>
                <div>{`Confirmed Date Range: ${confirmedFromDate} - ${confirmedToDate}`}</div>
            </>
        );
    }
}

export default ExampleDateRangePicker;
