import React from 'react';

import dateFnsFormat from 'date-fns/format';

import {
    DateRange,
    DateRangePicker,
    SLASH_DATE_FORMAT
} from '@preamp/datepicker';

interface DisabledDateRangePickerState {
    selectedDates: DateRange;
    confirmedDates: DateRange;
}
/**
 * Date Range Picker Example - Setting disabled dates & initial starting month
 */
class DisabledDateRangePicker extends React.Component<
    {},
    DisabledDateRangePickerState
> {
    state: DisabledDateRangePickerState = {
        selectedDates: {
            from: null,
            to: null
        },
        confirmedDates: {
            from: null,
            to: null
        }
    };

    handleDayClick = (selectedDates: DateRange): void =>
        this.setState({
            selectedDates
        });

    onClearSelectedDates = (selectedDates: DateRange): void =>
        this.setState({
            selectedDates
        });

    onConfirmDates = (confirmedDates: DateRange): void =>
        this.setState({
            confirmedDates
        });

    formatDate = (day: Date): string => {
        if (!day) {
            return '';
        }

        return dateFnsFormat(day, SLASH_DATE_FORMAT);
    };

    render(): React.ReactNode {
        const { selectedDates, confirmedDates } = this.state;

        const fromDate: string = this.formatDate(selectedDates.from);
        const toDate: string = this.formatDate(selectedDates.to);
        const confirmedFromDate: string = this.formatDate(confirmedDates.from);
        const confirmedToDate: string = this.formatDate(confirmedDates.to);

        const dateRangeStart: Date = new Date(2018, 11, 10);
        const dateRangeEnd: Date = new Date(2018, 11, 20);

        const validStartDate: string = this.formatDate(dateRangeStart);
        const validEndDate: string = this.formatDate(dateRangeEnd);

        return (
            <>
                <div className="mt-4 mb-4">
                    <DateRangePicker
                        disabledDays={{
                            before: dateRangeStart,
                            after: dateRangeEnd
                        }}
                        handleDayClick={this.handleDayClick}
                        initialMonth={dateRangeStart}
                        onClearSelectedDates={this.onClearSelectedDates}
                        onConfirmDates={this.onConfirmDates}
                    />
                </div>
                <div>{`Dates disabled before: ${validStartDate}`}</div>
                <div>{`Dates disabled after: ${validEndDate}`}</div>
                <div>{`Selected Date Range: ${fromDate} - ${toDate}`}</div>
                <div>{`Confirmed Date Range: ${confirmedFromDate} - ${confirmedToDate}`}</div>
            </>
        );
    }
}

export default DisabledDateRangePicker;
