import React from 'react';

import dateFnsFormat from 'date-fns/format';

import { Button } from '@preamp/core';
import { DatePickerInput } from '@preamp/datepicker';

/**
 * Date Picker Input Example
 */
export const SingleDatePickerInput: React.FC = (): React.ReactElement => {
    const [selectedDay, setSelectedDay] = React.useState<Date>(null);

    const selectedDate: string = selectedDay
        ? dateFnsFormat(selectedDay, 'MM/DD/YYYY')
        : '';

    function handleChange(day: Date): void {
        if (day === undefined) {
            setSelectedDay(null);
        } else {
            setSelectedDay(day);
        }
    }

    function resetDate(): void {
        setSelectedDay(null);
    }

    return (
        <>
            <div className="my-4 w-48">
                <DatePickerInput
                    id="datepicker-input"
                    isOptional
                    label="Plan Start Date"
                    onHandleChange={handleChange}
                    onHandleDayClick={handleChange}
                    selectedDay={selectedDay}
                />
            </div>
            <p className="mb-4">{`Selected Date: ${selectedDate}`}</p>
            <Button onClick={resetDate}>Clear Date</Button>
        </>
    );
};

export default SingleDatePickerInput;
