import * as React from 'react';

import dateFnsFormat from 'date-fns/format';

import { Button, Toggle } from '@preamp/core';
import {
    DateRange,
    DateRangeInput,
    SLASH_DATE_FORMAT
} from '@preamp/datepicker';

/**
 * Date Range Input Example - Broadcast View (First Day of the Week is Monday)
 */
export const SimpleDateRangeInput: React.FC = (): React.ReactElement => {
    const [confirmedDates, setConfirmedDates] = React.useState<DateRange>({
        from: null,
        to: null
    });

    const [toggle, setToggle] = React.useState<boolean>(false);

    function onConfirmDates(dates: DateRange): void {
        setConfirmedDates(dates);
    }

    function onBlurOverlay(_: boolean, dates: DateRange): void {
        setConfirmedDates(dates);
    }

    function onClearSelectedDates(): void {
        setConfirmedDates({ to: null, from: null });
    }

    function formatDate(day: Date): string {
        if (!day) {
            return '';
        }

        return dateFnsFormat(day, SLASH_DATE_FORMAT);
    }

    function resetDate(): void {
        setConfirmedDates({
            from: null,
            to: null
        });
    }

    const onToggle = (checked: boolean): void => {
        setToggle(checked);
    };

    const confirmedFromDate: string = formatDate(confirmedDates.from);

    const confirmedToDate: string = formatDate(confirmedDates.to);

    return (
        <>
            <div className="mt-4 mb-4 w-full max-w-sm">
                <Toggle
                    checked={toggle}
                    label="Full Width"
                    name="width-toggle"
                    onChange={onToggle}
                />
                <DateRangeInput
                    dateRangePickerProps={{
                        firstDayOfWeek: 1
                    }}
                    id="date-range-input-1"
                    isFullWidth={toggle}
                    isOptional
                    label="Enter Date Range"
                    onBlurOverlay={onBlurOverlay}
                    onClearSelectedDates={onClearSelectedDates}
                    onConfirmDates={onConfirmDates}
                    selectedDates={confirmedDates}
                />
            </div>
            <p className="mb-4">
                Confirmed Date Range: {confirmedFromDate} - {confirmedToDate}
            </p>
            <Button onClick={resetDate}>Clear Date Range</Button>
        </>
    );
};

export default SimpleDateRangeInput;
