import React from 'react';

import dateFnsFormat from 'date-fns/format';

import { Button } from '@preamp/core';

import {
    DateRange,
    DateRangeInput,
    SLASH_DATE_FORMAT
} from '@preamp/datepicker';

interface IInlineDateRangeInputState {
    confirmedDates: DateRange;
    selectedDates: DateRange;
}

/**
 * Inline Date Range Input Example
 */
class InlineDateRangeInput extends React.Component<
    {},
    IInlineDateRangeInputState
> {
    state: IInlineDateRangeInputState = {
        confirmedDates: {
            from: null,
            to: null
        },
        selectedDates: {
            from: null,
            to: null
        }
    };

    confirmDates = (): void => {
        this.setState(
            (prevState: IInlineDateRangeInputState): any => ({
                confirmedDates: prevState.selectedDates
            }),
            (): any =>
                console.log(
                    'confirmDates new shouldApplyDates state: ',
                    this.state
                )
        );
    };

    handleDayChange = (selectedDates: DateRange): void => {
        this.setState(
            {
                selectedDates: selectedDates
            },
            (): any => {
                if (
                    this.state.selectedDates.from ||
                    this.state.selectedDates.to
                ) {
                    // eslint-disable-next-line no-console
                    console.log(
                        'handleDayChange new selectedDates state: ',
                        this.state
                    );
                }
            }
        );
    };

    formatDate = (day: Date): string => {
        if (!day) {
            return '';
        }

        return dateFnsFormat(day, SLASH_DATE_FORMAT);
    };

    render(): React.ReactNode {
        const { confirmedDates, selectedDates } = this.state;

        const appliedFromDate: string = this.formatDate(confirmedDates.from);
        const appliedToDate: string = this.formatDate(confirmedDates.to);
        let confirmedDateRange: string;

        if (confirmedDates.from && confirmedDates.to) {
            confirmedDateRange = `${appliedFromDate} ${
                appliedToDate ? `- ${appliedToDate}` : null
            }`;
        } else {
            confirmedDateRange = 'Date range has not been confirmed';
        }

        return (
            <>
                <div className="mt-4 mb-4">
                    <DateRangeInput
                        dateRangePickerProps={{
                            initialMonth: new Date(2014, 5, 1)
                        }}
                        id="date-range-input-3"
                        inline
                        onEndChange={this.handleDayChange}
                        onEndFocus={this.handleDayChange}
                        onHandleDayClick={this.handleDayChange}
                        onStartChange={this.handleDayChange}
                        showActionsBar={false}
                    />
                </div>
                <div style={{ textAlign: 'right' }}>
                    Confirmed Date Range: {confirmedDateRange}
                    <Button
                        className="ml-2"
                        disabled={
                            selectedDates.from === null ||
                            selectedDates.to === null
                        }
                        onClick={this.confirmDates}
                    >
                        Confirm Dates
                    </Button>
                </div>
            </>
        );
    }
}

export default InlineDateRangeInput;
