import React from 'react';

import dateFnsFormat from 'date-fns/format';

import { Button, ButtonTheme } from '@preamp/core';
import {
    DateRange,
    DateRangeInput,
    SLASH_DATE_FORMAT
} from '@preamp/datepicker';

interface ISimpleDateRangeInputState {
    confirmedDates: DateRange;
}
/**
 * Date Range Input Error State - Date range input error state
 */
class DateRangeInputErrorState extends React.Component<
    {},
    ISimpleDateRangeInputState
> {
    state: ISimpleDateRangeInputState = {
        confirmedDates: {
            from: new Date(2018, 11, 31),
            to: new Date(2019, 1, 1)
        }
    };

    onConfirmDates = (confirmedDates: DateRange): void =>
        this.setState({
            confirmedDates
        });

    formatDate = (day: Date): string => {
        if (!day) {
            return '';
        }

        return dateFnsFormat(day, SLASH_DATE_FORMAT);
    };

    updateViaProps = (): void => {
        this.setState({
            confirmedDates: {
                from: new Date(2018, 11, 11),
                to: new Date(2018, 11, 18)
            }
        });
    };

    render(): React.ReactNode {
        const { confirmedDates } = this.state;
        const confirmedFromDate: string = this.formatDate(confirmedDates.from);
        const confirmedToDate: string = this.formatDate(confirmedDates.to);

        const dateRangeStart: Date = new Date(2018, 11, 10);
        const dateRangeEnd: Date = new Date(2018, 11, 20);

        const validStartDate: string = this.formatDate(dateRangeStart);
        const validEndDate: string = this.formatDate(dateRangeEnd);

        return (
            <>
                <div className="mt-4 mb-4 w-48">
                    <DateRangeInput
                        dateRangePickerProps={{
                            firstDayOfWeek: 1
                        }}
                        disabledDays={{
                            before: dateRangeStart,
                            after: dateRangeEnd
                        }}
                        id="date-range-input-4"
                        label="Enter Date Range"
                        onConfirmDates={this.onConfirmDates}
                        selectedDates={confirmedDates}
                    />
                </div>
                <Button
                    onClick={this.updateViaProps}
                    theme={ButtonTheme.Primary}
                >
                    Update via props
                </Button>
                <div>{`Dates disabled before: ${validStartDate}`}</div>
                <div>{`Dates disabled after: ${validEndDate}`}</div>
                <div>{`Confirmed Date Range: ${confirmedFromDate} - ${confirmedToDate}`}</div>
            </>
        );
    }
}

export default DateRangeInputErrorState;
