import React from 'react';

import dateFnsFormat from 'date-fns/format';

import {
    DateRange,
    DateRangeInput,
    SLASH_DATE_FORMAT
} from '@preamp/datepicker';

/**
 * Date Range Input Example with Label Inline - Setting disabled dates & initial starting month
 */
export const DisabledDateRangeInput: React.FC = (): React.ReactElement => {
    const [confirmedDates, setConfirmedDates] = React.useState<DateRange>({
        from: null,
        to: null
    });

    function onConfirmDates(dates: DateRange): void {
        setConfirmedDates(dates);
    }

    function onBlurOverlay(): void {
        if (confirmedDates.from === null && confirmedDates.to === null) {
            setConfirmedDates({ from: null, to: null });
        }
    }

    function formatDate(day: Date): string {
        if (!day) {
            return '';
        }

        return dateFnsFormat(day, SLASH_DATE_FORMAT);
    }

    const confirmedFromDate: string = formatDate(confirmedDates.from);
    const confirmedToDate: string = formatDate(confirmedDates.to);

    const dateRangeStart: Date = new Date(2018, 11, 10);
    const dateRangeEnd: Date = new Date(2018, 11, 20);

    const validStartDate: string = formatDate(dateRangeStart);
    const validEndDate: string = formatDate(dateRangeEnd);

    return (
        <>
            <div className="mt-4 mb-4 w-48">
                <DateRangeInput
                    dateRangePickerProps={{
                        firstDayOfWeek: 1,
                        initialMonth: dateRangeStart
                    }}
                    disabledDays={{
                        before: dateRangeStart,
                        after: dateRangeEnd
                    }}
                    id="date-range-input-6"
                    inlineLabel
                    label="Enter Date Range"
                    onBlurOverlay={onBlurOverlay}
                    onConfirmDates={onConfirmDates}
                    selectedDates={confirmedDates}
                />
            </div>
            <p className="mb-2">{`Dates disabled before: ${validStartDate}`}</p>
            <p className="mb-2">{`Dates disabled after: ${validEndDate}`}</p>
            <p>{`Confirmed Date Range: ${confirmedFromDate} - ${confirmedToDate}`}</p>
        </>
    );
};

export default DisabledDateRangeInput;
