import React from 'react';
import ReactMarkdown from 'react-markdown';
import { IMarkdownFile } from '../../../../types';
import { getMarkdownFileByName } from '../../utils/findFile';

import cx from 'classnames';

import * as styles from './colorsDoc.scss';

import { color } from './paletteColors';

export const colors: React.FC = (): React.ReactElement => {
    const mixerDoc: IMarkdownFile = getMarkdownFileByName(
        'mixer/colors',
        'colors.md'
    );

    return (
        <div
            className={cx(
                'va-grid va-columns-default',
                styles.colorsDocumentation
            )}
        >
            <div className="col-span-xl-10 col-span-12 ">
                <section>
                    <ReactMarkdown source={mixerDoc.contents} />
                </section>
                <section>
                    <h3>Color Palette</h3>

                    <table className="u-table">
                        <thead>
                            <tr>
                                <th>Color</th>
                                <th>CSS Variable</th>
                                <th>Hex Code</th>
                                <th>Usage and Rules</th>
                            </tr>
                        </thead>
                        <tbody>
                            {color.map(
                                (color): React.ReactNode => (
                                    <tr key={color.variable}>
                                        <td>
                                            <div
                                                className={styles.colorsSwatch}
                                                style={{
                                                    backgroundColor: `var(${color.variable})`
                                                }}
                                            />
                                        </td>
                                        <td>{color.variable}</td>
                                        <td className="uppercase">
                                            {color.hex}
                                        </td>
                                        <td>{color.usage}</td>
                                    </tr>
                                )
                            )}
                        </tbody>
                    </table>
                </section>
            </div>
        </div>
    );
};
