### Grid Layout

The Mixer grid layout is following and extending the Tailwind framework with some influence by Bootstrap's conventions. The grid is based on a 12 column grid using CSS Grid. The grid container must have the following classNames applied `va-grid` and either `va-columns-default` _or_ `va-columns-fluid`.

`va-columns-default` applies the 12 column grid that requires either 12 child elements, or fewer than 12 columns with the class `col-span-${n}` where the `${n}` are numbers that add up to 12.

`va-columns-fluid` allows you to have however many child elements you want and they'll all equally fill the space.

#### Usage Example

```tsx
<div className='va-grid va-columns-default'>
    <div className='col-span-12'>Full Width Column</div>
</div>
<div className='va-grid va-columns-default'>
    <div className='col-span-6'>50% Width Column</div>
    <div className='col-span-6'>50% Width Column</div>
</div>
<div className='va-grid va-columns-fluid'>
    <div>These columns</div>
    <div>Fill the space</div>
    <div>Evenly</div>
</div>
```

#### Gutters

By default the columns will have gutter spacing between them. The size of the gutter is configurable in the `_themes` partial (1.5rem or 24px by default). To remove the spacing, add the class `no-gutters` to the container element. For example:

```tsx
<div className="va-grid va-columns-default no-gutters">
    <div className="col-span-9">75% Width Column</div>
    <div className="col-span-3">25% Width Column</div>
</div>
```

### Responsive

Media queries follow the screen specifications set up in the Tailwind framework as `sm`, `md`, `lg`, and `xl`. Including them as part of the class names will apply them based on minimum width, so they will apply to that breakpoint and all above it.

|              | `sm`            | `md`            | `lg`            | `xl`            |
| ------------ | :-------------- | :-------------- | :-------------- | :-------------- |
| Breakpoint   | 576px           | 768px           | 992px           | 1200px          |
| Class prefix | `.col-span-sm-` | `.col-span-md-` | `.col-span-lg-` | `.col-span-xl-` |

So, for example, the following class additions:

```tsx
<div className="va-grid va-columns-default">
    <div className="col-span-sm-12 col-span-md-6 col-span-lg-3">
        Column Content
    </div>
</div>
```

Will adaptively render as the following:

| Browser Size                       | Column Width                    |
| :--------------------------------- | :------------------------------ |
| `sm` breakpoint to `md` breakpoint | 100% (applies `col-span-sm-12`) |
| `md` breakpoint to `lg` breakpoint | 50% (applies `col-span-md-6`)   |
| `lg` breakpoint and above          | 25% (applies `col-span-lg-3`)   |
