import React from 'react';
import ReactMarkdown from 'react-markdown';
import { IMarkdownFile } from '../../../../types';
import { getMarkdownFileByName } from '../../utils/findFile';

export const utilities: React.SFC = (): React.ReactElement => {
    const mixerDoc: IMarkdownFile = getMarkdownFileByName(
        'mixer/utilities',
        'utilities.md'
    );

    return (
        <div>
            <ReactMarkdown source={mixerDoc.contents} />
            <h4>Borders</h4>
            <p>
                For consistency, our default border style is{' '}
                <code>1px solid var(--va-primary-border-color)</code>. <br />
                The utility classNames for this and each side are listed below:
            </p>
            <h5 className="mt-4">Example:</h5>
            <div
                className="u-border-default p-3 mb-3 text-center bg-va-grey-100"
                style={{ width: '220px' }}
            >
                .u-border-default
            </div>
            <div
                className="u-border-default--left p-3 mb-3 text-center bg-va-grey-100"
                style={{ width: '220px' }}
            >
                .u-border-default--left
            </div>
            <div
                className="u-border-default--top p-3 mb-3 text-center bg-va-grey-100"
                style={{ width: '220px' }}
            >
                .u-border-default--top
            </div>
            <div
                className="u-border-default--right p-3 mb-3 text-center bg-va-grey-100"
                style={{ width: '220px' }}
            >
                .u-border-default--right
            </div>
            <div
                className="u-border-default--bottom p-3 mb-3 text-center bg-va-grey-100"
                style={{ width: '220px' }}
            >
                .u-border-default--bottom
            </div>
            <h4 className="mt-4">Drop Shadows</h4>
            <p>Standard drop shadows</p>
            <h5 className="mt-4">Examples:</h5>
            <div className="flex items-center mb-8">
                <div
                    className="u-shadow mr-8 flex items-center justify-center bg-va-grey-100"
                    style={{
                        width: '200px',
                        height: '50px'
                    }}
                >
                    <span>.u-shadow</span>
                </div>
                <span>Default shadow</span>
            </div>
            <div className="flex items-center mb-8">
                <div
                    className="u-shadow-2 mr-8 flex items-center justify-center bg-va-grey-100"
                    style={{
                        width: '200px',
                        height: '50px'
                    }}
                >
                    <span>.u-shadow-2</span>
                </div>
                <span>
                    Appearing visually higher in elevation (used in select
                    menus)
                </span>
            </div>
            <div className="flex items-center mb-8">
                <div
                    className="u-shadow-3 mr-8 flex items-center justify-center bg-va-grey-100"
                    style={{
                        width: '200px',
                        height: '50px'
                    }}
                >
                    <span>.u-shadow-3</span>
                </div>
                <span>
                    Used in pinned panels within other elements (ex: Pinned
                    columns in the DataTable)
                </span>
            </div>
            <div className="flex items-center mb-8">
                <div
                    className="u-shadow-4 mr-8 flex items-center justify-center bg-va-grey-100"
                    style={{
                        width: '200px',
                        height: '50px'
                    }}
                >
                    <span>.u-shadow-4</span>
                </div>
                <span>Used on panels.</span>
            </div>
            <div className="flex items-center mb-8">
                <div
                    className="u-shadow-glow mr-8 flex items-center justify-center bg-va-grey-100"
                    style={{
                        width: '200px',
                        height: '50px'
                    }}
                >
                    <span>.u-shadow-glow</span>
                </div>
                <span>Equal shadow on all sides. Used on the datepicker.</span>
            </div>
            <div className="flex items-center mb-8">
                <div
                    className="u-shadow-left u-border-default mr-8 flex items-center justify-center bg-va-grey-0"
                    style={{
                        width: '200px',
                        height: '50px'
                    }}
                >
                    <span>.u-shadow-left</span>
                </div>
                <span>
                    Can be used for elements pinned to the right of the screen
                    (RightRail or Drawer)
                </span>
            </div>
            <div className="flex items-center mb-8">
                <div
                    className="u-shadow-right u-border-default mr-8 flex items-center justify-center bg-va-grey-0"
                    style={{
                        width: '200px',
                        height: '50px'
                    }}
                >
                    <span>.u-shadow-right</span>
                </div>
                <span>
                    Can be used for elements pinned to the left of the screen
                    (Navigation)
                </span>
            </div>
            <h4 className="mt-4">Table Utility Classes</h4>
            <p>
                Applying the className <code>u-table</code> on static HTML Table
                markup will apply the styles.
                <br />
                To right-align table cells, the <code>
                    u-table_cell--right
                </code>{' '}
                class can be applied to the cell.
            </p>
            <table className="u-table">
                <thead>
                    <tr>
                        <th>First Name</th>
                        <th>Last Name</th>
                        <th>Age</th>
                        <th>Location</th>
                        <th className="u-table_cell--right">Date</th>
                    </tr>
                </thead>
                <tbody>
                    <tr>
                        <td>Bob</td>
                        <td>Samuelson</td>
                        <td>42</td>
                        <td>CA</td>
                        <td className="u-table_cell--right">11/17/1976</td>
                    </tr>
                    <tr>
                        <td>Amy</td>
                        <td>Gaudioso</td>
                        <td>26</td>
                        <td>MA</td>
                        <td className="u-table_cell--right">10/20/1992</td>
                    </tr>
                    <tr>
                        <td>Juan</td>
                        <td>Giuffrida</td>
                        <td>32</td>
                        <td>TX</td>
                        <td className="u-table_cell--right">9/15/1986</td>
                    </tr>
                    <tr>
                        <td>Doug</td>
                        <td>Ung</td>
                        <td>37</td>
                        <td>NY</td>
                        <td className="u-table_cell--right">12/9/1981</td>
                    </tr>
                    <tr>
                        <td>Ben</td>
                        <td>Behrens</td>
                        <td>35</td>
                        <td>NC</td>
                        <td className="u-table_cell--right">8/3/1983</td>
                    </tr>
                </tbody>
            </table>

            <h5>Markup:</h5>
            <pre>
                {`<table className="u-table">
    <thead>
        <tr>
            <th>First Name</th>
            <th>Last Name</th>
            <th>Age</th>
            <th>Location</th>
            <th className="u-table_cell--right">Date</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td>Bob</td>
            <td>Samuelson</td>
            <td>42</td>
            <td>CA</td>
            <td className="u-table_cell--right">11/17/1976</td>
        </tr>
        <tr>
            <td>Amy</td>
            <td>Gaudioso</td>
            <td>26</td>
            <td>MA</td>
            <td className="u-table_cell--right">10/20/1992</td>
        </tr>
        <tr>
            <td>Juan</td>
            <td>Giuffrida</td>
            <td>32</td>
            <td>TX</td>
            <td className="u-table_cell--right">9/15/1986</td>
        </tr>
        <tr>
            <td>Doug</td>
            <td>Ung</td>
            <td>37</td>
            <td>NY</td>
            <td className="u-table_cell--right">12/9/1981</td>
        </tr>
        <tr>
            <td>Ben</td>
            <td>Behrens</td>
            <td>35</td>
            <td>NC</td>
            <td className="u-table_cell--right">8/3/1983</td>
        </tr>
    </tbody>
</table>`}
            </pre>
            <h4 className="mt-4">Well</h4>
            <p>
                Applying the className <code>u-well</code> on an element will
                apply the styles.
            </p>
            <p className="u-well">
                Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
                eiusmod tempor incididunt ut labore et dolore magna aliqua.
                Malesuada pellentesque elit eget gravida cum sociis natoque
                penatibus.
            </p>
            <h5>Markup:</h5>
            <pre>
                {`<p className="u-well">
    Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
    eiusmod tempor incididunt ut labore et dolore magna aliqua.
    Malesuada pellentesque elit eget gravida cum sociis natoque
    penatibus.
</p>`}
            </pre>
        </div>
    );
};
