import React, { ReactElement } from 'react';

import {
    CardTable,
    CardTableContext,
    ColumnData,
    ColumnToggles,
    DroppableDef
} from '@videoamp-private/preamp-plus';

const getColumnData = (key: number): ColumnData[] => [
    { columnKey: `firstName_${key}`, columnName: 'First Name' },
    { columnKey: `lastName_${key}`, columnName: 'Last Name' },
    { columnKey: `age_${key}`, columnName: 'Age' },
    { columnKey: `visits_${key}`, columnName: 'Visits' },
    { columnKey: `status_${key}`, columnName: 'Status' }
];

const getPeople = (key: number): { [K: string]: string | number }[] => [
    {
        [`firstName_${key}`]: 'Sam',
        [`lastName_${key}`]: 'Smith',
        [`age_${key}`]: 41,
        [`visits_${key}`]: 8,
        [`status_${key}`]: 'complicated'
    },
    {
        [`firstName_${key}`]: 'Alex',
        [`lastName_${key}`]: 'Turner',
        [`age_${key}`]: 35,
        [`visits_${key}`]: 18,
        [`status_${key}`]: 'complicated'
    },
    {
        [`firstName_${key}`]: 'Bruce',
        [`lastName_${key}`]: 'Wayne',
        [`age_${key}`]: 40,
        [`visits_${key}`]: 945,
        [`status_${key}`]: 'single'
    },
    {
        [`firstName_${key}`]: 'Selena',
        [`lastName_${key}`]: 'Gomez',
        [`age_${key}`]: 28,
        [`visits_${key}`]: 50,
        [`status_${key}`]: 'relationship'
    }
];

const AdvancedCardTableExample = (): ReactElement => {
    const afterDrop = (droppables: DroppableDef<string>[]): void => {
        alert('Dropping Draggable!: ' + JSON.stringify(droppables));
    };

    return (
        <>
            <p className="mb-4">Advanced Example</p>
            <p className="mb-4">All Headers as Default, autoRender</p>
            <CardTableContext columns={getColumnData(0)} rows={getPeople(0)}>
                <div className="flex row mb-8">
                    <ColumnToggles />
                    <CardTable autoRender displayedHeaders />
                </div>
            </CardTableContext>
            <p className="mb-4">Custom Headers as Default: [1, 3]</p>
            <CardTableContext columns={getColumnData(1)} rows={getPeople(1)}>
                <div className="flex row mb-8">
                    <ColumnToggles />
                    <CardTable autoRender displayedHeaders={[1, 3]} />
                </div>
            </CardTableContext>
            <p className="mb-4">Custom Callback: afterDrop</p>
            <CardTableContext columns={getColumnData(2)} rows={getPeople(2)}>
                <div className="flex row mb-8">
                    <ColumnToggles />
                    <CardTable
                        afterDrop={afterDrop}
                        autoRender
                        displayedHeaders
                    />
                </div>
            </CardTableContext>
        </>
    );
};

export default AdvancedCardTableExample;
