import React, { ReactElement, useState } from 'react';

import { Button } from '@preamp/core';

import { DataTable } from '@videoamp-private/preamp-plus';

import { useMockData } from './utils/useMockData';

const BasicDataTableExample = (): ReactElement => {
    const [loadingDelayMs, setLoadingDelayMs] = useState<number>(1500);

    const { columns, isLoading, rows, summary } = useMockData({
        columnCount: 100,
        loadingDelayMs,
        minColumnWidth: 150,
        rowCount: 10000
    });

    function simulateLazyLoading(): void {
        setLoadingDelayMs((ms: number): number => ms + 1);
    }

    return (
        <>
            <p className="mb-4">Basic data table</p>
            <div className="flex justify-between items-center mb-3">
                <p>
                    This table supports data virtualization for both rows and
                    columns.
                </p>
                <Button onClick={simulateLazyLoading}>
                    Simulate lazy loading
                </Button>
            </div>

            <DataTable
                columns={columns}
                isLoading={isLoading}
                rows={rows}
                tableHeight={300}
            />
            {!isLoading && (
                <p className="mt-1 text-right u-body-2">{summary}</p>
            )}
        </>
    );
};

export default BasicDataTableExample;
