import React, { ReactElement } from 'react';

import { DataTable } from '@videoamp-private/preamp-plus';

import { useMockData } from './utils/useMockData';

/**
 * Table sizes
 */
const TableSizesExample = (): ReactElement => {
    const { columns, rows, summary } = useMockData({
        columnCount: 10,
        minColumnWidth: 100,
        rowCount: 5
    });

    return (
        <>
            <p className="my-2">Full width, full height</p>
            <DataTable columns={columns} rows={rows} />
            <p className="mt-1 mb-6 text-right u-body-2">{summary}</p>

            <p className="my-2">Full width, height = 200px</p>
            <DataTable columns={columns} rows={rows} tableHeight={200} />
            <p className="mt-1 mb-6 text-right u-body-2">{summary}</p>

            <p className="my-2">Width = 300px, full height</p>
            <DataTable columns={columns} rows={rows} tableWidth={300} />
            <p className="mt-1 mb-6 text-right u-body-2" style={{ width: 300 }}>
                {summary}
            </p>

            <p className="my-2">Width = 50%, full height</p>
            <DataTable columns={columns} rows={rows} tableWidth="50%" />
            <p
                className="mt-1 mb-6 text-right u-body-2"
                style={{ width: '50%' }}
            >
                {summary}
            </p>

            <p className="my-2">Width = 400px, height = 200px</p>
            <DataTable
                columns={columns}
                rows={rows}
                tableHeight={200}
                tableWidth={400}
            />
            <p className="mt-1 mb-6 text-right u-body-2" style={{ width: 400 }}>
                {summary}
            </p>
        </>
    );
};

export default TableSizesExample;
