import React, { ReactElement, useCallback, useState } from 'react';

import { PillButton, PillButtonGroup, PillTheme } from '@preamp/core';

import { DataTable, DataTableBorder } from '@videoamp-private/preamp-plus';

import { useMockData } from './utils/useMockData';

const createBorderTypePills = (selectedPill: string): ReactElement[] =>
    Object.entries(DataTableBorder).map(
        ([label, value]: string[]): ReactElement => (
            <PillButton
                key={value}
                label={label}
                name="border-type"
                theme={
                    selectedPill === value
                        ? PillTheme.Active
                        : PillTheme.Default
                }
                value={value}
            />
        )
    );

/**
 * Borders
 */
const BordersExample = (): React.ReactElement => {
    const { columns, rows, summary } = useMockData({
        columnCount: 15,
        minColumnWidth: 100,
        rowCount: 50
    });

    const [borderType, setBorderType] = useState<DataTableBorder>(
        DataTableBorder.Horizontal
    );

    const onChangeBorderType = useCallback((values: string[]): void => {
        setBorderType(values[0] as DataTableBorder);
    }, []);

    return (
        <>
            <PillButtonGroup
                className="mb-4 justify-end"
                name="border-types"
                onChange={onChangeBorderType}
                selectedValues={[borderType]}
                title="Border Types:"
            >
                {createBorderTypePills(borderType)}
            </PillButtonGroup>

            <DataTable
                border={borderType}
                columns={columns}
                rows={rows}
                tableHeight={300}
            />
            <p className="mt-1 mb-6 text-right u-body-2">{summary}</p>
        </>
    );
};

export default BordersExample;
