import React, { ReactElement } from 'react';

import { DataTable, DataTableBorder } from '@videoamp-private/preamp-plus';

import { useMockData } from './utils/useMockData';

const MIN_COL_WIDTH = 50;

/**
 * Cell sizes
 */
const CellSizesExample = (): ReactElement => {
    const { columns: c1, rows: r1, summary: s1 } = useMockData({
        columnCount: 5,
        minColumnWidth: 100,
        rowCount: 5
    });
    const { columns: c2, rows: r2, summary: s2 } = useMockData({
        columnCount: 10,
        maxColumnWidth: 300,
        minColumnWidth: MIN_COL_WIDTH,
        rowCount: 5
    });
    const { columns: c3, rows: r3, summary: s3 } = useMockData({
        columnCount: 10,
        minColumnWidth: 100,
        rowCount: 5
    });
    const { columns: c4, rows: r4, summary: s4 } = useMockData({
        columnCount: 10,
        maxColumnWidth: 300,
        minColumnWidth: MIN_COL_WIDTH,
        rowCount: 3
    });

    return (
        <>
            <p className="my-1">Width = min. 100px (*), height = auto</p>
            <p className="mb-2 u-body-2">
                (*) Column width will also depend on both the amount of columns
                and the table width. For instance, if we have 5 columns in a
                table width of 1000px, each column will be 200px although we
                have defined columns to be 100px.
            </p>
            <DataTable
                border={DataTableBorder.Vertical}
                columns={c1}
                rows={r1}
            />
            <p className="mt-1 mb-6 text-right u-body-2">{s1}</p>

            <p className="my-2">
                Width = variable (between 50px and 300px), height = auto
            </p>
            <DataTable
                border={DataTableBorder.Vertical}
                columns={c2}
                rows={r2}
            />
            <p className="mt-1 mb-6 text-right u-body-2">{s2}</p>

            <p className="my-2">Width = min. 100px, height = 100px</p>
            <DataTable
                border={DataTableBorder.Full}
                columns={c3}
                rowHeight={100}
                rows={r3}
            />
            <p className="mt-1 mb-6 text-right u-body-2">{s3}</p>

            <p className="my-2">
                Width = variable (between 50px and 300px), height = 150px
            </p>
            <DataTable
                border={DataTableBorder.Full}
                columns={c4}
                rowHeight={150}
                rows={r4}
            />
            <p className="mt-1 mb-6 text-right u-body-2">{s4}</p>
        </>
    );
};

export default CellSizesExample;
