import React, { ChangeEvent, ReactElement, useState } from 'react';

import { TextField, TextFieldType, Toggle } from '@preamp/core';

import { DataTable } from '@videoamp-private/preamp-plus';

import { useMockData } from './utils/useMockData';

/**
 * Custom number of columns to be sorted at the same time
 */
const MaxColumnsSortingExample = (): ReactElement<HTMLElement> => {
    const [enableSorting, setEnableSorting] = useState<boolean>(true);
    const [maxMultiSortColCount, setMaxMultiSortColCount] = useState<number>(1);

    const { columns, rows, summary } = useMockData({
        columnCount: 50,
        minColumnWidth: 150,
        rowCount: 10000
    });

    return (
        <>
            <div className="flex justify-around mb-3">
                <Toggle
                    checked={enableSorting}
                    label="Enable sorting"
                    name="enable-sorting"
                    onChange={setEnableSorting}
                />
                <div className="w-1/3">
                    <TextField
                        disabled={!enableSorting}
                        label="Maximum number of columns to be sorted"
                        max={`${columns.length}`}
                        min="1"
                        onChange={(e: ChangeEvent<HTMLInputElement>): void =>
                            setMaxMultiSortColCount(Number(e.target.value))
                        }
                        textFieldType={TextFieldType.Number}
                        value={`${maxMultiSortColCount || 0}`}
                    />
                </div>
            </div>
            <DataTable
                columns={columns}
                rows={rows}
                sortingOptions={{ enableSorting, maxMultiSortColCount }}
                tableHeight={300}
            />
            <p className="mt-1 text-right u-body-2">{summary}</p>
        </>
    );
};

export default MaxColumnsSortingExample;
