import React, { ReactElement, useCallback, useEffect, useState } from 'react';

import { DataTable, SortingState } from '@videoamp-private/preamp-plus';

import { useMockData } from './utils/useMockData';

/**
 * Manual sorting
 */
const ManualSortingExample = (): ReactElement<HTMLElement> => {
    const { columns, isLoading, rows, summary } = useMockData({
        columnCount: 50,
        loadingDelayMs: 1500,
        minColumnWidth: 150,
        rowCount: 10000
    });

    const [sortedRows, setSortedRows] = useState<number[][]>([]);

    const onManualSorting = useCallback(
        (sortingState: SortingState): void => {
            const allRows = [...rows];
            if (sortingState.length) {
                // manual sorting logic
                // it could be an API call, async function, etc
                const colIndex = Number(
                    sortingState[0].id.replace('column-', '')
                );
                allRows.sort(
                    (rowA, rowB): number =>
                        (rowA[colIndex] - rowB[colIndex]) *
                        (sortingState[0].desc ? -1 : 1)
                );
            }
            setSortedRows(allRows);
        },
        [rows]
    );

    useEffect((): void => {
        setSortedRows([...rows]);
    }, [rows]);

    return (
        <>
            <DataTable
                columns={columns}
                rows={sortedRows}
                sortingOptions={{ enableSorting: true, onManualSorting }}
                tableHeight={300}
            />
            {!isLoading && (
                <p className="mt-1 text-right u-body-2">{summary}</p>
            )}
        </>
    );
};

export default ManualSortingExample;
