import React, { ReactElement } from 'react';

import {
    ColumnDef,
    DataTable,
    DataTableBorder
} from '@videoamp-private/preamp-plus';

import { useMockData } from './utils/useMockData';

/**
 * Column pinning
 */

type Person = {
    clicks: number;
    data1: number;
    data2: number;
    data3: number;
    data4: number;
    data5: number;
    data6: number;
    firstName: string;
    lastName: string;
    age: number;
    visits: number;
    progress: number;
    status: 'relationship' | 'complicated' | 'single';
};

const GROUP_COLUMNS: ColumnDef<Person>[] = [
    {
        header: 'Name',
        columns: [
            {
                accessorKey: 'firstName',
                cell: (info): string => info.getValue()
            },
            {
                accessorKey: 'lastName',
                cell: (info): string => info.getValue()
            }
        ]
    },
    {
        header: 'Info',
        columns: [
            {
                accessorKey: 'age',
                header: (): string => 'Age'
            },
            {
                header: 'More Info',
                columns: [
                    {
                        accessorKey: 'visits',
                        header: (): string => 'Visits'
                    },
                    {
                        accessorKey: 'clicks',
                        header: 'Clicks'
                    },
                    {
                        accessorKey: 'data1',
                        header: 'Data-1'
                    },
                    {
                        accessorKey: 'data2',
                        header: 'Data-2'
                    },
                    {
                        accessorKey: 'data3',
                        header: 'Data-3'
                    },
                    {
                        accessorKey: 'data4',
                        header: 'Data-4'
                    },
                    {
                        accessorKey: 'data5',
                        header: 'Data-5'
                    },
                    {
                        accessorKey: 'data6',
                        header: 'Data-6'
                    },
                    {
                        accessorKey: 'status',
                        header: 'Status'
                    },
                    {
                        accessorKey: 'progress',
                        header: 'Profile Progress'
                    }
                ]
            }
        ]
    }
];

const PEOPLE: Person[] = [
    {
        clicks: 264,
        data1: Math.floor(Math.random() * 500),
        data2: Math.floor(Math.random() * 500),
        data3: Math.floor(Math.random() * 500),
        data4: Math.floor(Math.random() * 500),
        data5: Math.floor(Math.random() * 500),
        data6: Math.floor(Math.random() * 500),
        firstName: 'Sam',
        lastName: 'Smith',
        age: 41,
        visits: 8,
        progress: 90,
        status: 'complicated'
    },
    {
        clicks: 1993,
        data1: Math.floor(Math.random() * 500),
        data2: Math.floor(Math.random() * 500),
        data3: Math.floor(Math.random() * 500),
        data4: Math.floor(Math.random() * 500),
        data5: Math.floor(Math.random() * 500),
        data6: Math.floor(Math.random() * 500),
        firstName: 'Alex',
        lastName: 'Turner',
        age: 35,
        visits: 18,
        progress: 20,
        status: 'single'
    },
    {
        clicks: 10323,
        data1: Math.floor(Math.random() * 500),
        data2: Math.floor(Math.random() * 500),
        data3: Math.floor(Math.random() * 500),
        data4: Math.floor(Math.random() * 500),
        data5: Math.floor(Math.random() * 500),
        data6: Math.floor(Math.random() * 500),
        firstName: 'Selena',
        lastName: 'Gomez',
        age: 28,
        visits: 50,
        progress: 65,
        status: 'relationship'
    }
];

const ColumnPinningExample = (): ReactElement<HTMLElement> => {
    const { columns, rows, summary } = useMockData({
        columnCount: 100,
        minColumnWidth: 100,
        rowCount: 10000
    });

    return (
        <>
            <DataTable
                columnPinning={{
                    left: ['column-4', 'column-85', 'column-35'],
                    right: ['column-7']
                }}
                columns={columns}
                rows={rows}
                tableHeight={500}
            />
            <p className="mt-1 text-right u-body-2">{summary}</p>
            <p className="my-4">Pinning with header groups</p>
            <DataTable
                border={DataTableBorder.Vertical}
                columnPinning={{
                    left: ['firstName', 'lastName'],
                    right: ['progress']
                }}
                columns={GROUP_COLUMNS}
                disableColumnVirtualization
                rows={PEOPLE}
            />
        </>
    );
};

export default ColumnPinningExample;
