import React, { ReactElement } from 'react';

import { ColumnDef, DataTable } from '@videoamp-private/preamp-plus';

type Person = {
    firstName: string;
    lastName: string;
    age: number;
    visits: number;
    progress: number;
    status: 'relationship' | 'complicated' | 'single';
};

const GROUP_COLUMNS: ColumnDef<Person>[] = [
    {
        header: 'Name',
        columns: [
            {
                accessorKey: 'firstName',
                cell: (info): string => info.getValue()
            },
            {
                accessorKey: 'lastName',
                cell: (info): string => info.getValue()
            }
        ]
    },
    {
        header: 'Info',
        columns: [
            {
                accessorKey: 'age',
                header: (): string => 'Age'
            },
            {
                header: 'More Info',
                columns: [
                    {
                        accessorKey: 'visits',
                        header: (): string => 'Visits'
                    },
                    {
                        accessorKey: 'status',
                        header: 'Status'
                    },
                    {
                        accessorKey: 'progress',
                        header: 'Profile Progress'
                    }
                ]
            }
        ]
    }
];

const PEOPLE: Person[] = [
    {
        firstName: 'Sam',
        lastName: 'Smith',
        age: 41,
        visits: 8,
        progress: 90,
        status: 'complicated'
    },
    {
        firstName: 'Alex',
        lastName: 'Turner',
        age: 35,
        visits: 18,
        progress: 20,
        status: 'single'
    },
    {
        firstName: 'Selena',
        lastName: 'Gomez',
        age: 28,
        visits: 50,
        progress: 65,
        status: 'relationship'
    }
];

/**
 * Group Headers
 */
const GroupHeaderExample = (): ReactElement<HTMLElement> => (
    <>
        <p className="my-4">Group Headers</p>
        <DataTable columns={GROUP_COLUMNS} rows={PEOPLE} />
    </>
);

export default GroupHeaderExample;
