import React, { ReactElement, useState } from 'react';
import {
    Draggable,
    DragNDropContext,
    Droppable,
    DroppableDef
} from '@videoamp-private/preamp-plus';
import { Card, CardTheme, Panel, Pill } from '@preamp/core';

const DROPPABLE_DATA: DroppableDef<ReactElement>[] = [
    {
        items: [
            <Pill key={0}>
                <p>First element: Pill</p>
            </Pill>,
            <Card
                key={1}
                theme={CardTheme.White}
                title="Second element: Card"
            />,
            <Panel header="Third element: Panel with body" key={2}>
                <p className="va-body-1">
                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                    Suspendisse dolor arcu, luctus et nibh vel, consequat
                    feugiat diam.
                </p>
            </Panel>,
            <span
                className="p-2 rounded"
                key={3}
                style={{ background: 'lightblue', color: 'white' }}
            >
                Fourth element: span
            </span>
        ]
    }
];

const BasicDragNDropExample = (): ReactElement => {
    const [droppables, setDroppables] = useState<DroppableDef<ReactElement>[]>(
        DROPPABLE_DATA
    );

    return (
        <>
            <div className="mb-4">Basic Example</div>
            <DragNDropContext droppables={droppables} onDrop={setDroppables}>
                <Droppable
                    className="justify-center p-4 u-border-default va-grey-300--background"
                    id={0}
                >
                    {droppables[0].items.map(
                        (
                            draggable: ReactElement,
                            index: number
                        ): ReactElement => (
                            <Draggable
                                className="my-1"
                                droppableId={0}
                                id={index}
                                key={index}
                            >
                                {draggable}
                            </Draggable>
                        )
                    )}
                </Droppable>
            </DragNDropContext>
        </>
    );
};

export default BasicDragNDropExample;
