import React, { ReactElement, useState } from 'react';
import {
    Draggable,
    DragNDropContext,
    Droppable,
    DroppableDef
} from '@videoamp-private/preamp-plus';
import { Pill } from '@preamp/core';

const DroppableDirectionExample = (): ReactElement => {
    const [droppables, setDroppables] = useState<DroppableDef<string>[]>([
        { items: ['First', 'Second', 'Third'] },
        { items: ['Fourth', 'Fifth', 'Sixth', 'Seventh'] }
    ]);

    return (
        <>
            <div className="mb-4">Droppable direction</div>
            <DragNDropContext droppables={droppables} onDrop={setDroppables}>
                <div className="flex" style={{ gap: '1rem', minHeight: 200 }}>
                    <div className="flex flex-col">
                        <h2>Vertical Droppable</h2>
                        <Droppable
                            className="justify-center h-full mt-2 p-4 u-border-default va-grey-300--background"
                            direction="vertical"
                            id={0}
                        >
                            {droppables[0].items.map(
                                (
                                    draggable: string,
                                    index: number
                                ): ReactElement => (
                                    <Draggable
                                        droppableId={0}
                                        id={index}
                                        key={index}
                                    >
                                        <Pill className="m-1">{draggable}</Pill>
                                    </Draggable>
                                )
                            )}
                        </Droppable>
                    </div>
                    <div className="flex flex-col flex-grow">
                        <h2>Horizontal Droppable</h2>
                        <Droppable
                            className="items-center justify-center h-full mt-2 p-4 u-border-default va-grey-300--background"
                            direction="horizontal"
                            id={1}
                        >
                            {droppables[1].items.map(
                                (
                                    draggable: string,
                                    index: number
                                ): ReactElement => (
                                    <Draggable
                                        droppableId={1}
                                        id={index}
                                        key={index}
                                    >
                                        <Pill className="m-1">{draggable}</Pill>
                                    </Draggable>
                                )
                            )}
                        </Droppable>
                    </div>
                </div>
            </DragNDropContext>
        </>
    );
};

export default DroppableDirectionExample;
