import React, { ReactElement, useState } from 'react';
import {
    Draggable,
    DragNDropContext,
    Droppable,
    DroppableDef
} from '@videoamp-private/preamp-plus';
import { Pill } from '@preamp/core';

const DROPPABLES_DATA: DroppableDef<string>[] = [
    {
        enableCopy: true,
        items: ['First', 'Second', 'Third', 'Fourth', 'Fifth'],
        name: 'Copy Droppable'
    },
    {
        items: [],
        name: 'Non Copy Droppable'
    },
    {
        items: [],
        name: 'Non Copy Droppable'
    }
];

const CopyDraggableElementsExample = (): ReactElement => {
    const [droppables, setDroppables] = useState<DroppableDef<string>[]>(
        DROPPABLES_DATA
    );

    return (
        <>
            <div className="mb-4">Copy draggable elements</div>
            <DragNDropContext droppables={droppables} onDrop={setDroppables}>
                <div className="flex" style={{ gap: '1rem' }}>
                    {droppables.map(
                        (
                            droppable: DroppableDef<string>,
                            key: number
                        ): ReactElement => {
                            const { items, name } = droppable;

                            return (
                                <div
                                    className="flex-grow flex flex-col"
                                    key={key}
                                >
                                    <h2>{name}</h2>
                                    <Droppable
                                        className="justify-center h-full mt-2 p-4 u-border-default va-grey-300--background"
                                        id={key}
                                    >
                                        {items.map(
                                            (
                                                draggable: string,
                                                index: number
                                            ): ReactElement => (
                                                <div key={index}>
                                                    <Draggable
                                                        droppableId={key}
                                                        id={index}
                                                    >
                                                        <div className="m-1">
                                                            <Pill>
                                                                {draggable}
                                                            </Pill>
                                                        </div>
                                                    </Draggable>
                                                </div>
                                            )
                                        )}
                                    </Droppable>
                                </div>
                            );
                        }
                    )}
                </div>
            </DragNDropContext>
        </>
    );
};

export default CopyDraggableElementsExample;
