import React, { ReactElement, useState } from 'react';

import {
    Draggable,
    DragNDropContext,
    Droppable,
    DroppableDef
} from '@videoamp-private/preamp-plus';

import './styles/draggingOverStyles.scss';

const DroppableTablesExample = (): ReactElement => {
    const [droppables, setDroppables] = useState<DroppableDef<number>[]>([
        { items: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10] }
    ]);

    return (
        <>
            <div className="mb-4">Draggable table rows</div>
            <DragNDropContext droppables={droppables} onDrop={setDroppables}>
                <table className="draggable-table-rows table-fixed w-full">
                    <thead className="uppercase">
                        <tr className="border-2">
                            <th className="p-2 text-center">Column A</th>
                            <th className="p-2 text-center">Column B</th>
                            <th className="p-2 text-center">Column C</th>
                        </tr>
                    </thead>
                    <Droppable
                        className="border-2"
                        direction="vertical"
                        element={<tbody />}
                        id={0}
                    >
                        {droppables[0].items.map(
                            (draggable: number, key: number): ReactElement => (
                                <Draggable
                                    className="text-center"
                                    droppableId={0}
                                    element={<tr />}
                                    id={key}
                                    key={key}
                                >
                                    <td className="p-2 text-center">
                                        {draggable}.A
                                    </td>
                                    <td className="p-2 text-center">
                                        {draggable}.B
                                    </td>
                                    <td className="p-2 text-center">
                                        {draggable}.C
                                    </td>
                                </Draggable>
                            )
                        )}
                    </Droppable>
                </table>
            </DragNDropContext>
        </>
    );
};

export default DroppableTablesExample;
