import React, { ReactElement, useState } from 'react';
import {
    Draggable,
    DragNDropContext,
    Droppable,
    DroppableDef
} from '@videoamp-private/preamp-plus';
import { Pill } from '@preamp/core';

import './styles/draggingOverStyles.scss';

const DROPPABLES_DATA: DroppableDef<string>[] = [
    {
        className: 'first-droppable',
        id: 'droppable1',
        items: ['First', 'Second', 'Third', 'Fourth', 'Fifth']
    },
    {
        className: 'second-droppable',
        id: 'droppable2',
        items: []
    },
    {
        className: 'third-droppable',
        id: 'droppable3',
        items: []
    }
];

const CustomDroppablesExample = (): ReactElement => {
    const [droppables, setDroppables] = useState<DroppableDef<string>[]>(
        DROPPABLES_DATA
    );

    return (
        <>
            <div className="mb-4">Custom droppables</div>
            <DragNDropContext droppables={droppables} onDrop={setDroppables}>
                <div className="flex">
                    <div className="flex-grow mr-1">
                        <div
                            className="flex-grow flex mb-1"
                            style={{ minHeight: 175 }}
                        >
                            <Droppable
                                className="custom-dragging-over justify-center flex-grow mr-1 p-4 u-border-default va-grey-300--background"
                                id={0}
                            >
                                {droppables[0].items.map(
                                    (draggable, index): ReactElement => (
                                        <Draggable
                                            droppableId={0}
                                            id={index}
                                            key={index}
                                        >
                                            <Pill className="m-1">
                                                {draggable}
                                            </Pill>
                                        </Draggable>
                                    )
                                )}
                            </Droppable>
                            <div
                                className="flex items-center justify-center rounded-lg p-2"
                                style={{ backgroundColor: 'lightblue' }}
                            >
                                Not Droppable
                            </div>
                        </div>
                        <div
                            className="flex-grow flex flex-col"
                            style={{ minHeight: 100 }}
                        >
                            <div
                                className="flex items-center justify-center rounded-lg p-2 mb-1"
                                style={{ backgroundColor: 'lightblue' }}
                            >
                                Not Droppable
                            </div>
                            <Droppable
                                className="custom-dragging-over flex-grow p-4 u-border-default va-grey-300--background"
                                direction="horizontal"
                                id={2}
                            >
                                {droppables[2].items.map(
                                    (draggable, index): ReactElement => (
                                        <Draggable
                                            droppableId={2}
                                            id={index}
                                            key={index}
                                        >
                                            <Pill className="m-2">
                                                {draggable}
                                            </Pill>
                                        </Draggable>
                                    )
                                )}
                            </Droppable>
                        </div>
                    </div>
                    <Droppable
                        className="custom-dragging-over flex-grow p-4 u-border-default va-grey-300--background"
                        id={1}
                    >
                        {droppables[1].items.map(
                            (draggable, index): ReactElement => (
                                <Draggable
                                    droppableId={1}
                                    id={index}
                                    key={index}
                                >
                                    <Pill className="m-1">{draggable}</Pill>
                                </Draggable>
                            )
                        )}
                    </Droppable>
                </div>
            </DragNDropContext>
        </>
    );
};

export default CustomDroppablesExample;
