import React, { ReactElement, useState } from 'react';
import {
    Draggable,
    DragNDropContext,
    Droppable,
    DroppableDef
} from '@videoamp-private/preamp-plus';
import { Pill } from '@preamp/core';

const MultiTargetExample = (): ReactElement => {
    const [droppables, setDroppables] = useState<DroppableDef<string>[]>([
        { items: ['First', 'Second', 'Third'] },
        { items: [], receives: [0] },
        { items: [], receives: [0, 1] }
    ]);

    return (
        <>
            <div className="mb-4">Multi target</div>
            <DragNDropContext droppables={droppables} onDrop={setDroppables}>
                <div className="flex" style={{ gap: '1rem', minHeight: 200 }}>
                    <div className="flex flex-col w-1/3">
                        <h2>First Droppable</h2>
                        <p>Receives from: Any droppable</p>
                        <Droppable
                            className="justify-center h-full mt-2 p-4 u-border-default va-grey-300--background"
                            id={0}
                        >
                            {droppables[0].items.map(
                                (
                                    draggable: string,
                                    index: number
                                ): ReactElement => (
                                    <Draggable
                                        droppableId={0}
                                        id={index}
                                        key={index}
                                    >
                                        <Pill className="m-1">{draggable}</Pill>
                                    </Draggable>
                                )
                            )}
                        </Droppable>
                    </div>
                    <div className="flex flex-col w-1/3">
                        <h2>Second Droppable</h2>
                        <p>Receives from: First</p>
                        <Droppable
                            className="justify-center h-full mt-2 p-4 u-border-default va-grey-300--background"
                            id={1}
                        >
                            {droppables[1].items.map(
                                (
                                    draggable: string,
                                    index: number
                                ): ReactElement => (
                                    <Draggable
                                        droppableId={1}
                                        id={index}
                                        key={index}
                                    >
                                        <Pill className="m-1">{draggable}</Pill>
                                    </Draggable>
                                )
                            )}
                        </Droppable>
                    </div>
                    <div className="flex flex-col w-1/3">
                        <h2>Third Droppable</h2>
                        <p>Receives from: First and Second</p>
                        <Droppable
                            className="justify-center h-full mt-2 p-4 u-border-default va-grey-300--background"
                            id={2}
                        >
                            {droppables[2].items.map(
                                (
                                    draggable: string,
                                    index: number
                                ): ReactElement => (
                                    <Draggable
                                        droppableId={2}
                                        id={index}
                                        key={index}
                                    >
                                        <Pill className="m-1">{draggable}</Pill>
                                    </Draggable>
                                )
                            )}
                        </Droppable>
                    </div>
                </div>
            </DragNDropContext>
        </>
    );
};

export default MultiTargetExample;
