import React, { ReactElement, useState } from 'react';
import {
    Draggable,
    DragNDropContext,
    Droppable,
    DroppableDef
} from '@videoamp-private/preamp-plus';
import { Pill } from '@preamp/core';

const CustomCallbacksExample = (): ReactElement => {
    const [droppables, setDroppables] = useState<DroppableDef<string>[]>([
        { items: ['First', 'Second', 'Third'] },
        { items: [] }
    ]);
    const customCallback = (): void => {
        alert('Dropping Draggable!');
    };

    return (
        <>
            <div className="mb-4">Custom callbacks</div>
            <DragNDropContext
                afterDrop={customCallback}
                droppables={droppables}
                onDrop={setDroppables}
            >
                <div className="flex" style={{ gap: '1rem', minHeight: 200 }}>
                    <div className="flex flex-col" style={{ minWidth: 200 }}>
                        <Droppable
                            className="justify-center h-full mt-2 p-4 u-border-default va-grey-300--background"
                            id={0}
                        >
                            {droppables[0].items.map(
                                (
                                    draggable: string,
                                    index: number
                                ): ReactElement => (
                                    <Draggable
                                        droppableId={0}
                                        id={index}
                                        key={index}
                                    >
                                        <Pill className="m-1">{draggable}</Pill>
                                    </Draggable>
                                )
                            )}
                        </Droppable>
                    </div>
                    <div className="flex flex-col" style={{ minWidth: 200 }}>
                        <Droppable className="flex-grow mt-2" id={1}>
                            {droppables[1].items.map(
                                (
                                    draggable: string,
                                    index: number
                                ): ReactElement => (
                                    <Draggable
                                        droppableId={1}
                                        id={index}
                                        key={index}
                                    >
                                        <Pill className="m-1">{draggable}</Pill>
                                    </Draggable>
                                )
                            )}
                        </Droppable>
                    </div>
                </div>
            </DragNDropContext>
        </>
    );
};

export default CustomCallbacksExample;
