### Overview

External component from `@videoamp-private/preamp-plus` 

#### Row data

TreeAmp expects an array of objects representing each row with the following type definitions:

```ts
export interface RowDataObj {
  [key: string]: string | undefined;
}

export interface RowObj {
  children?: RowObj[];
  data: RowDataObj;
  key: string;
  selectable?: boolean;
}
```

Each row object's `data` property consists of user-defined values needed in order to render the row.

#### Sample row data

The following sample is a truncated version of the row data used to render most of the examples below. Any custom row data will appear within the code view. 

```ts
[
  {
    "children": [],
    "data": {
      "description": "Description of parent a",
      "name": "Parent a",
      "value": "value a",
      "value2": "value2 a"
    },
    "key": "a",
    "selectable": false
  },
  {
    "children": [
      {
        "data": {
          "name": "Child b-0",
          "value": "value b-0",
          "value2": "value2 b-0"
        },
        "key": "b-0",
        "selectable": false
      },
      {
        "data": {
          "name": "Child b-1",
          "value": "value b-1",
          "value2": "value2 b-1"
        },
        "key": "b-1"
      }
    ],
    "data": {
      "description": "Description of parent b",
      "name": "Parent b",
      "value": "value b",
      "value2": "value2 b"
    },
    "key": "b"
  }
]
```

#### Column data

TreeAmp's columns are also represented as an array of objects, defined as follows:

```ts
export interface ColumnObj {
  component?: (row: RowObj) => ReactNode;
  field?: string;
  headerText?: string;
  actions?: ActionTypes[];
}
```

`field` is the key for a given column, and should map to one of the rows' `data` properties. `component` represents a custom node, and `actions` is an array used to render the call-to-action buttons

#### Sample column data

The following sample is used to render most of the examples below

```ts
[
  {
    "field": "name",
    "headerText": "Entity name"
  },
  {
    "field": "value",
    "headerText": "Data point"
  },
  {
    "field": "value2",
    "headerText": "Data point 2"
  }
];
```
