import React, { ReactElement } from 'react';
import {
    Box,
    Card,
    CardActions,
    CardContent,
    CardHeader,
    ChevronDown,
    Collapse,
    IconButton,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const { useState } = React;

const ExpandableCardExample = (): ReactElement => {
    const [expanded, setExpanded] = useState<boolean>(false);
    const handleExpandClick = (): void => {
        setExpanded((prevState): boolean => !prevState);
    };

    return (
        <ThemeProvider>
            <Box component="section">
                <Typography
                    gutterBottom
                    sx={{
                        fontSize: '1rem',
                        lineHeight: 1.1
                    }}
                >
                    Expandable Card
                </Typography>
                <Card data-ui="card" sx={{ width: 190 }}>
                    <CardHeader
                        subheader="Try it!"
                        sx={{
                            fontSize: '1rem',
                            pb: 0
                        }}
                        title="Expandable Card"
                    />
                    <CardActions disableSpacing>
                        <IconButton
                            aria-expanded={expanded}
                            aria-label="show more"
                            data-ui="standard"
                            onClick={handleExpandClick}
                            size="small"
                            sx={{
                                transform: !expanded
                                    ? 'rotate(0deg)'
                                    : 'rotate(180deg)',
                                transition: 'transform ease 0.3s'
                            }}
                        >
                            <ChevronDown />
                        </IconButton>
                    </CardActions>
                    <Collapse in={expanded} timeout="auto" unmountOnExit>
                        <CardContent>
                            <Typography paragraph>
                                Lorem ipsum dolor sit amet, consectetur
                                adipiscing elit, sed do eiusmod tempor
                                incididunt ut labore et dolore magna aliqua. Ut
                                enim ad minim veniam.
                            </Typography>
                        </CardContent>
                    </Collapse>
                </Card>
            </Box>
        </ThemeProvider>
    );
};

export default ExpandableCardExample;
