import React, { ReactElement, useState } from 'react';

import {
    Box,
    Checkbox,
    FormControl,
    FormControlLabel,
    FormGroup,
    FormHelperText,
    FormLabel,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const CheckboxExample = (): ReactElement => {
    const [checked, setChecked] = useState([true, false]);
    const [state, setState] = useState({
        checkBox1: true,
        checkBox2: false,
        checkBox3: false
    });

    // Handling FormGroup state

    const handleChange = (event): void => {
        const { name, checked } = event.target;
        setState((prevState): typeof state => ({
            ...prevState,
            [name]: checked
        }));
    };

    const { checkBox1, checkBox2, checkBox3 } = state;
    const error =
        [checkBox1, checkBox2, checkBox3].filter((v): boolean => v).length !==
        2;

    //

    const handleChange1 = (event): void => {
        setChecked([event.target.checked, event.target.checked]);
    };

    const handleChange2 = (event): void => {
        setChecked([event.target.checked, checked[1]]);
    };

    const handleChange3 = (event): void => {
        setChecked([checked[0], event.target.checked]);
    };

    const children = (
        <Box sx={{ display: 'flex', flexDirection: 'column', ml: 3 }}>
            <FormControlLabel
                control={
                    <Checkbox checked={checked[0]} onChange={handleChange2} />
                }
                label="Child 1"
            />
            <FormControlLabel
                control={
                    <Checkbox checked={checked[1]} onChange={handleChange3} />
                }
                label="Child 2"
            />
        </Box>
    );

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom sx={{ mt: 4 }} variant="h5">
                Below are a few various instances of checkboxes
            </Typography>
            <Box
                sx={{
                    alignItems: 'flex-start',
                    display: 'flex',
                    flexDirection: 'column',
                    gap: 0
                }}
            >
                <FormControlLabel
                    control={<Checkbox />}
                    label="Normal checkbox"
                />
                <div>
                    <FormControlLabel
                        control={
                            <Checkbox
                                checked={checked[0] && checked[1]}
                                indeterminate={checked[0] !== checked[1]}
                                onChange={handleChange1}
                            />
                        }
                        label="Parent"
                    />
                    {children}
                </div>
                <FormControlLabel
                    control={<Checkbox disabled />}
                    label="Disabled checkbox"
                />
                <FormControlLabel
                    control={<Checkbox checked disabled />}
                    label="Disabled checked checkbox"
                />
                <FormControlLabel
                    control={<Checkbox checked disabled indeterminate />}
                    label="Disabled indeterminant checkbox"
                />
                <Typography
                    component="h2"
                    gutterBottom
                    sx={{ mt: 4 }}
                    variant="h5"
                >
                    FormGroup is a helpful wrapper used to group selection
                    control components.
                </Typography>
                <FormControl
                    component="fieldset"
                    error={error}
                    required
                    variant="standard"
                >
                    <FormLabel component="legend">
                        Required to Pick Two
                    </FormLabel>
                    <FormGroup>
                        <FormControlLabel
                            control={
                                <Checkbox
                                    checked={checkBox1}
                                    name="checkBox1"
                                    onChange={handleChange}
                                />
                            }
                            label="Checkbox 1"
                        />
                        <FormControlLabel
                            control={
                                <Checkbox
                                    checked={checkBox2}
                                    name="checkBox2"
                                    onChange={handleChange}
                                />
                            }
                            label="Checkbox 2"
                        />
                        <FormControlLabel
                            control={
                                <Checkbox
                                    checked={checkBox3}
                                    name="checkBox3"
                                    onChange={handleChange}
                                />
                            }
                            label="Checkbox 3"
                        />
                    </FormGroup>
                    <FormHelperText>You can display an error</FormHelperText>
                </FormControl>
            </Box>
        </ThemeProvider>
    );
};

export default CheckboxExample;
