import React, { ReactElement } from 'react';
import {
    ChevronDown,
    ChevronUp,
    DataGridPro,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const columns = [
    { field: 'id', headerName: 'ID', width: 110 },
    {
        field: 'firstName',
        headerName: 'First name',
        width: 150,
        editable: false
    },
    {
        field: 'lastName',
        headerName: 'Last name',
        width: 150,
        editable: false
    },
    {
        field: 'age',
        headerName: 'Age',
        width: 110,
        editable: false
    },
    {
        field: 'fullName',
        headerName: 'Full name',
        description: 'This column has a value getter and is not sortable.',
        sortable: false,
        width: 160,
        valueGetter: (params): string =>
            `${params.getValue(params.id, 'firstName') || ''} ${params.getValue(
                params.id,
                'lastName'
            ) || ''}`
    }
];

const rows = [
    { id: 1, lastName: 'Snow', firstName: 'Jon', age: 35 },
    { id: 2, lastName: 'Lannister', firstName: 'Cersei', age: 42 },
    { id: 3, lastName: 'Lannister', firstName: 'Jaime', age: 45 },
    { id: 4, lastName: 'Stark', firstName: 'Arya', age: 16 },
    { id: 5, lastName: 'Targaryen', firstName: 'Daenerys', age: null },
    { id: 6, lastName: 'Melisandre', firstName: null, age: 150 },
    { id: 7, lastName: 'Clifford', firstName: 'Ferrara', age: 44 },
    { id: 8, lastName: 'Frances', firstName: 'Rossini', age: 36 },
    { id: 9, lastName: 'Roxie', firstName: 'Harvey', age: 65 }
];

const BasicDataGridExample = (): ReactElement => {
    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Basic Data Grid
            </Typography>
            <DataGridPro
                autoHeight
                columns={columns}
                components={{
                    ColumnSortedAscendingIcon: ChevronUp,
                    ColumnSortedDescendingIcon: ChevronDown
                }}
                disableColumnFilter
                disableSelectionOnClick
                hideFooter
                rows={rows}
            />
        </ThemeProvider>
    );
};

export default BasicDataGridExample;
