import React, { ReactElement, useState } from 'react';
import {
    ChevronDown,
    ChevronUp,
    DataGridPro,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const columns = [
    { field: 'id', headerName: 'ID', width: 110 },
    {
        field: 'firstName',
        headerName: 'First name',
        width: 150,
        editable: false
    },
    {
        field: 'lastName',
        headerName: 'Last name',
        width: 150,
        editable: false
    },
    {
        field: 'height',
        headerName: 'Height',
        width: 110,
        editable: false
    },
    {
        field: 'origin',
        headerName: 'Origin',
        width: 150,
        editable: false
    }
];

const rows = [
    {
        id: 1,
        lastName: 'Solo',
        firstName: 'Han',
        height: 1.8,
        origin: 'Corellia'
    },
    {
        id: 2,
        lastName: 'Kenobi',
        firstName: 'Obi-Wan',
        height: 1.82,
        origin: 'Stewjon'
    },
    {
        id: 3,
        lastName: 'Skywalker',
        firstName: 'Anakin',
        height: 1.88,
        origin: 'Tatooine'
    },
    {
        id: 4,
        lastName: 'Palpatine',
        firstName: 'Sheev',
        height: 1.73,
        origin: 'Naboo'
    },
    { id: 5, lastName: null, firstName: 'Yoda', height: 0.66, origin: null },
    {
        id: 6,
        lastName: 'Jinn',
        firstName: 'Qui-Gon',
        height: 1.93,
        origin: 'Coruscant'
    },
    {
        id: 7,
        lastName: 'Skywalker',
        firstName: 'Luke',
        height: 1.72,
        origin: 'Tatooine'
    },
    {
        id: 8,
        lastName: 'Organa',
        firstName: 'Leia',
        height: 1.55,
        origin: 'Alderaan'
    },
    {
        id: 9,
        lastName: 'Windu',
        firstName: 'Mace',
        height: 1.92,
        origin: 'Haruun Kal'
    },
    {
        id: 10,
        lastName: null,
        firstName: 'Maul',
        height: 1.75,
        origin: 'Dathomir'
    },
    {
        id: 11,
        lastName: 'Amidala',
        firstName: 'Padmé',
        height: 1.65,
        origin: 'Naboo'
    },
    {
        id: 12,
        lastName: null,
        firstName: 'Grievous',
        height: 2.16,
        origin: 'Kalee'
    },
    {
        id: 13,
        lastName: 'Skywalker',
        firstName: 'Rey',
        height: 1.7,
        origin: 'Jakku'
    },
    {
        id: 14,
        lastName: 'Solo',
        firstName: 'Ben',
        height: 1.89,
        origin: 'Chandrila'
    },
    {
        id: 15,
        lastName: 'Tano',
        firstName: 'Ahsoka',
        height: 1.76,
        origin: 'Shili'
    },
    {
        id: 16,
        lastName: null,
        firstName: 'Chewbacca',
        height: 2.3,
        origin: 'Kashyyyk'
    }
];

const PaginationExample = (): ReactElement => {
    const [pageSize, setPageSize] = useState<number>(4);

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Data Grid with Pagination
            </Typography>
            <DataGridPro
                autoHeight
                columns={columns}
                components={{
                    ColumnSortedAscendingIcon: ChevronUp,
                    ColumnSortedDescendingIcon: ChevronDown
                }}
                disableColumnFilter
                disableSelectionOnClick
                onPageSizeChange={(newPageSize): void =>
                    setPageSize(newPageSize)
                }
                pageSize={pageSize}
                pagination
                rows={rows}
                rowsPerPageOptions={[4, 6, 8]}
            />
        </ThemeProvider>
    );
};

export default PaginationExample;
