import React, { ReactElement } from 'react';
import {
    ChevronDown,
    ChevronUp,
    DataGridPro,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const columns = [
    { field: 'id', headerName: 'ID', width: 110 },
    {
        field: 'firstName',
        headerName: 'First name',
        width: 150,
        editable: true
    },
    {
        field: 'lastName',
        headerName: 'Last name',
        width: 150,
        editable: true
    },
    {
        field: 'age',
        headerName: 'Age',
        width: 110,
        editable: true
    },
    {
        field: 'fullName',
        headerName: 'Full name',
        description: 'This column has a value getter and is not sortable.',
        sortable: false,
        width: 160,
        valueGetter: (params): string =>
            `${params.getValue(params.id, 'firstName') || ''} ${params.getValue(
                params.id,
                'lastName'
            ) || ''}`
    }
];

const rows = [
    { id: 1, lastName: 'Potter', firstName: 'Harry', age: 17 },
    { id: 2, lastName: 'Granger', firstName: 'Hermione', age: 18 },
    { id: 3, lastName: 'Longbottom', firstName: 'Neville', age: 17 },
    { id: 4, lastName: 'Malfoy', firstName: 'Draco', age: 18 },
    { id: 5, lastName: 'Weasley', firstName: 'Ron', age: 18 },
    { id: 6, lastName: 'Dumbledore', firstName: 'Albus', age: 116 },
    { id: 7, lastName: 'Snape', firstName: 'Serverus', age: 44 },
    { id: 8, lastName: 'McGonagall', firstName: 'Minerva', age: 70 },
    { id: 9, lastName: null, firstName: 'Dobby', age: null }
];

const SortableAndCheckableRowsExample = (): ReactElement => {
    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Sortable and Checkable Rows
            </Typography>
            <DataGridPro
                autoHeight
                checkboxSelection
                columns={columns}
                components={{
                    ColumnSortedAscendingIcon: ChevronUp,
                    ColumnSortedDescendingIcon: ChevronDown
                }}
                disableColumnFilter
                disableSelectionOnClick
                hideFooter
                rows={rows}
            />
        </ThemeProvider>
    );
};

export default SortableAndCheckableRowsExample;
