import React, { ReactElement, useState } from 'react';

import {
    Button,
    Close,
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    IconButton,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const DialogExample = (): ReactElement => {
    const [modalState, setModalState] = useState(false);
    const handleOpenModal = (): void => setModalState(true);
    const handleCloseModal = (): void => setModalState(false);

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                This is a description for the example Dialog.
            </Typography>
            <Button onClick={handleOpenModal}>Open dialog</Button>
            <Dialog
                aria-labelledby="dialog-title"
                fullWidth
                maxWidth="xl"
                onClose={handleCloseModal}
                open={modalState}
            >
                <DialogTitle id="dialog-title">
                    <Typography component="div" variant="h5">
                        Sample Modal
                        <Typography
                            sx={{
                                color: 'text.secondary',
                                mt: 0.25
                            }}
                            variant="body2"
                        >
                            Lorem ipsum dolor sit amet
                        </Typography>
                    </Typography>
                    <IconButton
                        aria-label="close"
                        edge="end"
                        onClick={handleCloseModal}
                    >
                        <Close />
                    </IconButton>
                </DialogTitle>
                <DialogContent>Some Content</DialogContent>
                <DialogActions>
                    <Button color="secondary" onClick={handleCloseModal}>
                        Discard changes
                    </Button>
                    <Button onClick={handleCloseModal}>Save changes</Button>
                </DialogActions>
            </Dialog>
        </ThemeProvider>
    );
};

export default DialogExample;
