import React, { ReactElement, useState } from 'react';

import {
    Audiences,
    Button,
    Box,
    Calendar,
    Close,
    CloudUpload,
    Delete,
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    IconButton,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const DialogHeaderOptionsExample = (): ReactElement => {
    const [modalState, setModalState] = useState(false);
    const handleOpenModal = (): void => setModalState(true);
    const handleCloseModal = (): void => setModalState(false);

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Dialog with header options.
            </Typography>
            <Button onClick={handleOpenModal}>Open dialog</Button>
            <Dialog
                aria-labelledby="dialog-headeroptions-title"
                fullWidth
                maxWidth="xl"
                onClose={handleCloseModal}
                open={modalState}
            >
                <DialogTitle id="dialog-headeroptions-title">
                    <Typography component="div" variant="h5">
                        Modal with Header Actions
                        <Typography
                            sx={{
                                color: 'text.secondary',
                                mt: 0.25
                            }}
                            variant="body2"
                        >
                            Lorem ipsum dolor sit amet, consectetur adipiscing
                            elit. Pellentesque lobortis quam in elit varius
                            vestibulum. Suspendisse hendrerit lacinia justo ut
                            facilisis. Nullam pharetra, felis ac condimentum
                            tristique, est nisi volutpat nisl.
                        </Typography>
                    </Typography>
                    <Box>
                        <IconButton aria-label="calendar">
                            <Calendar />
                        </IconButton>
                        <IconButton aria-label="audiences">
                            <Audiences />
                        </IconButton>
                        <IconButton aria-label="delete">
                            <Delete />
                        </IconButton>
                        <IconButton aria-label="cloud-upload">
                            <CloudUpload />
                        </IconButton>
                        <IconButton
                            aria-label="close"
                            onClick={handleCloseModal}
                        >
                            <Close />
                        </IconButton>
                    </Box>
                </DialogTitle>
                <DialogContent>Some Content</DialogContent>
                <DialogActions>
                    <Button color="secondary" onClick={handleCloseModal}>
                        Discard changes
                    </Button>
                    <Button onClick={handleCloseModal}>Save changes</Button>
                </DialogActions>
            </Dialog>
        </ThemeProvider>
    );
};

export default DialogHeaderOptionsExample;
