import React, { ReactElement, useCallback, useState } from 'react';

import {
    Box,
    FileUpload,
    FileUploadFile,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const MultipleFileUploadExample = (): ReactElement => {
    const [files, setFiles] = useState<FileUploadFile[]>([]);

    const onAdd = useCallback((selectedFiles: FileUploadFile[]): void => {
        setFiles((prevState): FileUploadFile[] =>
            prevState.concat(selectedFiles)
        );

        console.log('added', selectedFiles);
    }, []);
    const onRemove = useCallback((selectedFiles: FileUploadFile[]): void => {
        setFiles((prevState): FileUploadFile[] =>
            prevState.filter((file): boolean => !selectedFiles.includes(file))
        );

        console.log('removed', selectedFiles);
    }, []);

    return (
        <ThemeProvider>
            <Box
                sx={{
                    maxWidth: 360
                }}
            >
                <Typography component="h2" gutterBottom variant="h4">
                    Multiple
                </Typography>
                <FileUpload
                    files={files}
                    multiple
                    onAdd={onAdd}
                    onRemove={onRemove}
                />
            </Box>
        </ThemeProvider>
    );
};

export default MultipleFileUploadExample;
