import React, {
    ChangeEvent,
    ReactElement,
    useCallback,
    useEffect,
    useState
} from 'react';

import {
    Box,
    FileUpload,
    FileUploadFile,
    FormControlLabel,
    Switch,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const StatusFileUploadExample = (): ReactElement => {
    const [files, setFiles] = useState<FileUploadFile[]>([]);
    const [shouldError, setShouldError] = useState<boolean>(false);

    const onAdd = useCallback((selectedFiles: FileUploadFile[]): void => {
        setFiles(
            selectedFiles.map(
                (selectedFile): FileUploadFile => ({
                    ...selectedFile,
                    status: 'pending'
                })
            )
        );

        console.log('added', selectedFiles);
    }, []);
    const onRemove = useCallback((selectedFiles: FileUploadFile[]): void => {
        setFiles([]);

        console.log('removed', selectedFiles);
    }, []);

    useEffect((): void | (() => void) => {
        const pendingFiles = files.filter(
            (file): boolean => file.status === 'pending'
        );

        if (pendingFiles.length > 0) {
            const timeouts = pendingFiles.map((pendingFile): number =>
                window.setTimeout((): void => {
                    setFiles((prevState): FileUploadFile[] =>
                        prevState.map(
                            (file): FileUploadFile =>
                                file === pendingFile
                                    ? {
                                          ...file,
                                          status: shouldError
                                              ? 'error'
                                              : 'success'
                                      }
                                    : file
                        )
                    );
                }, 3000)
            );

            return (): void => {
                timeouts.forEach(window.clearTimeout);
            };
        }
    }, [files, shouldError]);

    return (
        <ThemeProvider>
            <Box
                sx={{
                    maxWidth: 360
                }}
            >
                <Typography component="h2" gutterBottom variant="h4">
                    Single with status
                </Typography>
                <FormControlLabel
                    control={
                        <Switch
                            checked={shouldError}
                            onChange={(
                                event: ChangeEvent<HTMLInputElement>
                            ): void => {
                                setShouldError(event.target.checked);
                            }}
                        />
                    }
                    label="Should Error"
                    sx={{
                        mb: 2,
                        mt: 3
                    }}
                />
                <FileUpload files={files} onAdd={onAdd} onRemove={onRemove} />
            </Box>
        </ThemeProvider>
    );
};

export default StatusFileUploadExample;
