import React, { ReactElement, useState } from 'react';

import {
    Box,
    Checkbox,
    List,
    ListItem,
    ListItemButton,
    ListItemText,
    ListItemIcon,
    ThemeProvider,
    Typography
} from '@preamp/rev';
import { Organization } from 'packages/rev/components/icons';

const ListExample = (): ReactElement => {
    const [checked, setChecked] = useState([0]);

    const handleChecked = (value): (() => void) => (): void => {
        const newChecked = [...checked];
        const currentIndex = checked.indexOf(value);
        if (!checked.includes(value)) {
            newChecked.push(value);
        } else {
            newChecked.splice(currentIndex, 1);
        }
        setChecked(newChecked);
    };

    return (
        <ThemeProvider>
            <Box
                sx={{
                    width: 500
                }}
            >
                <Typography
                    component="h2"
                    gutterBottom
                    sx={{ mt: 4 }}
                    variant="h5"
                >
                    Example of the List component with different text types.
                </Typography>
                <List>
                    <ListItem disablePadding>
                        <ListItemButton
                            onClick={handleChecked(0)}
                            selected={checked.includes(0)}
                        >
                            <ListItemIcon>
                                <Checkbox checked={checked.includes(0)} />
                            </ListItemIcon>
                            <ListItemText primary="Primary Text" />
                        </ListItemButton>
                    </ListItem>
                    <ListItem disablePadding>
                        <ListItemButton
                            onClick={handleChecked(1)}
                            selected={checked.includes(1)}
                        >
                            <ListItemIcon>
                                <Checkbox checked={checked.includes(1)} />
                            </ListItemIcon>
                            <ListItemText secondary="Secondary Text" />
                        </ListItemButton>
                    </ListItem>
                    <ListItem disablePadding>
                        <ListItemButton
                            onClick={handleChecked(2)}
                            selected={checked.includes(2)}
                        >
                            <ListItemIcon>
                                <Checkbox checked={checked.includes(2)} />
                            </ListItemIcon>
                            <ListItemText primary="Icon to the Right" />
                            <ListItemIcon>
                                <Organization />
                            </ListItemIcon>
                        </ListItemButton>
                    </ListItem>
                    <ListItem disablePadding>
                        <ListItemButton
                            onClick={handleChecked(3)}
                            selected={checked.includes(3)}
                        >
                            <ListItemIcon>
                                <Checkbox checked={checked.includes(3)} />
                            </ListItemIcon>
                            <ListItemText
                                primary="Primary Text Title"
                                secondary="Secondary Text Subtitle"
                            />
                        </ListItemButton>
                    </ListItem>
                </List>
            </Box>
        </ThemeProvider>
    );
};

export default ListExample;
