import React, { ReactElement, useCallback, useState } from 'react';

import {
    Audiences,
    Box,
    Button,
    ChevronDown,
    Divider,
    ListItemButton,
    ListItemIcon,
    ListItemText,
    ListSubheader,
    Measure,
    Menu,
    MenuItem,
    Power,
    Search,
    ThemeProvider,
    Typography,
    TypographyProps
} from '@preamp/rev';

export const MenuExample = (): ReactElement => {
    const [basicAnchorEl, setBasicAnchorEl] = useState<HTMLElement>(null);
    const [dashboardAnchorEl, setDashboardMenuEl] = useState<HTMLElement>(null);
    const [customizedAnchorEl, setCustomizedAnchorEl] = useState<HTMLElement>(
        null
    );

    const onCloseBasicMenu = useCallback((): void => {
        setBasicAnchorEl(null);
    }, []);

    const onCloseDashboardMenu = useCallback((): void => {
        setDashboardMenuEl(null);
    }, []);

    const onCloseCustomizedMenu = useCallback((): void => {
        setCustomizedAnchorEl(null);
    }, []);

    const primaryTypographyProps: TypographyProps = {
        sx: {
            fontFamily: 'var(--font-regular)'
        },
        variant: 'body1'
    };

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom sx={{ mt: 4 }} variant="h5">
                Basic Menu
            </Typography>

            <Button
                onClick={(event): void => setBasicAnchorEl(event.currentTarget)}
            >
                Open Basic Menu
            </Button>

            <Menu
                anchorEl={basicAnchorEl}
                id="basic-menu"
                MenuListProps={{
                    'aria-labelledby': 'basic-button'
                }}
                onClose={onCloseBasicMenu}
                open={Boolean(basicAnchorEl)}
            >
                <MenuItem onClick={onCloseBasicMenu}>Profile</MenuItem>
                <MenuItem onClick={onCloseBasicMenu}>My account</MenuItem>
                <MenuItem onClick={onCloseBasicMenu}>Logout</MenuItem>
            </Menu>

            <Typography component="h2" gutterBottom sx={{ mt: 4 }} variant="h5">
                Customized Menu
            </Typography>

            <Button
                endIcon={<ChevronDown />}
                onClick={(event): void =>
                    setCustomizedAnchorEl(event.currentTarget)
                }
                variant="contained"
            >
                Open Customized Menu
            </Button>
            <Menu
                anchorEl={customizedAnchorEl}
                id="mui-menu"
                MenuListProps={{
                    'aria-labelledby': 'mui-button'
                }}
                onClose={onCloseCustomizedMenu}
                open={Boolean(customizedAnchorEl)}
            >
                <MenuItem disableRipple onClick={onCloseCustomizedMenu}>
                    <ListItemIcon>
                        <Search fontSize="inherit" />
                    </ListItemIcon>
                    Search
                </MenuItem>
                <MenuItem disableRipple onClick={onCloseCustomizedMenu}>
                    <ListItemIcon>
                        <Audiences fontSize="inherit" />
                    </ListItemIcon>
                    Audiences
                </MenuItem>
                <Divider sx={{ my: 0.5 }} />
                <MenuItem disableRipple onClick={onCloseCustomizedMenu}>
                    <ListItemIcon>
                        <Measure fontSize="inherit" />
                    </ListItemIcon>
                    Measure
                </MenuItem>
                <MenuItem disableRipple onClick={onCloseCustomizedMenu}>
                    <ListItemIcon>
                        <Power fontSize="inherit" />
                    </ListItemIcon>
                    Power
                </MenuItem>
            </Menu>

            <Typography component="h2" gutterBottom sx={{ mt: 4 }} variant="h5">
                Dashboard Menu
            </Typography>

            <Button
                onClick={(event): void =>
                    setDashboardMenuEl(event.currentTarget)
                }
            >
                Open Dashboard Menu
            </Button>
            <Menu
                anchorEl={dashboardAnchorEl}
                onClose={onCloseDashboardMenu}
                open={Boolean(dashboardAnchorEl)}
            >
                <Box sx={{ p: 2 }}>
                    <Typography
                        component={ListSubheader}
                        gutterBottom
                        variant="subtitle1"
                    >
                        Heading 1
                    </Typography>
                    <ListItemButton onClick={onCloseDashboardMenu}>
                        <ListItemIcon
                            sx={{
                                backgroundColor: 'primary.main',
                                borderRadius: 1,
                                color: 'primary.contrastText',
                                minWidth: 'unset',
                                mr: 1,
                                p: 0.75
                            }}
                        >
                            <Audiences
                                color="inherit"
                                sx={{
                                    height: '0.75em',
                                    width: '0.75em'
                                }}
                            />
                        </ListItemIcon>
                        <ListItemText
                            primary="MenuItem 1"
                            primaryTypographyProps={primaryTypographyProps}
                            secondary="This is a description"
                        />
                    </ListItemButton>
                    <ListItemButton onClick={onCloseDashboardMenu}>
                        <ListItemText
                            primary="MenuItem 2"
                            primaryTypographyProps={primaryTypographyProps}
                            secondary="This is a description"
                        />
                    </ListItemButton>
                    <ListItemButton onClick={onCloseDashboardMenu}>
                        <ListItemIcon
                            sx={{
                                minWidth: 'unset',
                                mr: 1
                            }}
                        >
                            <Measure />
                        </ListItemIcon>
                        <ListItemText
                            primary="MenuItem 3"
                            primaryTypographyProps={primaryTypographyProps}
                        />
                    </ListItemButton>
                    <Typography
                        component={ListSubheader}
                        gutterBottom
                        sx={{
                            mt: 2
                        }}
                        variant="subtitle1"
                    >
                        Heading 2
                    </Typography>
                    <ListItemButton onClick={onCloseDashboardMenu}>
                        <ListItemText
                            primary="MenuItem 4"
                            primaryTypographyProps={primaryTypographyProps}
                        />
                    </ListItemButton>
                </Box>
            </Menu>
        </ThemeProvider>
    );
};

export default MenuExample;
