import React, { ReactElement, useState } from 'react';

import {
    Box,
    FormControlLabel,
    FormLabel,
    RadioGroup,
    Radio,
    Switch,
    ThemeProvider
} from '@preamp/rev';

const RadioGroupExample = (): ReactElement => {
    const [inline, setInline] = useState(false);
    const [selected, setSelected] = useState(null);
    const handleInline = (): void => {
        setInline(!inline);
    };
    const handleChange = (event): void => {
        setSelected(event.target.value);
    };

    return (
        <ThemeProvider>
            <Box
                sx={{
                    alignItems: 'flex-start',
                    display: 'flex',
                    flexDirection: 'column',
                    gap: 2
                }}
            >
                <FormLabel
                    component="legend"
                    sx={{
                        fontSize: 16
                    }}
                >
                    Direction
                </FormLabel>
                <FormControlLabel
                    control={<Switch onChange={handleInline} />}
                    label="This toggle enables the row prop"
                    sx={{
                        paddingLeft: '1rem'
                    }}
                />
                <Box
                    sx={{
                        backgroundColor: '#f5f5f5',
                        fontSize: 12,
                        padding: '1rem',
                        width: '100%'
                    }}
                >
                    <p>
                        {selected === null
                            ? 'No Radio Button is selected.'
                            : `Radio Button ${selected} is selected.`}
                    </p>
                </Box>
                <FormLabel
                    component="legend"
                    sx={{
                        fontSize: 16
                    }}
                >
                    Radio Group Title:
                </FormLabel>
                <RadioGroup
                    onChange={handleChange}
                    row={inline}
                    sx={{
                        paddingLeft: '0.5rem'
                    }}
                >
                    <FormControlLabel
                        control={<Radio />}
                        label="Button 1"
                        value="1"
                    />
                    <FormControlLabel
                        control={<Radio />}
                        label="Button 2"
                        value="2"
                    />
                    <FormControlLabel
                        control={<Radio />}
                        label="Button 3"
                        value="3"
                    />
                    <FormControlLabel
                        control={<Radio />}
                        label="Button 4"
                        value="4"
                    />
                </RadioGroup>
            </Box>
        </ThemeProvider>
    );
};

export default RadioGroupExample;
