import React, { ReactElement, ReactText, useState } from 'react';

import {
    Box,
    FormControl,
    InputLabel,
    ListItemText,
    MenuItem,
    Select,
    ThemeProvider,
    VideoAmp
} from '@preamp/rev';

const boxStyles = { mb: 4, width: 300 };
const options = [
    {
        label: 'Option 1',
        description: 'This is a description',
        value: '1'
    },
    {
        label: 'Option 2',
        description: 'Another description',
        value: '2'
    },
    {
        label: 'Option 3',
        description: 'New description here',
        value: '3'
    },
    {
        label: 'Option 4',
        description: 'Hello world description',
        value: '4'
    },
    {
        label: 'Option 5',
        description: 'Last description',
        value: '5'
    }
];

const placeholder = 'Placeholder';

const SelectExample = (): ReactElement => {
    const [placeholderValue, setPlaceholderValue] = useState('');
    const [standardValue, setStandardValue] = useState('1');
    const [concatSelectValue, setConcatSelectValue] = useState('1');
    const [descriptionValue, setDescriptionValue] = useState('');
    const [iconValue, setIconValue] = useState('');

    return (
        <ThemeProvider>
            <Box component="section" sx={boxStyles}>
                <InputLabel htmlFor="select-basic">Standard Select</InputLabel>
                <FormControl fullWidth>
                    <Select
                        data-ui="standard"
                        inputProps={{ id: 'select-basic' }}
                        onChange={({ target }): void => {
                            setStandardValue(
                                typeof target.value === 'string'
                                    ? target.value
                                    : ''
                            );
                        }}
                        value={standardValue}
                    >
                        {options.map(
                            ({ label, value }): ReactElement => (
                                <MenuItem
                                    data-ui={`standard-option-${value}`}
                                    key={value}
                                    value={value}
                                >
                                    {label}
                                </MenuItem>
                            )
                        )}
                    </Select>
                </FormControl>
            </Box>
            <Box component="section" sx={boxStyles}>
                <InputLabel htmlFor="select-placeholder">
                    Outlined with Placeholder
                </InputLabel>
                <FormControl fullWidth>
                    <Select
                        data-ui="placeholder"
                        displayEmpty
                        inputProps={{ id: 'select-placeholder' }}
                        onChange={({ target }): void => {
                            setPlaceholderValue(
                                typeof target.value === 'string'
                                    ? target.value
                                    : ''
                            );
                        }}
                        renderValue={(value): ReactText => {
                            if (!value) {
                                return placeholder;
                            }

                            const option = options.find(
                                (item): boolean => item.value === value
                            );

                            return option ? option.label : placeholder;
                        }}
                        size="small"
                        value={placeholderValue}
                        variant="outlined"
                    >
                        {options.map(
                            ({ label, value }): ReactElement => (
                                <MenuItem
                                    data-ui={`placeholder-option-${value}`}
                                    key={value}
                                    value={value}
                                >
                                    {label}
                                </MenuItem>
                            )
                        )}
                    </Select>
                </FormControl>
            </Box>
            <Box component="section" sx={boxStyles}>
                <InputLabel htmlFor="select-description">
                    Select with Descriptions
                </InputLabel>
                <FormControl fullWidth>
                    <Select
                        data-ui="select-description"
                        displayEmpty
                        inputProps={{ id: 'select-description' }}
                        onChange={(event): void => {
                            setDescriptionValue(event.target.value);
                        }}
                        renderValue={(value): ReactText => {
                            if (!value) {
                                return placeholder;
                            }

                            const option = options.find(
                                (item): boolean => item.value === value
                            );

                            return option ? option.label : placeholder;
                        }}
                        size="small"
                        value={descriptionValue}
                        variant="outlined"
                    >
                        {options.map(
                            ({ label, description, value }): ReactElement => (
                                <MenuItem
                                    data-ui={`description-option-${value}`}
                                    key={value}
                                    value={value}
                                >
                                    <ListItemText
                                        primary={label}
                                        secondary={description}
                                    />
                                </MenuItem>
                            )
                        )}
                    </Select>
                </FormControl>
            </Box>
            <Box component="section" sx={boxStyles}>
                <InputLabel htmlFor="select-icon">
                    Select with Option Icons
                </InputLabel>
                <FormControl fullWidth>
                    <Select
                        data-ui="select-icon"
                        displayEmpty
                        inputProps={{ id: 'select-icon' }}
                        onChange={({ target }): void => {
                            setIconValue(
                                typeof target.value === 'string'
                                    ? target.value
                                    : ''
                            );
                        }}
                        size="small"
                        value={iconValue}
                        variant="outlined"
                    >
                        <MenuItem disabled value="">
                            Select Option
                        </MenuItem>
                        {options.map(
                            ({ label, value }): ReactElement => (
                                <MenuItem
                                    data-ui={`icon-option-${value}`}
                                    key={value}
                                    value={value}
                                >
                                    <VideoAmp sx={{ mr: 1, width: 16 }} />
                                    {label}
                                </MenuItem>
                            )
                        )}
                    </Select>
                </FormControl>
            </Box>
            <Box component="section" sx={boxStyles}>
                <InputLabel htmlFor="select-basic-compact">
                    Basic Compact
                </InputLabel>
                <FormControl margin="dense">
                    <Select
                        data-ui="standard"
                        displayEmpty
                        inputProps={{ id: 'select-basic-compact' }}
                        onChange={({ target }): void => {
                            setConcatSelectValue(
                                typeof target.value === 'string'
                                    ? target.value
                                    : ''
                            );
                        }}
                        value={concatSelectValue}
                        variant="outlined"
                    >
                        {options.map(
                            ({ label, value }): ReactElement => (
                                <MenuItem
                                    data-ui={`standard-option-${value}`}
                                    dense
                                    key={value}
                                    value={value}
                                >
                                    {label}
                                </MenuItem>
                            )
                        )}
                    </Select>
                </FormControl>
            </Box>
        </ThemeProvider>
    );
};

export default SelectExample;
