import React, { ReactElement } from 'react';

import {
    Autocomplete,
    Box,
    InputLabel,
    TextField,
    ThemeProvider
} from '@preamp/rev';

const films = [
    { label: 'Snow White and the Seven Dwarfs', year: 1937 },
    { label: 'Cinderella', year: 1950 },
    { label: 'Sleeping Beauty', year: 1959 },
    { label: 'The Little Mermaid', year: 1989 },
    { label: 'Beauty and the Beast', year: 1991 },
    { label: 'Aladdin', year: 1992 },
    { label: 'Pocahontas', year: 1995 },
    { label: 'Mulan', year: 1998 },
    { label: 'The Princess and the Frog', year: 2009 },
    { label: 'Tangled', year: 2010 },
    { label: 'Brave', year: 2012 },
    { label: 'Moana', year: 2016 },
    { label: 'Raya and the Last Dragon', year: 2021 }
];

const games = [
    {
        category: 'Platform Games',
        description: 'Option Description',
        label: 'Super Mario 64',
        value: 'super-mario'
    },
    {
        category: 'Platform Games',
        description: 'Publisher: Naughty Dog',
        label: 'Crash Bandicoot',
        value: 'crash-bandicoot'
    },
    {
        category: 'Shooter Games',
        description: 'Publisher: Bethesda Softworks',
        label: 'Doom Eternal',
        value: 'doom-eternal'
    },
    {
        category: 'Shooter Games',
        description: 'Publisher: Xbox Game Studios',
        label: 'Halo Infinite',
        value: 'halo-infinite'
    },
    {
        category: 'Survival Games',
        description: 'Publisher: Mojang Studios',
        label: 'Minecraft',
        value: 'minecraft'
    },
    {
        category: 'Survival Games',
        description: 'Publisher: Klei Entertainment',
        label: "Don't Starve",
        value: 'dont-starve'
    }
];

const AutoCompleteExample = (): ReactElement => {
    return (
        <ThemeProvider>
            <Box component="section" sx={{ mb: 4 }}>
                <InputLabel htmlFor="auto-basic">
                    Standard Autocomplete
                </InputLabel>
                <Autocomplete
                    id="auto-basic"
                    options={films}
                    renderInput={(params): ReactElement => (
                        <TextField
                            {...params}
                            placeholder="Select Movie"
                            size="small"
                        />
                    )}
                    sx={{ width: 300 }}
                />
            </Box>
            <Box component="section" sx={{ mb: 4 }}>
                <InputLabel htmlFor="auto-grouped">
                    Autocomplete with Grouped Options
                </InputLabel>
                <Autocomplete
                    groupBy={(option): string => option.category}
                    id="auto-grouped"
                    options={games}
                    renderInput={(params): ReactElement => (
                        <TextField
                            {...params}
                            placeholder="Select Game"
                            size="small"
                        />
                    )}
                    sx={{ width: 300 }}
                />
            </Box>
            <Box component="section" sx={{ mb: 4 }}>
                <InputLabel htmlFor="auto-creatable">
                    Autocomplete with Creatable Option
                </InputLabel>
                <Autocomplete
                    freeSolo
                    id="auto-creatable"
                    options={films}
                    renderInput={(params): ReactElement => (
                        <TextField
                            {...params}
                            placeholder="Enter Movie"
                            size="small"
                        />
                    )}
                    sx={{ width: 300 }}
                />
            </Box>
        </ThemeProvider>
    );
};

export default AutoCompleteExample;
