import React, { ReactElement, useState } from 'react';

import {
    Autocomplete,
    Box,
    Check,
    InputLabel,
    MenuItem,
    TextField,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const checkStyles = {
    height: 21,
    ml: -1,
    mr: 0.5,
    width: 16
};
const disabledOptions = ['ashe', 'caitlyn', 'jinx'];
const options = [
    { label: 'Akshan', value: 'akshan' },
    { label: 'Aphelios', value: 'aphelios' },
    { label: 'Ashe', value: 'ashe' },
    { label: 'Azir', value: 'azir' },
    { label: 'Caitlyn', value: 'caitlyn' },
    { label: 'Corki', value: 'corki' },
    { label: 'Draven', value: 'draven' },
    { label: 'Ezreal', value: 'ezreal' },
    { label: 'Graves', value: 'graves' },
    { label: 'Jayce', value: 'jayce' },
    { label: 'Jhin', value: 'jhin' },
    { label: 'Jinx', value: 'jinx' },
    { label: "Kai'Sa", value: 'kaisa' },
    { label: 'Kalista', value: 'kalista' },
    { label: 'Kennen', value: 'kennen' },
    { label: 'Kindred', value: 'kindred' },
    { label: "Kog'Maw", value: 'kogmaw' },
    { label: 'Lucian', value: 'lucian' },
    { label: 'Miss Fortune', value: 'missfortune' },
    { label: 'Quinn', value: 'quinn' }
];

const MultiSelectExample = (): ReactElement => {
    const [values, setValues] = useState([]);
    const [autoValues, setAutoValues] = useState([]);

    return (
        <ThemeProvider>
            <Box component="section" sx={{ mb: 4 }}>
                <InputLabel htmlFor="multi-basic">
                    Standard Multi Select
                </InputLabel>
                <Autocomplete
                    disableClearable
                    disableCloseOnSelect
                    getOptionLabel={(option): string => option.label}
                    id="multi-basic"
                    multiple
                    onChange={(_event, value): void => {
                        setValues(value);
                    }}
                    options={options}
                    renderInput={(params): ReactElement => (
                        <TextField {...params} placeholder="Select Champions" />
                    )}
                    renderOption={(props, option): ReactElement => (
                        <MenuItem
                            {...props}
                            data-ui={`auto-multi-option-${option.value}`}
                        >
                            {values.includes(option) && (
                                <Check sx={checkStyles} />
                            )}
                            <Typography
                                sx={{ pl: values.includes(option) ? 0 : 1.5 }}
                            >
                                {option.label}
                            </Typography>
                        </MenuItem>
                    )}
                    size="small"
                    sx={{ width: 450 }}
                />
            </Box>
            <Box component="section" sx={{ mb: 4 }}>
                <InputLabel htmlFor="multi-delete">
                    Multi Select with Disabled Options
                </InputLabel>
                <Autocomplete
                    disableClearable
                    disableCloseOnSelect
                    getOptionLabel={(option): string => option.label}
                    id="multi-delete"
                    multiple
                    onChange={(_event, value): void => {
                        setAutoValues(value);
                    }}
                    options={options}
                    renderInput={(params): ReactElement => (
                        <TextField {...params} placeholder="Select Champions" />
                    )}
                    renderOption={(props, option): ReactElement => (
                        <MenuItem
                            {...props}
                            data-ui={`auto-multi-option-${option.value}`}
                            disabled={disabledOptions.includes(option.value)}
                        >
                            {autoValues.includes(option) && (
                                <Check sx={checkStyles} />
                            )}
                            <Typography
                                sx={{
                                    pl: autoValues.includes(option) ? 0 : 1.5
                                }}
                            >
                                {option.label}
                            </Typography>
                        </MenuItem>
                    )}
                    size="small"
                    sx={{ width: 450 }}
                />
            </Box>
        </ThemeProvider>
    );
};

export default MultiSelectExample;
