import React, { ReactElement } from 'react';

import { Box, Slider, ThemeProvider, Typography } from '@preamp/rev';

const SliderExample = (): ReactElement => {
    const [value, setValue] = React.useState<number | number[]>(30);

    const handleSliderChange = event => {
        setValue(event.target.value);
    };

    const customMarks = [
        {
            value: 0,
            label: '0'
        },
        {
            value: 10,
            label: '10'
        },
        {
            value: 20,
            label: '20'
        },
        {
            value: 30,
            label: '30'
        },
        {
            value: 40,
            label: '40'
        },
        {
            value: 50,
            label: '50'
        }
    ];

    return (
        <ThemeProvider>
            <Box sx={{ width: 300 }}>
                <Typography component="h2" gutterBottom variant="h5">
                    Continuous Slider
                </Typography>
                <Slider onChange={handleSliderChange} value={value} />
            </Box>
            <Box sx={{ width: 300 }}>
                <Typography component="h2" gutterBottom variant="h5">
                    Discrete Slider
                </Typography>
                <Slider
                    aria-label="Temperature"
                    defaultValue={30}
                    marks
                    max={110}
                    min={10}
                    step={10}
                    valueLabelDisplay="auto"
                />
            </Box>
            <Box sx={{ width: 300 }}>
                <Typography component="h2" gutterBottom variant="h5">
                    Custom Marks Slider
                </Typography>
                <Slider
                    aria-label="Temperature"
                    defaultValue={30}
                    marks={customMarks}
                    max={50}
                    step={10}
                    valueLabelDisplay="auto"
                />
            </Box>
        </ThemeProvider>
    );
};

export default SliderExample;
