import React, { ReactElement, useState } from 'react';

import { capitalize } from 'lodash';

import {
    Alert,
    AlertColor,
    AlertTitle,
    Box,
    Button,
    Snackbar,
    SnackbarOrigin,
    Slide,
    SlideProps,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const anchorOrigin: SnackbarOrigin = {
    horizontal: 'right',
    vertical: 'top'
};
const TransitionComponent = (props: SlideProps): ReactElement => (
    <Slide {...props} direction="left" />
);

const SnackbarExample = (): ReactElement => {
    const [open, setOpen] = useState<boolean>(false);
    const [severity, setSeverity] = useState<AlertColor | null>(null);

    const handleClick = (alertColor: AlertColor): (() => void) => (): void => {
        setSeverity(alertColor);
        setOpen(true);
    };
    const onClose = (): void => {
        setOpen(false);
    };

    return (
        <ThemeProvider>
            <Typography paragraph variant="h5">
                Click a button to open the Snackbar.
            </Typography>
            <Box
                sx={{
                    display: 'flex',
                    flexWrap: 'wrap',
                    gap: 1
                }}
            >
                <Button color="primary" onClick={handleClick('info')}>
                    Info Snackbar
                </Button>
                <Button color="secondary" onClick={handleClick('warning')}>
                    Warning Snackbar
                </Button>
                <Button color="success" onClick={handleClick('success')}>
                    Success Snackbar
                </Button>
                <Button color="error" onClick={handleClick('error')}>
                    Error Snackbar
                </Button>
            </Box>
            <Snackbar
                anchorOrigin={anchorOrigin}
                open={open}
                TransitionComponent={TransitionComponent}
            >
                <Alert onClose={onClose} severity={severity}>
                    <AlertTitle>{capitalize(severity)} Snackbar</AlertTitle>
                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                </Alert>
            </Snackbar>
        </ThemeProvider>
    );
};

export default SnackbarExample;
