import React, { ReactElement, useEffect, useState } from 'react';

import {
    Box,
    Button,
    Step,
    StepLabel,
    Stepper,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const steps = ['LABEL 1', 'LABEL 2', 'LABEL 3', 'LABEL 4', 'LABEL 5'];

const StepperExample = (): ReactElement => {
    const [activeStep, setActiveStep] = useState<number>(0);
    const [completedStep, setCompletedStep] = useState<number>(0);

    function onNext(): void {
        setActiveStep((prevState): number => prevState + 1);
    }
    function onPrev(): void {
        setActiveStep((prevState): number => prevState - 1);
    }
    function reset(): void {
        setActiveStep(0);
        setCompletedStep(0);
    }

    useEffect((): void => {
        if (activeStep > completedStep) {
            setCompletedStep(activeStep);
        }
    }, [activeStep, completedStep]);

    return (
        <ThemeProvider>
            <Typography paragraph sx={{ my: 3 }} variant="h5">
                Stepper is a component that displays a user’s progress in
                completing a stepped task within an application.
            </Typography>
            <Box
                sx={{
                    display: 'flex',
                    flexDirection: 'column',
                    position: 'relative',
                    width: '100%'
                }}
            >
                <Stepper activeStep={activeStep}>
                    {steps.map(
                        (label, i): ReactElement => (
                            <Step
                                active={i === activeStep}
                                completed={completedStep > i}
                                disabled={i > completedStep}
                                key={label}
                                onClick={
                                    i <= completedStep
                                        ? (): void => setActiveStep(i)
                                        : undefined
                                }
                            >
                                <StepLabel>{label}</StepLabel>
                            </Step>
                        )
                    )}
                </Stepper>
                <Box
                    sx={{
                        display: 'flex',
                        flexWrap: 'wrap',
                        gap: 1,
                        mt: 3
                    }}
                >
                    <Button color="secondary" onClick={reset}>
                        Reset Steps
                    </Button>
                    <Button disabled={activeStep === 0} onClick={onPrev}>
                        Previous Step
                    </Button>
                    <Button
                        disabled={activeStep === steps.length}
                        onClick={onNext}
                    >
                        Complete Step
                    </Button>
                </Box>
            </Box>
        </ThemeProvider>
    );
};

export default StepperExample;
