import React, { ReactElement, useState } from 'react';

import {
    FormControl,
    FormControlLabel,
    FormGroup,
    FormHelperText,
    FormLabel,
    Link,
    ThemeProvider,
    Typography,
    Switch,
    Box
} from '@preamp/rev';

const SwitchExample = (): ReactElement => {
    const [state, setState] = useState({
        switch1: true,
        switch2: false,
        switch3: false
    });

    const handleChange = (event): void => {
        const { name, checked } = event.target;
        setState((prevState): typeof state => ({
            ...prevState,
            [name]: checked
        }));
    };
    return (
        <ThemeProvider>
            <Box
                sx={{
                    alignItems: 'flex-start',
                    display: 'flex',
                    flexDirection: 'column',
                    gap: 2
                }}
            >
                <FormControlLabel control={<Switch />} label="Off" />
                <FormControlLabel
                    control={<Switch defaultChecked />}
                    label="On"
                />
                <FormControlLabel
                    control={<Switch disabled />}
                    label="Disabled Off"
                />
                <FormControlLabel
                    control={<Switch checked disabled />}
                    label="Disabled On"
                />
                <Typography
                    component="h2"
                    gutterBottom
                    sx={{ mt: 4 }}
                    variant="h5"
                >
                    FormGroup is a helpful wrapper used to group selection
                    controls components that provides an easier API. However,
                    you are encouraged to use{' '}
                    <Link href="/#/rev/components/Checkbox">Checkboxes</Link>{' '}
                    instead if multiple related controls are required.
                </Typography>
                <FormControl component="fieldset" variant="standard">
                    <FormLabel component="legend">Select a switch</FormLabel>
                    <FormGroup>
                        <Box
                            sx={{
                                alignItems: 'flex-start',
                                display: 'flex',
                                flexDirection: 'column',
                                gap: 2,
                                margin: '1rem 0'
                            }}
                        >
                            <FormControlLabel
                                control={
                                    <Switch
                                        checked={state.switch1}
                                        name="switch1"
                                        onChange={handleChange}
                                    />
                                }
                                label="Switch 1"
                            />
                            <FormControlLabel
                                control={
                                    <Switch
                                        checked={state.switch2}
                                        name="switch2"
                                        onChange={handleChange}
                                    />
                                }
                                label="Switch 2"
                            />
                            <FormControlLabel
                                control={
                                    <Switch
                                        checked={state.switch3}
                                        name="switch3"
                                        onChange={handleChange}
                                    />
                                }
                                label="Switch 3"
                            />
                        </Box>
                    </FormGroup>
                    <FormHelperText>
                        You can display a helper text
                    </FormHelperText>
                </FormControl>
            </Box>
        </ThemeProvider>
    );
};

export default SwitchExample;
