import React, { ReactElement, useState } from 'react';

import {
    Checkbox,
    Table,
    TableBody,
    TableCell,
    TableContainer,
    TableHead,
    TableRow,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const tableRows = [
    {
        id: 1,
        name: 'Clark Kent',
        description: 'Smallville / Metropolis',
        createdDate: '04/18/1938 10:00 AM',
        createdDescription: 'Some Description',
        status: 'Draft'
    },
    {
        id: 2,
        name: 'Bruce Wayne',
        description: 'Gotham City',
        createdDate: '03/30/1939 11:00 PM',
        createdDescription: '',
        status: 'Processing'
    },
    {
        id: 3,
        name: 'Diana Prince',
        description: '',
        createdDate: '12/01/1942 12:00 AM',
        createdDescription: 'Some Description',
        status: 'Processing'
    },
    {
        id: 4,
        name: 'Barry Allen',
        description: 'Central City',
        createdDate: '01/01/1940 1:00 PM',
        createdDescription: 'Some Description',
        status: 'Draft'
    },
    {
        id: 5,
        name: 'Arthur Curry',
        description: '',
        createdDate: '11/01/1941 3:00 PM',
        createdDescription: 'Some Description',
        status: 'Processing'
    },
    {
        id: 6,
        name: 'Hal Jordan',
        description: 'Coast City',
        createdDate: '10/01/1959 2:00 AM',
        createdDescription: '',
        status: 'Processing'
    },
    {
        id: 7,
        name: 'John Jones',
        description: '',
        createdDate: '11/01/1955 4:00 AM',
        createdDescription: 'Some Description',
        status: 'Processing'
    }
];

const CheckableRowsExample = (): ReactElement => {
    const [checkedRowIds, setCheckedRowIds] = useState<number[]>([]);

    const handleCheck = (id: number): void => {
        setCheckedRowIds((prevState): typeof checkedRowIds =>
            checkedRowIds.includes(id)
                ? prevState.filter((prevId): boolean => prevId !== id)
                : [...prevState, id]
        );
    };

    const handleCheckParent = (): void => {
        if (checkedRowIds.length < tableRows.length) {
            setCheckedRowIds(tableRows.map((row): number => row.id));
        } else {
            setCheckedRowIds([]);
        }
    };

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Checkable Table Rows
            </Typography>
            <TableContainer>
                <Table size="small">
                    <TableHead>
                        <TableRow>
                            <TableCell sx={{ width: 50 }}>
                                <Checkbox
                                    checked={checkedRowIds.length > 0}
                                    indeterminate={
                                        checkedRowIds.length > 0 &&
                                        checkedRowIds.length < tableRows.length
                                    }
                                    onChange={handleCheckParent}
                                />
                            </TableCell>
                            <TableCell sx={{ width: 400 }}>Name</TableCell>
                            <TableCell sx={{ width: 150 }}>Created</TableCell>
                            <TableCell sx={{ width: 100 }}>Status</TableCell>
                        </TableRow>
                    </TableHead>
                    <TableBody>
                        {tableRows.map(
                            (row, index): ReactElement => {
                                return (
                                    <TableRow key={index}>
                                        <TableCell>
                                            <Checkbox
                                                checked={checkedRowIds.includes(
                                                    row.id
                                                )}
                                                onChange={(): void =>
                                                    handleCheck(row.id)
                                                }
                                            />
                                        </TableCell>
                                        <TableCell component="th" scope="row">
                                            <Typography
                                                component="a"
                                                href="https://videoamp.com"
                                                variant="button"
                                            >
                                                {row.name}
                                            </Typography>
                                            <Typography
                                                sx={{ fontSize: '.625rem' }}
                                                variant="body2"
                                            >
                                                {row.description}
                                            </Typography>
                                        </TableCell>
                                        <TableCell>
                                            <Typography
                                                color="inherit"
                                                component="time"
                                                variant="body2"
                                            >
                                                {row.createdDate}
                                            </Typography>
                                            <Typography
                                                color="inherit"
                                                sx={{ fontSize: '.625rem' }}
                                                variant="body2"
                                            >
                                                {row.createdDescription}
                                            </Typography>
                                        </TableCell>
                                        <TableCell
                                            sx={{
                                                fontSize: '0.625rem',
                                                fontWeight: 'var(--font-bold)'
                                            }}
                                        >
                                            <Typography
                                                sx={{
                                                    color: 'var(--va-grey-600)',
                                                    fontWeight:
                                                        'var(--font-bold)'
                                                }}
                                                variant="subtitle1"
                                            >
                                                {row.status}
                                            </Typography>
                                        </TableCell>
                                    </TableRow>
                                );
                            }
                        )}
                    </TableBody>
                </Table>
            </TableContainer>
        </ThemeProvider>
    );
};
export default CheckableRowsExample;
