import React, { ReactElement } from 'react';

import {
    Library,
    IconButton,
    Measure,
    Plan,
    Star,
    Table,
    TableBody,
    TableCell,
    TableContainer,
    TableHead,
    TableRow,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const HoverableTableRowExample = (): ReactElement => (
    <ThemeProvider>
        <Typography component="h2" gutterBottom variant="h5">
            Hoverable Table Rows
        </Typography>
        <TableContainer>
            <Table size="small">
                <TableHead>
                    <TableRow>
                        <TableCell sx={{ width: 32 }} />
                        <TableCell sx={{ width: 300 }}>Name</TableCell>
                        <TableCell sx={{ width: 120 }}>Created</TableCell>
                        <TableCell sx={{ width: 120 }}>Status</TableCell>
                        <TableCell sx={{ width: 32 }} />
                    </TableRow>
                </TableHead>
                <TableBody
                    sx={{
                        'tr td:last-child > button': {
                            visibility: 'hidden'
                        },
                        'tr:hover td:last-child > button': {
                            visibility: 'visible'
                        }
                    }}
                >
                    <TableRow hover>
                        <TableCell sx={{ px: 2 }}>
                            <Library
                                fontSize="inherit"
                                sx={{ color: 'text.disabled' }}
                            />
                        </TableCell>
                        <TableCell component="th" scope="row">
                            <Typography
                                component="a"
                                href="https://videoamp.com"
                                variant="button"
                            >
                                Steve Rogers
                            </Typography>
                            <Typography
                                sx={{ fontSize: '.625rem' }}
                                variant="body2"
                            >
                                Some Description
                            </Typography>
                        </TableCell>
                        <TableCell>
                            <Typography
                                color="inherit"
                                component="time"
                                variant="body2"
                            >
                                01/03/2020 10:45 AM
                            </Typography>
                            <Typography
                                color="inherit"
                                sx={{ fontSize: '.625rem' }}
                                variant="body2"
                            >
                                Some Description
                            </Typography>
                        </TableCell>
                        <TableCell
                            sx={{
                                fontSize: '0.625rem',
                                fontWeight: 'var(--font-bold)'
                            }}
                        >
                            <Typography
                                sx={{
                                    color: 'var(--va-grey-600)',
                                    fontWeight: 'var(--font-bold)'
                                }}
                                variant="subtitle1"
                            >
                                Draft
                            </Typography>
                        </TableCell>
                        <TableCell>
                            <IconButton size="small">
                                <Star color="primary" fontSize="small" />
                            </IconButton>
                        </TableCell>
                    </TableRow>
                    <TableRow hover>
                        <TableCell sx={{ px: 2 }}>
                            <Measure
                                fontSize="inherit"
                                sx={{ color: 'text.disabled' }}
                            />
                        </TableCell>
                        <TableCell component="th" scope="row">
                            <Typography
                                component="a"
                                href="https://videoamp.com"
                                variant="button"
                            >
                                Peter Parker
                            </Typography>
                            <Typography
                                sx={{ fontSize: '.625rem' }}
                                variant="body2"
                            >
                                Some Description
                            </Typography>
                        </TableCell>
                        <TableCell>
                            <Typography
                                color="inherit"
                                component="time"
                                variant="body2"
                            >
                                12/04/2020 07:45 AM
                            </Typography>
                        </TableCell>
                        <TableCell
                            sx={{
                                fontSize: '0.625rem',
                                fontWeight: 'var(--font-bold)'
                            }}
                        >
                            <Typography
                                sx={{
                                    color: 'var(--va-grey-600)',
                                    fontWeight: 'var(--font-bold)'
                                }}
                                variant="subtitle1"
                            >
                                Processing
                            </Typography>
                        </TableCell>
                        <TableCell>
                            <IconButton size="small">
                                <Star color="primary" fontSize="small" />
                            </IconButton>
                        </TableCell>
                    </TableRow>
                    <TableRow hover>
                        <TableCell sx={{ px: 2 }}>
                            <Plan
                                fontSize="inherit"
                                sx={{ color: 'text.disabled' }}
                            />
                        </TableCell>
                        <TableCell component="th" scope="row">
                            <Typography
                                component="a"
                                href="https://videoamp.com"
                                variant="button"
                            >
                                Tony Stark
                            </Typography>
                        </TableCell>
                        <TableCell>
                            <Typography
                                color="inherit"
                                component="time"
                                variant="body2"
                            >
                                12/04/2020 07:45 AM
                            </Typography>
                            <Typography
                                color="inherit"
                                sx={{ fontSize: '.625rem' }}
                                variant="body2"
                            >
                                Some Description
                            </Typography>
                        </TableCell>
                        <TableCell
                            sx={{
                                fontSize: '0.625rem',
                                fontWeight: 'var(--font-bold)'
                            }}
                        >
                            <Typography
                                sx={{
                                    color: 'var(--va-grey-600)',
                                    fontWeight: 'var(--font-bold)'
                                }}
                                variant="subtitle1"
                            >
                                Processing
                            </Typography>
                        </TableCell>
                        <TableCell>
                            <IconButton size="small">
                                <Star color="primary" fontSize="small" />
                            </IconButton>
                        </TableCell>
                    </TableRow>
                </TableBody>
            </Table>
        </TableContainer>
    </ThemeProvider>
);
export default HoverableTableRowExample;
