import React, { ReactElement, useEffect, useState, useRef } from 'react';

import {
    Box,
    CircularProgress,
    Table,
    TableBody,
    TableCell,
    TableContainer,
    TableHead,
    TableRow,
    ThemeProvider,
    Typography
} from '@preamp/rev';
const userList = [
    {
        name: 'Tony Stark',
        description: 'Some Description',
        createdAt: '01/03/2020 10:45 AM',
        status: 'Draft'
    },
    {
        name: 'Peter Parker',
        description: 'Some Description',
        createdAt: '12/04/2020 07:45 AM',
        status: 'Processing'
    },
    {
        name: 'Clark Kent',
        description: '',
        createdAt: '10/01/1959 2:00 AM',
        status: 'Processing'
    },
    {
        name: 'Bruce Wayne',
        description: 'Some description',
        createdAt: '12/01/1942 12:00 AM',
        status: 'Processing'
    },
    {
        name: 'Diana Prince',
        description: 'Some description',
        createdAt: '01/03/2020 10:45 AM',
        status: 'Draft'
    },
    {
        name: 'Barry Allen',
        description: 'Some description',
        createdAt: '04/18/1938 10:00 AM',
        status: 'Draft'
    },
    {
        name: 'Hal Jordan',
        description: '',
        createdAt: '01/01/1940 1:00 PM',
        status: 'Processing'
    },
    {
        name: 'Wally West',
        description: '',
        createdAt: '10/01/1959 2:00 AM',
        status: 'Processing'
    },
    {
        name: 'Ben Grimm',
        description: 'Some description',
        createdAt: '01/03/2020 10:45 AM',
        status: 'Draft'
    },
    {
        name: 'Madelyne Pryor',
        description: 'Some Description',
        createdAt: '01/03/2020 10:45 AM',
        status: 'Draft'
    },
    {
        name: 'Charles Xavier',
        description: 'Some description',
        createdAt: '04/18/1938 10:00 AM',
        status: 'Draft'
    },
    {
        name: 'Alfred Pennyworth',
        description: '',
        createdAt: '01/01/1940 1:00 PM',
        status: 'Processing'
    }
];
const InfiniteScrollingTableExample = (): ReactElement => {
    const infiniteScrollTableRef = useRef(null);
    const [isLoading, setLoading] = useState(false);
    const [slicedList, setSlicedList] = useState(userList.slice(0, 5));
    const [reachedBottom, setReachedBottom] = useState(
        slicedList.length === userList.length
    );

    const handleScroll = (): void => {
        setReachedBottom(slicedList.length === userList.length);
        if (
            infiniteScrollTableRef.current.scrollHeight -
                infiniteScrollTableRef.current.scrollTop -
                infiniteScrollTableRef.current.clientHeight <=
            1
        ) {
            setLoading(true);
        }
    };
    useEffect((): void | (() => void) => {
        if (isLoading && slicedList.length < userList.length) {
            const timeOut = setTimeout((): void => {
                setSlicedList(userList.slice(0, slicedList.length + 3));
                setLoading(false);
            }, 3000);
            return (): void => clearTimeout(timeOut);
        }
    }, [isLoading, slicedList.length]);

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Infinite Scrolling Table
            </Typography>
            <TableContainer
                onScroll={handleScroll}
                ref={infiniteScrollTableRef}
                sx={{ height: 300 }}
            >
                <Table size="small">
                    <TableHead>
                        <TableRow>
                            <TableCell
                                sx={{
                                    width: 300
                                }}
                            >
                                Name
                            </TableCell>
                            <TableCell
                                sx={{
                                    width: 120
                                }}
                            >
                                Created
                            </TableCell>
                            <TableCell
                                sx={{
                                    width: 120
                                }}
                            >
                                Status
                            </TableCell>
                        </TableRow>
                    </TableHead>
                    <TableBody>
                        {slicedList.map(
                            (elem, i): ReactElement => (
                                <TableRow key={i}>
                                    <TableCell component="th" scope="row">
                                        <Typography
                                            component="a"
                                            href="https://videoamp.com"
                                            variant="button"
                                        >
                                            {elem.name}
                                        </Typography>
                                        <Typography
                                            sx={{
                                                fontSize: '.625rem'
                                            }}
                                            variant="body2"
                                        >
                                            {elem.description}
                                        </Typography>
                                    </TableCell>
                                    <TableCell>
                                        <Typography
                                            color="inherit"
                                            component="time"
                                            variant="body2"
                                        >
                                            {elem.createdAt}
                                        </Typography>
                                        <Typography
                                            color="inherit"
                                            sx={{
                                                fontSize: '.625rem'
                                            }}
                                            variant="body2"
                                        >
                                            {elem.description}
                                        </Typography>
                                    </TableCell>
                                    <TableCell
                                        sx={{
                                            fontSize: '0.625rem',
                                            fontWeight: 'var(--font-bold)'
                                        }}
                                    >
                                        <Typography
                                            sx={{
                                                color: 'var(--va-grey-600)',
                                                fontWeight: 'var(--font-bold)'
                                            }}
                                            variant="subtitle1"
                                        >
                                            {elem.status}
                                        </Typography>
                                    </TableCell>
                                </TableRow>
                            )
                        )}
                    </TableBody>
                </Table>
                <Box
                    sx={{
                        backgroundColor: 'white',
                        display: reachedBottom ? 'none' : 'flex',
                        justifyContent: 'center',
                        alignItems: 'center',
                        paddingBottom: 1,
                        visibility: !isLoading ? 'hidden' : 'visible',
                        width: '100%'
                    }}
                >
                    <CircularProgress size="medium" />
                </Box>
            </TableContainer>
        </ThemeProvider>
    );
};
export default InfiniteScrollingTableExample;
