import React, { ReactElement, useState } from 'react';

import {
    Check,
    Table,
    TableBody,
    TableCell,
    TableContainer,
    TableHead,
    TableRow,
    ThemeProvider,
    Typography
} from '@preamp/rev';

const rows = [
    {
        id: 1,
        name: 'Arya Stark',
        dob: '01/01/2020 12:35 PM',
        quote: 'Valar morghulis.'
    },
    {
        id: 2,
        name: 'Jon Snow (Aegon Targaryen)',
        dob: '12/04/2020 07:45 AM',
        quote: 'I know nothing'
    },
    {
        id: 3,
        name: 'Tyrion Lannister',
        dob: '01/01/2020',
        quote: 'I drink and i know things.'
    }
];

const SelectableSingleRowTableExample = (): ReactElement => {
    const [selectedRowId, setSelectedRowId] = useState<number | null>(null);
    const isSelected = (rowId: number): boolean => selectedRowId === rowId;

    const handleClick = (rowId): void => {
        setSelectedRowId(rowId);
    };

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Selectable Table Row (1 row only)
            </Typography>
            <TableContainer>
                <Table size="small">
                    <TableHead>
                        <TableRow>
                            <TableCell sx={{ width: 300 }}>Name</TableCell>
                            <TableCell sx={{ width: 120 }}>
                                Date of Birth
                            </TableCell>
                            <TableCell sx={{ width: 120 }}>Quote</TableCell>
                            <TableCell sx={{ width: 56 }} />
                        </TableRow>
                    </TableHead>
                    <TableBody>
                        {rows.map(
                            (row): ReactElement => {
                                const isRowSelected = isSelected(row.id);

                                return (
                                    <TableRow
                                        hover
                                        key={row.id}
                                        onClick={(): void =>
                                            handleClick(row.id)
                                        }
                                        role="checkbox"
                                        selected={isRowSelected}
                                    >
                                        <TableCell component="th" scope="row">
                                            <Typography
                                                component="a"
                                                href="https://videoamp.com"
                                                variant="button"
                                            >
                                                {row.name}
                                            </Typography>
                                        </TableCell>
                                        <TableCell>
                                            <Typography
                                                color="inherit"
                                                component="time"
                                                variant="body2"
                                            >
                                                {row.dob}
                                            </Typography>
                                        </TableCell>
                                        <TableCell
                                            sx={{
                                                fontSize: '0.625rem',
                                                fontWeight: 'var(--font-bold)'
                                            }}
                                        >
                                            <Typography
                                                sx={{
                                                    color: 'var(--va-grey-600)',
                                                    fontWeight:
                                                        'var(--font-bold)'
                                                }}
                                                variant="subtitle1"
                                            >
                                                {row.quote}
                                            </Typography>
                                        </TableCell>
                                        <TableCell>
                                            {isRowSelected && (
                                                <Check
                                                    color="primary"
                                                    fontSize="small"
                                                />
                                            )}
                                        </TableCell>
                                    </TableRow>
                                );
                            }
                        )}
                    </TableBody>
                </Table>
            </TableContainer>
        </ThemeProvider>
    );
};
export default SelectableSingleRowTableExample;
