import React, { ReactElement, useMemo, useState } from 'react';
import { reverse, sortBy } from 'lodash';
import {
    ChevronDown,
    Table,
    TableBody,
    TableCell,
    TableContainer,
    TableHead,
    TableRow,
    TableSortLabel,
    ThemeProvider,
    Typography
} from '@preamp/rev';
interface Row {
    attack: number;
    defense: number;
    hp: number;
    id: number;
    name: string;
    specialAttack: number;
    specialDefense: number;
    speed: number;
}
const rows: Row[] = [
    {
        attack: 55,
        defense: 40,
        hp: 35,
        id: 1,
        name: 'Pikachu',
        specialAttack: 50,
        specialDefense: 50,
        speed: 90
    },
    {
        attack: 49,
        defense: 49,
        hp: 45,
        id: 2,
        name: 'Bulbasaur',
        specialAttack: 65,
        specialDefense: 65,
        speed: 45
    },
    {
        attack: 48,
        defense: 65,
        hp: 44,
        id: 3,
        name: 'Squirtle',
        specialAttack: 50,
        specialDefense: 64,
        speed: 43
    },
    {
        attack: 52,
        defense: 43,
        hp: 39,
        id: 4,
        name: 'Charmander',
        specialAttack: 60,
        specialDefense: 50,
        speed: 65
    }
];
const SortableRowsTableExample = (): ReactElement => {
    const [order, setOrder] = useState<'asc' | 'desc'>('asc');
    const [orderBy, setOrderBy] = useState<keyof Row>('id');
    const sortedRows = useMemo<Row[]>(
        (): Row[] =>
            order === 'asc'
                ? sortBy(rows, orderBy)
                : reverse(sortBy(rows, orderBy)),
        [order, orderBy]
    );
    const handleRequestSort = (property: keyof Row): void => {
        const isAsc = orderBy === property && order === 'asc';
        setOrder(isAsc ? 'desc' : 'asc');
        setOrderBy(property);
    };
    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Sortable Rows
            </Typography>
            <TableContainer>
                <Table size="small">
                    <TableHead>
                        <TableRow>
                            <TableCell
                                padding="none"
                                sortDirection={
                                    orderBy === 'name' ? order : false
                                }
                            >
                                <TableSortLabel
                                    active={orderBy === 'name'}
                                    direction={
                                        orderBy === 'name' ? order : 'asc'
                                    }
                                    IconComponent={ChevronDown}
                                    onClick={(): void =>
                                        handleRequestSort('name')
                                    }
                                >
                                    Name
                                </TableSortLabel>
                            </TableCell>
                            <TableCell
                                align="right"
                                sortDirection={orderBy === 'hp' ? order : false}
                            >
                                <TableSortLabel
                                    active={orderBy === 'hp'}
                                    direction={orderBy === 'hp' ? order : 'asc'}
                                    IconComponent={ChevronDown}
                                    onClick={(): void =>
                                        handleRequestSort('hp')
                                    }
                                >
                                    HP
                                </TableSortLabel>
                            </TableCell>
                            <TableCell
                                align="right"
                                sortDirection={
                                    orderBy === 'attack' ? order : false
                                }
                            >
                                <TableSortLabel
                                    active={orderBy === 'attack'}
                                    direction={
                                        orderBy === 'attack' ? order : 'asc'
                                    }
                                    IconComponent={ChevronDown}
                                    onClick={(): void =>
                                        handleRequestSort('attack')
                                    }
                                >
                                    Attack
                                </TableSortLabel>
                            </TableCell>
                            <TableCell
                                align="right"
                                sortDirection={
                                    orderBy === 'defense' ? order : false
                                }
                            >
                                <TableSortLabel
                                    active={orderBy === 'defense'}
                                    direction={
                                        orderBy === 'defense' ? order : 'asc'
                                    }
                                    IconComponent={ChevronDown}
                                    onClick={(): void =>
                                        handleRequestSort('defense')
                                    }
                                >
                                    Defense
                                </TableSortLabel>
                            </TableCell>
                            <TableCell
                                align="right"
                                sortDirection={
                                    orderBy === 'specialAttack' ? order : false
                                }
                            >
                                <TableSortLabel
                                    active={orderBy === 'specialAttack'}
                                    direction={
                                        orderBy === 'specialAttack'
                                            ? order
                                            : 'asc'
                                    }
                                    IconComponent={ChevronDown}
                                    onClick={(): void =>
                                        handleRequestSort('specialAttack')
                                    }
                                >
                                    Special Attack
                                </TableSortLabel>
                            </TableCell>
                            <TableCell
                                align="right"
                                sortDirection={
                                    orderBy === 'specialDefense' ? order : false
                                }
                            >
                                <TableSortLabel
                                    active={orderBy === 'specialDefense'}
                                    direction={
                                        orderBy === 'specialDefense'
                                            ? order
                                            : 'asc'
                                    }
                                    IconComponent={ChevronDown}
                                    onClick={(): void =>
                                        handleRequestSort('specialDefense')
                                    }
                                >
                                    Special Defense
                                </TableSortLabel>
                            </TableCell>
                            <TableCell
                                align="right"
                                sortDirection={
                                    orderBy === 'speed' ? order : false
                                }
                            >
                                <TableSortLabel
                                    active={orderBy === 'speed'}
                                    direction={
                                        orderBy === 'speed' ? order : 'asc'
                                    }
                                    IconComponent={ChevronDown}
                                    onClick={(): void =>
                                        handleRequestSort('speed')
                                    }
                                >
                                    Speed
                                </TableSortLabel>
                            </TableCell>
                        </TableRow>
                    </TableHead>
                    <TableBody>
                        {sortedRows.map(
                            ({
                                attack,
                                defense,
                                hp,
                                id,
                                name,
                                specialAttack,
                                specialDefense,
                                speed
                            }): ReactElement => (
                                <TableRow hover key={id} role="checkbox">
                                    <TableCell
                                        component="th"
                                        padding="none"
                                        scope="row"
                                    >
                                        {name}
                                    </TableCell>
                                    <TableCell align="right">{hp}</TableCell>
                                    <TableCell align="right">
                                        {attack}
                                    </TableCell>
                                    <TableCell align="right">
                                        {defense}
                                    </TableCell>
                                    <TableCell align="right">
                                        {specialAttack}
                                    </TableCell>
                                    <TableCell align="right">
                                        {specialDefense}
                                    </TableCell>
                                    <TableCell align="right">{speed}</TableCell>
                                </TableRow>
                            )
                        )}
                    </TableBody>
                </Table>
            </TableContainer>
        </ThemeProvider>
    );
};
export default SortableRowsTableExample;
