import React, { ReactElement, useCallback, useEffect, useState } from 'react';
import {
    Box,
    Close,
    IconButton,
    InputAdornment,
    InputLabel,
    Search,
    TextField,
    ThemeProvider
} from '@preamp/rev';
import { debounce } from 'lodash';

const TextFieldExample = (): ReactElement => {
    const [searchValue, setSearchValue] = useState('');
    const handleSearchInput = (event): void => {
        setSearchValue(event.target.value);
    };
    const debouncedHandleSearchInput = useCallback(
        debounce((searchValue): void => console.log(searchValue), 500),
        []
    );
    useEffect((): void => {
        debouncedHandleSearchInput(searchValue);
    }, [debouncedHandleSearchInput, searchValue]);
    return (
        <ThemeProvider>
            <Box component="section" sx={{ mt: 4 }}>
                <InputLabel htmlFor="outlined-basic">
                    This is a Label
                </InputLabel>
                <TextField
                    fullWidth
                    id="outlined-basic"
                    placeholder="Enter text…"
                    size="small"
                    variant="outlined"
                />
            </Box>
            <Box component="section" sx={{ mt: 4 }}>
                <InputLabel htmlFor="outlined-password">Password</InputLabel>
                <TextField
                    fullWidth
                    helperText="This is a helper text"
                    id="outlined-password"
                    size="small"
                    type="password"
                    variant="outlined"
                />
            </Box>
            <Box component="section" sx={{ mt: 4 }}>
                <InputLabel htmlFor="outlined-number" required>
                    Required Number Field
                </InputLabel>
                <TextField
                    fullWidth
                    id="outlined-number"
                    required
                    size="small"
                    type="number"
                    variant="outlined"
                />
            </Box>
            <Box component="section" sx={{ mt: 4 }}>
                <InputLabel htmlFor="outlined-adorned">
                    Input with Start/End Adornments
                </InputLabel>
                <TextField
                    fullWidth
                    id="outlined-adorned"
                    InputProps={{
                        endAdornment: (
                            <InputAdornment position="end">USD</InputAdornment>
                        ),
                        startAdornment: (
                            <InputAdornment position="start">$</InputAdornment>
                        )
                    }}
                    size="small"
                    type="number"
                    variant="outlined"
                />
            </Box>
            <Box component="section" sx={{ mt: 4 }}>
                <InputLabel htmlFor="outlined-disabled">
                    This Field is Disabled
                </InputLabel>
                <TextField
                    disabled
                    fullWidth
                    id="outlined-disabled"
                    placeholder="You can't enter text here."
                    size="small"
                    variant="outlined"
                />
            </Box>
            <Box component="section" sx={{ mt: 4 }}>
                <InputLabel htmlFor="multiline">Multiline Input</InputLabel>
                <TextField
                    fullWidth
                    id="multiline"
                    multiline
                    placeholder="Enter text…"
                    rows={5}
                    size="small"
                />
            </Box>
            <Box component="section" sx={{ mt: 4 }}>
                <InputLabel htmlFor="standard-search">Search Field</InputLabel>
                <TextField
                    fullWidth
                    id="standard-search"
                    InputProps={{
                        endAdornment: searchValue ? (
                            <InputAdornment position="end">
                                <IconButton
                                    onClick={(): void => setSearchValue('')}
                                    size="small"
                                >
                                    <Close />
                                </IconButton>
                            </InputAdornment>
                        ) : null,
                        startAdornment: (
                            <InputAdornment position="start">
                                <Search />
                            </InputAdornment>
                        )
                    }}
                    onChange={handleSearchInput}
                    size="small"
                    type="search"
                    value={searchValue}
                    variant="outlined"
                />
            </Box>
        </ThemeProvider>
    );
};

export default TextFieldExample;
