import React, { ReactElement, useCallback, useEffect, useState } from 'react';

import {
    Box,
    Calendar,
    Close,
    IconButton,
    InputAdornment,
    Search,
    Send,
    StarOutline,
    TextField,
    ThemeProvider,
    Toolbar,
    Typography
} from '@preamp/rev';
import { debounce } from 'lodash';

const HeaderExample = (): ReactElement => {
    const [searchValue, setSearchValue] = useState('');
    const handleSearchInput = (event): void => {
        setSearchValue(event.target.value);
    };
    const debouncedHandleSearchInput = useCallback(
        debounce((searchValue): void => console.log(searchValue), 500),
        []
    );
    useEffect((): void => {
        debouncedHandleSearchInput(searchValue);
    }, [debouncedHandleSearchInput, searchValue]);

    return (
        <ThemeProvider>
            <Typography component="h2" gutterBottom variant="h5">
                Toolbar Header
            </Typography>
            <Toolbar
                disableGutters
                sx={{
                    borderTop: '1px solid var(--va-grey-300)',
                    display: 'flex',
                    justifyContent: 'space-between'
                }}
            >
                <TextField
                    InputProps={{
                        endAdornment: (
                            <InputAdornment position="end">
                                <IconButton
                                    onClick={(): void => setSearchValue('')}
                                    size="small"
                                    sx={{
                                        visibility: searchValue
                                            ? 'visible'
                                            : 'hidden'
                                    }}
                                >
                                    <Close />
                                </IconButton>
                            </InputAdornment>
                        ),
                        startAdornment: (
                            <InputAdornment position="start">
                                <Search />
                            </InputAdornment>
                        )
                    }}
                    onChange={handleSearchInput}
                    size="small"
                    type="search"
                    value={searchValue}
                    variant="outlined"
                />
                <Box>
                    <IconButton aria-label="Calendar" color="inherit">
                        <Calendar sx={{ height: 16, width: 16 }} />
                    </IconButton>
                    <IconButton aria-label="Send" color="inherit">
                        <Send sx={{ height: 16, width: 16 }} />
                    </IconButton>
                    <IconButton aria-label="Star Outline" color="inherit">
                        <StarOutline sx={{ height: 16, width: 16 }} />
                    </IconButton>
                </Box>
            </Toolbar>
        </ThemeProvider>
    );
};

export default HeaderExample;
