import React from 'react';

import { ButtonTheme } from '@preamp/core';
import { DropdownButton, OptionType, ValueType } from '@preamp/select';
import { MenuEllipsis } from '@preamp/signal';

const exampleOptions: OptionType[] = [
    { label: 'Amy Gaudioso', value: '1' },
    { label: 'Bob Samuelson', value: '2' },
    { label: 'Juan Giuffrida', value: '3' },
    { label: 'Doug Ung', value: '4' },
    { label: 'Ben Behrens', value: '5' },
    { label: 'Vera Carrillo-Marquez', value: '6' },
    { label: 'Helen Kim', value: '7' }
];

/**
 * Basic dropdown buttons
 */
export const ExampleDropdownButton: React.FC = (): React.ReactElement<HTMLDivElement> => {
    function dropdownChanged(value: ValueType<OptionType>): void {
        console.log('changed', value);
    }

    return (
        <div className="mt-4 mb-6 flex">
            <DropdownButton
                dataUI="primary-dropdown"
                onChange={dropdownChanged}
                options={exampleOptions}
            >
                Dropdown
            </DropdownButton>
            <DropdownButton
                buttonProps={{
                    theme: ButtonTheme.Secondary
                }}
                dataUI="secondary-dropdown"
                onChange={dropdownChanged}
                options={exampleOptions}
            >
                Secondary Dropdown
            </DropdownButton>
            <DropdownButton
                buttonProps={{
                    theme: ButtonTheme.Link
                }}
                dataUI="link-dropdown"
                onChange={dropdownChanged}
                options={exampleOptions}
            >
                Link Dropdown
            </DropdownButton>
            <DropdownButton
                buttonProps={{
                    disabled: true
                }}
                dataUI="disabled-dropdown"
                onChange={dropdownChanged}
                options={exampleOptions}
            >
                Disabled Dropdown
            </DropdownButton>
            <DropdownButton
                dataUI="icon-dropdown"
                icon={MenuEllipsis}
                isMulti
                onChange={dropdownChanged}
                options={exampleOptions}
                shouldCloseOnSelect={false}
                style={{ width: 200 }}
            />
        </div>
    );
};

export default ExampleDropdownButton;
