import React from 'react';

import { Button, ButtonTheme } from '@preamp/core';
import { DropdownButton, OptionType, ValueType } from '@preamp/select';

const exampleOptions: OptionType[] = [
    { label: 'Amy Gaudioso', value: '1' },
    { label: 'Bob Samuelson', value: '2' },
    { label: 'Juan Giuffrida', value: '3' },
    { label: 'Doug Ung', value: '4' },
    { label: 'Ben Behrens', value: '5' },
    { label: 'Vera Carrillo-Marquez', value: '6' },
    { label: 'Helen Kim', value: '7' }
];

/**
 * Dropdown button with a manual toggle
 */
export const ManualToggleDropdownButton: React.FC = (): React.ReactElement<HTMLDivElement> => {
    const [menuIsOpen, setMenuIsOpen] = React.useState<boolean>(false);

    function dropdownChanged(value: ValueType<OptionType>): void {
        console.log('changed', value);
    }

    function buttonClicked(): void {
        setMenuIsOpen((prevState: boolean): boolean => !prevState);
    }

    return (
        <>
            <div className="mt-4 mb-2">
                <Button onClick={buttonClicked}>
                    {menuIsOpen ? 'Close' : 'Open'} Menu
                </Button>
                <DropdownButton
                    buttonProps={{
                        onClick: buttonClicked,
                        theme: ButtonTheme.Secondary
                    }}
                    dataUI="primary-dropdown"
                    isMenuOpen={menuIsOpen}
                    onChange={dropdownChanged}
                    options={exampleOptions}
                >
                    Dropdown
                </DropdownButton>
            </div>
            <div className="mt-4 mb-6" />
        </>
    );
};

export default ManualToggleDropdownButton;
