import React from 'react';

import {
    DropdownButton,
    OptionsType,
    OptionType,
    selectAllOption
} from '@preamp/select';

const basicOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1' },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    { value: 'option 5', label: 'Option 5' }
];

/**
 * Dropdown button with Select All option.
 */
export const SelecteAllDropdownButton: React.FunctionComponent = (): React.ReactElement => {
    const [selectAllSelected, setSelectAllSelected] = React.useState([]);

    function getIsSelectAllOption({
        option,
        removedValue
    }: OptionType): boolean {
        return (
            (Boolean(option) && option.value === selectAllOption.value) ||
            (Boolean(removedValue) &&
                removedValue.value === selectAllOption.value)
        );
    }

    function handleSelectAllChange(
        options: OptionsType<OptionType>,
        option: OptionType
    ): void {
        const isSelectAllOption: boolean = getIsSelectAllOption(option);

        if (option.action === 'select-option') {
            setSelectAllSelected(isSelectAllOption ? basicOptions : options);
        } else {
            setSelectAllSelected(isSelectAllOption ? [] : options);
        }
    }
    return (
        <div className="mt-4 mb-2">
            <section className="mb-6">
                <DropdownButton
                    isMulti
                    numberOfOptions={basicOptions.length}
                    onChange={handleSelectAllChange}
                    options={basicOptions}
                    shouldAllowSelectAll
                    shouldCloseOnSelect={false}
                    style={{ width: 200 }}
                    value={selectAllSelected}
                >
                    Dropdown
                </DropdownButton>
            </section>
        </div>
    );
};

export default SelecteAllDropdownButton;
