import React, { ChangeEvent } from 'react';

import { ActionMeta, OptionType, TextDropdownCombo } from '@preamp/select';

interface IExampleTextDropdownComboState {
    dropdown: OptionType;
    text: string;
}

const options: OptionType[] = [
    { label: 'Option 1', value: '1' },
    { label: 'Option 2', value: '2' },
    { label: 'Option 3', value: '3' }
];

/** Basic Example */
class ExampleTextDropdownCombo extends React.Component {
    state: IExampleTextDropdownComboState = {
        text: '',
        dropdown: options[0]
    };

    textChange = (event: ChangeEvent<HTMLInputElement>): void => {
        this.setState({
            ...this.state,
            text: event.target.value
        });
    };

    dropdownChange = (value: OptionType, _: ActionMeta): void => {
        this.setState({
            ...this.state,
            dropdown: value
        });
    };

    render(): React.ReactNode {
        const { dropdownChange, textChange } = this;
        const { dropdown, text } = this.state;

        return (
            <div className="va-form-group">
                <TextDropdownCombo
                    dropdownValue={options[2]}
                    helpText="This is helper text"
                    id="example1"
                    isOptional
                    label="Input Label"
                    onDropdownChange={dropdownChange}
                    onTextChange={textChange}
                    options={options}
                    placeholder="Text Placeholder"
                    value={text}
                />
                <div className="mt-3">Text Value: {text}</div>
                <div>Dropdown Value: {dropdown.label}</div>
            </div>
        );
    }
}

export default ExampleTextDropdownCombo;
