import React, { ChangeEvent } from 'react';

import { TextFieldType } from '@preamp/core';
import { ActionMeta, OptionType, TextDropdownCombo } from '@preamp/select';

interface IPrependAppendTextDropdownCombo {
    dropdown: OptionType;
    text: string;
}

const options: OptionType[] = [
    { label: 'USD', value: '$' },
    { label: 'GRP', value: '' }
];

/** Prepend Example */
class PrependAppendTextDropdownCombo extends React.Component {
    state: IPrependAppendTextDropdownCombo = {
        text: '',
        dropdown: options[0]
    };

    textChange = (event: ChangeEvent<HTMLInputElement>): void => {
        this.setState({
            ...this.state,
            text: event.target.value
        });
    };

    dropdownChange = (value: OptionType, _: ActionMeta): void => {
        this.setState({
            ...this.state,
            dropdown: value
        });
    };

    render(): React.ReactNode {
        const { dropdownChange, textChange } = this;
        const { dropdown, text } = this.state;

        return (
            <div className="va-form-group">
                <TextDropdownCombo
                    dropdownValue={options[2]}
                    helpText="This is helper text"
                    id="prependexample"
                    label="Prepend/Append"
                    onDropdownChange={dropdownChange}
                    onTextChange={textChange}
                    options={options}
                    placeholder="Text Placeholder"
                    prepend={dropdown.value}
                    textFieldType={TextFieldType.Number}
                    value={text}
                />
                <div className="mt-3">Text Value: {text}</div>
                <div>Dropdown Value: {dropdown.label}</div>
            </div>
        );
    }
}

export default PrependAppendTextDropdownCombo;
