import React, { ChangeEvent } from 'react';

import { ActionMeta, OptionType, TextDropdownCombo } from '@preamp/select';

interface IExampleDisabledTextDropdownComboState {
    dropdown: OptionType;
    text: string;
}

const options: OptionType[] = [
    { label: 'Option 1', value: '1' },
    { label: 'Option 2', value: '2' },
    { label: 'Option 3', value: '3' }
];

/** Disabled Example */
class ExampleDisabledTextDropdownCombo extends React.Component {
    state: IExampleDisabledTextDropdownComboState = {
        text: '',
        dropdown: options[0]
    };

    textChange = (event: ChangeEvent<HTMLInputElement>): void => {
        this.setState({
            ...this.state,
            text: event.target.value
        });
    };

    dropdownChange = (value: OptionType, _: ActionMeta): void => {
        this.setState({
            ...this.state,
            dropdown: value
        });
    };

    render(): React.ReactNode {
        const { dropdownChange, textChange } = this;

        return (
            <div className="va-form-group mt-6">
                <TextDropdownCombo
                    disabled={true}
                    dropdownValue={options[2]}
                    helpText="This is disabled helper text"
                    id="example2"
                    label="Disabled Input Label"
                    onDropdownChange={dropdownChange}
                    onTextChange={textChange}
                    options={options}
                    placeholder="Text Disabled Placeholder"
                />
            </div>
        );
    }
}

export default ExampleDisabledTextDropdownCombo;
