import React from 'react';

import { Drilldropdown, OptionsType, OptionType } from '@preamp/select';

const basicOptions: OptionsType<OptionType> = [
    { value: 'option A', label: 'Option A' },
    {
        label: 'Array of Options 1',
        value: [
            { value: 'option X', label: 'Option X' },
            { value: 'option Y', label: 'Option Y' },
            { value: 'option M', label: 'Option M' },
            { value: 'option C', label: 'Option C' }
        ]
    },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    {
        label: 'Array of Options 2',
        value: [
            { value: 'option 5', label: 'Option 5' },
            {
                label: 'Array of Options 3',
                value: [
                    { value: 'option C', label: 'Option C' },
                    { value: 'option B', label: 'Option B' }
                ]
            }
        ]
    }
];

interface DrilldropdownExampleState {
    currentOption?: OptionType;
    optionList?: OptionType;
    previousOptions?: OptionsType<OptionType>;
    selectedOptions?: OptionsType<OptionType>;
}

class SimpleDrilldropdown extends React.Component<DrilldropdownExampleState> {
    state: DrilldropdownExampleState = {
        optionList: basicOptions,
        previousOptions: [],
        selectedOptions: []
    };

    onNavigate = (currentOption: OptionType): void => {
        // Use previousOptions to keep track of visited options
        const previousOptions: OptionsType<OptionType> = this.state
            .currentOption
            ? this.state.previousOptions.concat(this.state.currentOption)
            : [];

        this.setState({
            currentOption,
            optionList: currentOption.value || basicOptions,
            previousOptions
        });
    };

    onBack = (): void => {
        const { previousOptions } = this.state;
        const currentOption: OptionType = previousOptions.pop() || {};

        this.setState({
            currentOption,
            optionList: currentOption.value || basicOptions,
            previousOptions
        });
    };

    onSearch = (searchVal: string = ''): void => {
        const listToSearch: OptionsType<OptionType> = this.state.currentOption
            ? this.state.currentOption.value
            : basicOptions;
        if (searchVal) {
            const filteredOptions: OptionsType<OptionType> = listToSearch.filter(
                (option: OptionType): React.ReactNode =>
                    option.label.toLowerCase().includes(searchVal.toLowerCase())
            );
            this.setState({ optionList: filteredOptions });
        } else {
            this.setState({ optionList: basicOptions });
        }
    };

    onChange = (
        selectedOptions: OptionsType<OptionType>,
        selected: { option: OptionType }
    ): void => {
        this.setState({ selectedOptions, selectedOption: selected.option });
    };

    render(): React.ReactNode {
        const { currentOption, optionList } = this.state;

        return (
            <div className="max-w-md mt-12">
                <p className="mb-6">
                    Example with search functionality. The search field becomes
                    available when <code>onSearch</code> prop is provided.
                </p>
                <Drilldropdown
                    currentOption={currentOption}
                    levels={['Top Level', 'Agencies', 'Advertisers']}
                    onBack={this.onBack}
                    onNavigate={this.onNavigate}
                    onSearch={this.onSearch}
                    onSelect={this.onChange}
                    optionList={optionList}
                />
            </div>
        );
    }
}

export default SimpleDrilldropdown;
