import React, { useReducer } from 'react';

import { Drilldropdown, OptionsType, OptionType } from '@preamp/select';

const basicOptions: OptionsType<OptionType> = [
    { value: 'option A', label: 'Option A' },
    {
        label: 'Array of Options 1',
        value: [
            { value: 'option X', label: 'Option X' },
            { value: 'option Y', label: 'Option Y' },
            { value: 'option M', label: 'Option M' },
            { value: 'option C', label: 'Option C' }
        ]
    },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    {
        label: 'Array of Options 2',
        value: [
            { value: 'option 5', label: 'Option 5' },
            {
                label: 'Array of Options 3',
                value: [
                    { value: 'option C', label: 'Option C' },
                    { value: 'option B', label: 'Option B' }
                ]
            }
        ]
    }
];

interface IIsMultiState {
    currentOption?: OptionType;
    optionList?: OptionsType<OptionType>;
    previousOptions?: OptionsType<OptionType>;
    selectedOptions?: OptionsType<OptionType>;
}

function reducer(
    state: IIsMultiState,
    update: Partial<IIsMultiState>
): IIsMultiState {
    return { ...state, ...update };
}

export default function IsMult(): React.ReactElement<{}> {
    const [
        { currentOption, optionList, previousOptions, selectedOptions },
        updateState
    ] = useReducer(reducer, {
        currentOption: null,
        optionList: basicOptions,
        previousOptions: [],
        selectedOptions: []
    });

    function onApply(): void {
        alert(`${selectedOptions.length || 0} options currently selected.`);
    }
    function onBack(): void {
        const previousOption: OptionType = previousOptions.slice(-1)[0] || {};

        updateState({
            currentOption: previousOption,
            optionList: previousOption.value || basicOptions,
            previousOptions: previousOptions.slice(0, -1)
        });
    }
    function onCancel(): void {
        updateState({ selectedOptions: [] });
    }
    function onChange(allSelected: OptionsType<OptionType>): void {
        updateState({ selectedOptions: allSelected });
    }
    function onNavigate(newCurrentOption: OptionType): void {
        updateState({
            currentOption: newCurrentOption,
            optionList: newCurrentOption.value || basicOptions,
            // Use previousOptions to keep track of visited options
            previousOptions: currentOption
                ? previousOptions.concat(currentOption)
                : []
        });
    }
    function onSearch(searchVal: string = ''): void {
        const listToSearch: OptionsType<OptionType> = currentOption
            ? currentOption.value
            : basicOptions;

        if (searchVal) {
            const filteredOptions: OptionsType<OptionType> = listToSearch.filter(
                (option: OptionType): React.ReactNode =>
                    option.label.toLowerCase().includes(searchVal.toLowerCase())
            );
            updateState({ optionList: filteredOptions });
        } else {
            updateState({ optionList: basicOptions });
        }
    }

    return (
        <div className="max-w-md mt-12">
            <p className="mb-6">
                Example of setting max limit to 1 via <code>isMulti</code> prop.
                This differs from <code>selectionLimit</code> in how the
                selected option is rendered.
            </p>
            <Drilldropdown
                currentOption={currentOption}
                isMulti={false}
                levels={['Top Level', 'Agencies', 'Advertisers']}
                onApply={onApply}
                onBack={onBack}
                onCancel={onCancel}
                onNavigate={onNavigate}
                onSearch={onSearch}
                onSelect={onChange}
                optionList={optionList}
            />
        </div>
    );
}
