import React from 'react';

import { Drilldropdown, OptionsType, OptionType } from '@preamp/select';

const basicOptions: OptionsType<OptionType> = [
    { value: 'option A', label: 'Option A' },
    {
        label: 'Array of Options 1',
        value: [
            { value: 'option X', label: 'Option X' },
            { value: 'option Y', label: 'Option Y' },
            { value: 'option M', label: 'Option M' },
            { value: 'option C', label: 'Option C' }
        ]
    },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    {
        label: 'Array of Options 2',
        value: [
            { value: 'option 5', label: 'Option 5' },
            {
                label: 'Array of Options 3',
                value: [
                    { value: 'option C', label: 'Option C' },
                    { value: 'option B', label: 'Option B' }
                ]
            }
        ]
    }
];

interface ISimpleDrilldropdownState {
    currentOption?: OptionType;
    optionList?: OptionsType<OptionType>;
    previousOptions?: OptionsType<OptionType>;
    selectedOptions?: OptionsType<OptionType>;
}

class SimpleDrilldropdown extends React.Component<ISimpleDrilldropdownState> {
    state: ISimpleDrilldropdownState = {
        optionList: basicOptions,
        previousOptions: [],
        selectedOptions: []
    };

    onNavigate = (currentOption: OptionType): void => {
        // Use previousOptions to keep track of visited options
        const previousOptions: OptionsType<OptionType> = this.state
            .currentOption
            ? this.state.previousOptions.concat(this.state.currentOption)
            : [];

        this.setState({
            currentOption,
            optionList: currentOption.value || basicOptions,
            previousOptions
        });
    };

    onBack = (): void => {
        const { previousOptions } = this.state;
        const currentOption: OptionType = previousOptions.pop() || {};

        this.setState({
            currentOption,
            optionList: currentOption.value || basicOptions,
            previousOptions
        });
    };

    onChange = (
        selectedOptions: OptionsType<OptionType>,
        selectedOption: OptionType
    ): void => {
        // eslint-disable-next-line no-console
        console.log('Option selected:', selectedOption);
        this.setState({ selectedOptions });
    };

    render(): React.ReactNode {
        const { currentOption, optionList } = this.state;

        return (
            <div className="max-w-md">
                <p className="mb-6">
                    A simple drilldropdown example with the minimum required
                    props and inlineLabel. The implementation will need to
                    handle navigating down through the levels of options by
                    setting the value of <code>optionList</code> when either{' '}
                    <code>onNavigate</code> or <code>onBack</code> are called.
                </p>
                <Drilldropdown
                    currentOption={currentOption}
                    inlineLabel
                    label="Basic DrillDropdown"
                    levels={['Top Level', 'Agencies', 'Advertisers']}
                    onBack={this.onBack}
                    onNavigate={this.onNavigate}
                    onSelect={this.onChange}
                    optionList={optionList}
                />
            </div>
        );
    }
}

export default SimpleDrilldropdown;
