import React from 'react';

import { Drilldropdown, OptionsType, OptionType } from '@preamp/select';

const basicOptions: OptionsType<OptionType> = [
    {
        label: '1',
        value: [
            {
                label: 'Array of Options 1',
                value: [
                    { value: 'option X', label: 'Option X' },
                    { value: 'option Y', label: 'Option Y' },
                    { value: 'option M', label: 'Option M' },
                    { value: 'option C', label: 'Option C' }
                ]
            }
        ]
    },
    {
        label: '2',
        value: [
            {
                label: 'Array of Options 2',
                value: [{ value: 'option A', label: 'Option A' }]
            }
        ]
    }
];

interface SavedOptionsDrilldropdownState {
    currentOption?: OptionType;
    optionList?: OptionsType<OptionType>;
    previousOptions?: OptionsType<OptionType>;
    selectedOptions?: OptionsType<OptionType>;
    savedOptions?: OptionsType<OptionType>;
}

class SavedOptionsDrilldropdown extends React.Component<
    SavedOptionsDrilldropdownState
> {
    state: SavedOptionsDrilldropdownState = {
        optionList: basicOptions,
        previousOptions: [],
        selectedOptions: [],
        savedOptions: []
    };

    onApply = (): void => {
        this.setState({
            savedOptions: this.state.selectedOptions
        });
    };

    onBack = (): void => {
        const { previousOptions } = this.state;
        const currentOption: OptionType = previousOptions.pop() || {};
        this.setState({
            currentOption,
            optionList: currentOption.value || basicOptions,
            previousOptions
        });
    };

    onCancel = (): void => {
        this.setState({ selectedOptions: this.state.savedOptions });
    };

    onChange = (
        _selectedOptions: OptionsType<OptionType>,
        selectedOption: OptionType
    ): void => {
        // eslint-disable-next-line no-console
        if (selectedOption.action === 'select-option') {
            this.setState({
                selectedOptions: [
                    ...this.state.selectedOptions,
                    selectedOption.option
                ]
            });
        } else if (selectedOption.action === 'deselect-option') {
            const newSelectedOptions = this.state.selectedOptions.filter(
                (op: OptionType): boolean =>
                    !(
                        op.value === selectedOption.option.value &&
                        op.parent === selectedOption.option.parent
                    )
            );
            console.log(newSelectedOptions);
            this.setState({
                selectedOptions: newSelectedOptions
            });
        }
    };

    onNavigate = (currentOption: OptionType): void => {
        // Use previousOptions to keep track of visited options
        const previousOptions: OptionsType<OptionType> = this.state
            .currentOption
            ? this.state.previousOptions.concat(this.state.currentOption)
            : [];

        this.setState({
            currentOption,
            optionList: currentOption.value || basicOptions,
            previousOptions
        });
    };

    onSearch = (searchVal: string = ''): void => {
        const listToSearch: OptionsType<OptionType> = this.state.currentOption
            ? this.state.currentOption.value
            : basicOptions;
        if (searchVal) {
            const filteredOptions: OptionsType<OptionType> = listToSearch.filter(
                (option: OptionType): React.ReactNode =>
                    option.label.toLowerCase().includes(searchVal.toLowerCase())
            );
            this.setState({ optionList: filteredOptions });
        } else {
            this.setState({ optionList: basicOptions });
        }
    };

    createCustomSelectedLabel = (option: OptionType): string => option.label;

    getTopParent = (option: OptionType): OptionType => {
        if (
            !option ||
            !option.parent ||
            (option.parent && !option.parent.parent)
        ) {
            return option;
        } else {
            return this.getTopParent(option.parent);
        }
    };

    render(): React.ReactNode {
        const { currentOption, optionList, selectedOptions } = this.state;

        return (
            <div className="max-w-md mt-12">
                <p className="mb-6">
                    Drilldropdown with save options, black parents disabled,
                    selected options as group parent top text and cancel on
                    click outside.
                </p>
                <Drilldropdown
                    createCustomSelectedLabel={this.createCustomSelectedLabel}
                    currentOption={currentOption}
                    groupBy={this.getTopParent}
                    levels={['Top Level', 'Agencies', 'Advertisers']}
                    onApply={this.onApply}
                    onBack={this.onBack}
                    onCancel={this.onCancel}
                    onNavigate={this.onNavigate}
                    onSearch={this.onSearch}
                    onSelect={this.onChange}
                    optionList={optionList}
                    selected={selectedOptions}
                    shouldBeBlackParentsDisabled={true}
                    shouldCancelWithClickOutside={true}
                    shouldMultiOptionsBeText={true}
                    shouldUpdateSelectedValue={true}
                />
            </div>
        );
    }
}

export default SavedOptionsDrilldropdown;
