import * as React from 'react';

import { OptionsType, OptionType, Select, SelectType } from '@preamp/select';
import {
    AppSelect,
    Build,
    Code,
    Equalizer,
    Notification
} from '@preamp/signal';
import { Button, ContentPadding } from '@preamp/core';
import { Toggle } from '@preamp/core';

const dotStyle = {
    background: 'var(--va-teal-300)',
    borderRadius: '100%',
    content: ' ',
    display: 'inline-block',
    height: '8px',
    margin: '0 5px 2px 8px',
    transition: 'background 0.25s ease-in',
    width: '8px'
};

const basicOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1' },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    { value: 'option 5', label: 'Option 5' }
];

const basicDisableOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1' },
    { value: 'option 2', label: 'Option 2', isDisabled: true },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4', isDisabled: true },
    { value: 'option 5', label: 'Option 5' }
];

const pagingOptions: OptionsType<OptionType> = [
    { value: '10', label: '10' },
    { value: '20', label: '20' },
    { value: '50', label: '50' },
    { value: '100', label: '100' }
];

const groupedOptions: OptionsType<OptionType> = [
    {
        label: 'Option Group 1',
        options: [
            { value: 'option 1a', label: 'Option 1' },
            { value: 'option 2a', label: 'Option 2' },
            { value: 'option 3a', label: 'Option 3' },
            { value: 'option 4a', label: 'Option 4' },
            { value: 'option 5a', label: 'Option 5' }
        ]
    },
    {
        label: 'Option Group 2',
        options: [
            { value: 'option 1b', label: 'Option 1' },
            { value: 'option 2b', label: 'Option 2' },
            { value: 'option 3b', label: 'Option 3' },
            { value: 'option 4b', label: 'Option 4' }
        ]
    }
];

const iconOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1', icon: AppSelect },
    { value: 'option 2', label: 'Option 2', spacer: true },
    { value: 'option 3', label: 'Option 3', icon: Code },
    { value: 'option 4', label: 'Option 4', icon: Build },
    { value: 'option 5', label: 'Option 5', icon: Notification }
];
const iconOptionsWithLongText: OptionsType<OptionType> = [
    {
        value:
            'optionoptionoptiomoptionoptionoptionoptionoptionoptionoptionoptionoptionoptionoptionoption',
        label:
            'optionoptionoptiomoptionoptionoptionoptionoptionoptionoptionoptionoptionoptionoptionoption',
        icon: AppSelect
    }
];

const infoOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1', info: 'More info (plain text)…' },
    {
        value: 'option 2',
        label: 'Option 2',
        info: (
            <div>
                More info (<em>react element</em>)…
            </div>
        ),
        infoOption: {
            contentPadding: ContentPadding.None,
            description: 'Insert some custom description here',
            maxWidth: '420px',
            style: { boxShadow: '5px 5px 5px var(--va-blue-grey-200)' },
            shouldCloseOnOverlayClick: false,
            title: `Option name won't be shown as title anymore when this is set`
        }
    },
    { value: 'option 3', label: 'Option 3', info: 'More info (plain text)…' },
    { value: 'option 4', label: 'Option 4', info: 'More info (plain text)…' },
    { value: 'option 5', label: 'Option 5', info: 'More info (plain text)…' }
];

const justifiedOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1', description: 'ID: 001' },
    { value: 'option 2', label: 'Option 2', description: 'ID: 002' },
    { value: 'option 3', label: 'Option 3', description: 'ID: 003' },
    { value: 'option 4', label: 'Option 4', description: 'ID: 004' },
    { value: 'option 5', label: 'Option 5', description: 'ID: 005' }
];

const subtitleOptions: OptionsType<OptionType> = [
    {
        value: 'option 1',
        label: 'Option 1',
        subtitle: 'Option Subtitle'
    },
    {
        value: 'option 2',
        label: 'Option 2',
        subtitle: 'Option Subtitle'
    },
    {
        value: 'option 3',
        label: 'Option 3',
        subtitle: 'Option Subtitle'
    }
];

const descriptionOptions: OptionsType<OptionType> = [
    {
        value: 'option 1',
        label: 'Option 1',
        description: 'This is a description of the field'
    },
    {
        value: 'option 2',
        label: 'Option 2',
        description: 'This is a description of the field'
    },
    {
        value: 'option 3',
        label: 'Option 3',
        description: 'This is a description of the field'
    }
];

const subtitleDescriptionOptions: OptionsType<OptionType> = [
    {
        value: 'option 1',
        label: 'Option 1',
        subtitle: 'Option Subtitle',
        description: 'This is a description of the field'
    },
    {
        value: 'option 2',
        label: 'Option 2',
        subtitle: 'Option Subtitle',
        description: 'This is a description of the field'
    },
    {
        value: 'option 3',
        label: 'Option 3',
        subtitle: 'Option Subtitle',
        description: 'This is a description of the field'
    }
];

const sortOptions: OptionsType<OptionType> = [
    {
        value: 'Alphabetical',
        label: 'Alphabetical'
    },
    {
        value: 'Recently Added',
        label: 'Recently Added'
    },
    {
        value: 'Recently Updated',
        label: 'Recently Updated'
    }
];

const allOptions: OptionsType<OptionType> = [
    {
        label: 'Option Group 1',
        value: '',
        options: [
            {
                value: 'option 1a',
                label: 'Option 1',
                isFixed: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: AppSelect
            },
            {
                value: 'option 2a',
                label: 'Option 2',
                disabled: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            },
            {
                value: 'option 3a',
                label: 'Option 3',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Code
            },
            {
                value: 'option 4a',
                label: 'Option 4',
                isFixed: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Notification
            },
            {
                value: 'option 5a',
                label: 'Option 5',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            }
        ]
    },
    {
        label: 'Option Group 2',
        value: '',
        options: [
            {
                value: 'option 1b',
                label: 'Option 1',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Build
            },
            {
                value: 'option 2b',
                label: 'Option 2',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            },
            {
                value: 'option 2c',
                label: 'Option 3',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Equalizer
            }
        ]
    }
];

interface SimpleSelectState {
    isValid: boolean;
    toggle: boolean;
}

class SimpleSelect extends React.Component<{}, SimpleSelectState> {
    state: SimpleSelectState = {
        isValid: false,
        toggle: false
    };

    handleChange = (): void => {
        this.setState({ isValid: true });
    };

    onToggle = (checked: boolean): void => {
        this.setState({ toggle: checked });
    };

    render(): React.ReactNode {
        return (
            <div className="max-w-md">
                <h3>Inline Label</h3>
                <h4>
                    This is preferred to be used for Filters and Data Viz
                    filters
                </h4>

                <Toggle
                    checked={this.state.toggle}
                    label="inlineLabel"
                    name="width-toggle"
                    onChange={this.onToggle}
                />
                <h3>Simple Select</h3>
                <section className="mb-6">
                    <h4>Basic with Required Label</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        label="Field label"
                        options={basicOptions}
                        required
                    />
                </section>
                <h3>Simple Select</h3>
                <section className="mb-6">
                    <h4>Basic w/ Label &amp; Description</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        isOptional={true}
                        label="Field label"
                        labelDescription="Description text goes here."
                        options={basicOptions}
                    />
                </section>
                <h3>Simple Select</h3>
                <section className="mb-6">
                    <h4>
                        Basic w/ Label, Description &amp; specific options
                        disabled
                    </h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        isOptional={true}
                        label="Field label"
                        labelDescription="Description text goes here."
                        options={basicDisableOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Disabled</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        isDisabled
                        options={basicOptions}
                        tabIndex="-1"
                    />
                </section>
                <section className="mb-6">
                    <h4>Disabled w/ Selected Option</h4>
                    <Select
                        defaultValue={basicOptions[0]}
                        inlineLabel={this.state.toggle}
                        isDisabled
                        options={basicOptions}
                        tabIndex="-1"
                    />
                </section>
                <section className="mb-6">
                    <h4>Disabled w/ Label &amp; Description </h4>
                    <Select
                        defaultValue={basicOptions[0]}
                        inlineLabel={this.state.toggle}
                        isDisabled
                        label="Field label"
                        labelDescription="Description text goes here."
                        options={basicOptions}
                        tabIndex="-1"
                    />
                </section>
                <section className="mb-6">
                    <h4>Label &amp; Error</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        isValid={this.state.isValid}
                        label="Field label"
                        onChange={this.handleChange}
                        options={basicOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Grouped Options</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={groupedOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Icons</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={iconOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Inline Icons</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={iconOptions}
                        shouldShowSelectedOptionIcon
                    />
                </section>
                <section className="mb-6">
                    <h4>Inline Icons with Long Text</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={iconOptionsWithLongText}
                        shouldShowSelectedOptionIcon
                    />
                </section>
                <section className="mb-6">
                    <h4>Info</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={infoOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Justified</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={justifiedOptions}
                        selectType={SelectType.Justified}
                    />
                </section>
                <section className="mb-6">
                    <h4>Subtitles</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={subtitleOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Description</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={descriptionOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Subtitle &amp; Description</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={subtitleDescriptionOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Grouped Icons, Subtitle &amp; Description</h4>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={allOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Menu Options with Footer</h4>
                    <Select
                        menuFooter={
                            <div className="va-caption py-2">
                                This is the footer with a button:
                                <Button className="ml-2">Click me!</Button>
                            </div>
                        }
                        options={basicOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Basic Compact Type</h4>
                    <Select
                        defaultValue={pagingOptions[0]}
                        inlineLabel={this.state.toggle}
                        menuPlacement="top"
                        options={pagingOptions}
                        selectType={SelectType.Compact}
                    />
                </section>
                <section className="mb-6">
                    <h4>Basic Compact w/ Custom Width</h4>
                    <Select
                        defaultValue={pagingOptions[2]}
                        inlineLabel={this.state.toggle}
                        menuPlacement="top"
                        options={pagingOptions}
                        selectType={SelectType.Compact}
                        style={{ width: '14rem' }}
                    />
                </section>

                <section className="mb-6">
                    <h4>LinkRight Type w/ Selected Value Prefix</h4>
                    <p>(label right aligned)</p>
                    <Select
                        defaultValue={sortOptions[0]}
                        inlineLabel={this.state.toggle}
                        options={sortOptions}
                        selectedValuePrefix="Sort by:"
                        selectType={SelectType.LinkRight}
                        style={{ width: '12rem' }}
                    />
                </section>
                <section className="mb-6">
                    <h4>Link Type</h4>
                    <p>(label left aligned)</p>
                    <Select
                        inlineLabel={this.state.toggle}
                        options={sortOptions}
                        selectType={SelectType.Link}
                        style={{ width: '12rem' }}
                    />
                </section>
                <section className="mb-6">
                    <h4>Large Link Type</h4>
                    <div className="flex items-center">
                        <span className="u-title-3 u-font-light mr-2">
                            Display items:{' '}
                        </span>
                        <Select
                            inlineLabel={this.state.toggle}
                            options={sortOptions}
                            selectType={SelectType.LinkLarge}
                            style={{ width: '12rem' }}
                        />
                    </div>
                </section>
                <section className="mb-6">
                    <h4>Box Link Type</h4>
                    <div className="flex items-center">
                        <Select
                            inlineLabel={this.state.toggle}
                            options={sortOptions}
                            selectedValuePrefix={<span style={dotStyle}></span>}
                            selectType={SelectType.BoxLink}
                            style={{ width: '14rem' }}
                        />
                    </div>
                </section>
            </div>
        );
    }
}

export default SimpleSelect;
