import React, { useState } from 'react';

import {
    OptionsType,
    OptionType,
    Select,
    selectAllOption
} from '@preamp/select';
import {
    AppSelect,
    Build,
    Code,
    Equalizer,
    HouseholdLevel,
    Notification
} from '@preamp/signal';
import { SelectComponentsConfig } from 'react-select/lib/components';
import { MultiValueProps } from 'react-select/lib/components/MultiValue';

const basicOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1' },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    { value: 'option 5', label: 'Option 5' }
];
const basicIconOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1', icon: HouseholdLevel },
    { value: 'option 2', label: 'Option 2', icon: AppSelect },
    { value: 'option 3', label: 'Option 3', icon: Build },
    { value: 'option 4', label: 'Option 4', icon: Code },
    { value: 'option 5', label: 'Option 5', icon: Equalizer }
];

const basicDisableOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1', isDisabled: true },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3', isDisabled: true },
    { value: 'option 4', label: 'Option 4' },
    { value: 'option 5', label: 'Option 5' }
];

const allOptions: OptionsType<OptionType> = [
    {
        label: 'Option Group 1',
        value: '',
        options: [
            {
                value: 'option 1a',
                label: 'Option 1',
                isFixed: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: AppSelect,
                parent: { label: 'Option Group 1' }
            },
            {
                value: 'option 2a',
                label: 'Option 2',
                disabled: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true,
                parent: { label: 'Option Group 1' }
            },
            {
                value: 'option 3a',
                label: 'Option 3',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Code,
                parent: { label: 'Option Group 1' }
            },
            {
                value: 'option 4a',
                label: 'Option 4',
                isFixed: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Notification,
                parent: { label: 'Option Group 1' }
            },
            {
                value: 'option 5a',
                label: 'Option 5',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true,
                parent: { label: 'Option Group 1' }
            }
        ]
    },
    {
        label: 'Option Group 2',
        value: '',
        options: [
            {
                value: 'option 1b',
                label: 'Option 1',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Build,
                parent: { label: 'Option Group 2' }
            },
            {
                value: 'option 2b',
                label: 'Option 2',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true,
                parent: { label: 'Option Group 2' }
            },
            {
                value: 'option 2c',
                label: 'Option 3',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Equalizer,
                parent: { label: 'Option Group 2' }
            }
        ]
    }
];

const MultiSelect: React.FunctionComponent = (): React.ReactElement => {
    const [selectedBasicValues, setSelectedBasicValues] = useState([]);
    const [selectedDisabledValues, setSelectedDisabledValues] = useState([]);

    const [selectAllSelected, setSelectAllSelected] = useState([]);
    const [consolidatedSelected, setConsolidatedSelected] = useState([]);
    const [
        selectAllAndConsolidatedSelected,
        setSelectAllAndConsolidatedSelected
    ] = useState([]);

    function getIsSelectAllOption({
        option,
        removedValue
    }: OptionType): boolean {
        return (
            (Boolean(option) && option.value === selectAllOption.value) ||
            (Boolean(removedValue) &&
                removedValue.value === selectAllOption.value)
        );
    }

    function handleSelectAllChange(
        options: OptionsType<OptionType>,
        option: OptionType
    ): void {
        const isSelectAllOption: boolean = getIsSelectAllOption(option);

        if (option.action === 'select-option') {
            setSelectAllSelected(isSelectAllOption ? basicOptions : options);
        } else {
            setSelectAllSelected(isSelectAllOption ? [] : options);
        }
    }

    function handleConsolidatedChange(
        options: OptionsType<OptionType>,
        option: OptionType
    ): void {
        const isSelectAllOption: boolean = getIsSelectAllOption(option);

        if (option.action === 'select-option') {
            setConsolidatedSelected(options);
        } else {
            setConsolidatedSelected(isSelectAllOption ? [] : options);
        }
    }

    function handleSelectAllAndConsolidatedChange(
        options: OptionsType<OptionType>,
        option: OptionType
    ): void {
        const isSelectAllOption: boolean = getIsSelectAllOption(option);

        if (option.action === 'select-option') {
            setSelectAllAndConsolidatedSelected(
                isSelectAllOption ? basicOptions : options
            );
        } else {
            setSelectAllAndConsolidatedSelected(
                isSelectAllOption ? [] : options
            );
        }
    }

    const getTopParent = (option: OptionType): OptionType => {
        if (!option || !option.parent) {
            return option;
        } else {
            return option.parent;
        }
    };

    const createCustomSelectedLabel = (option: OptionType): string =>
        option.label;

    const customComponents: SelectComponentsConfig<OptionType> = {
        // eslint-disable-next-line react/display-name
        MultiValueLabel: (
            props: MultiValueProps<OptionType>
        ): React.ReactElement<React.ReactNode> => (
            <p>
                {createCustomSelectedLabel
                    ? createCustomSelectedLabel(props.data)
                    : `${props.data.parent.label}: ${props.data.label}`}
            </p>
        )
    };

    return (
        <div className="max-w-md">
            <h3>Multi Select</h3>
            <section className="mb-6">
                <h4>Basic w/ Label</h4>
                <Select
                    isMulti
                    label="Field label"
                    onChange={(options): void => {
                        setSelectedBasicValues(
                            options.map(({ value }): React.ReactText => value)
                        );
                    }}
                    options={basicOptions}
                />
                <p className="mt-1">
                    Selected Values: {selectedBasicValues.join(', ')}
                </p>
            </section>
            <section className="mb-6">
                <h4>Inline Icons</h4>
                <Select
                    isMulti
                    label="MultiValue Icons"
                    options={basicIconOptions}
                    shouldShowSelectedOptionIcon
                />
            </section>
            <section className="mb-6">
                <h4>Disabled</h4>
                <Select
                    isMulti
                    onChange={(options): void => {
                        setSelectedDisabledValues(
                            options.map(({ value }): React.ReactText => value)
                        );
                    }}
                    options={basicDisableOptions}
                />
                <p className="mt-1">
                    Selected Values: {selectedDisabledValues.join(', ')}
                </p>
            </section>
            <section className="mb-6">
                <h4>Disabled w/ Selected Options</h4>
                <Select
                    defaultValue={basicDisableOptions.slice(0, 3)}
                    isMulti
                    options={basicDisableOptions}
                />
            </section>
            <section className="mb-6">
                <h4>Disabled</h4>
                <Select isMulti options={basicDisableOptions} />
            </section>
            <section className="mb-6">
                <h4>Disabled w/ Selected Options</h4>
                <Select
                    defaultValue={basicDisableOptions.slice(0, 3)}
                    isMulti
                    options={basicDisableOptions}
                />
            </section>
            <section className="mb-6">
                <h4>Grouped Icons, Subtitle &amp; Description</h4>
                <Select isMulti label="Field label" options={allOptions} />
            </section>
            <section className="mb-6">
                <h4>Select All</h4>
                <Select
                    isMulti
                    label="Field label"
                    numberOfOptions={basicOptions.length}
                    onChange={handleSelectAllChange}
                    options={basicOptions}
                    shouldAllowSelectAll
                    value={selectAllSelected}
                />
            </section>
            <section className="mb-6">
                <h4>Consolidated value for all selected</h4>
                <Select
                    isMulti
                    label="Field label"
                    numberOfOptions={basicOptions.length}
                    onChange={handleConsolidatedChange}
                    options={basicOptions}
                    shouldConsolidateAllValues
                    value={consolidatedSelected}
                />
            </section>
            <section className="mb-6">
                <h4>Select All and consolidated value for all selected</h4>
                <Select
                    isMulti
                    label="Field label"
                    numberOfOptions={basicOptions.length}
                    onChange={handleSelectAllAndConsolidatedChange}
                    options={basicOptions}
                    shouldAllowSelectAll
                    shouldConsolidateAllValues
                    value={selectAllAndConsolidatedSelected}
                />
            </section>
            <section className="mb-6">
                <h4>Grouped Icons with selected options as group parent</h4>
                <Select
                    components={customComponents}
                    groupBy={getTopParent}
                    isMulti
                    label="Field label"
                    options={allOptions}
                />
            </section>
        </div>
    );
};

export default MultiSelect;
