import * as React from 'react';

import { Checkbox } from '@preamp/core';
import { OptionsType, OptionType, Select } from '@preamp/select';
import {
    AppSelect,
    Build,
    Code,
    Equalizer,
    Notification
} from '@preamp/signal';

const allOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1' },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    { value: 'option 5', label: 'Option 5' },
    {
        label: 'Option Group 1',
        value: '',
        options: [
            {
                value: 'option 1a',
                label: 'Option 1',
                isFixed: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: AppSelect
            },
            {
                value: 'option 2a',
                label: 'Option 2',
                disabled: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            },
            {
                value: 'option 3a',
                label: 'Option 3',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Code
            },
            {
                value: 'option 4a',
                label: 'Option 4',
                isFixed: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Notification
            },
            {
                value: 'option 5a',
                label: 'Option 5',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            }
        ]
    },
    {
        label: 'Option Group 2',
        value: '',
        options: [
            {
                value: 'option 1b',
                label: 'Option 1',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Build
            },
            {
                value: 'option 2b',
                label: 'Option 2',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            },
            {
                value: 'option 2c',
                label: 'Option 3',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Equalizer
            }
        ]
    }
];

interface ControlledSelectState {
    value: string;
}

export default function ControlledSelectState(): React.ReactNode {
    const defaultOption: OptionsType<OptionType> = allOptions[5].options[0];

    const [hasOptions, setHasOptions] = React.useState<boolean>(true);
    const [selectedSingleValue, setSelectedSingleValue] = React.useState<
        OptionsType<OptionType>
    >(defaultOption);
    const [selectedMultiValue, setSelectedMultiValue] = React.useState<
        OptionsType<OptionType>
    >(defaultOption);

    return (
        <div className="max-w-md">
            <Checkbox
                checked={hasOptions}
                className="mb-2"
                label="Show Options"
                name="show-options"
                onChange={(checked: boolean): void => {
                    setHasOptions(checked);
                }}
            />
            <h3>Controlled Select</h3>
            <section className="mb-6">
                <h4>
                    Controlling the value state of the Select component via the
                    value prop
                </h4>
                <Select
                    label="Field label"
                    labelDescription="Description text goes here."
                    onChange={(option: OptionType): void =>
                        setSelectedSingleValue(option)
                    }
                    options={hasOptions ? allOptions : []}
                    value={hasOptions ? selectedSingleValue : undefined}
                />
            </section>
            <section className="mb-6">
                <h4>
                    Controlling the value state of the Multi Select component
                    via the value prop
                </h4>
                <Select
                    isMulti
                    label="Field label"
                    labelDescription="Description text goes here."
                    onChange={(options: OptionsType<OptionType>): void =>
                        setSelectedMultiValue(options)
                    }
                    options={hasOptions ? allOptions : []}
                    value={hasOptions ? selectedMultiValue : undefined}
                />
            </section>
        </div>
    );
}
