import React from 'react';

import { OptionsType, OptionType, Select, ValueType } from '@preamp/select';

const basicOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1' },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    { value: 'option 5', label: 'Option 5' }
];

const infiniteScrollOptions: OptionsType<OptionType> = [
    { value: '1.a', label: 'Option 1.a' },
    { value: '2.a', label: 'Option 2.a' },
    { value: '3.a', label: 'Option 3.a' },
    { value: '4.a', label: 'Option 4.a' },
    { value: '5.a', label: 'Option 5.a' },
    { value: '1.b', label: 'Option 1.b' },
    { value: '2.b', label: 'Option 2.b' },
    { value: '3.b', label: 'Option 3.b' },
    { value: '4.b', label: 'Option 4.b' },
    { value: '5.b', label: 'Option 5.b' },
    { value: '1.c', label: 'Option 1.c' },
    { value: '2.c', label: 'Option 2.c' },
    { value: '3.c', label: 'Option 3.c' },
    { value: '4.c', label: 'Option 4.c' },
    { value: '5.c', label: 'Option 5.c' },
    { value: '1.d', label: 'Option 1.d' },
    { value: '2.d', label: 'Option 2.d' },
    { value: '3.d', label: 'Option 3.d' },
    { value: '4.d', label: 'Option 4.d' },
    { value: '5.d', label: 'Option 5.d' },
    { value: '1.e', label: 'Option 1.e' },
    { value: '2.e', label: 'Option 2.e' },
    { value: '3.e', label: 'Option 3.e' },
    { value: '4.e', label: 'Option 4.e' },
    { value: '5.e', label: 'Option 5.e' }
];

function filterOptions(inputValue: string, options: any): any {
    if (inputValue) {
        return options.filter((option: any): void =>
            option.label.toLowerCase().includes(inputValue.toLowerCase())
        );
    }

    return options;
}

function loadOptionsWithCallback(inputValue: string, callback: any): void {
    setTimeout((): void => {
        callback(filterOptions(inputValue, basicOptions));
    }, 1000);
}

function loadOptionsWithPromise(inputValue: string): Promise<any> {
    return new Promise((resolve: (value: any) => any): void => {
        setTimeout((): void => {
            resolve(filterOptions(inputValue, basicOptions));
        }, 1000);
    });
}

interface AsyncSelectState {
    isLoading: boolean;
    scrollCount: number;
    value: OptionsType<OptionType>;
}

class AsyncSelect extends React.Component<{}, AsyncSelectState> {
    state: AsyncSelectState = {
        isLoading: false,
        scrollCount: 0,
        value: [infiniteScrollOptions[1], infiniteScrollOptions[7]]
    };

    onChange = (value: ValueType<OptionType>): void => {
        this.setState({
            value
        });
    };

    onMenuScrollToBottom = (): void => {
        this.setState({
            isLoading: true
        });

        // Fake async fetch
        setTimeout((): void => {
            this.setState({
                isLoading: false,
                scrollCount: this.state.scrollCount + 1
            });
        }, 2000);
    };

    render(): React.ReactNode {
        return (
            <div className="max-w-md">
                <h3>Async Select</h3>
                <section className="mb-6">
                    <h4>
                        No default options w/ Label using Callback (start typing
                        &quot;option&quot;)
                    </h4>
                    <Select
                        cacheOptions
                        isSearchable
                        label="Field label"
                        loadOptions={loadOptionsWithCallback}
                    />
                </section>
                <section className="mb-6">
                    <h4>
                        No default options w/ Label using Promise (start typing
                        &quot;option&quot;)
                    </h4>
                    <Select
                        cacheOptions
                        isSearchable
                        label="Field label"
                        loadOptions={loadOptionsWithPromise}
                    />
                </section>
                <section className="mb-6">
                    <h4>Default options w/ infinite scroll</h4>
                    <Select
                        isLoading={this.state.isLoading}
                        isMulti
                        maxMenuHeight={160}
                        onChange={this.onChange}
                        onMenuScrollToBottom={
                            this.state.scrollCount < 4 &&
                            this.onMenuScrollToBottom
                        }
                        options={infiniteScrollOptions.slice(
                            0,
                            (this.state.scrollCount + 1) * 5
                        )}
                        value={this.state.value}
                    />
                </section>
            </div>
        );
    }
}

export default AsyncSelect;
