import * as React from 'react';

import { get } from 'lodash';

import { OptionsType, OptionType, Select } from '@preamp/select';
import {
    AppSelect,
    Build,
    Code,
    Equalizer,
    Notification
} from '@preamp/signal';

const basicOptions: OptionsType<OptionType> = [
    { value: 'option 1', label: 'Option 1' },
    { value: 'option 2', label: 'Option 2' },
    { value: 'option 3', label: 'Option 3' },
    { value: 'option 4', label: 'Option 4' },
    { value: 'option 5', label: 'Option 5' }
];

const emailOptions: OptionsType<OptionType> = [
    { value: 'alyssa', label: 'alyssa@preamp.design' },
    { value: 'brad', label: 'brad@preamp.design' },
    { value: 'brian', label: 'brian@preamp.design' },
    { value: 'david', label: 'david@preamp.design' },
    { value: 'hope', label: 'hope@preamp.design' },
    { value: 'joe', label: 'joe@preamp.design' },
    { value: 'veiko', label: 'veiko@preamp.design' }
];

const allOptions: OptionsType<OptionType> = [
    {
        label: 'Option Group 1',
        value: '',
        options: [
            {
                value: 'option 1a',
                label: 'Option 1',
                isFixed: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: AppSelect
            },
            {
                value: 'option 2a',
                label: 'Option 2',
                disabled: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            },
            {
                value: 'option 3a',
                label: 'Option 3',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Code
            },
            {
                value: 'option 4a',
                label: 'Option 4',
                isFixed: true,
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Notification
            },
            {
                value: 'option 5a',
                label: 'Option 5',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            }
        ]
    },
    {
        label: 'Option Group 2',
        value: '',
        options: [
            {
                value: 'option 1b',
                label: 'Option 1',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Build
            },
            {
                value: 'option 2b',
                label: 'Option 2',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                spacer: true
            },
            {
                value: 'option 2c',
                label: 'Option 3',
                subtitle: 'Option Subtitle',
                description: 'This is a description of the field',
                icon: Equalizer
            }
        ]
    }
];

interface TypedownSelectState {
    selectedValues: OptionsType<OptionType>;
}

class TypedownSelect extends React.Component<{}, TypedownSelectState> {
    state: TypedownSelectState = {
        selectedValues: []
    };

    onChange = (newOptions: OptionsType<OptionType>): void => {
        let customValues: OptionsType<OptionType> = [];

        const values: OptionsType<OptionType> = newOptions.map(
            (option: OptionType): React.ReactNode => {
                if (
                    get(option, '__isNew__') &&
                    (option.value as string).match(/,|;/)
                ) {
                    customValues = (option.value as string).split(/,|;/).map(
                        (val: string): React.ReactNode => ({
                            label: val,
                            value: val
                        })
                    );
                } else {
                    return option;
                }
            }
        );

        this.setState({
            selectedValues: [...values, ...customValues]
        });
    };

    render(): React.ReactNode {
        return (
            <div className="max-w-md">
                <h3>Typedown Select</h3>
                <section className="mb-6">
                    <h4>Basic w/ Label</h4>
                    <Select
                        isSearchable
                        label="Field label"
                        options={basicOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Grouped Icons, Subtitle &amp; Description</h4>
                    <Select
                        isMulti
                        isSearchable
                        label="Field label"
                        options={allOptions}
                    />
                </section>
                <section className="mb-6">
                    <h4>Creatable Typedown</h4>
                    <p>
                        This example will separate any custom values by a `,` or
                        `;` and create a new value for each.
                    </p>
                    <Select
                        isMulti
                        isSearchable
                        label="Field label"
                        onChange={this.onChange}
                        options={emailOptions}
                        shouldAllowCustomValues
                        value={this.state.selectedValues}
                    />
                </section>
            </div>
        );
    }
}

export default TypedownSelect;
