import React from 'react';

import { StackSelect, StackSelectOptionType } from '@preamp/select';

const data: StackSelectOptionType[] = [
    {
        label: 'Checkbox Select Item 1',
        name: 'checkbox-1',
        value: 'item-1'
    },
    {
        label: 'Checkbox Select Item 2',
        name: 'checkbox-2',
        value: 'item-2'
    },
    {
        label: 'Checkbox Select Item 3',
        name: 'checkbox-3',
        value: 'item-3'
    },
    {
        label: 'Checkbox Select Item 4',
        name: 'checkbox-4',
        value: 'item-4'
    },
    {
        label: 'Checkbox Select Item 5',
        name: 'checkbox-5',
        value: 'item-5',
        isDisabled: true
    },
    {
        label: 'Checkbox Select Item 6',
        name: 'checkbox-6',
        value: 'item-6',
        isDisabled: true
    }
];

const CheckboxSelect: React.FC = (): React.ReactElement => {
    const [selected, setSelected] = React.useState<Set<string>>(
        new Set('checkbox-6')
    );

    function handleChange(name: string, _: string, checked: boolean): void {
        const newSelectedOptions: Set<string> = new Set(selected);
        if (checked) {
            newSelectedOptions.add(name);
        } else {
            newSelectedOptions.delete(name);
        }
        setSelected(newSelectedOptions);
    }

    return (
        <section className="max-w-xs">
            <StackSelect
                dataUI="checkbox-stack-select"
                id="checkbox-stack-select"
                isMulti
                label="Checkbox Select"
                onChange={handleChange}
                options={data}
                selected={selected}
            />
        </section>
    );
};

export default CheckboxSelect;
