import React from 'react';

import { StackSelect, StackSelectOptionType } from '@preamp/select';

const data: StackSelectOptionType[] = [
    {
        label: 'Color Select Item 1',
        name: 'color-1',
        value: 'item-1',
        color: '#ff8a80'
    },
    {
        label: 'Color Select Item 2',
        name: 'color-2',
        value: 'item-2',
        color: '#FF80AB'
    },
    {
        label: 'Color Select Item 3',
        name: 'color-3',
        value: 'item-3',
        color: '#EA80FC'
    },
    {
        label: 'Color Select Item 4',
        name: 'color-4',
        value: 'item-4',
        color: '#B388FF'
    },
    {
        label: 'Color Select Item 5',
        name: 'color-5',
        value: 'item-5',
        color: '#8C9EFF',
        isDisabled: true
    },
    {
        label: 'Color Select Item 6',
        name: 'color-6',
        value: 'item-6',
        color: '#82B1FF',
        isDisabled: true
    }
];

const ColorSelect: React.FC = (): React.ReactElement => {
    const [selected, setSelected] = React.useState<Set<string>>(
        new Set([data[2].name, data[3].name, data[5].name])
    );

    function handleChange(name: string, _: string, checked: boolean): void {
        const newSelectedOptions: Set<string> = new Set(selected);
        if (checked) {
            newSelectedOptions.add(name);
        } else {
            newSelectedOptions.delete(name);
        }
        setSelected(newSelectedOptions);
    }

    return (
        <section className="max-w-xs">
            <StackSelect
                id="checkbox-dv-stack-select"
                isMulti
                label="Color Select w/ Defaults"
                onChange={handleChange}
                options={data}
                selected={selected}
            />
        </section>
    );
};

export default ColorSelect;
