import React, { ReactElement, useState } from 'react';

import { TextField, TextFieldType } from '@preamp/core';
import {
    AppSelect,
    Account,
    Edit,
    Error,
    LightningBolt,
    Notification,
    Signal,
    SignalSize,
    Visibility
} from '@preamp/signal';

/**
 * Basic Signal example.
 */

function BasicSignal(): ReactElement {
    const [customIconSize, setCustomSize] = useState('1');
    const [iconColorPrimary, setIconColorPrimary] = useState(
        'var(--va-indigo-500)'
    );
    const [iconColorSecondary, setIconColorSecondary] = useState(
        'var(--va-grey-500)'
    );

    const svg: React.ReactNode = (
        <svg viewBox="0 0 24 24">
            <defs>
                <path d="M24 24H0V0h24v24z" id="a" />
            </defs>
            <path d="M3 4V1h2v3h3v2H5v3H3V6H0V4h3zm3 6V7h3V4h7l1.83 2H21c1.1 0 2 .9 2 2v12c0 1.1-.9 2-2 2H5c-1.1 0-2-.9-2-2V10h3zm7 9c2.76 0 5-2.24 5-5s-2.24-5-5-5-5 2.24-5 5 2.24 5 5 5zm-3.2-5c0 1.77 1.43 3.2 3.2 3.2s3.2-1.43 3.2-3.2-1.43-3.2-3.2-3.2-3.2 1.43-3.2 3.2z" />
        </svg>
    );

    function onIconSizeChange(
        event?: React.ChangeEvent<HTMLInputElement>
    ): void {
        setCustomSize(event.currentTarget.value);
    }
    function onIconPrimaryColorChange(
        event?: React.ChangeEvent<HTMLInputElement>
    ): void {
        setIconColorPrimary(event.currentTarget.value);
    }
    function onIconSecondaryColorChange(
        event?: React.ChangeEvent<HTMLInputElement>
    ): void {
        setIconColorSecondary(event.currentTarget.value);
    }

    return (
        <>
            <style>
                {`
                        .signal-example-container {

                            color: ${iconColorPrimary}
                        }
                    `}
            </style>
            <div className="va-grid va-columns-default mt-4">
                <div className="signal-example-container text-sm col-span-6">
                    <div className="flex items-center mb-4">
                        <span className="mr-6">Default:</span>
                        <Signal
                            colorSecondary={iconColorSecondary}
                            icon={Account}
                            size={parseFloat(customIconSize)}
                        />
                        <Signal
                            colorSecondary={iconColorSecondary}
                            icon={Visibility}
                            size={parseFloat(customIconSize)}
                        />
                    </div>
                    <div className="flex items-center mb-4">
                        <span className="mr-4">Small:</span>
                        <Signal
                            colorSecondary={iconColorSecondary}
                            icon={Account}
                            size={SignalSize.Small}
                        />

                        <Signal icon={Edit} size={SignalSize.Small} />
                    </div>
                    <div className="flex items-center mb-4">
                        <span className="mr-4">Medium:</span>
                        <Signal
                            colorSecondary={iconColorSecondary}
                            icon={Account}
                            size={SignalSize.Medium}
                        />
                        <Signal icon={AppSelect} size={SignalSize.Medium} />
                    </div>
                    <div className="flex items-center mb-4">
                        <span className="mr-4">Large:</span>
                        <Signal
                            colorSecondary={iconColorSecondary}
                            icon={Account}
                            size={SignalSize.Large}
                        />
                        <Signal
                            colorSecondary={iconColorSecondary}
                            icon={LightningBolt}
                            size={SignalSize.Large}
                        />
                    </div>
                    <div className="flex items-center mb-4">
                        <span className="mr-4">XL:</span>
                        <Signal
                            colorSecondary={iconColorSecondary}
                            icon={Account}
                            size={SignalSize.XL}
                        />
                        <Signal icon={Notification} size={SignalSize.XL} />
                    </div>
                    <div className="flex items-center mb-4">
                        <span className="mr-4">size = &quot;32px&quot;:</span>
                        <Signal
                            colorSecondary={iconColorSecondary}
                            icon={Account}
                            size="32px"
                        />
                    </div>
                    <div className="mb-4">
                        <div className="mb-2">
                            Color prop set to <code>var(--va-red-500)</code>:
                        </div>
                        <Signal
                            color="var(--va-red-500)"
                            icon={Error}
                            size="60px"
                        />
                    </div>
                    <div className="mb-4">
                        <div className="mb-2">Raw SVG code:</div>
                        <Signal
                            color="var(--va-red-500)"
                            icon={svg}
                            size="60px"
                        />
                    </div>
                </div>
                <div className="col-span-6">
                    <div className="mb-6">
                        <TextField
                            helpText="Custom icon size from the customeSize prop in rem - if undefined, it takes font-size of parent element."
                            label="Default size (rem)"
                            onChange={onIconSizeChange}
                            textFieldType={TextFieldType.Number}
                            value={customIconSize}
                        />
                    </div>
                    <div className="mb-6">
                        <TextField
                            helpText="Enter CSS Custom Property or hex value"
                            label="Primary Color"
                            onChange={onIconPrimaryColorChange}
                            textFieldType={TextFieldType.Text}
                            value={iconColorPrimary}
                        />
                    </div>
                    <div className="mb-6">
                        <TextField
                            helpText="Enter CSS Custom Property or hex value, or leave blank to use the primary color"
                            label="Secondary Color"
                            onChange={onIconSecondaryColorChange}
                            textFieldType={TextFieldType.Text}
                            value={iconColorSecondary}
                        />
                    </div>
                </div>
            </div>
        </>
    );
}

export default BasicSignal;
