import React from 'react';

import { ComparisonCell } from '@preamp/tables';

const ComparisonCellExample: React.SFC = (): React.ReactElement => {
    const customFormat = {
        customDecreasePrefix: <small className="mr-1">↘︎</small>,
        customIncreasePrefix: <small className="mr-1">↗︎</small>
    };

    const negativeExample = {
        base: 100,
        compareTo: 50
    };

    const positiveExample = {
        base: 50,
        compareTo: 100
    };

    const abbreviatedExample = {
        base: 10000,
        compareTo: 5000
    };

    const currencyExample = {
        base: 10.25,
        compareTo: 5.5
    };

    const preciseExample = {
        base: 0.24382024034227728,
        compareTo: 0.82024034227728243
    };

    const numberFormatExample = {
        base: 1000000,
        compareTo: 2000000
    };

    return (
        <div className="grid">
            <div className="pb-2">
                <p>{`Negative Value (base value: ${negativeExample.base}, compare to value: ${negativeExample.compareTo})`}</p>
                <ComparisonCell baseValue={100} comparisonValue={50} />
            </div>
            <div className="pb-2">
                <p>{`Positive Value (base value: ${positiveExample.base}, compare to value: ${positiveExample.compareTo})`}</p>
                <ComparisonCell baseValue={50} comparisonValue={100} />
            </div>
            <div className="pb-2">
                <p>{`Abbreviated Value (base value: ${abbreviatedExample.base}, compare to value: ${abbreviatedExample.compareTo})`}</p>
                <ComparisonCell
                    baseValue={abbreviatedExample.base}
                    comparisonValue={abbreviatedExample.compareTo}
                    isAbbreviated={true}
                />
            </div>
            <div className="pb-2">
                <p>{`Currency Value (base value: ${currencyExample.base}, compare to value: ${currencyExample.compareTo})`}</p>
                <ComparisonCell
                    baseValue={currencyExample.base}
                    comparisonValue={currencyExample.compareTo}
                    isCurrency={true}
                />
            </div>
            <div className="pb-2">
                <p>{`Precise Value set to 4 decimal places (base value: ${preciseExample.base}, compare to value: ${preciseExample.compareTo})`}</p>
                <ComparisonCell
                    baseValue={preciseExample.base}
                    comparisonValue={preciseExample.compareTo}
                    precision={4}
                />
            </div>
            <div className="pb-2">
                <p>{`Abbreviated and Currency Value (base value: ${abbreviatedExample.base}, compare to value: ${abbreviatedExample.compareTo})`}</p>
                <ComparisonCell
                    baseValue={abbreviatedExample.base}
                    comparisonValue={abbreviatedExample.compareTo}
                    isAbbreviated={true}
                    isCurrency={true}
                />
            </div>
            <div className="pb-2">
                <p>With Custom Prefix</p>
                <ComparisonCell
                    baseValue={100}
                    comparisonValue={50}
                    customFormat={customFormat}
                    id={'1'}
                />
            </div>
            <div>
                <p>{`With Inverted Logic (base value: ${positiveExample.base}, compare to value: ${positiveExample.compareTo})`}</p>
                <ComparisonCell
                    baseValue={50}
                    comparisonValue={100}
                    customFormat={{ isInverted: true }}
                    id={'1'}
                />
            </div>
            <div className="pb-2">
                <p>{`Custom number format (0,0) using NumeralJS formatting: http://numeraljs.com/#format (base value: ${numberFormatExample.base}, compare to value: ${numberFormatExample.compareTo})`}</p>
                <ComparisonCell
                    baseValue={numberFormatExample.base}
                    comparisonValue={numberFormatExample.compareTo}
                    numberFormat={'0,0'}
                />
            </div>
        </div>
    );
};

export default ComparisonCellExample;
