import React, { ReactElement, useState } from 'react';

import { OptionsType, OptionType } from '@preamp/select';
import {
    DotPrefix,
    HeaderSelectCell,
    HeaderSelectCellSortMode
} from '@preamp/tables';

const OPTIONS: OptionsType<OptionType> = [
    { label: 'Option 1', value: 'opt1' },
    { label: 'Option 2', value: 'opt2' }
];

/**
 * Basic example
 */

function HeaderSelectCellBasicExample(): ReactElement<HTMLElement> {
    const [option, setOption] = useState<OptionType>(OPTIONS[0]);
    const [sortMode, setSortMode] = useState<HeaderSelectCellSortMode>();

    function toggleSortMode(): void {
        setSortMode(
            (mode: HeaderSelectCellSortMode): HeaderSelectCellSortMode =>
                mode === HeaderSelectCellSortMode.Desc
                    ? HeaderSelectCellSortMode.Asc
                    : HeaderSelectCellSortMode.Desc
        );
    }
    return (
        <HeaderSelectCell
            label="Select"
            menuFooter={
                <div className="va-caption p-1">This is a menu footer</div>
            }
            onChange={setOption}
            onSortClick={toggleSortMode}
            options={OPTIONS}
            sortMode={sortMode}
            value={option}
            valuePrefix={<DotPrefix color="var(--waveform-default-500)" />}
        />
    );
}

export default HeaderSelectCellBasicExample;
