import React from 'react';

import { clone, random, times } from 'lodash';

import { IListTableColumn, ListTable } from '@preamp/tables';

enum columns {
    Letter = 'letter',
    Number = 'number'
}

interface LoadMoreListTableRows {
    identifier: number;
    [columns.Letter]: string;
    [columns.Number]: number;
}

interface LoadMoreListTableState {
    isLoading: boolean;
    rows: LoadMoreListTableRows[];
    rowNumber: number;
}

const startingRows: LoadMoreListTableRows[] = [
    {
        identifier: 0,
        letter: 'h',
        number: 100
    },
    {
        identifier: 0,
        letter: 'n',
        number: 80
    },
    {
        identifier: 0,
        letter: 'b',
        number: 60
    },
    {
        identifier: 0,
        letter: 'j',
        number: 73
    },
    {
        identifier: 0,
        letter: 'd',
        number: 26
    }
];

class LoadMoreListTable extends React.Component<{}, LoadMoreListTableState> {
    state: LoadMoreListTableState = {
        isLoading: false,
        rowNumber: 0,
        rows: []
    };

    columns: IListTableColumn[] = [
        {
            identifier: columns.Letter,
            sortable: true,
            header: 'Random Letter',
            minWidth: 150
        },
        {
            identifier: columns.Number,
            sortable: true,
            header: 'Random Number',
            minWidth: 150,
            isMetric: true
        }
    ];

    componentDidMount(): void {
        this.setState({ rows: startingRows, isLoading: false });
    }

    createRandomRow = (): LoadMoreListTableRows => ({
        identifier: this.state.rowNumber,
        letter: String.fromCharCode(random(97, 122)),
        number: random(0, 100)
    });

    appendMoreRows = (amount: number): void => {
        const newRows: LoadMoreListTableRows[] = clone(this.state.rows);
        times(amount, (): void => {
            newRows.push(this.createRandomRow());
        });
        this.setState({ rows: newRows, isLoading: false });
    };

    onClickLoadMore = (): void => {
        this.setState(
            {
                isLoading: true
            },
            (): void => {
                setTimeout((): void => {
                    this.appendMoreRows(5);
                }, 500);
            }
        );
    };

    render(): React.ReactNode {
        return (
            <>
                <div>Load More Option</div>
                <ListTable
                    columns={this.columns}
                    dataUI="LoadMoreListTable"
                    isLoadingMoreRows={this.state.isLoading}
                    onClickLoadMore={this.onClickLoadMore}
                    rows={this.state.rows}
                />
            </>
        );
    }
}

export default LoadMoreListTable;
