import React from 'react';

import { Edit, Trash } from '@preamp/signal';
import {
    DateCell,
    DateCellProps,
    IListTableColumn,
    IRowAction,
    ListTable,
    NameDescriptionCell,
    NameDescriptionCellProps,
    NumberCell,
    NumberCellProps
} from '@preamp/tables';

enum columns {
    Name = 'name',
    Created = 'created',
    LastUpdated = 'lastUpdated',
    Size = 'size'
}

interface RowActionsListTableRow {
    identifier: number;
    [columns.Name]: NameDescriptionCellProps;
    [columns.Created]: DateCellProps;
    [columns.LastUpdated]: DateCellProps;
    [columns.Size]: NumberCellProps;
}

class RowActionsListTable extends React.Component {
    columns: IListTableColumn[] = [
        {
            identifier: columns.Name,
            header: 'Name',
            minWidth: 150,
            CustomCell: ({ value }: any): React.ReactNode => (
                <NameDescriptionCell
                    description={value.description}
                    name={value.name}
                />
            )
        },
        {
            identifier: columns.Created,
            header: 'Created',
            minWidth: 100,
            CustomCell: ({ value }: any): React.ReactNode => (
                <DateCell date={value.date} description={value.description} />
            )
        },
        {
            identifier: columns.LastUpdated,
            header: 'Last Updated',
            minWidth: 100,
            CustomCell: ({ value }: any): React.ReactNode => (
                <DateCell date={value.date} description={value.description} />
            )
        },
        {
            identifier: columns.Size,
            header: 'Size',
            minWidth: 100,
            isMetric: true,
            CustomCell: ({ value }: any): React.ReactNode => (
                <NumberCell
                    description={value.description}
                    value={value.value}
                />
            )
        }
    ];

    rows: RowActionsListTableRow[] = [
        {
            identifier: 1,
            name: {
                name: 'Bob',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 1, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 3, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 35189 }
        },
        {
            identifier: 2,
            [columns.Name]: {
                name: 'Amy',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 2, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2019, 4, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 14138890 }
        },
        {
            identifier: 3,
            [columns.Name]: {
                name: 'Carl',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 2, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2016, 5, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 145876 }
        },
        {
            identifier: 4,
            [columns.Name]: {
                name: 'Doug',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 3, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 6, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 75463 }
        },
        {
            identifier: 5,
            [columns.Name]: {
                name: 'Emily',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 4, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 7, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 984153 }
        }
    ];

    onClickDelete = (
        rowIdentifier: string | number,
        event: React.MouseEvent
    ): void => {
        event.stopPropagation();
        // eslint-disable-next-line no-console
        console.log('DELETE', rowIdentifier);
    };
    onClickEdit = (
        rowIdentifier: string | number,
        event: React.MouseEvent
    ): void => {
        event.stopPropagation();
        // eslint-disable-next-line no-console
        console.log('EDIT', rowIdentifier);
    };

    render(): React.ReactNode {
        const rowActions: IRowAction[] = [
            {
                icon: Trash,
                onClick: this.onClickDelete,
                dataUI: 'delete-button',
                tooltip: 'Delete this item.'
            },
            {
                icon: Edit,
                onClick: this.onClickEdit,
                dataUI: 'edit-button',
                tooltip: 'Edit this item'
            }
        ];

        return (
            <>
                <div>Row Actions</div>
                <ListTable
                    columns={this.columns}
                    dataUI="row-actions-list-table"
                    rowActions={rowActions}
                    rows={this.rows}
                    rowTabIndex={0}
                />
            </>
        );
    }
}

export default RowActionsListTable;
