import React from 'react';

import { keyboardKeys } from '@preamp/core';
import {
    DateCell,
    DateCellProps,
    IListTableColumn,
    ListTable,
    NameDescriptionCell,
    NameDescriptionCellProps
} from '@preamp/tables';

enum columnEnum {
    Name = 'name',
    Selected = 'selected',
    Created = 'created',
    LastUpdated = 'updated'
}
interface SelectableCheckboxListTableRow {
    identifier: number;
    [columnEnum.Name]: NameDescriptionCellProps;
    [columnEnum.Created]: DateCellProps;
    [columnEnum.LastUpdated]: DateCellProps;
}

function NameDescriptionCellComponent({ value }: any): React.ReactNode {
    return (
        <NameDescriptionCell
            description={value.description}
            descriptionTruncationLines={2}
            name={value.name}
            pending={value.pending}
        />
    );
}
function CreatedDateCellComponent({ value }: any): React.ReactNode {
    return <DateCell date={value.date} description={value.description} />;
}
function UpdatedDateCellComponent({ value }: any): React.ReactNode {
    return <DateCell date={value.date} description={value.description} />;
}

const columns: IListTableColumn[] = [
    {
        identifier: columnEnum.Name,
        header: 'Name',
        minWidth: 150,
        CustomCell: NameDescriptionCellComponent
    },
    {
        identifier: columnEnum.Created,
        header: 'Created',
        minWidth: 100,
        CustomCell: CreatedDateCellComponent
    },
    {
        identifier: columnEnum.LastUpdated,
        header: 'Last Updated',
        minWidth: 100,
        CustomCell: UpdatedDateCellComponent
    }
];

const rows: SelectableCheckboxListTableRow[] = [
    {
        identifier: 1,
        [columnEnum.Name]: {
            name:
                'This is a really long name that should truncate and should show an ellipsis after set number of lines',
            description:
                'Ancient alien Annunaki otherworldly visitors clearly extraterrestrial golden disk mercury weightless, pre-colonial aerodynamics NASA clearly Vymaanika-Shaastra Sumerian texts space time. Burmuta triangle Indian texts clearly evidence cover up grey ancient alien, petroglyph sightings vimana Easter island gods inter-dimensional earth mound, I know it sounds crazy... Puma Punku mainstream archaelogy sightings.'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 1, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 3, 20),
            description: 'Kaleho Naki'
        }
    },
    {
        identifier: 2,
        [columnEnum.Name]: {
            name:
                'This is a really long name that should truncate and should show an ellipsis after set number of lines',
            description:
                'Ancient alien Annunaki otherworldly visitors clearly extraterrestrial golden disk mercury weightless, pre-colonial aerodynamics NASA clearly Vymaanika-Shaastra Sumerian texts space time. Burmuta triangle Indian texts clearly evidence cover up grey ancient alien, petroglyph sightings vimana Easter island gods inter-dimensional earth mound, I know it sounds crazy... Puma Punku mainstream archaelogy sightings.'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 1, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 3, 20),
            description: 'Kaleho Naki'
        }
    },
    {
        identifier: 3,
        [columnEnum.Name]: {
            name:
                'This is a really long name that should truncate and should show an ellipsis after set number of lines',
            description:
                'Ancient alien Annunaki otherworldly visitors clearly extraterrestrial golden disk mercury weightless, pre-colonial aerodynamics NASA clearly Vymaanika-Shaastra Sumerian texts space time. Burmuta triangle Indian texts clearly evidence cover up grey ancient alien, petroglyph sightings vimana Easter island gods inter-dimensional earth mound, I know it sounds crazy... Puma Punku mainstream archaelogy sightings.'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 1, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 3, 20),
            description: 'Kaleho Naki'
        }
    }
];

interface SelectableCheckboxListTableState {
    selectedRows: number[];
}

class SelectableCheckmarkListTable extends React.Component<
    {},
    SelectableCheckboxListTableState
> {
    state: SelectableCheckboxListTableState = {
        selectedRows: []
    };

    onRowClicked = (rowIdentifier: number): void => {
        this.setSelectedRows(rowIdentifier);
    };

    onRowKeyPressed = (
        rowIdentifier: number,
        event: React.KeyboardEvent
    ): void => {
        const key: number = event.keyCode || event.which;

        if (key === keyboardKeys.Enter || key === keyboardKeys.SpaceBar) {
            event.preventDefault();

            this.setSelectedRows(rowIdentifier);
        }
    };

    setSelectedRows = (rowIdentifier: number): void => {
        const { selectedRows } = this.state;
        const selected: boolean = selectedRows.includes(rowIdentifier);
        let newSelectedRows: number[] = [...selectedRows];

        if (selected) {
            newSelectedRows = newSelectedRows.filter(
                (row: number): React.ReactNode => row !== rowIdentifier
            );
        } else {
            newSelectedRows.push(rowIdentifier);
        }

        this.setState({
            selectedRows: newSelectedRows
        });
    };

    render(): React.ReactNode {
        const { selectedRows } = this.state;

        return (
            <>
                <div>Selectable List Table with Checkmarks</div>
                <ListTable
                    columns={columns}
                    dataUI="checkmark-selectable-list-table"
                    onRowClicked={this.onRowClicked}
                    onRowKeyPress={this.onRowKeyPressed}
                    rows={rows}
                    selectedRows={selectedRows}
                    showSelectableIcon
                />
            </>
        );
    }
}

export default SelectableCheckmarkListTable;
