import React from 'react';

import { Panel } from '@preamp/core';

import { Edit, Trash } from '@preamp/signal';
import {
    DateCell,
    DateCellProps,
    IListTableColumn,
    IRowAction,
    ListTable,
    NameDescriptionCell,
    NameDescriptionCellProps,
    NumberCell,
    NumberCellProps
} from '@preamp/tables';

enum columns {
    Name = 'name',
    Created = 'created',
    LastUpdated = 'lastUpdated',
    Size = 'size'
}

interface StickyHeaderListTableRow {
    identifier: number;
    [columns.Name]: NameDescriptionCellProps;
    [columns.Created]: DateCellProps;
    [columns.LastUpdated]: DateCellProps;
    [columns.Size]: NumberCellProps;
}

class StickyHeaderListTable extends React.Component {
    columns: IListTableColumn[] = [
        {
            identifier: columns.Name,
            header: 'Name',
            minWidth: 150,
            CustomCell: ({ value }: any): React.ReactNode => (
                <NameDescriptionCell
                    description={value.description}
                    name={value.name}
                />
            )
        },
        {
            identifier: columns.Created,
            header: 'Created',
            minWidth: 100,
            CustomCell: ({ value }: any): React.ReactNode => (
                <DateCell date={value.date} description={value.description} />
            )
        },
        {
            identifier: columns.LastUpdated,
            header: 'Last Updated',
            minWidth: 100,
            CustomCell: ({ value }: any): React.ReactNode => (
                <DateCell date={value.date} description={value.description} />
            )
        },
        {
            identifier: columns.Size,
            header: 'Size',
            minWidth: 100,
            isMetric: true,
            CustomCell: ({ value }: any): React.ReactNode => (
                <NumberCell
                    description={value.description}
                    value={value.value}
                />
            )
        }
    ];

    rows: StickyHeaderListTableRow[] = [
        {
            identifier: 1,
            name: {
                name: 'Bob',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 1, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 3, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 35189 }
        },
        {
            identifier: 2,
            [columns.Name]: {
                name: 'Amy',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 2, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2019, 4, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 14138890 }
        },
        {
            identifier: 3,
            [columns.Name]: {
                name: 'Carl',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 2, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2016, 5, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 145876 }
        },
        {
            identifier: 4,
            [columns.Name]: {
                name: 'Doug',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 3, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 6, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 75463 }
        },
        {
            identifier: 5,
            [columns.Name]: {
                name: 'Emily',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 4, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 7, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 984153 }
        },
        {
            identifier: 6,
            name: {
                name: 'Bob',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 1, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 3, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 35189 }
        },
        {
            identifier: 7,
            [columns.Name]: {
                name: 'Amy',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 2, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2019, 4, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 14138890 }
        },
        {
            identifier: 8,
            [columns.Name]: {
                name: 'Carl',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 2, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2016, 5, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 145876 }
        },
        {
            identifier: 9,
            [columns.Name]: {
                name: 'Doug',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 3, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 6, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 75463 }
        },
        {
            identifier: 10,
            [columns.Name]: {
                name: 'Emily',
                description:
                    'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
            },
            [columns.Created]: {
                date: new Date(2017, 4, 20),
                description: 'John Doe'
            },
            [columns.LastUpdated]: {
                date: new Date(2018, 7, 20),
                description: 'John Doe'
            },
            [columns.Size]: { value: 984153 }
        }
    ];

    onClickDelete = (
        rowIdentifier: string | number,
        event: React.MouseEvent
    ): void => {
        event.stopPropagation();
        // eslint-disable-next-line no-console
        console.log('DELETE', rowIdentifier);
    };
    onClickEdit = (
        rowIdentifier: string | number,
        event: React.MouseEvent
    ): void => {
        event.stopPropagation();
        // eslint-disable-next-line no-console
        console.log('EDIT', rowIdentifier);
    };

    render(): React.ReactNode {
        const rowActions: IRowAction[] = [
            {
                icon: Trash,
                onClick: this.onClickDelete,
                dataUI: 'delete-button'
            },
            { icon: Edit, onClick: this.onClickEdit, dataUI: 'edit-button' }
        ];

        return (
            <>
                <div className="mb-4">
                    When using the sticky header, the backround requires a
                    color. If the color of the parent element is something other
                    than white, you can use the{' '}
                    <code>headerBackgroundColor</code> prop to match the
                    background.
                </div>
                <div className="mb-4">
                    ListTable with a sticky header in a fixed height container
                    with fillHeight set to true.
                </div>
                <div
                    className="p-4"
                    style={{
                        height: '400px',
                        backgroundColor: 'var(--va-base-bg)'
                    }}
                >
                    <ListTable
                        columns={this.columns}
                        dataUI="row-actions-list-table"
                        fillHeight
                        headerBackgroundColor="var(--va-base-bg)"
                        isHeaderSticky
                        rowActions={rowActions}
                        rows={this.rows}
                        rowTabIndex={0}
                    />
                </div>
                <div className="py-4">
                    ListTable with a sticky header that will stick to the top of
                    the window.
                </div>
                <Panel>
                    <ListTable
                        columns={this.columns}
                        dataUI="row-actions-list-table"
                        isHeaderSticky
                        rowActions={rowActions}
                        rows={this.rows}
                        rowTabIndex={0}
                    />
                </Panel>
            </>
        );
    }
}

export default StickyHeaderListTable;
