import React from 'react';

import { Lock } from '@preamp/signal';
import {
    DateCell,
    DateCellProps,
    IListTableColumn,
    IRowAction,
    ListTable,
    ListTableTheme,
    NameDescriptionCell,
    NameDescriptionCellProps,
    NumberCell,
    NumberCellProps,
    StatusIndicator
} from '@preamp/tables';

enum columnEnum {
    Name = 'name',
    Created = 'created',
    LastUpdated = 'lastUpdated',
    Size = 'size'
}

interface BasicListTableRow {
    identifier: number;
    [columnEnum.Name]: NameDescriptionCellProps;
    [columnEnum.Created]: DateCellProps;
    [columnEnum.LastUpdated]: DateCellProps;
    [columnEnum.Size]: NumberCellProps;
}

const rows: BasicListTableRow[] = [
    {
        identifier: 1,
        [columnEnum.Name]: {
            name:
                'This is a really long name that should truncate and should show an ellipsis after set number of lines'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 1, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 3, 20)
        },
        [columnEnum.Size]: { value: 35189 }
    },
    {
        identifier: 2,
        [columnEnum.Name]: {
            isIndicatorShown: true,
            status: StatusIndicator.Pending,
            name: 'Amy'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 2, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2019, 4, 20)
        },
        [columnEnum.Size]: { value: 14138890 }
    },
    {
        identifier: 3,
        [columnEnum.Name]: {
            name: 'Carl'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 2, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2016, 5, 20)
        },
        [columnEnum.Size]: { value: 145876 }
    },
    {
        identifier: 4,
        [columnEnum.Name]: {
            isIndicatorShown: true,
            status: StatusIndicator.Failing,
            name: 'Doug'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 3, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 6, 20)
        },
        [columnEnum.Size]: { value: 75463 }
    },
    {
        identifier: 5,
        [columnEnum.Name]: {
            name: 'Emily'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 4, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 7, 20)
        },
        [columnEnum.Size]: { value: 984153 }
    }
];

const DisabledListTable: React.FC = (): React.ReactElement => {
    function nameClick(event: React.MouseEvent): void {
        event.stopPropagation();
        alert('Name clicked');
    }
    function NameDescriptionCellComponent({ value }: any): React.ReactNode {
        return (
            <NameDescriptionCell
                description={value.description}
                descriptionTruncationLines={2}
                indicatorColor={value.indicatorColor}
                isIndicatorShown={value.isIndicatorShown}
                name={value.name}
                nameUrl={`/#/tables/list/ListTable/${value.name}`}
                onNameClick={nameClick}
                status={value.status}
            />
        );
    }
    function CreatedDateCellComponent({ value }: any): React.ReactNode {
        return <DateCell date={value.date} description={value.description} />;
    }
    function UpdatedDateCellComponent({ value }: any): React.ReactNode {
        return <DateCell date={value.date} description={value.description} />;
    }
    function SizeNumberCellComponent({ value }: any): React.ReactNode {
        return (
            <NumberCell description={value.description} value={value.value} />
        );
    }

    const columns: IListTableColumn[] = [
        {
            identifier: columnEnum.Name,
            header: 'Name',
            maxWidth: 335,
            CustomCell: NameDescriptionCellComponent
        },
        {
            identifier: columnEnum.Created,
            header: 'Created',
            maxWidth: 100,
            CustomCell: CreatedDateCellComponent
        },
        {
            identifier: columnEnum.LastUpdated,
            header: 'Last Updated',
            minWidth: 100,
            CustomCell: UpdatedDateCellComponent
        },
        {
            identifier: columnEnum.Size,
            header: 'Size',
            minWidth: 100,
            isMetric: true,
            CustomCell: SizeNumberCellComponent
        }
    ];

    function rowClicked(): void {
        alert('Row clicked');
    }

    const rowActions: IRowAction[] = [
        { icon: Lock, onClick: (): void => null, size: 'lg' }
    ];

    return (
        <div className="mt-5">
            <div>Disabled List Table</div>
            <ListTable
                columns={columns}
                dataUI="list-table-disabled"
                isDisabled={true}
                onRowClicked={rowClicked}
                rowActions={rowActions}
                rows={rows}
                theme={ListTableTheme.Simple}
            />
        </div>
    );
};

DisabledListTable.displayName = 'DisabledListTable';

export default DisabledListTable;
