import React from 'react';

import {
    DateCell,
    DateCellProps,
    IListTableColumn,
    ListTable,
    NameDescriptionCell,
    NameDescriptionCellProps,
    NumberCell,
    NumberCellProps,
    sortDirectionEnum
} from '@preamp/tables';

enum columnEnum {
    Name = 'name',
    Created = 'created',
    LastUpdated = 'lastUpdated',
    Size = 'size'
}

interface AllFeatureListTableRow {
    identifier: React.ReactText;
    [columnEnum.Name]: NameDescriptionCellProps;
    [columnEnum.Created]: DateCellProps;
    [columnEnum.LastUpdated]: DateCellProps;
    [columnEnum.Size]: NumberCellProps;
}

interface AllFeatureListTableState {
    allRowsChecked: boolean;
    checkedRows: Set<React.ReactText>;
    isLoading: boolean;
    rows: AllFeatureListTableRow[];
    selectedRow: React.ReactText;
    sortDirection: sortDirectionEnum;
    sortedColumnIdentifier: React.ReactText;
}

function NameDescriptionCellComponent({ value }: any): React.ReactNode {
    return (
        <NameDescriptionCell
            description={value.description}
            name={value.name}
            pending={value.pending}
        />
    );
}
function CreatedDateCellComponent({ value }: any): React.ReactNode {
    return <DateCell date={value.date} description={value.description} />;
}
function UpdatedDateCellComponent({ value }: any): React.ReactNode {
    return <DateCell date={value.date} description={value.description} />;
}
function SizeNumberCellComponent({ value }: any): React.ReactNode {
    return <NumberCell description={value.description} value={value.value} />;
}

const originalColumns: IListTableColumn[] = [
    {
        identifier: columnEnum.Name,
        header: 'Name',
        minWidth: 150,
        sortable: true,
        CustomCell: NameDescriptionCellComponent
    },
    {
        identifier: columnEnum.Created,
        header: 'Created',
        minWidth: 100,
        CustomCell: CreatedDateCellComponent
    },
    {
        identifier: columnEnum.LastUpdated,
        header: 'Last Updated',
        minWidth: 100,
        CustomCell: UpdatedDateCellComponent
    },
    {
        identifier: columnEnum.Size,
        header: 'Size',
        minWidth: 100,
        sortable: true,
        isMetric: true,
        CustomCell: SizeNumberCellComponent
    }
];

const originalRows: AllFeatureListTableRow[] = [
    {
        identifier: 1,
        name: {
            name: 'Bob',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 1, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 3, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 35189 }
    },
    {
        identifier: 2,
        [columnEnum.Name]: {
            name: 'Amy',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 2, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2019, 4, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 14138890 }
    },
    {
        identifier: 3,
        [columnEnum.Name]: {
            name: 'Carl',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 2, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2016, 5, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 145876 }
    },
    {
        identifier: 4,
        [columnEnum.Name]: {
            name: 'Doug',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 3, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 6, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 75463 }
    },
    {
        identifier: 5,
        [columnEnum.Name]: {
            name: 'Emily',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 4, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 7, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 984153 }
    },
    {
        identifier: 6,
        [columnEnum.Name]: {
            name: 'Jack',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 4, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 4, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 94123 }
    },
    {
        identifier: 7,
        [columnEnum.Name]: {
            name: 'Helen',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2019, 2, 24),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2000, 5, 2),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 543 }
    },
    {
        identifier: 8,
        [columnEnum.Name]: {
            name: 'Greg',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(1999, 4, 2),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 7, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 58764 }
    },
    {
        identifier: 9,
        [columnEnum.Name]: {
            name: 'Fred',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 4, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 7, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 68713 }
    },
    {
        identifier: 10,
        [columnEnum.Name]: {
            name: 'Issac',
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 4, 20),
            description: 'John Doe'
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 7, 20),
            description: 'John Doe'
        },
        [columnEnum.Size]: { value: 6874 }
    }
];

const InfiniteScrollTable: React.FC = (): React.ReactElement => {
    const [state, setState] = React.useState<AllFeatureListTableState>({
        allRowsChecked: false,
        checkedRows: new Set(),
        isLoading: false,
        rows: [],
        selectedRow: null,
        sortDirection: sortDirectionEnum.Asc,
        sortedColumnIdentifier: 'name'
    });

    function appendMoreRows(): void {
        const { rows } = state;
        const newRows: AllFeatureListTableRow[] = originalRows.slice(
            0,
            rows.length + 1
        );
        setState(
            (
                prevState: AllFeatureListTableState
            ): AllFeatureListTableState => ({
                ...prevState,
                rows: newRows,
                isLoading: false
            })
        );
    }

    function onScrollToBottom(): void {
        if (state.rows.length < originalRows.length) {
            setState(
                (
                    prevState: AllFeatureListTableState
                ): AllFeatureListTableState => {
                    setTimeout((): void => {
                        appendMoreRows();
                    }, 1500);
                    return {
                        ...prevState,
                        isLoading: true
                    };
                }
            );
        }
    }

    // mock initial loading of data
    React.useEffect((): void => {
        setState(
            (
                prevState: AllFeatureListTableState
            ): AllFeatureListTableState => ({
                ...prevState,
                isLoading: true
            })
        );
        window.setTimeout((): void => {
            setState(
                (
                    prevState: AllFeatureListTableState
                ): AllFeatureListTableState => ({
                    ...prevState,
                    isLoading: false,
                    rows: originalRows.slice(0, 4)
                })
            );
        }, 3000);
    }, []);

    return (
        <>
            <div>Infinite scroll</div>
            <div style={{ height: '400px' }}>
                <ListTable
                    columns={originalColumns}
                    dataUI="infinite-scroll-list-table"
                    EmptyState={<h2>No Results Found.</h2>}
                    fillHeight
                    isHeaderSticky
                    isLoadingMoreRows={state.isLoading}
                    onRowChangeWithNoScrollbar={onScrollToBottom}
                    onScrollToBottom={onScrollToBottom}
                    rows={state.rows}
                />
            </div>
        </>
    );
};

export default InfiniteScrollTable;
