import * as React from 'react';

import { Button } from '@preamp/core';
import {
    DateCell,
    DateCellProps,
    IListTableColumn,
    ListTable,
    NameDescriptionCell,
    NameDescriptionCellProps
} from '@preamp/tables';

enum columnEnum {
    Name = 'name',
    Created = 'created',
    Updated = 'updated'
}

interface ListTableRow {
    identifier: React.ReactText;
    [columnEnum.Name]: NameDescriptionCellProps;
    [columnEnum.Created]: DateCellProps;
    [columnEnum.Updated]: DateCellProps;
}

function NameDescriptionCellComponent({ value }: any): React.ReactNode {
    return (
        <NameDescriptionCell
            description={value.description}
            name={value.name}
            pending={value.pending}
        />
    );
}

function CreatedDateCellComponent({ value }: any): React.ReactNode {
    return <DateCell date={value.date} description={value.description} />;
}

const columns: IListTableColumn[] = [
    {
        identifier: columnEnum.Name,
        header: 'Name',
        minWidth: 250,
        CustomCell: NameDescriptionCellComponent
    },
    {
        identifier: columnEnum.Created,
        header: 'Created',
        minWidth: 250,
        CustomCell: CreatedDateCellComponent
    },
    {
        identifier: columnEnum.Updated,
        header: 'Created',
        minWidth: 250,
        CustomCell: CreatedDateCellComponent
    }
];

function createRow(id: number): ListTableRow {
    return {
        identifier: id,
        name: {
            name: `Row #${id}`,
            description:
                'Donec id elit non mi porta gravida at eget metus. Sed posuere consectet'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 1, 20),
            description: 'John Doe'
        },
        [columnEnum.Updated]: {
            date: new Date(2017, 1, 20),
            description: 'John Doe'
        }
    };
}

const LIST_TABLE_DATA = [
    createRow(1),
    createRow(2),
    createRow(3),
    createRow(4),
    createRow(5),
    createRow(6),
    createRow(7)
];

const HandlingNoScrollbar: React.FC = (): React.ReactElement => {
    const [example1Rows, setExample1Rows] = React.useState<ListTableRow[]>([]);
    const [isLoading, setIsLoading] = React.useState<boolean>();

    function onLoadData(): void {
        setIsLoading(true);

        setTimeout((): void => {
            setExample1Rows(LIST_TABLE_DATA);
            setIsLoading(false);
        }, 1500);
    }

    return (
        <>
            <div>Shadowing on horizontal overflow</div>

            <div className="flex justify-between mt-4">
                <div className="w-1/2 pr-4">
                    <div className="font-bold mb-4">
                        Example 1: Basic shadows
                    </div>

                    <div style={{ height: 300 }}>
                        <ListTable
                            columns={columns}
                            dataUI="scrollable-example"
                            fillHeight
                            isHeaderSticky
                            isLoading={isLoading}
                            rows={example1Rows}
                        />
                    </div>

                    <div className="mt-4">
                        <Button
                            disabled={isLoading || !!example1Rows.length}
                            onClick={onLoadData}
                        >
                            Load Data
                        </Button>
                        <Button
                            disabled={isLoading || !example1Rows.length}
                            onClick={(): void => setExample1Rows([])}
                        >
                            Empty Data
                        </Button>
                    </div>
                </div>

                <div className="w-1/2">
                    <div className="font-bold mb-4">
                        Example 2: Background color
                    </div>

                    <div
                        style={{
                            backgroundColor: '#d4d4d4',
                            padding: 20
                        }}
                    >
                        <ListTable
                            columns={columns}
                            headerBackgroundColor="#d4d4d4"
                            isHeaderSticky
                            rows={LIST_TABLE_DATA}
                        />
                    </div>
                </div>
            </div>
        </>
    );
};

export default HandlingNoScrollbar;
