import React, { ReactElement } from 'react';

import { IListTableColumn, ListTable, ListTableTheme } from '@preamp/tables';

enum columnEnum {
    Name = 'name',
    Description = 'description',
    LastUpdated = 'lastUpdated',
    Size = 'size',
    Status = 'status'
}

interface BasicListTableRow {
    identifier: number;
    [columnEnum.Name]: string;
    [columnEnum.Description]: string;
}

const columns: IListTableColumn[] = [
    {
        identifier: columnEnum.Name,
        header: 'Name',
        minWidth: 150
    },
    {
        identifier: columnEnum.Description,
        header: 'Description',
        minWidth: 150
    }
];

const rows: BasicListTableRow[] = [
    {
        identifier: 1,
        [columnEnum.Name]:
            'Thisisareallylongnamethatshouldtruncateandshouldshowanellipsisaftersetnumberoflines',
        [columnEnum.Description]:
            'Thisisareallylongnamethatshouldtruncateandshouldshowanellipsisaftersetnumberoflines'
    }
];

const rowClicked = (): void => {
    alert('Row clicked');
};

const WrappedCells: React.FC = (): ReactElement => (
    <>
        <div>Simple theme with long unbroken strings - not wrapped</div>
        <ListTable
            columns={columns}
            dataUI="basic-list-table"
            onRowClicked={rowClicked}
            rows={rows}
            theme={ListTableTheme.Simple}
        />

        <div className="mt-5">
            Simple theme with long unbroken strings - wrapped
        </div>
        <ListTable
            columns={columns}
            dataUI="basic-list-table"
            onRowClicked={rowClicked}
            rows={rows}
            shouldWrap={true}
            theme={ListTableTheme.Simple}
        />
    </>
);

export default WrappedCells;
