import React from 'react';

import { Lock } from '@preamp/signal';
import { IconButton } from '@preamp/core';
import {
    DateCell,
    DateCellProps,
    IListTableColumn,
    ListTable,
    ListTableTheme,
    NameDescriptionCell,
    NameDescriptionCellProps,
    NumberCell,
    NumberCellProps,
    RowActionsCell
} from '@preamp/tables';

enum columnEnum {
    Name = 'name',
    Created = 'created',
    LastUpdated = 'lastUpdated',
    Size = 'size',
    RowAction = 'action'
}

const DISABLED_ICON = (
    <IconButton icon={Lock} key="lock" onClick={(): void => null} />
);

interface BasicListTableRow {
    identifier: number;
    isDisabled?: boolean;
    [columnEnum.Name]: NameDescriptionCellProps;
    [columnEnum.Created]: DateCellProps;
    [columnEnum.LastUpdated]: DateCellProps;
    [columnEnum.Size]: NumberCellProps;
    [columnEnum.RowAction]?: React.ReactNode;
}

const rows: BasicListTableRow[] = [
    {
        identifier: 1,
        [columnEnum.Name]: {
            name: 'Andy'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 1, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 3, 20)
        },
        [columnEnum.Size]: { value: 35189 }
    },
    {
        identifier: 2,
        isDisabled: true,
        [columnEnum.Name]: {
            name: 'Amy'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 2, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2019, 4, 20)
        },
        [columnEnum.RowAction]: DISABLED_ICON,
        [columnEnum.Size]: { value: 14138890 }
    },
    {
        identifier: 3,
        [columnEnum.Name]: {
            name: 'Carl'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 2, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2016, 5, 20)
        },
        [columnEnum.Size]: { value: 145876 }
    },
    {
        identifier: 4,
        isDisabled: true,
        [columnEnum.Name]: {
            name: 'Doug'
        },
        [columnEnum.Created]: {
            date: new Date(2017, 3, 20)
        },
        [columnEnum.LastUpdated]: {
            date: new Date(2018, 6, 20)
        },
        [columnEnum.RowAction]: DISABLED_ICON,
        [columnEnum.Size]: { value: 75463 }
    }
];

function NameDescriptionCellComponent({ value }: any): React.ReactNode {
    return (
        <NameDescriptionCell
            description={value.description}
            indicatorColor={value.indicatorColor}
            isIndicatorShown={value.isIndicatorShown}
            name={value.name}
            nameUrl={`/#/tables/list/ListTable/${value.name}`}
            status={value.status}
        />
    );
}
function CreatedDateCellComponent({ value }: any): React.ReactNode {
    return <DateCell date={value.date} description={value.description} />;
}
function UpdatedDateCellComponent({ value }: any): React.ReactNode {
    return <DateCell date={value.date} description={value.description} />;
}
function SizeNumberCellComponent({ value }: any): React.ReactNode {
    return <NumberCell description={value.description} value={value.value} />;
}
function RowActionCellComponent({ value }: any): React.ReactNode {
    return <RowActionsCell rowActions={value} />;
}

const columns: IListTableColumn[] = [
    {
        identifier: columnEnum.Name,
        header: 'Name',
        maxWidth: 335,
        CustomCell: NameDescriptionCellComponent
    },
    {
        identifier: columnEnum.Created,
        header: 'Created',
        maxWidth: 100,
        CustomCell: CreatedDateCellComponent
    },
    {
        identifier: columnEnum.LastUpdated,
        header: 'Last Updated',
        minWidth: 100,
        CustomCell: UpdatedDateCellComponent
    },
    {
        identifier: columnEnum.Size,
        header: 'Size',
        minWidth: 100,
        isMetric: true,
        CustomCell: SizeNumberCellComponent
    },
    {
        identifier: columnEnum.RowAction,
        header: '',
        maxWidth: 100,
        isMetric: true,
        CustomCell: RowActionCellComponent
    }
];

const ListTableIndividualDisabledRows: React.FC = (): React.ReactElement => {
    return (
        <div className="mt-5">
            <div>Individual Rows Disabled</div>
            <ListTable
                columns={columns}
                dataUI="list-table-individual-rows-disabled"
                rows={rows}
                theme={ListTableTheme.Simple}
            />
        </div>
    );
};

export default ListTableIndividualDisabledRows;
