import React, { ReactElement } from 'react';

import { ComparisonTable, ComparisonTableColumn } from '@preamp/tables';

enum columnEnum {
    Assists = 'ast',
    Blocks = 'blk',
    Points = 'pts',
    Player = 'player',
    Rebounds = 'reb',
    Steals = 'stl',
    Turnovers = 'tov'
}

interface ComparisonTableRow {
    identifier: number;
    [columnEnum.Assists]: number;
    [columnEnum.Blocks]: number;
    [columnEnum.Points]: number;
    [columnEnum.Player]: string;
    [columnEnum.Rebounds]: number;
    [columnEnum.Steals]: number;
    [columnEnum.Turnovers]: number;
}

/**
 * Basic ComparisonTable component.
 * */
function BasicComparisonTable(): ReactElement<HTMLDivElement> {
    const columns: ComparisonTableColumn[] = [
        {
            header: 'Player',
            identifier: columnEnum.Player,
            isComparable: false
        },
        {
            header: 'Points',
            identifier: columnEnum.Points,
            isMetric: true
        },
        {
            header: 'Rebounds',
            identifier: columnEnum.Rebounds,
            isMetric: true
        },
        {
            header: 'Assists',
            identifier: columnEnum.Assists,
            isMetric: true
        },
        {
            header: 'Steals',
            identifier: columnEnum.Steals,
            isMetric: true
        },
        {
            header: 'Blocks',
            identifier: columnEnum.Blocks,
            isMetric: true
        },
        {
            header: 'Turnovers',
            identifier: columnEnum.Turnovers,
            isMetric: true
        }
    ];
    const rows: [ComparisonTableRow, ComparisonTableRow] = [
        {
            identifier: 2345,
            [columnEnum.Player]: 'Michael Jordan',
            [columnEnum.Assists]: 5633,
            [columnEnum.Blocks]: 893,
            [columnEnum.Points]: 32292,
            [columnEnum.Rebounds]: 6672,
            [columnEnum.Steals]: 2514,
            [columnEnum.Turnovers]: 2924
        },
        {
            identifier: 824,
            [columnEnum.Player]: 'Kobe Bryant',
            [columnEnum.Assists]: 6306,
            [columnEnum.Blocks]: 640,
            [columnEnum.Points]: 33643,
            [columnEnum.Rebounds]: 7047,
            [columnEnum.Steals]: 1944,
            [columnEnum.Turnovers]: 4010
        }
    ];

    return <ComparisonTable columns={columns} rows={rows} />;
}

export default BasicComparisonTable;
