import React, { ReactElement } from 'react';

import { ComparisonTable, ComparisonTableColumn } from '@preamp/tables';

enum columnEnum {
    Assists = 'ast',
    Blocks = 'blk',
    Points = 'pts',
    Player = 'player',
    Rebounds = 'reb',
    Steals = 'stl',
    Turnovers = 'tov',
    ThreePointFGP = 'fgp'
}

interface ComparisonTableRow {
    identifier: number;
    [columnEnum.Assists]: number;
    [columnEnum.Blocks]: number;
    [columnEnum.Points]: number;
    [columnEnum.Player]: string;
    [columnEnum.Rebounds]: number;
    [columnEnum.Steals]: number;
    [columnEnum.Turnovers]: number;
    [columnEnum.ThreePointFGP]: number;
}

/**
 * ComparisonTable component with value formatting and incalculable values.
 */
function ValueFormattingAndIncalculableValuesComparisonTable(): ReactElement<
    HTMLDivElement
> {
    const columns: ComparisonTableColumn[] = [
        {
            header: 'Player',
            identifier: columnEnum.Player,
            isComparable: false
        },
        {
            header: 'Points',
            identifier: columnEnum.Points,
            numberFormat: '0,0',
            isMetric: true
        },
        {
            header: 'Rebounds',
            identifier: columnEnum.Rebounds,
            isAbbreviated: true,
            isMetric: true
        },
        {
            header: 'Assists',
            identifier: columnEnum.Assists,
            isAbbreviated: true,
            isMetric: true
        },
        {
            header: 'Steals',
            identifier: columnEnum.Steals,
            isAbbreviated: true,
            isMetric: true
        },
        {
            header: 'Blocks',
            identifier: columnEnum.Blocks,
            isAbbreviated: true,
            isMetric: true
        },
        {
            header: 'Turnovers',
            identifier: columnEnum.Turnovers,
            isAbbreviated: true,
            isMetric: true
        },
        {
            header: 'Three Point Field Goal Percentage',
            identifier: columnEnum.ThreePointFGP,
            precision: 3,
            isMetric: true
        }
    ];
    const rows: [ComparisonTableRow, ComparisonTableRow] = [
        {
            identifier: 2345,
            [columnEnum.Player]: 'Michael Jordan',
            [columnEnum.Assists]: null,
            [columnEnum.Blocks]: 893,
            [columnEnum.Points]: 32292,
            [columnEnum.Rebounds]: 6672,
            [columnEnum.Steals]: 2514,
            [columnEnum.Turnovers]: 2924,
            [columnEnum.ThreePointFGP]: 0.327
        },
        {
            identifier: 824,
            [columnEnum.Player]: 'Kobe Bryant',
            [columnEnum.Assists]: 6306,
            [columnEnum.Blocks]: 640,
            [columnEnum.Points]: 33643,
            [columnEnum.Rebounds]: null,
            [columnEnum.Steals]: 1944,
            [columnEnum.Turnovers]: null,
            [columnEnum.ThreePointFGP]: 0.329
        }
    ];

    return <ComparisonTable columns={columns} rows={rows} />;
}

export default ValueFormattingAndIncalculableValuesComparisonTable;
