import React from 'react';

import { DataTable, IDataTableColumn } from '@preamp/tables';

enum columnEnum {
    FirstName = 'firstName',
    LastName = 'lastName',
    Age = 'age',
    Location = 'location',
    Date = 'date'
}

interface BasicDataTableRow {
    identifier: number;
    [columnEnum.FirstName]: string;
    [columnEnum.LastName]: string;
    [columnEnum.Age]: number;
    [columnEnum.Location]: string;
    [columnEnum.Date]: string;
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.FirstName,
        header: 'First Name'
    },
    {
        identifier: columnEnum.LastName,
        header: 'Last Name'
    },
    {
        identifier: columnEnum.Age,
        header: 'Age'
    },
    {
        identifier: columnEnum.Location,
        header: 'Location',
        isCentered: true
    },
    {
        identifier: columnEnum.Date,
        header: 'Date'
    }
];

const rows: BasicDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 2,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 3,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986'
    },
    {
        identifier: 4,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981'
    },
    {
        identifier: 5,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 35,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983'
    }
];

class BasicDataTable extends React.Component {
    render(): React.ReactNode {
        return (
            <>
                <div>Basic Data Table</div>
                <DataTable
                    backgroundColor="transparent"
                    columns={columns}
                    dataUI="basic-data-table"
                    rows={rows}
                />
            </>
        );
    }
}

export default BasicDataTable;
