import React from 'react';

import numeral from 'numeral';

import { DataTable, EmptyState, IDataTableColumn } from '@preamp/tables';

enum columnEnum {
    Name = 'name',
    Created = 'created',
    LastUpdated = 'lastUpdated',
    Size = 'size'
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.Name,
        header: 'Name',
        minWidth: 150
    },
    {
        identifier: columnEnum.Created,
        header: 'Created',
        minWidth: 100
    },
    {
        identifier: columnEnum.LastUpdated,
        header: 'Last Updated',
        minWidth: 100
    },
    {
        identifier: columnEnum.Size,
        header: 'Size',
        minWidth: 100,
        isMetric: true,
        CustomCell: (rowInfo: any): React.ReactNode =>
            numeral(rowInfo.value).format('0,0')
    }
];

class EmptyStateDataTable extends React.Component {
    LetsGetStarted: React.ReactNode;

    constructor(props: any) {
        super(props);

        this.LetsGetStarted = (
            <EmptyState
                buttonChildren="Create Item"
                mainTitle="Let's Get Started!"
                onClick={this.onClick}
                subText="Nothing has been created yet, start by creating an item below."
            />
        );
    }

    onClick = (): void => {
        // eslint-disable-next-line no-console
        console.log('you clicked get started');
    };

    render(): React.ReactNode {
        return (
            <>
                <div>Empty State</div>
                <DataTable
                    columns={columns}
                    dataUI="basic-data-table"
                    EmptyState={this.LetsGetStarted}
                    rows={[]}
                />
            </>
        );
    }
}

export default EmptyStateDataTable;
