import React from 'react';

import { Visibility } from '@preamp/signal';

import {
    DataTable,
    HeaderGroupWithIconButtonCell,
    IDataTableColumn
} from '@preamp/tables';

enum columnGroupEnum {
    Name = 'name',
    Info = 'info'
}

enum columnEnum {
    FirstName = 'firstName',
    LastName = 'lastName',
    Age = 'age',
    Location = 'location',
    Date = 'date'
}

interface GroupedColumnsDataTableRow {
    identifier: number;
    [columnEnum.FirstName]: string;
    [columnEnum.LastName]: string;
    [columnEnum.Age]: number;
    [columnEnum.Location]: string;
    [columnEnum.Date]: string;
}

function onEyeClick(): void {
    // eslint-disable-next-line no-console
    console.log('clicked the eye');
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnGroupEnum.Name,
        header: 'Name',
        columns: [
            {
                identifier: columnEnum.FirstName,
                header: 'First Name'
            },
            {
                identifier: columnEnum.LastName,
                header: 'Last Name'
            }
        ]
    },
    {
        identifier: columnGroupEnum.Info,
        header: (
            <HeaderGroupWithIconButtonCell
                icon={Visibility}
                onClick={onEyeClick}
                title="Info"
            />
        ),
        columns: [
            {
                identifier: columnEnum.Age,
                header: 'Age'
            },
            {
                identifier: columnEnum.Location,
                header: 'Location'
            },
            {
                identifier: columnEnum.Date,
                header: 'Date'
            }
        ]
    }
];

const rows: GroupedColumnsDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 2,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 3,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986'
    },
    {
        identifier: 4,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981'
    },
    {
        identifier: 5,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 35,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983'
    }
];

const emptyRows: GroupedColumnsDataTableRow[] = [];

class GroupedColumnsDataTable extends React.Component {
    render(): React.ReactNode {
        return (
            <>
                <div>Grouped Columns</div>
                <DataTable
                    columns={columns}
                    dataUI="grouped-columns-data-table"
                    rows={rows}
                />
                <div className="mt-4">Grouped Columns with no rows</div>
                <DataTable
                    columns={columns}
                    dataUI="grouped-columns-data-table-empty"
                    rows={emptyRows}
                />
            </>
        );
    }
}

export default GroupedColumnsDataTable;
