import React from 'react';

import { Card, CardTheme, RightRail, RightRailTheme } from '@preamp/core';
import { DataTable, DataTableTheme, IDataTableColumn } from '@preamp/tables';

enum columnEnum {
    Length = 'length',
    Goal = 'goal',
    Current = 'current'
}

interface BasicDataTableRow {
    identifier: number;
    [columnEnum.Length]: string;
    [columnEnum.Goal]: number;
    [columnEnum.Current]: number;
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.Length,
        header: 'Length'
    },
    {
        identifier: columnEnum.Goal,
        header: 'Goal GRPS'
    },
    {
        identifier: columnEnum.Current,
        header: 'Current GRPS'
    }
];

const rows: BasicDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.Length]: ':15 secs',
        [columnEnum.Goal]: 1.1,
        [columnEnum.Current]: 1.1
    },
    {
        identifier: 2,
        [columnEnum.Length]: ':30 secs',
        [columnEnum.Goal]: 1.1,
        [columnEnum.Current]: 1.1
    },
    {
        identifier: 3,
        [columnEnum.Length]: ':60 secs',
        [columnEnum.Goal]: 1.1,
        [columnEnum.Current]: 1.1
    }
];

class CompactDataTable extends React.Component {
    render(): React.ReactNode {
        return (
            <>
                <div className="mt-6 mb-2">Compact Data Table</div>
                <DataTable
                    columns={columns}
                    dataUI="basic-data-table"
                    rows={rows}
                    theme={DataTableTheme.Compact}
                />
                <div className="mt-6 mb-2">
                    Compact Data Table inside a rightrail and card
                </div>
                <div className="va-grid va-columns-default">
                    <div className="col-span-8">
                        <RightRail
                            theme={RightRailTheme.Item}
                            title="RightRail"
                        >
                            <Card
                                subTitle="Subtitle"
                                theme={CardTheme.Horizontal}
                                title="Title"
                            >
                                <DataTable
                                    columns={columns}
                                    dataUI="basic-data-table"
                                    rows={rows}
                                    theme={DataTableTheme.Compact}
                                />
                            </Card>
                        </RightRail>
                    </div>
                </div>
                <div className="mt-6 mb-2">
                    Disabled compact Data Table inside a disabled Card
                </div>
                <div className="va-grid va-columns-default">
                    <div className="col-span-8">
                        <Card
                            isDisabled
                            subTitle="Subtitle"
                            theme={CardTheme.Horizontal}
                            title="Title"
                        >
                            <DataTable
                                backgroundColor="transparent"
                                columns={columns}
                                dataUI="basic-data-table"
                                isDisabled
                                rows={rows}
                                theme={DataTableTheme.Compact}
                            />
                        </Card>
                    </div>
                </div>
            </>
        );
    }
}

export default CompactDataTable;
