import React from 'react';

import { Button, Toggle } from '@preamp/core';
import { DataTable, EmptyState, IDataTableColumn } from '@preamp/tables';

enum columnEnum {
    FirstName = 'firstName',
    LastName = 'lastName',
    Age = 'age',
    Location = 'location',
    Date = 'date'
}

interface BasicDataTableRow {
    identifier: number;
    [columnEnum.FirstName]: string;
    [columnEnum.LastName]: string;
    [columnEnum.Age]: number;
    [columnEnum.Location]: string;
    [columnEnum.Date]: string;
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.FirstName,
        header: 'First Name'
    },
    {
        identifier: columnEnum.LastName,
        header: 'Last Name'
    },
    {
        identifier: columnEnum.Age,
        header: 'Age'
    },
    {
        identifier: columnEnum.Location,
        header: 'Location'
    },
    {
        identifier: columnEnum.Date,
        header: 'Date'
    }
];

const rows: BasicDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 2,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 3,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986'
    },
    {
        identifier: 4,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981'
    },
    {
        identifier: 5,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 35,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983'
    }
];

interface ExampleTableState {
    limit: number;
    loadedRows: BasicDataTableRow[];
    loading: boolean;
    offset: number;
    showEmptyState: boolean;
}

class BasicDataTable extends React.Component<{}, ExampleTableState> {
    state: ExampleTableState = {
        limit: 20,
        loadedRows: [],
        loading: false,
        offset: 0,
        showEmptyState: false
    };
    LetsGetStarted: React.ReactNode;

    constructor(props) {
        super(props);

        this.LetsGetStarted = (
            <EmptyState
                buttonChildren="Load Data"
                mainTitle="Let's Get Started!"
                onClick={this.load}
                subText="Nothing has been created yet, start by loading some data below."
            />
        );
    }

    load = (): void => {
        this.setState({
            loading: true
        });

        setTimeout((): void => {
            this.setState({
                loadedRows: rows,
                loading: false
            });
        }, 3000);
    };

    reset = (): void => {
        this.setState({
            loading: true
        });

        setTimeout((): void => {
            this.setState({
                loadedRows: [],
                loading: false
            });
        }, 3000);
    };

    toggleEmptyState = (): void => {
        this.setState({ showEmptyState: !this.state.showEmptyState });
    };

    onResultsPerPageChange = (limit: number, offset: number): void => {
        this.setState({ limit, offset });
    };

    render(): React.ReactNode {
        return (
            <>
                <div>Async Example</div>
                <div className="my-6 flex justify-between">
                    <div>
                        <Button onClick={this.load}>Load Data</Button>
                        <Button onClick={this.reset}>Clear Data</Button>
                    </div>
                    <Toggle
                        checked={this.state.showEmptyState}
                        label="Custom Empty State Component"
                        name="empty-state"
                        onChange={this.toggleEmptyState}
                    />
                </div>
                <DataTable
                    columns={columns}
                    dataUI="basic-data-table"
                    EmptyState={
                        this.state.showEmptyState
                            ? this.LetsGetStarted
                            : undefined
                    }
                    isLoading={this.state.loading}
                    limit={this.state.limit}
                    offset={this.state.offset}
                    onResultsPerPageChange={this.onResultsPerPageChange}
                    rows={this.state.loadedRows}
                    showPagination={true}
                    totalRows={this.state.loadedRows.length}
                />
            </>
        );
    }
}

export default BasicDataTable;
