import React from 'react';

import { DataTable, IDataTableColumn } from '@preamp/tables';

enum columnEnum {
    FirstName = 'firstName',
    LastName = 'lastName',
    Age = 'age',
    Location = 'location',
    Date = 'date'
}

interface FullHeightDataTableRow {
    identifier: number;
    [columnEnum.FirstName]: string;
    [columnEnum.LastName]: string;
    [columnEnum.Age]: number;
    [columnEnum.Location]: string;
    [columnEnum.Date]: string;
}

interface FullHeightDataTableState {
    rows: FullHeightDataTableRow[];
}

const originalColumns: IDataTableColumn[] = [
    {
        identifier: columnEnum.FirstName,
        header: 'First Name'
    },
    {
        identifier: columnEnum.LastName,
        header: 'last name with a header that wraps by default'
    },
    {
        identifier: columnEnum.Age,
        header: 'Age'
    },
    {
        identifier: columnEnum.Location,
        header: 'Location'
    },
    {
        identifier: columnEnum.Date,
        header: 'Date'
    }
];

const originalRows: FullHeightDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 2,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 3,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986'
    },
    {
        identifier: 4,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981'
    },
    {
        identifier: 5,
        [columnEnum.FirstName]: 'Hannah',
        [columnEnum.LastName]: 'Kim',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 6,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983'
    },
    {
        identifier: 7,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 8,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 9,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986'
    },
    {
        identifier: 10,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981'
    },
    {
        identifier: 11,
        [columnEnum.FirstName]: 'Hannah',
        [columnEnum.LastName]: 'Kim',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 12,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 35,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983'
    },
    {
        identifier: 13,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 14,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 15,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986'
    },
    {
        identifier: 16,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981'
    },
    {
        identifier: 17,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 35,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983'
    },
    {
        identifier: 18,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 19,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 20,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986'
    },
    {
        identifier: 21,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981'
    },
    {
        identifier: 22,
        [columnEnum.FirstName]: 'Hannah',
        [columnEnum.LastName]: 'Kim',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 23,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 35,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983'
    }
];

class FullHeightDataTable extends React.Component {
    state: FullHeightDataTableState = {
        rows: originalRows.slice(0, 20)
    };

    render(): React.ReactNode {
        const { rows } = this.state;

        return (
            <>
                <div>Full Height</div>
                <p className="text-sm">
                    Table fills the height of its container (in this example,
                    400px)
                </p>

                <div style={{ height: '400px' }}>
                    <DataTable
                        backgroundColor="var(--va-grey-200)"
                        columns={originalColumns}
                        dataUI="full-height-data-table"
                        fillHeight={true}
                        rows={rows}
                    />
                </div>
            </>
        );
    }
}

export default FullHeightDataTable;
