import React from 'react';

import { LiveTv, Signal, Tv } from '@preamp/signal';
import {
    DataTable,
    IDataTableColumn,
    NameDescriptionCell,
    NameDescriptionCellProps
} from '@preamp/tables';

enum columnEnum {
    Icon = 'icon',
    Name = 'name'
}

interface IconColumnTableRow {
    identifier: number;
    [columnEnum.Icon]: React.ReactNode;
    [columnEnum.Name]: NameDescriptionCellProps;
}

function NameDescriptionCellComponent({ value }: any): React.ReactNode {
    return (
        <NameDescriptionCell
            description={value.description}
            name={value.name}
        />
    );
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.Icon,
        header: '',
        maxWidth: 56
    },
    {
        identifier: columnEnum.Name,
        header: 'Investments',
        CustomCell: NameDescriptionCellComponent
    }
];

const rows: IconColumnTableRow[] = [
    {
        identifier: 1,
        [columnEnum.Icon]: <Signal icon={LiveTv} size={1.5} />,
        [columnEnum.Name]: {
            name:
                'This_is_a_really_long_name_for_an_Investment_example_002123422134556_to_show_how_really_long_names_would_look',
            description: 'Investments > Level 2 Example > Level 3 Example'
        }
    },
    {
        identifier: 2,
        [columnEnum.Icon]: <Signal icon={Tv} size={1.5} />,
        [columnEnum.Name]: {
            name:
                'This_is_a_really_long_name_for_an_Investment_example_002123422134556_to_show_how_really_long_names_would_look',
            description: 'Investments > Level 2 Example > Level 3 Example'
        }
    }
];

class IconColumnTable extends React.Component {
    render(): React.ReactNode {
        return (
            <>
                <div>DataTable with an Icon column and NameDescriptionCell</div>
                <DataTable
                    columns={columns}
                    dataUI="basic-data-table"
                    rows={rows}
                />
            </>
        );
    }
}

export default IconColumnTable;
