import React from 'react';

import { Tooltip } from '@preamp/core';
import { DataTable, IDataTableColumn } from '@preamp/tables';

enum columnEnum {
    FirstName = 'firstName',
    LastName = 'lastName',
    Age = 'age',
    Location = 'location',
    Date = 'date'
}

interface TruncatedHeaderDataTableRow {
    identifier: number;
    [columnEnum.FirstName]: string;
    [columnEnum.LastName]: string;
    [columnEnum.Age]: number;
    [columnEnum.Location]: string;
    [columnEnum.Date]: string;
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.FirstName,
        header: (
            <Tooltip
                content="First Name also sometimes referred to as Given Name"
                placement="top"
            >
                <>First Name also sometimes referred to as Given Name</>
            </Tooltip>
        ),
        sortable: true
    },
    {
        identifier: columnEnum.LastName,
        header: (
            <Tooltip
                content="Last Name also sometimes referred to as Surname"
                placement="top"
            >
                <>Last Name also sometimes referred to as Surname</>
            </Tooltip>
        ),
        sortable: true
    },
    {
        identifier: columnEnum.Age,
        header: 'Age',
        sortable: true
    },
    {
        identifier: columnEnum.Location,
        header: 'Location',
        sortable: true
    },
    {
        identifier: columnEnum.Date,
        header: 'Date',
        sortable: true
    }
];

const rows: TruncatedHeaderDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976'
    },
    {
        identifier: 2,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 3,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986'
    },
    {
        identifier: 4,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981'
    },
    {
        identifier: 5,
        [columnEnum.FirstName]: 'Hannah',
        [columnEnum.LastName]: 'Kim',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '10/20/1992'
    },
    {
        identifier: 6,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983'
    }
];

class TruncatedHeaderDataTable extends React.Component {
    render(): React.ReactNode {
        return (
            <>
                <div>Truncated Column Headers (with tooltips)</div>

                <div>
                    <DataTable
                        columns={columns}
                        dataUI="full-height-data-table"
                        rows={rows}
                        truncateColHeader
                    />
                </div>
            </>
        );
    }
}

export default TruncatedHeaderDataTable;
