import React, { ReactNode } from 'react';
import { format, parse } from 'date-fns';

import {
    DataTable,
    IDataTableColumn,
    LinkCell,
    ITableRow
} from '@preamp/tables';

enum columnEnum {
    FirstName = 'firstName',
    LastName = 'lastName',
    Age = 'age',
    Location = 'location',
    Date = 'date'
}

interface BasicDataTableRow {
    identifier: number;
    [columnEnum.FirstName]: string;
    [columnEnum.LastName]: string;
    [columnEnum.Age]: number;
    [columnEnum.Location]: string;
    [columnEnum.Date]: string;
}

const LinkCellComponent = ({ value, row }: ITableRow): ReactNode => {
    const onClick = (event: React.MouseEvent): void => {
        event.preventDefault();
        const anchor = event.target as HTMLAnchorElement;
        const { lastName, age, location, date } = row;
        const birthMonth = format(parse(date), 'MMMM');
        alert(
            `${anchor.textContent} ${lastName} is ${age} years old, his birthday is in ${birthMonth} and he is from ${location}`
        );
    };
    return <LinkCell content={value} href="#" onClick={onClick} />;
};

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.FirstName,
        header: 'First Name',
        CustomCell: LinkCellComponent
    },
    {
        identifier: columnEnum.LastName,
        header: 'Last Name'
    },
    {
        identifier: columnEnum.Age,
        header: 'Age'
    },
    {
        identifier: columnEnum.Location,
        header: 'Location',
        isCentered: true
    },
    {
        identifier: columnEnum.Date,
        header: 'Date'
    }
];

const rows: BasicDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.FirstName]: 'Jude',
        [columnEnum.LastName]: 'Arana',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'MT',
        [columnEnum.Date]: '9/18/1977'
    },
    {
        identifier: 2,
        [columnEnum.FirstName]: 'John',
        [columnEnum.LastName]: 'Santana',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'OK',
        [columnEnum.Date]: '11/2/1982'
    },
    {
        identifier: 3,
        [columnEnum.FirstName]: 'Joffrey',
        [columnEnum.LastName]: 'Lenis',
        [columnEnum.Age]: 31,
        [columnEnum.Location]: 'OH',
        [columnEnum.Date]: '3/26/1988'
    },
    {
        identifier: 4,
        [columnEnum.FirstName]: 'Adam',
        [columnEnum.LastName]: 'Molano',
        [columnEnum.Age]: 29,
        [columnEnum.Location]: 'WA',
        [columnEnum.Date]: '1/10/1991'
    },
    {
        identifier: 5,
        [columnEnum.FirstName]: 'Geralt',
        [columnEnum.LastName]: 'Alfonso',
        [columnEnum.Age]: 31,
        [columnEnum.Location]: 'TN',
        [columnEnum.Date]: '2/6/1989'
    }
];

class BasicDataTable extends React.Component {
    render(): React.ReactNode {
        return (
            <>
                <div>Basic Data Table with LinkCell</div>
                <DataTable
                    backgroundColor="transparent"
                    columns={columns}
                    dataUI="bas-data-table-link-cell"
                    rows={rows}
                />
            </>
        );
    }
}

export default BasicDataTable;
