import React from 'react';

import {
    ComparisonCell,
    DataTable,
    DataTableTheme,
    IDataTableColumn
} from '@preamp/tables';

enum columnEnum {
    Stat = 'stat',
    MichaelJordan = 'michaelJordan',
    KobeBryant = 'kobeBryant',
    Delta = 'delta'
}

interface BasicDataTableRow {
    identifier: number;
    [columnEnum.Stat]: string;
    [columnEnum.MichaelJordan]: number;
    [columnEnum.KobeBryant]: number;
}

const renderComparisonCell = ({ row }: any): React.ReactNode => {
    const { kobeBryant, michaelJordan } = row;

    return (
        <ComparisonCell
            baseValue={michaelJordan}
            comparisonValue={kobeBryant}
        />
    );
};

const columns: IDataTableColumn[] = [
    {
        identifier: columnEnum.Stat,
        header: 'Stat'
    },
    {
        identifier: columnEnum.MichaelJordan,
        header: 'Michael Jordan'
    },
    {
        identifier: columnEnum.Delta,
        header: 'Δ',
        CustomCell: renderComparisonCell
    },
    {
        identifier: columnEnum.KobeBryant,
        header: 'Kobe Bryant'
    }
];

const rows: BasicDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.Stat]: 'Assists',
        [columnEnum.MichaelJordan]: 5600,
        [columnEnum.KobeBryant]: 6300
    },
    {
        identifier: 2,
        [columnEnum.Stat]: 'Steals',
        [columnEnum.MichaelJordan]: 2500,
        [columnEnum.KobeBryant]: 1900
    },
    {
        identifier: 2,
        [columnEnum.Stat]: 'Blocks',
        [columnEnum.MichaelJordan]: 893,
        [columnEnum.KobeBryant]: 640
    }
];

class PanelDataTable extends React.Component {
    render(): React.ReactNode {
        return (
            <>
                <div className="mt-6 mb-2">
                    Data Table with a Panel theme and ComparisonCell
                </div>
                <DataTable
                    columns={columns}
                    dataUI="basic-data-table"
                    rows={rows}
                    theme={DataTableTheme.Panel}
                />
            </>
        );
    }
}

export default PanelDataTable;
