import React from 'react';

import { Visibility } from '@preamp/signal';

import {
    DataTable,
    HeaderGroupWithIconButtonCell,
    IDataTableColumn
} from '@preamp/tables';

enum columnGroupEnum {
    Name = 'name',
    Info = 'info',
    Career = 'career',
    Random = 'random'
}

enum columnEnum {
    FirstName = 'firstName',
    LastName = 'lastName',
    Age = 'age',
    Location = 'location',
    Date = 'date',
    Employer = 'employer',
    StartDate = 'startDate',
    Role = 'role'
}

interface FloatingGroupHeadersDataTableRow {
    identifier: number;
    [columnEnum.FirstName]: string;
    [columnEnum.LastName]: string;
    [columnEnum.Age]: number;
    [columnEnum.Location]: string;
    [columnEnum.Date]: string;
    [columnEnum.Employer]: string;
    [columnEnum.StartDate]: string;
    [columnEnum.Role]: string;
}

function onEyeClick(): void {
    // eslint-disable-next-line no-console
    console.log('clicked the eye');
}

const columns: IDataTableColumn[] = [
    {
        identifier: columnGroupEnum.Name,
        header: 'Name',
        columns: [
            {
                identifier: columnEnum.FirstName,
                header: 'First Name'
            },
            {
                identifier: columnEnum.LastName,
                header: 'Last Name'
            }
        ]
    },
    {
        identifier: columnGroupEnum.Info,
        header: (
            <HeaderGroupWithIconButtonCell
                icon={Visibility}
                onClick={onEyeClick}
                title="Info"
            />
        ),
        columns: [
            {
                identifier: columnEnum.Age,
                header: 'Age'
            },
            {
                identifier: columnEnum.Location,
                header: 'Location'
            },
            {
                identifier: columnEnum.Date,
                header: 'Date'
            }
        ]
    },
    {
        identifier: columnGroupEnum.Career,
        header: (
            <HeaderGroupWithIconButtonCell
                icon={Visibility}
                onClick={onEyeClick}
                title="Career"
            />
        ),
        columns: [
            {
                identifier: columnEnum.Employer,
                header: 'Employer'
            },
            {
                identifier: columnEnum.StartDate,
                header: 'Start Date'
            },
            {
                identifier: columnEnum.Role,
                header: 'Role'
            }
        ]
    },
    {
        identifier: columnGroupEnum.Info,
        header: (
            <HeaderGroupWithIconButtonCell
                icon={Visibility}
                onClick={onEyeClick}
                title="Info"
            />
        ),
        columns: [
            {
                identifier: columnEnum.Age,
                header: 'Age'
            },
            {
                identifier: columnEnum.Location,
                header: 'Location'
            },
            {
                identifier: columnEnum.Date,
                header: 'Date'
            }
        ]
    },
    {
        identifier: columnGroupEnum.Career,
        header: (
            <HeaderGroupWithIconButtonCell
                icon={Visibility}
                onClick={onEyeClick}
                title="Career"
            />
        ),
        columns: [
            {
                identifier: columnEnum.Employer,
                header: 'Employer'
            },
            {
                identifier: columnEnum.StartDate,
                header: 'Start Date'
            },
            {
                identifier: columnEnum.Role,
                header: 'Role'
            }
        ]
    },
    {
        identifier: columnGroupEnum.Random,
        header: (
            <HeaderGroupWithIconButtonCell
                icon={Visibility}
                onClick={onEyeClick}
                title="Random 1"
            />
        ),
        columns: [
            {
                identifier: columnEnum.Age,
                header: 'Age'
            },
            {
                identifier: columnEnum.Location,
                header: 'Location'
            },
            {
                identifier: columnEnum.Date,
                header: 'Date'
            }
        ]
    },
    {
        identifier: columnGroupEnum.Random,
        header: (
            <HeaderGroupWithIconButtonCell
                icon={Visibility}
                onClick={onEyeClick}
                title="Random 2"
            />
        ),
        columns: [
            {
                identifier: columnEnum.Age,
                header: 'Age'
            },
            {
                identifier: columnEnum.Location,
                header: 'Location'
            },
            {
                identifier: columnEnum.Date,
                header: 'Date'
            },
            {
                identifier: columnEnum.Age,
                header: 'Age'
            },
            {
                identifier: columnEnum.Location,
                header: 'Location'
            },
            {
                identifier: columnEnum.Date,
                header: 'Date'
            },
            {
                identifier: columnEnum.Age,
                header: 'Age'
            },
            {
                identifier: columnEnum.Location,
                header: 'Location'
            },
            {
                identifier: columnEnum.Date,
                header: 'Date'
            }
        ]
    }
];

const rows: FloatingGroupHeadersDataTableRow[] = [
    {
        identifier: 1,
        [columnEnum.FirstName]: 'Bob',
        [columnEnum.LastName]: 'Samuelson',
        [columnEnum.Age]: 42,
        [columnEnum.Location]: 'CA',
        [columnEnum.Date]: '11/17/1976',
        [columnEnum.Employer]: 'VideoAmp',
        [columnEnum.StartDate]: '2/7/2018',
        [columnEnum.Role]: 'Developer'
    },
    {
        identifier: 2,
        [columnEnum.FirstName]: 'Amy',
        [columnEnum.LastName]: 'Gaudioso',
        [columnEnum.Age]: 26,
        [columnEnum.Location]: 'MA',
        [columnEnum.Date]: '10/20/1992',
        [columnEnum.Employer]: 'Google',
        [columnEnum.StartDate]: '6/24/2014',
        [columnEnum.Role]: 'Project Manager'
    },
    {
        identifier: 3,
        [columnEnum.FirstName]: 'Juan',
        [columnEnum.LastName]: 'Giuffrida',
        [columnEnum.Age]: 32,
        [columnEnum.Location]: 'TX',
        [columnEnum.Date]: '9/15/1986',
        [columnEnum.Employer]: 'Uber',
        [columnEnum.StartDate]: '5/18/2020',
        [columnEnum.Role]: 'Driver'
    },
    {
        identifier: 4,
        [columnEnum.FirstName]: 'Doug',
        [columnEnum.LastName]: 'Ung',
        [columnEnum.Age]: 37,
        [columnEnum.Location]: 'NY',
        [columnEnum.Date]: '12/9/1981',
        [columnEnum.Employer]: 'Playstation',
        [columnEnum.StartDate]: '11/8/2017',
        [columnEnum.Role]: 'Game Tester'
    },
    {
        identifier: 5,
        [columnEnum.FirstName]: 'Ben',
        [columnEnum.LastName]: 'Behrens',
        [columnEnum.Age]: 35,
        [columnEnum.Location]: 'NC',
        [columnEnum.Date]: '8/3/1983',
        [columnEnum.Employer]: 'Taco Bell',
        [columnEnum.StartDate]: '8/3/1983',
        [columnEnum.Role]: 'Chef'
    }
];

const FloatingGroupHeadersDataTable = () => (
    <>
        <div>Floating Group Headers</div>
        <DataTable
            columns={columns}
            dataUI="grouped-columns-data-table"
            hasFloatingHeaders={true}
            rows={rows}
        />
    </>
);

export default FloatingGroupHeadersDataTable;
