import { find, propEq } from 'ramda';
import React from 'react';
import ReactMarkdown from 'react-markdown';
import { IDocumentationFileGroup, IMarkdownFile } from '../../../types';
import { documentationData } from '../../config/data';
import * as DocumentationComponents from '../index';

export function getSectionData(dirPath: string): IDocumentationFileGroup {
    return find(propEq('dirPath', dirPath))(documentationData);
}

export function getMarkdownFileByName(
    dirPath: string,
    fileName: string
): IMarkdownFile {
    const documentationFileGroup: IDocumentationFileGroup = getSectionData(
        dirPath
    );
    const MarkdownFiles: IMarkdownFile[] = documentationFileGroup.markdownFiles;

    return find(propEq('fileName', fileName))(MarkdownFiles);
}

export function buildDocumentation(dirPath: string): React.ReactNode {
    const sectionData: IDocumentationFileGroup = getSectionData(dirPath);

    if (sectionData.componentName) {
        const DocumentationComponent: any =
            DocumentationComponents[sectionData.componentName];

        return <DocumentationComponent />;
    }

    return sectionData.markdownFiles.map(
        (markdownFile: IMarkdownFile): React.ReactNode => (
            <ReactMarkdown
                key={markdownFile.fileName}
                source={markdownFile.contents}
            />
        )
    );
}
