import * as React from 'react';

import cx from 'classnames';
import ReactMarkdown from 'react-markdown';

import { colors } from '@preamp/waveform';

import { IMarkdownFile } from '../../../types';
import { getMarkdownFileByName } from '../utils/findFile';

import * as styles from './waveformDoc.scss';

export const Waveform: React.FC = (): React.ReactElement => {
    const waveformDoc: IMarkdownFile = getMarkdownFileByName(
        'waveform',
        'waveform.md'
    );

    return (
        <div
            className={cx(
                'va-grid va-columns-default',
                styles.waveformDocumentation
            )}
        >
            <div className="col-span-xl-10 col-span-12 ">
                <section>
                    <ReactMarkdown source={waveformDoc.contents} />
                </section>
                <section>
                    <h3>Data Visualization Colors</h3>
                    <p>
                        PreAmp Waveform data visualization should use and follow
                        color usage in the following manners. Colors without
                        details in the ‘Usage &amp; Rules’ column are defined
                        supplementary colors until usage is assigned.
                    </p>
                    <table className="u-table">
                        <thead>
                            <tr>
                                <th>Color</th>
                                <th>CSS Variable</th>
                                <th>Hex Code</th>
                                <th>Usage and Rules</th>
                            </tr>
                        </thead>
                        <tbody>
                            {colors.map(
                                (color): React.ReactNode => (
                                    <tr key={color.name}>
                                        <td>
                                            <div
                                                className={
                                                    styles.waveformColorSwatch
                                                }
                                                style={{
                                                    backgroundColor: `var(${color.variable})`
                                                }}
                                            />
                                        </td>
                                        <td>{color.variable}</td>
                                        <td>{color.hex}</td>
                                        <td>{color.usage}</td>
                                    </tr>
                                )
                            )}
                        </tbody>
                    </table>
                </section>
            </div>
        </div>
    );
};
