import React from 'react';

import { random } from 'lodash';

import { Button } from '@preamp/core';
import { BarChart, PlotData, PlotValue } from '@preamp/waveform';

const basicData: PlotData[] = [
    {
        name: 'Added',
        data: [
            ['Adam Molano', 15000],
            ['Amy Gaudioso', 20000],
            ['Ben Behrens', 0],
            ['Bob Samuelson', 50000],
            ['Daniel Raynes', 25000],
            ['Doug Ung', 33199],
            ['Helen Kim', 25358],
            ['Juan Giuffrida', 43020],
            ['Vera Carrillo-Marquez', 321],
            ['Matt Rodriguez', 10221]
        ]
    }
];

/**
 * A Basic BarChart - only data is required to create a basic chart.
 */
export const BasicBarChart: React.FC = (): React.ReactElement => {
    const [data, setData] = React.useState<PlotData[]>(basicData);
    const onRegenerateData = (): void => {
        setData(
            data.map(
                (item: PlotData): PlotData => {
                    item.data = item.data.map(
                        ([name]: PlotValue): PlotValue => [
                            name,
                            random(125000, 175000)
                        ]
                    );
                    return item;
                }
            )
        );
    };

    return (
        <>
            <BarChart data={data} />
            <Button className="mt-4" onClick={onRegenerateData}>
                Regenerate Data
            </Button>
        </>
    );
};

export default BasicBarChart;
