import * as React from 'react';

import { BarChart, PlotData, PlotValue } from '@preamp/waveform';

const basicData: PlotData[] = [
    {
        name: 'Added',
        data: [
            ['Adam Molano', 152343],
            ['Amy Gaudioso', 155838],
            ['Ben Behrens', 142747],
            ['Bob Samuelson', 120301],
            ['Daniel Raynes', 143255],
            ['Doug Ung', 131998],
            ['Helen Kim', 153558],
            ['Juan Giuffrida', 123020],
            ['Vera Carrillo-Marquez', 152321]
        ]
    }
];

const customLabels: string[] = basicData[0].data.map(
    ([label]: PlotValue): string => label.split(' ')[0]
);

export const BarLabelFormatsExample: React.FC = (): React.ReactElement => (
    <section className="mt-5">
        <h4>Axis Label Formatting</h4>
        <div className="mt-2 mb-3">
            Axis tick label formats can be customized through providing the
            yLabelFormat prop.
            <h5 className="mt-3">yLabelFormat</h5>
            Y-Axis labels are formatted numbers and accept a format string to be
            used with d3&apos;s{' '}
            <a
                href="https://github.com/d3/d3-format#api-reference"
                rel="noopener noreferrer"
                target="_blank"
            >
                format
            </a>
        </div>
        <BarChart
            data={basicData}
            xAxisTitle="Team Members"
            yAxisTitle="Lines of Code"
            yLabelFormat="$~s"
        />

        <div className="mt-3">
            <h5>
                X-Axis labels can be customized by providing a custom array of
                labels to the BarChart.
            </h5>
            <BarChart
                data={basicData}
                labels={customLabels}
                xAxisTitle="Team Members"
                yAxisTitle="Lines of Code"
                yLabelFormat="$~s"
            />
        </div>
    </section>
);

export default BarLabelFormatsExample;
