import * as React from 'react';

import { Button } from '@preamp/core';
import { BarChart, PlotData } from '@preamp/waveform';

const emptyData: PlotData[] = [{ name: 'Empty', data: [] }];

const basicData: PlotData[] = [
    {
        name: 'Added',
        data: [
            ['Adam Molano', 152343],
            ['Amy Gaudioso', 155838],
            ['Ben Behrens', 142747],
            ['Bob Samuelson', 120301],
            ['Daniel Raynes', 143255],
            ['Doug Ung', 131998],
            ['Helen Kim', 153558],
            ['Juan Giuffrida', 123020],
            ['Vera Carrillo-Marquez', 152321]
        ]
    }
];

let timeoutID: NodeJS.Timeout;

export class EmptyLoadingBarChart extends React.Component {
    state: { data: PlotData[]; feature: PlotData[]; isLoading: boolean } = {
        data: emptyData,
        feature: emptyData,
        isLoading: false
    };

    componentWillUnmount(): void {
        clearTimeout(timeoutID);
    }

    simulateLoading = (): void => {
        this.setState(
            {
                isLoading: true
            },
            (): void => {
                timeoutID = setTimeout((): void => {
                    this.setState({
                        isLoading: false,
                        data: basicData
                    });
                }, 3000);
            }
        );
    };

    resetData = (): void => {
        this.setState({
            data: emptyData
        });
    };

    render(): React.ReactNode {
        return (
            <>
                <BarChart
                    data={this.state.data}
                    isLoading={this.state.isLoading}
                    xAxisTitle="Team members"
                    yAxisTitle="Lines of code"
                />
                <div className="mt-4">
                    <Button onClick={this.simulateLoading}>
                        Simulate Loading
                    </Button>
                    <Button onClick={this.resetData}>Clear Data</Button>
                </div>
            </>
        );
    }
}

export default EmptyLoadingBarChart;
