import * as React from 'react';

import { times } from 'lodash';

import { BarChart, PlotData } from '@preamp/waveform';

declare type DataPoint = [string, number];

function buildData(): DataPoint[] {
    const exampleData: DataPoint[] = [
        ['Adam Molano', 152343],
        ['Amy Gaudioso', 155838],
        ['Ben Behrens', 142747],
        ['Bob Samuelson', 120301],
        ['Daniel Raynes', 143255],
        ['Doug Ung', 131998],
        ['Helen Kim', 153558],
        ['Juan Giuffrida', 123020],
        ['Vera Carrillo-Marquez', 152321]
    ];

    return [
        ...times(4, (i: number): DataPoint[] =>
            exampleData.map(
                ([name, value]: DataPoint): DataPoint => [
                    `${name} ${i + 1}`,
                    value
                ]
            )
        ).reduce(
            (data: any[], currValue: DataPoint[]): any[] => [
                ...data,
                ...currValue
            ],
            []
        )
    ];
}

const bigData: PlotData[] = [
    {
        name: 'Added',
        data: buildData()
    }
];

export const DataDeterminingOverflowExample: React.FC = (): React.ReactElement => {
    return (
        <section className="mt-5">
            <div>
                <h4>Automatic Overflow</h4>
                <p className="mt-2 mb-3">
                    BarCharts with more than 30 data points will calculate a
                    width and automatically overflow to avoid crowding data.
                </p>
                <BarChart data={bigData} xAxisTitle="time" yAxisTitle="pets" />
            </div>
            <div className="mt-4 mb-4">
                <p className="mt-2 mb-3">
                    This can be optionally overridden through the shouldOverflow
                    prop. It doesn&apos;t respect the minimum and maximum values
                    established
                </p>
                <BarChart
                    data={bigData}
                    shouldDataDetermineWidth={false}
                    xAxisTitle="time"
                    yAxisTitle="pets"
                />
            </div>
        </section>
    );
};

export default DataDeterminingOverflowExample;
