import React from 'react';

import { BarChart, PlotData } from '@preamp/waveform';
import { TextField, TextFieldType } from '@preamp/core';
const basicData: PlotData[] = [
    {
        name: 'Added',
        data: [
            ['Adam Molano', 15000],
            ['Amy Gaudioso', 20000],
            ['Ben Behrens', 1000],
            ['Bob Samuelson', 50000],
            ['Daniel Raynes', 25000],
            ['Doug Ung', 33199],
            ['Helen Kim', 25358],
            ['Juan Giuffrida', 43020],
            ['Vera Carrillo-Marquez', 321],
            ['Matt Rodriguez', 10221]
        ]
    }
];

export const CustomTicksExample: React.FC = (): React.ReactElement => {
    const [ticks, setTicks] = React.useState(6);

    return (
        <section className="mt-5">
            <h4>Custom number of X-Axis ticks aligned to labels</h4>
            <div className="mt-2 mb-3 w-1/6">
                <TextField
                    label="Number of X-Axis ticks"
                    min="0"
                    onChange={(
                        event: React.ChangeEvent<HTMLInputElement>
                    ): void => {
                        setTicks(Number(event.target.value));
                    }}
                    step="1"
                    textFieldType={TextFieldType.Number}
                    value={`${ticks}`}
                />
            </div>

            <BarChart
                data={basicData}
                xAxisTitle="x axis"
                xTickAlignToData
                xTickCount={ticks}
                yAxisTitle="y axis"
            />
        </section>
    );
};

export default CustomTicksExample;
