import React from 'react';

import { random } from 'lodash';

import { Button } from '@preamp/core';
import { BarLineChart, PlotData, PlotValue } from '@preamp/waveform';

const basicData: PlotData[] = [
    {
        name: 'Added',
        data: [
            ['Adam Molano', [152343, 102]],
            ['Amy Gaudioso', [155838, 120]],
            ['Ben Behrens', [142747, 245]],
            ['Bob Samuelson', [120301, 100]],
            ['Daniel Raynes', [143255, 77]],
            ['Doug Ung', [131998, 89]],
            ['Helen Kim', [153558, 300]],
            ['Juan Giuffrida', [123020, 59]],
            ['Vera Carrillo-Marquez', [152321, 93]],
            ['Matt Rodriguez', [102321, 63]]
        ]
    }
];

/**
 * Note: Also refer to the BarChart examples.
 */
export const BarLineChartBasicExample: React.FC = (): React.ReactElement => {
    const [data, setData] = React.useState<PlotData[]>(basicData);

    const onRegenerateData = (): void => {
        setData(
            basicData.map(
                (item: PlotData): PlotData => {
                    item.data = item.data.map(
                        ([name]: PlotValue): PlotValue => [
                            name,
                            [random(125000, 175000), random(50, 150)]
                        ]
                    );
                    return item;
                }
            )
        );
    };

    return (
        <>
            <section className="mt-5">
                <h5>Basic BarLineChart</h5>
                <p className="mt-2 mb-3">
                    Only data prop is required to create a basic chart.
                </p>
            </section>
            <BarLineChart data={data} />
            <Button className="mt-4" onClick={onRegenerateData}>
                Regenerate Data
            </Button>
        </>
    );
};

export default BarLineChartBasicExample;
