import React from 'react';

import { BarLineChart, PlotData, PlotValue } from '@preamp/waveform';

const basicData: PlotData[] = [
    {
        name: 'Added',
        data: [
            ['Adam Molano', [152343, 102]],
            ['Amy Gaudioso', [155838, 120]],
            ['Ben Behrens', [142747, 245]],
            ['Bob Samuelson', [120301, 100]],
            ['Daniel Raynes', [143255, 77]],
            ['Doug Ung', [131998, 89]],
            ['Helen Kim', [153558, 300]],
            ['Juan Giuffrida', [123020, 59]],
            ['Vera Carrillo-Marquez', [152321, 93]]
        ]
    }
];

const customLabels: string[] = basicData[0].data.map(
    ([label]: PlotValue): string => label.split(' ')[0]
);

export const BarLineChartLabelFormatsExample: React.FC = (): React.ReactElement => (
    <section className="mt-5">
        <h4>Axis Label Formatting</h4>
        <div className="mt-2 mb-3">
            Axis tick label formats can be customized through providing the
            labels, yLabelFormat and/or yLabelFormat props.
            <h5 className="mt-3">* labels</h5>
            X-Axis labels can be customized by providing a custom array of
            labels to the BarLineChart.
            <h5 className="mt-3">* yLabelFormat / y2LabelFormat</h5>
            Y-Axis labels are formatted numbers and accept a format string to be
            used with d3&apos;s{' '}
            <a
                href="https://github.com/d3/d3-format#api-reference"
                rel="noopener noreferrer"
                target="_blank"
            >
                format
            </a>
        </div>
        <BarLineChart
            data={basicData}
            labels={customLabels}
            xAxisTitle="Team Members"
            y2AxisTitle="Commits"
            y2LabelFormat="$~s"
            yAxisTitle="Lines of Code"
            yLabelFormat={'~s'}
        />
    </section>
);

export default BarLineChartLabelFormatsExample;
