import React from 'react';

import { Button } from '@preamp/core';
import { BarLineChart, PlotData } from '@preamp/waveform';

const emptyData: PlotData[] = [{ name: 'Added', data: [] }];

const basicData: PlotData[] = [
    {
        name: 'Added',
        data: [
            ['Adam Molano', [152343, 102]],
            ['Amy Gaudioso', [155838, 120]],
            ['Ben Behrens', [142747, 245]],
            ['Bob Samuelson', [120301, 100]],
            ['Daniel Raynes', [143255, 77]],
            ['Doug Ung', [131998, 89]],
            ['Helen Kim', [153558, 300]],
            ['Juan Giuffrida', [123020, 59]],
            ['Vera Carrillo-Marquez', [152321, 93]]
        ]
    }
];

let timeoutID: NodeJS.Timeout;

export const BarLineChartEmptyStateExample: React.FC = (): React.ReactElement => {
    const [data, setData] = React.useState(emptyData);
    const [isLoading, setLoading] = React.useState(false);

    const handleSimulateLoading = (): void => {
        setLoading(true);
        timeoutID = setTimeout((): void => {
            setLoading(false);
            setData(basicData);
            clearTimeout(timeoutID);
        }, 3000);
    };

    const handleClearData = (): void => {
        setData(emptyData);
    };

    return (
        <>
            <section className="mt-5">
                <h4>Empty chart</h4>
            </section>
            <BarLineChart
                data={data}
                isLoading={isLoading}
                xAxisTitle="Team members"
                y2AxisTitle="Commits"
                yAxisTitle="Lines of code"
            />
            <div className="mt-4">
                <Button onClick={handleSimulateLoading}>
                    Simulate Loading
                </Button>
                <Button onClick={handleClearData}>Clear Data</Button>
            </div>
        </>
    );
};

export default BarLineChartEmptyStateExample;
