import React from 'react';

import { times } from 'lodash';

import { BarLineChart, PlotData } from '@preamp/waveform';

declare type DataBarLine = [number, number];
declare type DataPoint = [string, DataBarLine];

function buildData(): DataPoint[] {
    const exampleData: DataPoint[] = [
        ['Adam Molano', [152343, 102]],
        ['Amy Gaudioso', [155838, 120]],
        ['Ben Behrens', [142747, 245]],
        ['Bob Samuelson', [120301, 100]],
        ['Daniel Raynes', [143255, 77]],
        ['Doug Ung', [131998, 89]],
        ['Helen Kim', [153558, 300]],
        ['Juan Giuffrida', [123020, 59]],
        ['Vera Carrillo-Marquez', [152321, 93]]
    ];

    return [
        ...times(4, (i: number): DataPoint[] =>
            exampleData.map(
                ([name, value]: DataPoint): DataPoint => [
                    `${name} ${i + 1}`,
                    value
                ]
            )
        ).reduce(
            (data: DataBarLine, currValue: DataPoint[]): any => [
                ...data,
                ...currValue
            ],
            []
        )
    ];
}

const bigData: PlotData[] = [
    {
        name: 'Added',
        data: buildData()
    }
];

export const BarLineChartAutoOverflowExample: React.FC = (): React.ReactElement => {
    return (
        <section className="mt-5">
            <div>
                <h4>Automatic Overflow</h4>
                <p className="mt-2 mb-3">
                    BarLineCharts with more than 30 data points will calculate a
                    width and automatically overflow to avoid crowding data.
                </p>
                <BarLineChart
                    data={bigData}
                    xAxisTitle="Team members"
                    y2AxisTitle="Commits"
                    yAxisTitle="Lines of code"
                />
            </div>
            <div className="mt-4 mb-4">
                <p className="mt-2 mb-3">
                    This can be optionally overridden through the shouldOverflow
                    prop. It doesn&apos;t respect the minimum and maximum values
                    established
                </p>
                <BarLineChart
                    data={bigData}
                    shouldDataDetermineWidth={false}
                    xAxisTitle="Team members"
                    y2AxisTitle="Commits"
                    yAxisTitle="Lines of code"
                />
            </div>
        </section>
    );
};

export default BarLineChartAutoOverflowExample;
