import React from 'react';

import { random } from 'lodash';

import { Button } from '@preamp/core';
import { BarLineChart, PlotData } from '@preamp/waveform';

const emptyData: PlotData[] = [
    {
        name: 'Added',
        data: []
    }
];

let timeoutID: NodeJS.Timeout;

export const BarLineChartElementWidthSpacingExample: React.FC = (): React.ReactElement => {
    const [data, setData] = React.useState(emptyData);
    const [isLoading, setLoading] = React.useState(false);

    const handleSimulateLoading = (): void => {
        const currentSize = data[0].data.length;
        const newData: PlotData[] = [
            {
                name: 'Added',
                data: [
                    ...data[0].data,
                    [
                        `Adam Molano ${currentSize + 1}`,
                        [random(50000, 100000), random(50, 100)]
                    ]
                ]
            }
        ];

        setLoading(true);

        timeoutID = setTimeout((): void => {
            setLoading(false);
            setData(newData);
            clearTimeout(timeoutID);
        }, 500);
    };

    const handleClearData = (): void => {
        setData(emptyData);
    };

    return (
        <section className="mt-5">
            <h4>Data Element Width &amp; Spacing</h4>
            <p className="mt-2 mb-3">
                Chart spacing management: When the chart’s data changes it’s
                bars are automatically resized to best fit into the chart.
            </p>
            <BarLineChart
                data={data}
                isLoading={isLoading}
                xAxisTitle="Team members"
                y2AxisTitle="Commits"
                yAxisTitle="Lines of code"
            />
            <div className="mt-4">
                <Button onClick={handleSimulateLoading}>Add element</Button>
                <Button onClick={handleClearData}>Clear Data</Button>
            </div>
        </section>
    );
};

export default BarLineChartElementWidthSpacingExample;
