import React, { useState } from 'react';

import { Slider } from '@preamp/core';
import { OptionsType, OptionType, Select, SelectType } from '@preamp/select';
import { BubbleChart, PlotData } from '@preamp/waveform';
import { smallBubbleData } from './data/smallBubble';

const basicOptions: OptionsType<OptionType> = [
    { value: 'data 1', label: 'Genre/Network' },
    { value: 'data 2', label: 'Daypart/Custom Daypart' }
];

/**
 * A BubbleChart show-casing changing data
 */
export const DataChangingBubbleChart: React.FC = (): React.ReactElement => {
    const [dataSet, setDataSet] = useState<PlotData[]>(
        smallBubbleData.slice(0, 2)
    );
    const [opacity, setOpacity] = useState<number>(0.5);
    const [range, setRange] = useState<[number, number]>([4, 40]);

    const updateCircleOpacity = (value: number): void => {
        setOpacity(value / 100);
    };

    const updateCircleRange = (min: number, max: number): void => {
        setRange([min, max]);
    };

    const handleChange = (option: OptionType): void => {
        setDataSet([
            ...(option.value === 'data 2'
                ? smallBubbleData.slice(2, 4)
                : smallBubbleData.slice(0, 2))
        ]);
    };

    return (
        <section className="mt-5">
            <h4>Dynamic Data Changes</h4>
            <div className="va-form-group">
                <Slider
                    currentValue={50}
                    isSingleThumb
                    label="Adjust the Opacity by moving the Slider"
                    max={100}
                    min={0}
                    onChange={updateCircleOpacity}
                    showTextInput={false}
                    step={10}
                />
                <Slider
                    currentValue={[4, 40]}
                    label="Adjust the Circle Range (Size) with slider or values"
                    max={100}
                    min={1}
                    onChange={updateCircleRange}
                />
                <Select
                    isOptional={false}
                    label="Change Data"
                    labelDescription="Select an item from the list to update the chart"
                    onChange={handleChange}
                    options={basicOptions}
                    selectType={SelectType.Compact}
                    style={{ width: '18rem' }}
                />
            </div>
            <BubbleChart
                autoWidth
                circleOpacity={opacity}
                circleRange={range}
                colors={[
                    'var(--waveform-default-500)',
                    'var(--waveform-violet-500)',
                    'var(--waveform-magenta-500)',
                    'var(--waveform-success-500)',
                    'var(--waveform-sky-500)'
                ]}
                data={dataSet}
                dataUI="data-change_bubble-chart"
                height={600}
                xAxisTitle="Comparison Index"
                yAxisTitle="Base Index"
            />
        </section>
    );
};

export default DataChangingBubbleChart;
