import React from 'react';

import { BubbleChart, PlotValue } from '@preamp/waveform';
import { smallBubbleData } from './data/smallBubble';

function getCustomTooltip(data: PlotValue, idx: number): React.ReactNode {
    const [percentage, index, metaProperties] = data;
    const label = smallBubbleData[idx].name;

    return (
        <div className="p-3 whitespace-no-wrap">
            <div style={{ fontSize: '1rem' }}>{metaProperties.value}</div>
            <div style={{ color: 'var(--va-grey-500)' }}>
                <span
                    className="va-chart-legend-dot"
                    style={{ backgroundColor: metaProperties.color }}
                />
                {label}
            </div>

            <div className="mt-2" style={{ fontSize: '.85rem' }}>
                {metaProperties.audienceName}
            </div>
            <div className="flex mt-1">
                <div className="flex-1 pr-3">
                    <div className="uppercase" style={{ fontSize: '0.6rem' }}>
                        Index
                    </div>
                    <div>{index}</div>
                </div>
                <div className="flex-1 pr-3">
                    <div className="uppercase" style={{ fontSize: '0.6rem' }}>
                        HH Count
                    </div>
                    <div>{metaProperties.radiusSize}</div>
                </div>
                <div className="flex-1">
                    <div className="uppercase" style={{ fontSize: '0.6rem' }}>
                        % of Audience
                    </div>
                    <div>{percentage}%</div>
                </div>
            </div>

            <div className="mt-3" style={{ fontSize: '.85rem' }}>
                Total Universe
            </div>
            <div className="flex mt-1">
                <div className="flex-1 pr-3">
                    <div className="uppercase" style={{ fontSize: '0.6rem' }}>
                        Index
                    </div>
                    <div>{index}</div>
                </div>
                <div className="flex-1 pr-3">
                    <div className="uppercase" style={{ fontSize: '0.6rem' }}>
                        HH Count
                    </div>
                    <div>{metaProperties.radiusSize}</div>
                </div>
                <div className="flex-1">
                    <div className="uppercase" style={{ fontSize: '0.6rem' }}>
                        % of Audience
                    </div>
                    <div>{percentage}%</div>
                </div>
            </div>
        </div>
    );
}

export const BubbleChartCustomTooltipsExample: React.FC = (): React.ReactElement => {
    return (
        <section className="mt-5">
            <h4>Custom Tooltips</h4>
            <p className="mt-2 mb-5">
                BubbleChart tooltips can be customized through the
                tooltipCustomLabelDescription property.
            </p>

            <BubbleChart
                autoWidth
                data={smallBubbleData.slice(0, 2)}
                dataUI="bubble-chart-1"
                tooltipCustomLabelDescription={getCustomTooltip}
                xAxisTitle="Comparison Index"
                xTickAlignToData={false}
                yAxisTitle="Base Index"
            />
        </section>
    );
};

export default BubbleChartCustomTooltipsExample;
