import React, { ReactElement } from 'react';

import { HeatMap, PlotData } from '@preamp/waveform';

enum Identifier {
    Chicago = 'Chicago',
    Dallas = 'Dallas',
    LosAngeles = 'Los Angeles',
    NewYork = 'New York'
}

export const data: PlotData[] = [
    {
        data: [
            [Identifier.Dallas, 0.92],
            [Identifier.LosAngeles, 0.41],
            [Identifier.NewYork, 0.66]
        ],
        name: Identifier.Chicago
    },
    {
        data: [
            [Identifier.Chicago, 0.04],
            [Identifier.LosAngeles, 0],
            [Identifier.NewYork, 0.39]
        ],
        name: Identifier.Dallas
    },
    {
        data: [
            [Identifier.Dallas, 0.58],
            [Identifier.Chicago, 0.1],
            [Identifier.NewYork, 1]
        ],
        name: Identifier.LosAngeles
    },
    {
        data: [
            [Identifier.Chicago, 0.87],
            [Identifier.Dallas, 0.22],
            [Identifier.LosAngeles, undefined]
        ],
        name: Identifier.NewYork
    }
];

function BasicHeatMap(): ReactElement {
    return (
        <section>
            <h2>Basic Heat Map</h2>
            <p className="max-w-sm mt-2">
                A heat map is a two-dimensional representation of a metric’s
                correlation between two dimensions/categories. They are useful
                in showing variance across multiple variables. A scale of color
                is used to represent the range in values, while each cell in the
                heat map represents the intersection of variables.
            </p>
            <HeatMap
                columnsLabel="Arrival City"
                data={data}
                format="0%"
                rowsLabel="Departure City"
                valueLabel="Percentage"
            />
        </section>
    );
}

export default BasicHeatMap;
