import React, { ReactElement } from 'react';

import { HeatMap, PlotData } from '@preamp/waveform';

enum Identifier {
    Chicago = 'Chicago',
    Dallas = 'Dallas',
    LosAngeles = 'Los Angeles',
    NewYork = 'New York'
}

export const data: PlotData[] = [
    {
        data: [
            [Identifier.Dallas, 0.92],
            [Identifier.LosAngeles, 0.41],
            [Identifier.NewYork, 0.66]
        ],
        name: Identifier.Chicago
    },
    {
        data: [
            [Identifier.Chicago, 0.04],
            [Identifier.LosAngeles, 0],
            [Identifier.NewYork, 0.39]
        ],
        name: Identifier.Dallas
    },
    {
        data: [
            [Identifier.Dallas, 0.58],
            [Identifier.Chicago, 0.1],
            [Identifier.NewYork, 1]
        ],
        name: Identifier.LosAngeles
    },
    {
        data: [
            [Identifier.Chicago, 0.87],
            [Identifier.Dallas, 0.22],
            [Identifier.LosAngeles, undefined]
        ],
        name: Identifier.NewYork
    }
];

function DisplayMetrics(): ReactElement {
    return (
        <section className="mt-8">
            <h2>Heat Map w/ Secondary Metric Display</h2>
            <p className="max-w-sm mt-2">
                The secondary metric display in a heat map provides additional
                information for the intersection of variables. While color is
                used to represent values of one metric, the textual display
                within each cell is used to represent values of another.
            </p>
            <HeatMap
                className="mt-8"
                columnsLabel="Arrival City"
                data={data}
                format="0%"
                id="heat-map--display-metrics"
                rowsLabel="Departure City"
                showMetrics
                valueLabel="Percentage"
            />
        </section>
    );
}

export default DisplayMetrics;
