import React, { ReactElement, useState } from 'react';

import { Button } from '@preamp/core';
import { HeatMap, PlotData } from '@preamp/waveform';

const mockData: PlotData[] = [
    {
        data: [
            ['Chicago', 1],
            ['New York', 0.010498],
            ['Dallas', 0.011369],
            ['Los Angeles', 0.053405],
            ['Minneapolis', 0.044175],
            ['Seattle', 0.059953],
            ['Baltimore', 0.032068],
            ['Boston', 0.409512],
            ['Nashville', 0.012589],
            ['Indianapolis', 0.003928],
            ['Des Moines', 0.032541],
            ['Saint Paul', 0.726741],
            ['Scranton', 0.00605],
            ['Raleigh', 0.005307],
            ['Salt Lake City', 0.014823],
            ['Austin', 0.036555],
            ['Madison', 0.009785],
            ['Richmond', 0.037058],
            ['Charleston', 0.008082],
            ['Bismarck', 0.057554],
            ['Columbus', 0.013232],
            ['Oklahoma City', 0.000298],
            ['Portland', 0.010445],
            ['Miami', 0.038588]
        ],
        name: 'Chicago'
    },
    {
        data: [
            ['Chicago', 0.145743],
            ['New York', 1],
            ['Dallas', 0.016502],
            ['Los Angeles', 0.088015],
            ['Minneapolis', 0.172982],
            ['Seattle', 0.092378],
            ['Baltimore', 0.068959],
            ['Boston', 0.260922],
            ['Nashville', 0.011107],
            ['Indianapolis', 0.006999],
            ['Des Moines', 0.044618],
            ['Saint Paul', 0.476534],
            ['Scranton', 0.014281],
            ['Raleigh', 0.046957],
            ['Salt Lake City', 0.023215],
            ['Austin', 0.09445],
            ['Madison', 0.01965],
            ['Richmond', 0.097773],
            ['Charleston', 0.01758],
            ['Bismarck', 0.144986],
            ['Columbus', 0.020593],
            ['Oklahoma City', 0.000214],
            ['Portland', 0.023386],
            ['Miami', 0.117668]
        ],
        name: 'New York'
    },
    {
        data: [
            ['Chicago', 0.166929],
            ['New York', 0.018882],
            ['Dallas', 1],
            ['Los Angeles', 0.091304],
            ['Minneapolis', 0.083128],
            ['Seattle', 0.104025],
            ['Baltimore', 0.063653],
            ['Boston', 0.285166],
            ['Nashville', 0.013254],
            ['Indianapolis', 0.003057],
            ['Des Moines', 0.042575],
            ['Saint Paul', 0.582107],
            ['Scranton', 0.023221],
            ['Raleigh', 0.013764],
            ['Salt Lake City', 0.04862],
            ['Austin', 0.052279],
            ['Madison', 0.017033],
            ['Richmond', 0.079074],
            ['Charleston', 0.010115],
            ['Bismarck', 0.102649],
            ['Columbus', 0.013584],
            ['Oklahoma City', 0.000337],
            ['Portland', 0.02178],
            ['Miami', 0.072468]
        ],
        name: 'Dallas'
    },
    {
        data: [
            ['Chicago', 0.145117],
            ['New York', 0.018377],
            ['Dallas', 0.017355],
            ['Los Angeles', 1],
            ['Minneapolis', 0.073733],
            ['Seattle', 0.098423],
            ['Baltimore', 0.121691],
            ['Boston', 0.224788],
            ['Nashville', 0.010208],
            ['Indianapolis', 0.004421],
            ['Des Moines', 0.05785],
            ['Saint Paul', 0.484199],
            ['Scranton', 0.009541],
            ['Raleigh', 0.007613],
            ['Salt Lake City', 0.020909],
            ['Austin', 0.106668],
            ['Madison', 0.011072],
            ['Richmond', 0.043737],
            ['Charleston', 0.013206],
            ['Bismarck', 0.094292],
            ['Columbus', 0.016524],
            ['Oklahoma City', 0.000254],
            ['Portland', 0.017015],
            ['Miami', 0.074154]
        ],
        name: 'Los Angeles'
    },
    {
        data: [
            ['Chicago', 0.157395],
            ['New York', 0.055909],
            ['Dallas', 0.019183],
            ['Los Angeles', 0.092846],
            ['Minneapolis', 1],
            ['Seattle', 0.088243],
            ['Baltimore', 0.064687],
            ['Boston', 0.272954],
            ['Nashville', 0.010872],
            ['Indianapolis', 0.003391],
            ['Des Moines', 0.042531],
            ['Saint Paul', 0.549601],
            ['Scranton', 0.012327],
            ['Raleigh', 0.025395],
            ['Salt Lake City', 0.032556],
            ['Austin', 0.082156],
            ['Madison', 0.017948],
            ['Richmond', 0.083088],
            ['Charleston', 0.010087],
            ['Bismarck', 0.115134],
            ['Columbus', 0.012944],
            ['Oklahoma City', 0.000172],
            ['Portland', 0.017261],
            ['Miami', 0.068776]
        ],
        name: 'Minneapolis'
    },
    {
        data: [
            ['Chicago', 0.149218],
            ['New York', 0.019508],
            ['Dallas', 0.019572],
            ['Los Angeles', 0.088993],
            ['Minneapolis', 0.063666],
            ['Seattle', 1],
            ['Baltimore', 0.056948],
            ['Boston', 0.214301],
            ['Nashville', 0.00853],
            ['Indianapolis', 0.002146],
            ['Des Moines', 0.049789],
            ['Saint Paul', 0.543033],
            ['Scranton', 0.010722],
            ['Raleigh', 0.00933],
            ['Salt Lake City', 0.023666],
            ['Austin', 0.073541],
            ['Madison', 0.021765],
            ['Richmond', 0.051839],
            ['Charleston', 0.006483],
            ['Bismarck', 0.144022],
            ['Columbus', 0.009698],
            ['Oklahoma City', 0.000173],
            ['Portland', 0.016029],
            ['Miami', 0.051556]
        ],
        name: 'Seattle'
    },
    {
        data: [
            ['Chicago', 0.140691],
            ['New York', 0.021524],
            ['Dallas', 0.01751],
            ['Los Angeles', 0.166178],
            ['Minneapolis', 0.076359],
            ['Seattle', 0.09663],
            ['Baltimore', 1],
            ['Boston', 0.213877],
            ['Nashville', 0.00744],
            ['Indianapolis', 0.003085],
            ['Des Moines', 0.053035],
            ['Saint Paul', 0.492411],
            ['Scranton', 0.010911],
            ['Raleigh', 0.009425],
            ['Salt Lake City', 0.023303],
            ['Austin', 0.094587],
            ['Madison', 0.0129],
            ['Richmond', 0.058407],
            ['Charleston', 0.012969],
            ['Bismarck', 0.108371],
            ['Columbus', 0.017755],
            ['Oklahoma City', 0.000217],
            ['Portland', 0.019509],
            ['Miami', 0.069717]
        ],
        name: 'Baltimore'
    },
    {
        data: [
            ['Chicago', 0.367457],
            ['New York', 0.018836],
            ['Dallas', 0.018225],
            ['Los Angeles', 0.069239],
            ['Minneapolis', 0.067033],
            ['Seattle', 0.06348],
            ['Baltimore', 0.040641],
            ['Boston', 1],
            ['Nashville', 0.047228],
            ['Indianapolis', 0.005493],
            ['Des Moines', 0.040713],
            ['Saint Paul', 0.761457],
            ['Scranton', 0.010629],
            ['Raleigh', 0.007813],
            ['Salt Lake City', 0.017653],
            ['Austin', 0.053959],
            ['Madison', 0.00946],
            ['Richmond', 0.048142],
            ['Charleston', 0.006129],
            ['Bismarck', 0.056616],
            ['Columbus', 0.011984],
            ['Oklahoma City', 0.000303],
            ['Portland', 0.01523],
            ['Miami', 0.064087]
        ],
        name: 'Boston'
    },
    {
        data: [
            ['Chicago', 0.279418],
            ['New York', 0.019703],
            ['Dallas', 0.019037],
            ['Los Angeles', 0.07935],
            ['Minneapolis', 0.069878],
            ['Seattle', 0.069535],
            ['Baltimore', 0.037925],
            ['Boston', 0.670473],
            ['Nashville', 1],
            ['Indianapolis', 0.00953],
            ['Des Moines', 0.048514],
            ['Saint Paul', 0.723972],
            ['Scranton', 0.00928],
            ['Raleigh', 0.0075],
            ['Salt Lake City', 0.018443],
            ['Austin', 0.048101],
            ['Madison', 0.01102],
            ['Richmond', 0.044204],
            ['Charleston', 0.008717],
            ['Bismarck', 0.07136],
            ['Columbus', 0.016131],
            ['Oklahoma City', 0.000306],
            ['Portland', 0.017008],
            ['Miami', 0.064382]
        ],
        name: 'Nashville'
    },
    {
        data: [
            ['Chicago', 0.138419],
            ['New York', 0.028206],
            ['Dallas', 0.004634],
            ['Los Angeles', 0.082431],
            ['Minneapolis', 0.040881],
            ['Seattle', 0.028246],
            ['Baltimore', 0.017689],
            ['Boston', 0.310246],
            ['Nashville', 0.02842],
            ['Indianapolis', 1],
            ['Des Moines', 0.02296],
            ['Saint Paul', 0.430547],
            ['Scranton', 0.005658],
            ['Raleigh', 0.00543],
            ['Salt Lake City', 0.003439],
            ['Austin', 0.025984],
            ['Madison', 0.004268],
            ['Richmond', 0.018345],
            ['Charleston', 0.188906],
            ['Bismarck', 0.052559],
            ['Columbus', 0.467792],
            ['Oklahoma City', 0.009963],
            ['Portland', 0.004615],
            ['Miami', 0.030236]
        ],
        name: 'Indianapolis'
    },
    {
        data: [
            ['Chicago', 0.156329],
            ['New York', 0.016553],
            ['Dallas', 0.01439],
            ['Los Angeles', 0.097608],
            ['Minneapolis', 0.055647],
            ['Seattle', 0.093009],
            ['Baltimore', 0.059631],
            ['Boston', 0.232433],
            ['Nashville', 0.010657],
            ['Indianapolis', 0.003299],
            ['Des Moines', 1],
            ['Saint Paul', 0.538429],
            ['Scranton', 0.006978],
            ['Raleigh', 0.008312],
            ['Salt Lake City', 0.018323],
            ['Austin', 0.051269],
            ['Madison', 0.014849],
            ['Richmond', 0.055049],
            ['Charleston', 0.010164],
            ['Bismarck', 0.086184],
            ['Columbus', 0.013694],
            ['Oklahoma City', 0.000258],
            ['Portland', 0.016336],
            ['Miami', 0.041298]
        ],
        name: 'Des Moines'
    },
    {
        data: [
            ['Chicago', 0.223015],
            ['New York', 0.009953],
            ['Dallas', 0.011036],
            ['Los Angeles', 0.04876],
            ['Minneapolis', 0.04489],
            ['Seattle', 0.06327],
            ['Baltimore', 0.031486],
            ['Boston', 0.297379],
            ['Nashville', 0.01005],
            ['Indianapolis', 0.004023],
            ['Des Moines', 0.031361],
            ['Saint Paul', 1],
            ['Scranton', 0.006202],
            ['Raleigh', 0.00565],
            ['Salt Lake City', 0.015287],
            ['Austin', 0.036454],
            ['Madison', 0.010744],
            ['Richmond', 0.039543],
            ['Charleston', 0.009263],
            ['Bismarck', 0.061157],
            ['Columbus', 0.014923],
            ['Oklahoma City', 0.000312],
            ['Portland', 0.011738],
            ['Miami', 0.034117]
        ],
        name: 'Saint Paul'
    },
    {
        data: [
            ['Chicago', 0.15666],
            ['New York', 0.026006],
            ['Dallas', 0.03829],
            ['Los Angeles', 0.085565],
            ['Minneapolis', 0.081506],
            ['Seattle', 0.105593],
            ['Baltimore', 0.061988],
            ['Boston', 0.277824],
            ['Nashville', 0.011212],
            ['Indianapolis', 0.004964],
            ['Des Moines', 0.038298],
            ['Saint Paul', 0.553937],
            ['Scranton', 1],
            ['Raleigh', 0.016547],
            ['Salt Lake City', 0.032551],
            ['Austin', 0.069799],
            ['Madison', 0.013143],
            ['Richmond', 0.104597],
            ['Charleston', 0.013584],
            ['Bismarck', 0.097155],
            ['Columbus', 0.019151],
            ['Oklahoma City', 0.000351],
            ['Portland', 0.026373],
            ['Miami', 0.095094]
        ],
        name: 'Scranton'
    },
    {
        data: [
            ['Chicago', 0.134339],
            ['New York', 0.081774],
            ['Dallas', 0.022655],
            ['Los Angeles', 0.065978],
            ['Minneapolis', 0.152546],
            ['Seattle', 0.089292],
            ['Baltimore', 0.053165],
            ['Boston', 0.219526],
            ['Nashville', 0.00779],
            ['Indianapolis', 0.00418],
            ['Des Moines', 0.040802],
            ['Saint Paul', 0.501447],
            ['Scranton', 0.016068],
            ['Raleigh', 1],
            ['Salt Lake City', 0.038497],
            ['Austin', 0.063672],
            ['Madison', 0.021493],
            ['Richmond', 0.105563],
            ['Charleston', 0.008674],
            ['Bismarck', 0.109217],
            ['Columbus', 0.012166],
            ['Oklahoma City', 0.000359],
            ['Portland', 0.019559],
            ['Miami', 0.054567]
        ],
        name: 'Raleigh'
    },
    {
        data: [
            ['Chicago', 0.157161],
            ['New York', 0.022211],
            ['Dallas', 0.036029],
            ['Los Angeles', 0.080064],
            ['Minneapolis', 0.098822],
            ['Seattle', 0.100302],
            ['Baltimore', 0.061237],
            ['Boston', 0.226846],
            ['Nashville', 0.007396],
            ['Indianapolis', 0.00146],
            ['Des Moines', 0.041723],
            ['Saint Paul', 0.57826],
            ['Scranton', 0.015539],
            ['Raleigh', 0.018406],
            ['Salt Lake City', 1],
            ['Austin', 0.053225],
            ['Madison', 0.020424],
            ['Richmond', 0.088682],
            ['Charleston', 0.003953],
            ['Bismarck', 0.105089],
            ['Columbus', 0.007388],
            ['Oklahoma City', 0.000078],
            ['Portland', 0.018413],
            ['Miami', 0.049189]
        ],
        name: 'Salt Lake City'
    },
    {
        data: [
            ['Chicago', 0.145055],
            ['New York', 0.029],
            ['Dallas', 0.014508],
            ['Los Angeles', 0.148625],
            ['Minneapolis', 0.094915],
            ['Seattle', 0.112762],
            ['Baltimore', 0.0898],
            ['Boston', 0.253631],
            ['Nashville', 0.008289],
            ['Indianapolis', 0.002922],
            ['Des Moines', 0.042365],
            ['Saint Paul', 0.511633],
            ['Scranton', 0.010895],
            ['Raleigh', 0.009886],
            ['Salt Lake City', 0.019189],
            ['Austin', 1],
            ['Madison', 0.01183],
            ['Richmond', 0.047535],
            ['Charleston', 0.008958],
            ['Bismarck', 0.139803],
            ['Columbus', 0.012945],
            ['Oklahoma City', 0.000216],
            ['Portland', 0.018452],
            ['Miami', 0.121115]
        ],
        name: 'Austin'
    },
    {
        data: [
            ['Chicago', 0.138017],
            ['New York', 0.020406],
            ['Dallas', 0.013224],
            ['Los Angeles', 0.055915],
            ['Minneapolis', 0.065087],
            ['Seattle', 0.118379],
            ['Baltimore', 0.04119],
            ['Boston', 0.176697],
            ['Nashville', 0.006203],
            ['Indianapolis', 0.002453],
            ['Des Moines', 0.041904],
            ['Saint Paul', 0.506372],
            ['Scranton', 0.006542],
            ['Raleigh', 0.010574],
            ['Salt Lake City', 0.02705],
            ['Austin', 0.040603],
            ['Madison', 1],
            ['Richmond', 0.063141],
            ['Charleston', 0.005316],
            ['Bismarck', 0.202617],
            ['Columbus', 0.007741],
            ['Oklahoma City', 0.000359],
            ['Portland', 0.011628],
            ['Miami', 0.028627]
        ],
        name: 'Madison'
    },
    {
        data: [
            ['Chicago', 0.153028],
            ['New York', 0.027519],
            ['Dallas', 0.02196],
            ['Los Angeles', 0.063644],
            ['Minneapolis', 0.085589],
            ['Seattle', 0.085089],
            ['Baltimore', 0.055853],
            ['Boston', 0.232403],
            ['Nashville', 0.0076],
            ['Indianapolis', 0.0022],
            ['Des Moines', 0.043005],
            ['Saint Paul', 0.556471],
            ['Scranton', 0.01794],
            ['Raleigh', 0.016208],
            ['Salt Lake City', 0.030366],
            ['Austin', 0.048159],
            ['Madison', 0.018871],
            ['Richmond', 1],
            ['Charleston', 0.007377],
            ['Bismarck', 0.101379],
            ['Columbus', 0.010663],
            ['Oklahoma City', 0.000211],
            ['Portland', 0.021367],
            ['Miami', 0.051036]
        ],
        name: 'Richmond'
    },
    {
        data: [
            ['Chicago', 0.065041],
            ['New York', 0.013497],
            ['Dallas', 0.005135],
            ['Los Angeles', 0.04319],
            ['Minneapolis', 0.024939],
            ['Seattle', 0.022401],
            ['Baltimore', 0.023816],
            ['Boston', 0.08869],
            ['Nashville', 0.003744],
            ['Indianapolis', 0.058002],
            ['Des Moines', 0.017077],
            ['Saint Paul', 0.258018],
            ['Scranton', 0.00314],
            ['Raleigh', 0.003322],
            ['Salt Lake City', 0.002777],
            ['Austin', 0.017725],
            ['Madison', 0.003115],
            ['Richmond', 0.015887],
            ['Charleston', 1],
            ['Bismarck', 0.049406],
            ['Columbus', 0.410948],
            ['Oklahoma City', 0.008668],
            ['Portland', 0.002818],
            ['Miami', 0.033977]
        ],
        name: 'Charleston'
    },
    {
        data: [
            ['Chicago', 0.136095],
            ['New York', 0.027427],
            ['Dallas', 0.015718],
            ['Los Angeles', 0.083921],
            ['Minneapolis', 0.073953],
            ['Seattle', 0.150527],
            ['Baltimore', 0.063075],
            ['Boston', 0.181721],
            ['Nashville', 0.006643],
            ['Indianapolis', 0.002503],
            ['Des Moines', 0.045358],
            ['Saint Paul', 0.489367],
            ['Scranton', 0.010506],
            ['Raleigh', 0.011613],
            ['Salt Lake City', 0.028349],
            ['Austin', 0.079048],
            ['Madison', 0.047968],
            ['Richmond', 0.062008],
            ['Charleston', 0.008018],
            ['Bismarck', 1],
            ['Columbus', 0.011153],
            ['Oklahoma City', 0.000307],
            ['Portland', 0.015527],
            ['Miami', 0.055389]
        ],
        name: 'Bismarck'
    },
    {
        data: [
            ['Chicago', 0.071017],
            ['New York', 0.010215],
            ['Dallas', 0.004558],
            ['Los Angeles', 0.035468],
            ['Minneapolis', 0.019997],
            ['Seattle', 0.019732],
            ['Baltimore', 0.019464],
            ['Boston', 0.09252],
            ['Nashville', 0.003144],
            ['Indianapolis', 0.088088],
            ['Des Moines', 0.015672],
            ['Saint Paul', 0.284561],
            ['Scranton', 0.003451],
            ['Raleigh', 0.002226],
            ['Salt Lake City', 0.003676],
            ['Austin', 0.014836],
            ['Madison', 0.002964],
            ['Richmond', 0.012454],
            ['Charleston', 0.273817],
            ['Bismarck', 0.034913],
            ['Columbus', 1],
            ['Oklahoma City', 0.010407],
            ['Portland', 0.003195],
            ['Miami', 0.019155]
        ],
        name: 'Columbus'
    },
    {
        data: [
            ['Chicago', 0.068585],
            ['New York', 0.006099],
            ['Dallas', 0.008255],
            ['Los Angeles', 0.037202],
            ['Minneapolis', 0.017599],
            ['Seattle', 0.022177],
            ['Baltimore', 0.018462],
            ['Boston', 0.095795],
            ['Nashville', 0.002752],
            ['Indianapolis', 0.078475],
            ['Des Moines', 0.015216],
            ['Saint Paul', 0.326376],
            ['Scranton', 0.004311],
            ['Raleigh', 0.003132],
            ['Salt Lake City', 0.004882],
            ['Austin', 0.015609],
            ['Madison', 0.006543],
            ['Richmond', 0.016015],
            ['Charleston', 0.282213],
            ['Bismarck', 0.034895],
            ['Columbus', 0.482109],
            ['Oklahoma City', 1],
            ['Portland', 0.002422],
            ['Miami', 0.021746]
        ],
        name: 'Oklahoma City'
    },
    {
        data: [
            ['Chicago', 0.130639],
            ['New York', 0.020337],
            ['Dallas', 0.017192],
            ['Los Angeles', 0.072497],
            ['Minneapolis', 0.053305],
            ['Seattle', 0.070826],
            ['Baltimore', 0.052254],
            ['Boston', 0.209651],
            ['Nashville', 0.008858],
            ['Indianapolis', 0.002023],
            ['Des Moines', 0.03887],
            ['Saint Paul', 0.495656],
            ['Scranton', 0.012276],
            ['Raleigh', 0.009837],
            ['Salt Lake City', 0.023721],
            ['Austin', 0.055147],
            ['Madison', 0.010167],
            ['Richmond', 0.065631],
            ['Charleston', 0.005407],
            ['Bismarck', 0.07481],
            ['Columbus', 0.009063],
            ['Oklahoma City', 0.000233],
            ['Portland', 1],
            ['Miami', 0.066346]
        ],
        name: 'Portland'
    },
    {
        data: [
            ['Chicago', 0.168602],
            ['New York', 0.042626],
            ['Dallas', 0.019083],
            ['Los Angeles', 0.120954],
            ['Minneapolis', 0.081009],
            ['Seattle', 0.084521],
            ['Baltimore', 0.070184],
            ['Boston', 0.310345],
            ['Nashville', 0.013024],
            ['Indianapolis', 0.003986],
            ['Des Moines', 0.037169],
            ['Saint Paul', 0.49497],
            ['Scranton', 0.017543],
            ['Raleigh', 0.009901],
            ['Salt Lake City', 0.0173],
            ['Austin', 0.128419],
            ['Madison', 0.006945],
            ['Richmond', 0.051271],
            ['Charleston', 0.014663],
            ['Bismarck', 0.120963],
            ['Columbus', 0.014699],
            ['Oklahoma City', 0.000279],
            ['Portland', 0.024018],
            ['Miami', 1]
        ],
        name: 'Miami'
    }
];

function DisplayMetrics(): ReactElement {
    const [isLoading, setLoading] = useState<boolean>(false);
    const [data, setData] = useState<PlotData[]>(mockData);

    return (
        <section className="mt-8">
            <h2>Heat Map w/ Overflow Display</h2>
            <p className="max-w-sm mt-2">
                This is a large heat map display with overflow.
            </p>
            <p className="mt-2">
                <Button
                    onClick={(): void => {
                        setLoading(true);
                    }}
                >
                    Simulate Loading
                </Button>
                <Button
                    onClick={(): void => {
                        setLoading(false);
                        setData(mockData);
                    }}
                >
                    Show Mock Data
                </Button>
                <Button
                    onClick={(): void => {
                        setLoading(false);
                        setData([]);
                    }}
                >
                    Clear Data
                </Button>
            </p>
            <HeatMap
                className="mt-8"
                columnsLabel="Arrival City"
                data={data}
                format="0%"
                id="heat-map--display-metrics"
                isLoading={isLoading}
                maxHeight="530px"
                maxWidth="100%"
                rowsLabel="Departure City"
                showMetrics
                valueLabel="Percentage"
            />
        </section>
    );
}

export default DisplayMetrics;
