import React, { ReactElement, ReactText } from 'react';

import numeral from 'numeral';

import { CategoryValue, HeatMap, PlotData } from '@preamp/waveform';

enum Identifier {
    Chicago = 'Chicago',
    Dallas = 'Dallas',
    LosAngeles = 'Los Angeles',
    NewYork = 'New York'
}

export const data: PlotData[] = [
    {
        data: [
            [Identifier.Dallas, 0.92],
            [Identifier.LosAngeles, 0.41],
            [Identifier.NewYork, 0.66]
        ],
        name: Identifier.Chicago
    },
    {
        data: [
            [Identifier.Chicago, 0.04],
            [Identifier.LosAngeles, 0.003],
            [Identifier.NewYork, 0.39]
        ],
        name: Identifier.Dallas
    },
    {
        data: [
            [Identifier.Dallas, 0.58],
            [Identifier.Chicago, 0.1],
            [Identifier.NewYork, 0.997]
        ],
        name: Identifier.LosAngeles
    },
    {
        data: [
            [Identifier.Chicago, 0.87],
            [Identifier.Dallas, 0.22],
            [Identifier.LosAngeles, undefined]
        ],
        name: Identifier.NewYork
    }
];

function tooltipValueFormatter([, value]: CategoryValue): ReactText {
    return numeral(value).format('0.00%');
}

function valueFormatter([, value]: CategoryValue): ReactText {
    if (value > 0 && value < 0.01) {
        return '< 1%';
    }

    if (value < 1 && value > 0.99) {
        return '> 99%';
    }

    return numeral(value).format('0%');
}

function Formatters(): ReactElement {
    return (
        <section>
            <h2>Heat Map with custom value formatters</h2>
            <HeatMap
                columnsLabel="Arrival City"
                data={data}
                rowsLabel="Departure City"
                showMetrics
                tooltipValueFormatter={tooltipValueFormatter}
                valueFormatter={valueFormatter}
                valueLabel="Percentage"
            />
        </section>
    );
}

export default Formatters;
