import React from 'react';

import { Button } from '@preamp/core';

import { EmptyState, ErrorState, LineChart, PlotData } from '@preamp/waveform';

import { emptyDataArrays } from './data/emptyDataArrays';
import { smallData } from './data/small';

let timeoutID: NodeJS.Timeout;
const smallDataSet: PlotData[] = smallData.slice(0, 2);
export class EmptyLoadingLineChart extends React.Component {
    state: {
        data: PlotData[];
        errorState: React.Component;
        isError: boolean;
        isLoading: boolean;
    } = {
        data: smallDataSet,
        errorState: null,
        isError: false,
        isLoading: true
    };

    componentDidMount(): void {
        this.simulateLoading();
    }

    componentWillUnmount(): void {
        clearTimeout(timeoutID);
    }

    triggerData = (): void => {
        // this.simulateLoading();
        this.setState({
            data: this.state.data.length ? [] : smallDataSet,
            errorState: null,
            isError: false
        });
    };

    triggerError = (): void => {
        this.setState({
            isError: true,
            errorState: (
                <ErrorState
                    mainTitle="Nothing to see here."
                    subText="Custom EmptyState component used!"
                />
            )
        });
    };

    triggerEmptyDataArrays = (): void => {
        this.setState({
            data: emptyDataArrays,
            errorState: null,
            isError: false
        });
    };

    simulateLoading = (): void => {
        this.setState({ isLoading: true }, (): void => {
            timeoutID = setTimeout((): void => {
                this.setState({
                    data: smallDataSet,
                    isLoading: false,
                    errorState: null,
                    isError: false
                });
            }, 3000);
        });
    };

    render(): React.ReactNode {
        return (
            <>
                <LineChart
                    autoWidth
                    data={this.state.data}
                    ErrorState={
                        this.state.isError ? (
                            this.state.errorState
                        ) : (
                            <EmptyState
                                mainTitle="Nothing to see here."
                                subText="Custom EmptyState component used!"
                            />
                        )
                    }
                    isError={this.state.isError}
                    isLoading={this.state.isLoading}
                />
                <div className="mt-4">
                    <Button onClick={this.simulateLoading}>
                        Simulate Loading
                    </Button>
                    <Button onClick={this.triggerData}>
                        {this.state.data.length ? 'Empty' : 'Reset'} Data
                    </Button>
                    <Button onClick={this.triggerEmptyDataArrays}>
                        Empty Data Arrays
                    </Button>
                    <Button onClick={this.triggerError}>Custom Error</Button>
                </div>
            </>
        );
    }
}

export default EmptyLoadingLineChart;
