import React from 'react';

import { LineChart } from '@preamp/waveform';

import { smallData } from './data/small';

/**
 * Resizable LineChart
 */
export const ResponsiveLineChart: React.FC = (): React.ReactElement => {
    const [isLoading, setIsLoading] = React.useState<boolean>(true);

    React.useEffect((): any => {
        const loadingTimeout: number = window.setTimeout((): void => {
            setIsLoading(false);
        }, 5000);

        return (): void => {
            window.clearTimeout(loadingTimeout);
        };
    }, []);

    return (
        <div
            style={{
                boxSizing: 'border-box',
                minHeight: '65px',
                overflow: 'hidden',
                padding: '3px',
                resize: 'both'
            }}
        >
            <LineChart
                autoHeight
                autoWidth
                data={isLoading ? [] : smallData.slice(0, 2)}
                isLoading={isLoading}
                maxHeight={600}
                maxWidth={900}
                minHeight={100}
                minWidth={500}
            />
        </div>
    );
};

export default ResponsiveLineChart;
