import React from 'react';

import {
    OptionsType,
    OptionType,
    Select,
    SelectType,
    ValueType
} from '@preamp/select';
import { AlertTriangle, Signal } from '@preamp/signal';
import {
    LineChart,
    NullIndicators,
    PlotData,
    TimeValue
} from '@preamp/waveform';

import { smallData } from './data/small';

const nullOptions: OptionsType<OptionType> = [
    { value: NullIndicators.All, label: 'All' },
    { value: NullIndicators.Some, label: 'Some' },
    { value: NullIndicators.None, label: 'None' }
];

export const NullDataPointsExample: React.FC = (): React.ReactElement => {
    const [nullIndicators, setNullIndicators] = React.useState<NullIndicators>(
        NullIndicators.All
    );
    const data: PlotData<TimeValue>[] = smallData.map(
        (plotData: PlotData<TimeValue>): PlotData<TimeValue> => ({
            ...plotData,
            data: plotData.data
                .filter(
                    (_, i: number): boolean =>
                        !(plotData.name === 'Fish' && i === 0)
                )
                .map(
                    (timeValue: TimeValue, i: number): TimeValue => {
                        const [date] = timeValue;

                        if (plotData.name === 'Cats') {
                            switch (i) {
                                case 1:
                                case 3:
                                case 5:
                                case 10:
                                    return [date, null];
                                default:
                                    return timeValue;
                            }
                        }

                        if (plotData.name === 'Dogs') {
                            switch (i) {
                                case 1:
                                case 3:
                                case 4:
                                case 10:
                                    return [date, null];
                                default:
                                    return timeValue;
                            }
                        }

                        if (plotData.name === 'Fish') {
                            switch (i) {
                                case 0:
                                case 2:
                                case 3:
                                case 9:
                                    return [date, null];
                                default:
                                    return timeValue;
                            }
                        }

                        switch (i) {
                            case 0:
                            case 3:
                            case 4:
                            case 10:
                                return [date, null];
                            default:
                                return timeValue;
                        }
                    }
                )
        })
    );

    return (
        <div className="mt-3">
            <p className="mt-2 mb-3">
                If all data points for a sepecifc date are null indicator bars
                are shown. This can be changed to show the bars when some data
                points are null for a specific date or to hide the bars
                completely.
            </p>
            <Select
                defaultValue={nullOptions[0]}
                isOptional={false}
                label="Null Indicators"
                labelDescription="Select when to show null indicators"
                onChange={(option: ValueType<NullIndicators>): void => {
                    setNullIndicators(option.value);
                }}
                options={nullOptions}
                selectType={SelectType.Compact}
                style={{ width: '18rem' }}
            />
            <LineChart
                data={data}
                dataUI="null-data-points"
                nullIndicators={nullIndicators}
                tooltipNullContent={
                    <span className="va-grey-900--text normal-case">
                        <Signal
                            className="align-middle mr-1"
                            color="var(--va-grey-600)"
                            icon={AlertTriangle}
                            size=".65rem"
                        />
                        Data Unavailable
                    </span>
                }
            />
        </div>
    );
};

export default NullDataPointsExample;
