import React, { FunctionComponent, ReactElement, ReactNode } from 'react';

import { LineChart, PlotData, TimeValue } from '@preamp/waveform';

import { smallData } from './data/small';

const data: PlotData<TimeValue>[] = smallData.slice(0, 2);

/**
 * LineChart with custom tooltip content.
 */
export const CustomTooltipContentLineChart: FunctionComponent = (): ReactElement => (
    <LineChart
        data={data}
        tooltipContent={(
            xIndex: number,
            value: PlotData<TimeValue>
        ): ReactNode => {
            if (!value) {
                return;
            }

            return (
                <p>{`On ${value.data[xIndex][0].toLocaleDateString(
                    'en-US'
                )}, there were ${data
                    .map(
                        (line: PlotData<TimeValue>): string =>
                            `${line.data[xIndex][1]} ${line.name}`
                    )
                    .join(' and ')}.`}</p>
            );
        }}
    />
);

export default CustomTooltipContentLineChart;
