import React, { ReactElement, FC, useState } from 'react';

import { LineChart, PlotData } from '@preamp/waveform';
import { TextField, TextFieldType } from '@preamp/core';

export const data: PlotData[] = [
    {
        name: 'Company A',
        data: [
            [0, 1],
            [1, 5],
            [3, 3],
            [8, 2]
        ]
    },
    {
        name: 'Company B',
        data: [
            [1, 2],
            [2, 4],
            [5, 4],
            [8, 5],
            [10, 3]
        ]
    }
];

export const CustomXTicksExample: FC = (): ReactElement => {
    const [ticks, setTicks] = useState(6);

    return (
        <section className="mt-5">
            <h4>Custom number of X-Axis ticks</h4>
            <div className="my-2">
                The specified amount is only a hint; the scale may return more
                or fewer values depending on the domain. For more info, please
                see{' '}
                <a
                    href="https://github.com/d3/d3-scale/blob/main/README.md#continuous_ticks"
                    rel="noopener noreferrer"
                    target="_blank"
                >
                    d3.ticks
                </a>
                .
            </div>
            <div className="mt-2 mb-3 w-1/6">
                <TextField
                    label="Number of X-Axis ticks"
                    min="0"
                    onChange={(
                        event: React.ChangeEvent<HTMLInputElement>
                    ): void => {
                        setTicks(Number(event.target.value));
                    }}
                    step="1"
                    textFieldType={TextFieldType.Number}
                    value={`${ticks}`}
                />
            </div>

            <LineChart
                data={data}
                xAxisTitle="x axis"
                xTickCount={ticks}
                yAxisTitle="y axis"
            />
        </section>
    );
};

export default CustomXTicksExample;
