import React, { ReactElement, FC, useState } from 'react';

import { LineChart, PlotData } from '@preamp/waveform';
import { TextField, TextFieldType } from '@preamp/core';

export const data: PlotData[] = [
    {
        name: 'Company A',
        data: [
            [0, 1],
            [1, 5],
            [4, 5],
            [6, 2],
            [9, 3],
            [12, 2],
            [18, 4],
            [20, 3],
            [28, 2],
            [36, 3],
            [44, 1],
            [48, 2],
            [60, 3],
            [70, 4],
            [76, 2]
        ]
    },
    {
        name: 'Company B',
        data: [
            [1, 2],
            [2, 4],
            [5, 4],
            [8, 5],
            [10, 3],
            [16, 1],
            [38, 3],
            [28, 1],
            [40, 3],
            [52, 1],
            [76, 3]
        ]
    }
];

export const CustomXTicksAlignedExample: FC = (): ReactElement => {
    const [ticks, setTicks] = useState(6);

    return (
        <section className="mt-5">
            <h4>Custom number of X-Axis ticks aligned to labels</h4>
            <div className="mt-2 mb-3 w-1/6">
                <TextField
                    label="Number of X-Axis ticks"
                    min="0"
                    onChange={(
                        event: React.ChangeEvent<HTMLInputElement>
                    ): void => {
                        setTicks(Number(event.target.value));
                    }}
                    step="1"
                    textFieldType={TextFieldType.Number}
                    value={`${ticks}`}
                />
            </div>

            <LineChart
                data={data}
                xAxisTitle="x axis"
                xTickAlignToData
                xTickCount={ticks}
                yAxisTitle="y axis"
            />
        </section>
    );
};

export default CustomXTicksAlignedExample;
