import * as React from 'react';

import { LollipopChart, PlotValue } from '@preamp/waveform';

import { basicData } from './data/basic';

const customLabels: string[] = basicData.data.map(
    ([label]: PlotValue): string => label.split(' ')[0]
);

export const LollipopLabelFormatsExample: React.FC = (): React.ReactElement => (
    <section className="mt-5">
        <h4>Axis Label Formatting</h4>
        <div className="mt-2 mb-3">
            Axis tick label formats can be customized through providing the
            yLabelFormat prop.
            <h5 className="mt-3">yLabelFormat</h5>
            Y-Axis labels are formatted numbers and accept a format string to be
            used with d3&apos;s{' '}
            <a
                href="https://github.com/d3/d3-format#api-reference"
                rel="noopener noreferrer"
                target="_blank"
            >
                format
            </a>
        </div>
        <LollipopChart
            data={basicData}
            xAxisTitle="Team Members"
            yAxisTitle="Lines of Code"
            yLabelFormat="$~s"
        />

        <div className="mt-3">
            <h5>
                X-Axis labels can be customized by providing a custom array of
                labels to the LollipopChart.
            </h5>
            <LollipopChart
                data={basicData}
                labels={customLabels}
                xAxisTitle="Team Members"
                yAxisTitle="Lines of Code"
                yLabelFormat="$~s"
            />
        </div>
    </section>
);

export default LollipopLabelFormatsExample;
