import * as React from 'react';

import { Button } from '@preamp/core';

import { ErrorState, LollipopChart, PlotData } from '@preamp/waveform';

import { basicData } from './data/basic';
import { featureData } from './data/feature';

let timeoutID: NodeJS.Timeout;

const emptyData: PlotData = { name: 'Empty', data: [] };
export class EmptyLoadingLollipopChart extends React.Component {
    state: {
        data: PlotData;
        errorState: React.Component;
        feature: PlotData;
        isError: boolean;
        isLoading: boolean;
    } = {
        data: emptyData,
        errorState: null,
        feature: emptyData,
        isError: false,
        isLoading: false
    };

    componentWillUnmount(): void {
        clearTimeout(timeoutID);
    }

    simulateLoading = (): void => {
        this.setState({ isLoading: true }, (): void => {
            timeoutID = setTimeout((): void => {
                this.setState({
                    isLoading: false,
                    data: basicData,
                    errorState: null,
                    isError: false,
                    feature: featureData
                });
            }, 3000);
        });
    };

    resetData = (): void => {
        this.setState({
            data: this.state.data.data.length ? emptyData : basicData,
            errorState: null,
            isError: false
        });
    };
    triggerError = (): void => {
        this.setState({
            isError: true,
            errorState: (
                <ErrorState
                    mainTitle="Nothing to see here."
                    subText="Custom EmptyState component used!"
                />
            )
        });
    };

    render(): React.ReactNode {
        return (
            <>
                <LollipopChart
                    data={{ data: this.state.data.data, name: 'Empty Chart' }}
                    ErrorState={this.state.errorState}
                    feature={{
                        data: this.state.feature.data,
                        name: 'Filled Chart'
                    }}
                    isError={this.state.isError}
                    isLoading={this.state.isLoading}
                    xAxisTitle="Team members"
                    yAxisTitle="Lines of code"
                />
                <div className="mt-4">
                    <Button onClick={this.simulateLoading}>
                        Simulate Loading
                    </Button>
                    <Button onClick={this.resetData}>
                        {this.state.data.data.length ? 'Empty' : 'Reset'} Data
                    </Button>
                    <Button onClick={this.triggerError}>Custom Error</Button>
                </div>
            </>
        );
    }
}

export default EmptyLoadingLollipopChart;
