import * as React from 'react';

import { LollipopChart } from '@preamp/waveform';

import { bigData } from './data/big';
import { bigFeatureData } from './data/bigFeature';
import { emptyData, emptyFeatureData } from './data/empty';

const LollipopResizeableExample: React.FC = (): React.ReactElement => {
    const [isLoading, setIsLoading] = React.useState<boolean>(true);

    React.useEffect((): any => {
        const loadingTimeout: number = window.setTimeout((): void => {
            setIsLoading(false);
        }, 5000);

        return (): void => {
            window.clearTimeout(loadingTimeout);
        };
    }, []);

    return (
        <section className="mt-5">
            <h4>Resizeable Charts</h4>
            <div className="mt-2 mb-3">
                By default, charts are static sizes, autoWidth will make charts
                automatically expand to fit their container&apos;s width.
            </div>
            <div
                style={{
                    boxSizing: 'border-box',
                    minHeight: '65px',
                    overflow: 'scroll',
                    padding: '8px',
                    resize: 'both'
                }}
            >
                <LollipopChart
                    autoHeight
                    autoWidth
                    data={isLoading ? emptyData : bigData}
                    feature={isLoading ? emptyFeatureData : bigFeatureData}
                    isLoading={isLoading}
                    margin={{ top: 10, right: 20, bottom: 20, left: 20 }}
                    minWidth={500}
                />
            </div>
        </section>
    );
};

export default LollipopResizeableExample;
