import React from 'react';

import { CategoryValue, PlotData, LollipopChart } from '@preamp/waveform';
import { Button } from '@preamp/core';

const emptyData: PlotData<CategoryValue> = {
    name: 'Added',
    data: []
};

let timeoutID: NodeJS.Timeout;

export class DataElementWidthSpacingLolipopChart extends React.Component {
    state: {
        data: PlotData<CategoryValue>;
        isLoading: boolean;
    } = {
        data: emptyData,
        isLoading: false
    };

    componentWillUnmount(): void {
        clearTimeout(timeoutID);
    }

    simulateLoading = (): void => {
        const currentSize = this.state.data.data.length;
        const newData: PlotData<CategoryValue> = {
            name: 'Added',
            data: [
                ...this.state.data.data,
                [`Adam Molano ${currentSize + 1}`, 152343]
            ]
        };
        this.setState(
            {
                isLoading: true
            },
            (): void => {
                timeoutID = setTimeout((): void => {
                    this.setState({
                        isLoading: false,
                        data: newData
                    });
                }, 1000);
            }
        );
    };

    resetData = (): void => {
        this.setState({
            data: emptyData
        });
    };

    render(): React.ReactNode {
        return (
            <section className="mt-5">
                <h4>Data Element Width & Spacing</h4>
                <p className="mt-2 mb-3">
                    Chart spacing management: When the chart’s data changes it’s
                    lollipops are automatically resized to best fit into the
                    chart.
                </p>
                <LollipopChart
                    autoWidth
                    data={this.state.data}
                    isLoading={this.state.isLoading}
                />
                <div className="mt-4">
                    <Button onClick={this.simulateLoading}>
                        Simulate Loading Adding Elements
                    </Button>
                    <Button onClick={this.resetData}>Clear Data</Button>
                </div>
            </section>
        );
    }
}

export default DataElementWidthSpacingLolipopChart;
