import React from 'react';

import { random } from 'lodash';

import {
    MekkoChart,
    PlotData,
    MekkoGrouping,
    PlotValue
} from '@preamp/waveform';
import { Button } from '@preamp/core';

const groupings: MekkoGrouping[] = [
    {
        id: 'redshell',
        name: 'Used a Redshell',
        color: {
            activeFill: 'var(--waveform-magenta-900)',
            activeText: 'var(--va-grey-0)',
            fill: 'var(--waveform-magenta-300)',
            text: 'var(--va-grey-900)'
        }
    },
    {
        id: 'noredshell',
        name: `Didn't Use a Redshell`,
        color: {
            activeFill: 'var(--waveform-success-900)',
            activeText: 'var(--va-grey-0)',
            fill: 'var(--waveform-success-100)',
            text: 'var(--va-grey-900)'
        }
    }
];

const multiData: PlotData[] = [
    {
        name: 'Mariokart Winners',
        data: [
            ['Baby Mario', 20, { grouping: 'redshell' }],
            ['Peach', 14, { grouping: 'noredshell' }],
            ['Yoshi', 24, { grouping: 'redshell' }],
            ['Toad', 10, { grouping: 'noredshell' }],
            ['Wario', 12, { grouping: 'noredshell' }]
        ]
    },
    {
        name: 'Mariokart Losers',
        data: [
            ['Luigi', 5, { grouping: 'noredshell' }],
            ['Bowser', 8, { grouping: 'noredshell' }],
            ['Birdo', 10, { grouping: 'redshell' }],
            ['Waluigi', 8, { grouping: 'redshell' }]
        ]
    },
    {
        name: 'Mariokart Ultimate Losers',
        data: [['Diddy Kong', 0, { grouping: 'redshell' }]]
    }
];

export const GroupingsMekkoChart: React.FC = (): React.ReactElement => {
    const [data, setData] = React.useState(multiData);
    const regenerateData = (): void => {
        const newData = data.map(
            (item: PlotData): PlotData => ({
                ...item,
                data: item.data.map(
                    ([name, _, meta]: PlotValue): PlotValue => [
                        name,
                        random(1, 25),
                        meta
                    ]
                )
            })
        );

        setData(newData);
    };
    return (
        <section className="mt-6">
            <h4>Custom Groupings</h4>
            <p className="mt-2 mb-3">
                Custom groupings allow for highlighting extra information in a
                MekkoChart, they also enable grouping totals in the legend and
                allow for custom grouping colors, including active/highlight
                text and backgrounds.
            </p>
            <MekkoChart
                autoWidth
                colors={['var(--va-cyan-A100)', 'var(--va-orange-A100)']}
                data={data}
                groupings={groupings}
                totalLabel="Racers"
            />
            <div className="mt-5 mb-3">
                <Button onClick={regenerateData}>Regenerate Data</Button>
            </div>
        </section>
    );
};

export default GroupingsMekkoChart;
