import * as React from 'react';

import { flattenXValuesById, MultiBarChart } from '@preamp/waveform';
import { multiData } from './data/multi';

const flatValues: string[] = flattenXValuesById(multiData);
const customLabels: string[] = flatValues.map(
    (label: string): string => label.split(' ')[0]
);
export const MultiBarLabelFormatsExample: React.FC = (): React.ReactElement => (
    <section className="mt-5">
        <h4>Axis Label Formatting</h4>
        <div className="mt-2 mb-3">
            Axis tick label formats can be customized through providing the
            yLabelFormat prop.
            <h5 className="mt-3">yLabelFormat</h5>
            Y-Axis labels are formatted numbers and accept a format string to be
            used with d3&apos;s{' '}
            <a
                href="https://github.com/d3/d3-format#api-reference"
                rel="noopener noreferrer"
                target="_blank"
            >
                format
            </a>
        </div>
        <MultiBarChart
            data={multiData}
            xAxisTitle="Team Members"
            yAxisTitle="Lines of Code"
            yLabelFormat="$~s"
        />

        <div className="mt-3">
            <h5>
                X-Axis labels can be customized by providing a custom array of
                labels to the BarChart.
            </h5>
            <MultiBarChart
                data={multiData}
                labels={customLabels}
                xAxisTitle="Team Members"
                yAxisTitle="Lines of Code"
                yLabelFormat="$~s"
            />
        </div>
    </section>
);

export default MultiBarLabelFormatsExample;
