import * as React from 'react';

import { Button } from '@preamp/core';
import { MultiBarChart, PlotData } from '@preamp/waveform';

const emptyData: PlotData[] = [
    {
        name: 'Added',
        data: [['Juan Giuffrida', 152343]]
    },
    {
        name: 'Removed',
        data: [['Juan Giuffrida', 152343]]
    },
    {
        name: 'Refactored',
        data: [['Juan Giuffrida', 152343]]
    }
];

let timeoutID: NodeJS.Timeout;

export class DataElementWidthSpacingBarchart extends React.Component {
    state: {
        data: PlotData[];
        feature: PlotData[];
        isLoading: boolean;
    } = {
        data: emptyData,
        feature: emptyData,
        isLoading: false
    };

    componentWillUnmount(): void {
        clearTimeout(timeoutID);
    }

    simulateLoading = (): void => {
        const currentSize = this.state.data[0].data.length;
        const newData: PlotData[] = [
            {
                name: 'Added',
                data: [
                    ...this.state.data[0].data,
                    [`Juan Giuffrida ${currentSize + 1}`, 152343]
                ]
            },
            {
                name: 'Removed',
                data: [
                    ...this.state.data[0].data,
                    [`Juan Giuffrida ${currentSize + 1}`, 152343]
                ]
            },
            {
                name: 'Refactored',
                data: [
                    ...this.state.data[0].data,
                    [`Juan Giuffrida ${currentSize + 1}`, 152343]
                ]
            }
        ];

        this.setState(
            {
                isLoading: true
            },
            (): void => {
                timeoutID = setTimeout((): void => {
                    this.setState({
                        isLoading: false,
                        data: newData
                    });
                }, 1000);
            }
        );
    };

    resetData = (): void => {
        this.setState(
            {
                isLoading: true
            },
            (): void => {
                timeoutID = setTimeout((): void => {
                    this.setState({
                        isLoading: false,
                        data: emptyData
                    });
                }, 500);
            }
        );
    };

    render(): React.ReactNode {
        return (
            <section className="mt-5">
                <h4>Data Element Width & Spacing</h4>
                <p className="mt-2 mb-3">
                    Chart spacing management: When the chart’s data changes it’s
                    bars are automatically resized to best fit into the chart.
                </p>
                <MultiBarChart
                    data={this.state.data}
                    isLoading={this.state.isLoading}
                    xAxisTitle="Team members"
                    yAxisTitle="Lines of code"
                />
                <div className="mt-4">
                    <Button onClick={this.simulateLoading}>
                        Simulate Loading Adding Elements
                    </Button>
                    <Button onClick={this.resetData}>Clear Data</Button>
                </div>
            </section>
        );
    }
}

export default DataElementWidthSpacingBarchart;
