import React from 'react';

import cx from 'classnames';
import { MultiBarChart, PlotValue, PlotData } from '@preamp/waveform';

const chartData: PlotData[] = [
    {
        name: 'Cats',
        data: [
            ['Adam Molano', 152343, { id: 0 }],
            ['Amy Gaudioso', 155838, { id: 1 }],
            ['Ben Behrens', 142747, { id: 2 }],
            ['Bob Samuelson', 120301, { id: 3 }],
            ['Daniel Raynes', 143255, { id: 4 }],
            ['Doug Ung', 131998, { id: 5 }],
            ['Helen Kim', 153558, { id: 6 }],
            ['Juan Giuffrida', 123020, { id: 7 }],
            ['Vera Carrillo-Marquez', 152321, { id: 8 }]
        ]
    },
    {
        name: 'Dogs',
        data: [
            ['Adam Molano', 155838, { id: 0 }],
            ['Amy Gaudioso', 142747, { id: 1 }],
            ['Ben Behrens', 120301, { id: 2 }],
            ['Bob Samuelson', 143255, { id: 3 }],
            ['Daniel Raynes', 131998, { id: 4 }],
            ['Doug Ung', 153558, { id: 5 }],
            ['Helen Kim', 123020, { id: 6 }],
            ['Juan Giuffrida', 152321, { id: 7 }],
            ['Vera Carrillo-Marquez', 155843, { id: 8 }]
        ]
    },
    {
        name: 'Birds',
        data: [
            ['Adam Molano', 142747, { id: 0 }],
            ['Amy Gaudioso', 155838, { id: 1 }],
            ['Ben Behrens', 142747, { id: 2 }],
            ['Bob Samuelson', 120301, { id: 3 }],
            ['Daniel Raynes', 143255, { id: 4 }],
            ['Doug Ung', 131998, { id: 5 }],
            ['Helen Kim', 153558, { id: 6 }],
            ['Juan Giuffrida', 123020, { id: 7 }],
            ['Vera Carrillo-Marquez', 152221, { id: 8 }]
        ]
    },
    {
        name: 'Fish',
        data: [
            ['Adam Molano', 154343, { id: 0 }],
            ['Amy Gaudioso', 165838, { id: 1 }],
            ['Ben Behrens', 142947, { id: 2 }],
            ['Bob Samuelson', 125301, { id: 3 }],
            ['Daniel Raynes', 143155, { id: 4 }],
            ['Doug Ung', 131798, { id: 5 }],
            ['Helen Kim', 153358, { id: 6 }],
            ['Juan Giuffrida', 123920, { id: 7 }],
            ['Vera Carrillo-Marquez', 152329, { id: 8 }]
        ]
    },
    {
        name: 'Goats',
        data: [
            ['Adam Molano', 152348, { id: 0 }],
            ['Amy Gaudioso', 155838, { id: 1 }],
            ['Ben Behrens', 142746, { id: 2 }],
            ['Bob Samuelson', 120304, { id: 3 }],
            ['Daniel Raynes', 143253, { id: 4 }],
            ['Doug Ung', 135993, { id: 5 }],
            ['Helen Kim', 133587, { id: 6 }],
            ['Juan Giuffrida', 133587, { id: 7 }],
            ['Vera Carrillo-Marquez', 152624, { id: 8 }]
        ]
    }
];

function getCustomTooltipWithDataColumns(
    data: PlotValue,
    index: number
): React.ReactNode {
    const [name, value, { active, color }] = data;
    const percentage = Math.round((100 * value) / 300000);

    const classNames: string = cx('va-chart-tooltip-entity', {
        active: active
    });

    return (
        <div className={`custom-tooltip-multichart-${index}`}>
            <div className={classNames}>
                <div className="va-chart-tooltip-entity-name">
                    <span
                        className="va-chart-legend-dot"
                        style={{ backgroundColor: color }}
                    />
                    {name}
                </div>
            </div>
            <div
                className={'flex mb-5 ' + (active ? 'font-bold' : '')}
                style={{ fontSize: '0.65rem' }}
            >
                <div className="flex-1 pl-3">
                    <div className="uppercase">HH Count</div>
                    <div>{value}</div>
                </div>
                <div className="flex-1 pl-3 pr-3">
                    <div className="uppercase whitespace-no-wrap">
                        % of Audience
                    </div>
                    <div>{percentage}%</div>
                </div>
            </div>
        </div>
    );
}

function getCustomTooltipWithBorderColorOnHover(
    data: PlotValue,
    index: number
): React.ReactNode {
    const [name, value, { color, active }] = data;
    return (
        <div
            className={`p-1 custom-tooltip-description-2-${index}`}
            style={{
                borderColor: active ? color : 'transparent',
                borderWidth: 2
            }}
        >
            <div className="text-center font-bold">
                <span
                    className="va-chart-legend-dot"
                    style={{ backgroundColor: color }}
                />
                {name}
            </div>
            <div className="text-center">
                <div>{value}</div>
                <div style={{ fontSize: '.5rem' }}>(Note about {name})</div>
            </div>
        </div>
    );
}

export const MultiBarChartCustomTooltipDescriptionExample: React.FC = (): React.ReactElement => {
    return (
        <section className="mt-5">
            <h4>Custom Tooltip Descriptions</h4>
            <p className="mt-2">
                MultiBarChart tooltips can be customized through the
                tooltipCustomLabelDescription property.
            </p>

            <h5 className="mt-5">* Example 1:</h5>
            <MultiBarChart
                data={chartData}
                tooltipCustomLabelDescription={getCustomTooltipWithDataColumns}
            />

            <h5 className="mt-5">* Example 2:</h5>
            <MultiBarChart
                data={chartData}
                isHorizontal
                tooltipCustomLabelDescription={getCustomTooltipWithDataColumns}
            />

            <h5 className="mt-5">* Example 3:</h5>
            <MultiBarChart
                data={chartData}
                tooltipCustomLabelDescription={
                    getCustomTooltipWithBorderColorOnHover
                }
            />
        </section>
    );
};

export default MultiBarChartCustomTooltipDescriptionExample;
