import React from 'react';

import { Slider, Toggle } from '@preamp/core';
import { PieChart, CategoryValue } from '@preamp/waveform';

const dataOne: CategoryValue[] = [
    ['Dachshund', 68, { color: 'var(--waveform-royal-400)' }],
    ['Chihuahua', 48, { color: 'var(--waveform-sky-400)' }],
    ['Beagle', 38, { color: 'var(--waveform-magenta-400)' }],
    ['Pomeranian', 26, { color: 'var(--waveform-violet-400)' }]
];

const dataTwo: CategoryValue[] = [
    ['Dachshund', 68, { color: 'var(--waveform-royal-600)' }],
    ['Chihuahua', 48, { color: 'var(--waveform-sky-600)' }],
    ['Beagle', 38, { color: 'var(--waveform-magenta-600)' }],
    ['Pomeranian', 26, { color: 'var(--waveform-violet-600)' }],
    ['Corgi', 32, { color: 'var(--waveform-warning-600)' }]
];

/**
 * A PieChart with prop controls
 */
export const ControlsPieChart: React.FC = (): React.ReactElement => {
    const [isDonut, setIsDonut] = React.useState<boolean>(false);
    const [isLoading, setIsLoading] = React.useState<boolean>(false);
    const [isError, setIsError] = React.useState<boolean>(false);
    const [data, setData] = React.useState<CategoryValue[]>(dataOne);
    const [isLegendVisible, setIsLegendVisible] = React.useState<boolean>(true);
    const [innerRadiusScale, setInnerRadiusScale] = React.useState<number>(75);
    const [strokeWidth, setStrokeWidth] = React.useState<number>(4);

    return (
        <>
            <PieChart
                className="my-8"
                data={data}
                innerRadiusScale={innerRadiusScale / 100}
                isDonut={isDonut}
                isError={isError}
                isLoading={isLoading}
                shouldShowLegend={isLegendVisible}
                strokeWidth={strokeWidth}
                width={360}
            />
            <Toggle
                checked={isLegendVisible}
                label="isLegendVisible"
                name="legend-toggle"
                onChange={(checked: boolean): void => {
                    setIsLegendVisible(checked);
                }}
            />
            <Toggle
                checked={isDonut}
                label="isDonut"
                name="donut-chart-toggle"
                onChange={(checked: boolean): void => {
                    setIsDonut(checked);
                }}
            />
            <Toggle
                checked={isLoading}
                label="isLoading"
                name="loading-toggle"
                onChange={(checked: boolean): void => {
                    setIsLoading(checked);
                }}
            />
            <Toggle
                checked={isError}
                label="isError"
                name="error-toggle"
                onChange={(checked: boolean): void => {
                    setIsError(checked);
                }}
            />
            <Toggle
                checked={data !== dataOne}
                label="Include Corgi"
                name="corgi-toggle"
                onChange={(checked: boolean): void => {
                    checked ? setData(dataTwo) : setData(dataOne);
                }}
            />
            <Slider
                className="my-6"
                currentValue={strokeWidth}
                isSingleThumb
                label="Stroke Width"
                max={8}
                min={0}
                onChange={(value: number): void => {
                    setStrokeWidth(value);
                }}
                showTextInput={false}
            />
            {isDonut && (
                <Slider
                    className="my-6"
                    currentValue={innerRadiusScale}
                    isSingleThumb
                    label="Donut Chart Inner Radius %"
                    max={80}
                    min={20}
                    onChange={(value: number): void => {
                        setInnerRadiusScale(value);
                    }}
                    showTextInput={false}
                />
            )}
        </>
    );
};

export default ControlsPieChart;
