import React from 'react';

import { Button } from '@preamp/core';
import { PieChart, CategoryValue } from '@preamp/waveform';

const dataToLoad: CategoryValue[] = [
    ['Dachshund', 68, { color: 'var(--waveform-royal-600)' }],
    ['Chihuahua', 48, { color: 'var(--waveform-sky-600)' }],
    ['Beagle', 38, { color: 'var(--waveform-magenta-600)' }],
    ['Pomeranian', 26, { color: 'var(--waveform-violet-600)' }],
    ['Corgi', 32, { color: 'var(--waveform-warning-600)' }]
];

/**
 * A PieChart with async data loading
 */
export const AsyncPieChart: React.FC = (): React.ReactElement => {
    const [isLoading, setIsLoading] = React.useState<boolean>(false);
    const [data, setData] = React.useState<CategoryValue[]>();

    return (
        <>
            <PieChart
                className="my-8"
                data={data}
                isDonut
                isLoading={isLoading}
                tooltipNumFormat=",.2f"
                width={360}
            />
            <Button
                onClick={(): void => {
                    setIsLoading(true);
                    setTimeout((): void => {
                        setIsLoading(false);
                        setData(dataToLoad);
                    }, 2000);
                }}
            >
                Simulate Load
            </Button>
            <Button
                onClick={(): void => {
                    setIsLoading(false);
                    setData(null);
                }}
            >
                Clear Data
            </Button>
        </>
    );
};

export default AsyncPieChart;
