import React from 'react';

import { cloneDeep, get, set } from 'lodash';
import {
    CategoryValue,
    PIECHART_DEFAULT_DOMAIN,
    PieChart,
    DataDomain
} from '@preamp/waveform';

import { TextField, TextFieldType, Toggle } from '@preamp/core';

const basicData: CategoryValue[] = [
    ['Dachshund', 2],
    ['Chihuahua', 4],
    ['Poodle', -4], // bad value: it will be internally filtered out
    ['Beagle', 8],
    ['Pomeranian', 5],
    ['Molosser', null] // bad value: it will be internally filtered out
];

export const DataDomainsPieChartExample: React.FC = (): React.ReactElement => {
    const [isCustomDomain, setIsCustomDomain] = React.useState<boolean>();
    const [domain, setDomain] = React.useState<DataDomain>(
        cloneDeep(PIECHART_DEFAULT_DOMAIN)
    );

    function onChange(
        prop: string
    ): (_: React.ChangeEvent<HTMLInputElement>) => void {
        return (e: React.ChangeEvent<HTMLInputElement>): void => {
            const value = Number(e.target.value);
            setDomain(
                (prevDomain: DataDomain): DataDomain => {
                    const newDomain = { ...prevDomain };
                    set(newDomain, ['y', 0, prop], value);
                    return newDomain;
                }
            );
        };
    }

    function onToggleCustomDomain(value: boolean): void {
        setDomain(cloneDeep(PIECHART_DEFAULT_DOMAIN));
        setIsCustomDomain(value);
    }

    return (
        <section className="mt-5">
            <h4>Plot Data Domains</h4>
            <p className="mt-2 mb-5">
                Values out of range or not allowed by the chart definition will
                be filtered out from data.
            </p>

            <Toggle
                checked={isCustomDomain}
                label="Set a custom domain"
                name="custom-domain"
                onChange={onToggleCustomDomain}
            />

            <div className="flex items-end mb-4">
                <div className="flex-1 text-right pr-4 pb-3">Values:</div>
                <div className="flex-1 pr-4">
                    <TextField
                        disabled={!isCustomDomain}
                        label="min"
                        onChange={onChange('min')}
                        textFieldType={TextFieldType.Number}
                        value={`${get(domain, ['y', 0, 'min'], -4)}`}
                    />
                </div>
                <div className="flex-1 pr-4">
                    <TextField
                        disabled={!isCustomDomain}
                        label="max"
                        onChange={onChange('max')}
                        textFieldType={TextFieldType.Number}
                        value={`${get(domain, ['y', 0, 'max'], 8)}`}
                    />
                </div>
                <div className="flex-1 u-body-2 mb-3">Nulls not allowed</div>
            </div>

            <PieChart autoWidth data={basicData} dataDomain={domain} />
        </section>
    );
};

export default DataDomainsPieChartExample;
