import * as React from 'react';

import { chunk, flatMap } from 'lodash';

import { NumericValue, PlotData, ScatterChart } from '@preamp/waveform';

import { smallData } from './data/small';

export const DataTransformationExample: React.FC = (): React.ReactElement => {
    const maxDataPointsAllowed = 30;
    const n = 3;
    const dataSets: PlotData<NumericValue>[] = smallData.slice(0, n);

    const transformedData: () => PlotData<NumericValue>[] = (): PlotData<
        NumericValue
    >[] => {
        const flattenedData: NumericValue[] = flatMap(
            dataSets,
            (data: PlotData<NumericValue>): any => data.data
        );
        const chunkedData: NumericValue[][] = chunk(
            flattenedData,
            maxDataPointsAllowed / n
        );

        return dataSets.map(
            (dataSet: PlotData<NumericValue>, i: number): any => ({
                name: dataSet.name,
                data: chunkedData[i]
            })
        );
    };

    return (
        <section className="mt-5">
            <h4> Data Transformation Example</h4>
            <p className="mt-2 mb-3">
                This example shows 3 data sets with 10 NumericValue[] points.
                See the code to see how this can be achieved.
            </p>
            <ScatterChart
                data={transformedData()}
                xAxisTitle="Farenheit"
                yAxisTitle="Profit"
            />
            <p className="mt-2 mb-3">
                This example shows what would happen if you didn&apos;t
                transform the data before passing it down.
            </p>
            <ScatterChart
                data={dataSets}
                xAxisTitle="Farenheit"
                yAxisTitle="Profit"
            />
        </section>
    );
};

export default DataTransformationExample;
