import * as React from 'react';

import { Button } from '@preamp/core';

import {
    ErrorState,
    NumericValue,
    PlotData,
    ScatterChart
} from '@preamp/waveform';

import { smallData } from './data/small';

let timeoutID: NodeJS.Timeout;
export class EmptyLoadingScatterChart extends React.Component {
    state: {
        data: PlotData<NumericValue>[];
        errorState: React.Component;
        isError: boolean;
        isLoading: boolean;
    } = {
        data: [],
        errorState: null,
        isError: false,
        isLoading: false
    };

    componentWillUnmount(): void {
        clearTimeout(timeoutID);
    }

    simulateLoading = (): void => {
        this.setState({ isLoading: true }, (): void => {
            timeoutID = setTimeout((): void => {
                this.setState({
                    isLoading: false,
                    data: smallData.slice(2, 3),
                    errorState: null,
                    isError: false
                });
            }, 3000);
        });
    };

    resetData = (): void => {
        this.setState({
            data: this.state.data.length ? [] : smallData.slice(2, 3),
            errorState: null,
            isError: false
        });
    };
    triggerError = (): void => {
        this.setState({
            isError: true,
            errorState: (
                <ErrorState
                    mainTitle="Nothing to see here."
                    subText="Custom EmptyState component used!"
                />
            )
        });
    };

    render(): React.ReactNode {
        return (
            <>
                <ScatterChart
                    data={this.state.data}
                    ErrorState={this.state.errorState}
                    isError={this.state.isError}
                    isLoading={this.state.isLoading}
                    xAxisTitle="Team members"
                    yAxisTitle="Lines of code"
                />
                <div className="mt-4">
                    <Button onClick={this.simulateLoading}>
                        Simulate Loading
                    </Button>
                    <Button onClick={this.resetData}>
                        {this.state.data.length ? 'Empty' : 'Reset'} Data
                    </Button>
                    <Button onClick={this.triggerError}>Custom Error</Button>
                </div>
            </>
        );
    }
}

export default EmptyLoadingScatterChart;
