import * as React from 'react';

import { Button } from '@preamp/core';

import { PlotData, StackedAreaChart } from '@preamp/waveform';

import { smallData } from '../LineChart/data/small';

let timeoutID: NodeJS.Timeout;

class EmptyLoadingStackedAreaChart extends React.Component {
    state: { data: PlotData[]; isLoading: boolean } = {
        data: smallData,
        isLoading: true
    };

    componentDidMount(): void {
        this.simulateLoading();
    }

    componentWillUnmount(): void {
        clearTimeout(timeoutID);
    }

    triggerData = (): void => {
        // this.simulateLoading();
        this.setState({ data: this.state.data.length ? [] : smallData });
    };

    simulateLoading = (): void => {
        this.setState({ isLoading: true }, (): void => {
            timeoutID = setTimeout((): void => {
                this.setState({ data: smallData, isLoading: false });
            }, 3000);
        });
    };

    render(): React.ReactNode {
        return (
            <>
                <StackedAreaChart
                    data={this.state.data}
                    isLoading={this.state.isLoading}
                />
                <div className="mt-4">
                    <Button onClick={this.simulateLoading}>
                        Simulate Loading
                    </Button>
                    <Button onClick={this.triggerData}>
                        {this.state.data.length ? 'Empty' : 'Reset'} Data
                    </Button>
                </div>
            </>
        );
    }
}

export default EmptyLoadingStackedAreaChart;
