import React from 'react';

import { StackedAreaChart, PlotData, LegendData } from '@preamp/waveform';
import { Button } from '@preamp/core';

const basicData: PlotData[] = [
    {
        name: 'Cats',
        data: [
            [new Date(2018, 0, 1), 20000],
            [new Date(2018, 1, 1), 25000],
            [new Date(2018, 2, 1), 40000],
            [new Date(2018, 3, 1), 35000],
            [new Date(2018, 4, 1), 50000],
            [new Date(2018, 5, 1), 48740],
            [new Date(2018, 6, 1), 40000],
            [new Date(2018, 7, 1), 20000],
            [new Date(2018, 8, 1), 20009],
            [new Date(2018, 9, 1), 10000],
            [new Date(2018, 10, 1), 8000],
            [new Date(2018, 11, 1), 18000]
        ]
    },
    {
        name: 'Dogs',
        data: [
            [new Date(2018, 0, 1), 12000],
            [new Date(2018, 1, 1), 10000],
            [new Date(2018, 2, 1), 9000],
            [new Date(2018, 3, 1), 8000],
            [new Date(2018, 4, 1), 9000],
            [new Date(2018, 5, 1), 12000],
            [new Date(2018, 6, 1), 20000],
            [new Date(2018, 7, 1), 30000],
            [new Date(2018, 8, 1), 40000],
            [new Date(2018, 9, 1), 60000],
            [new Date(2018, 10, 1), 80000],
            [new Date(2018, 11, 1), 82334]
        ]
    },
    {
        name: 'Birds',
        data: [
            [new Date(2018, 0, 1), 40000],
            [new Date(2018, 1, 1), 45000],
            [new Date(2018, 2, 1), 55245],
            [new Date(2018, 3, 1), 50023],
            [new Date(2018, 4, 1), 46000],
            [new Date(2018, 5, 1), 45000],
            [new Date(2018, 6, 1), 33045],
            [new Date(2018, 7, 1), 26000],
            [new Date(2018, 8, 1), 19500],
            [new Date(2018, 9, 1), 12000],
            [new Date(2018, 10, 1), 23000],
            [new Date(2018, 11, 1), 40000]
        ]
    },
    {
        name: 'Fish',
        data: [
            [new Date(2018, 0, 1), 4000],
            [new Date(2018, 1, 1), 5500],
            [new Date(2018, 2, 1), 2500],
            [new Date(2018, 3, 1), 10000],
            [new Date(2018, 4, 1), 8000],
            [new Date(2018, 5, 1), 4500],
            [new Date(2018, 6, 1), 7000],
            [new Date(2018, 7, 1), 7800],
            [new Date(2018, 8, 1), 8200],
            [new Date(2018, 9, 1), 9000],
            [new Date(2018, 10, 1), 9500],
            [new Date(2018, 11, 1), 0]
        ]
    },
    {
        name: 'Goats',
        data: [
            [new Date(2018, 0, 1), 12],
            [new Date(2018, 1, 1), 3000],
            [new Date(2018, 2, 1), 3500],
            [new Date(2018, 3, 1), 3555],
            [new Date(2018, 4, 1), 3900],
            [new Date(2018, 5, 1), 3800],
            [new Date(2018, 6, 1), 12000],
            [new Date(2018, 7, 1), 12500],
            [new Date(2018, 8, 1), 13000],
            [new Date(2018, 9, 1), 80000],
            [new Date(2018, 10, 1), 78000],
            [new Date(2018, 11, 1), 82000]
        ]
    }
];

export const ToggableLegendFilterExample: React.FC = (): React.ReactElement => {
    const [data, setData] = React.useState<PlotData[]>(basicData);

    const filterByLegend = (
        currentSelection: LegendData[],
        _clicked: number,
        event: React.MouseEvent<HTMLLIElement>
    ): void => {
        event && event.preventDefault();

        const selection = currentSelection
            .filter((item: LegendData): boolean => item.selected)
            .map((item: LegendData): string => item.name as string);

        const filteredData = !selection.length
            ? basicData
            : basicData.map(
                  ({ name, data, ...rest }: PlotData): PlotData => ({
                      name,
                      ...rest,
                      data: selection.includes(name) ? data : []
                  })
              );
        setData([...filteredData]);
    };

    return (
        <>
            <p className="mb-5">Filtering data when clicking on legend</p>
            <StackedAreaChart
                autoWidth
                data={data}
                onLegendClick={filterByLegend}
            />
        </>
    );
};

const ToggableLegendKeepLegendSelectionExample: React.FC = (): React.ReactElement => {
    const [data, setData] = React.useState<PlotData[]>(basicData);
    const [legendData, setLegendData] = React.useState<LegendData[]>(null);
    const [loading, setLoading] = React.useState<boolean>(false);

    const filterByLegend = (
        currentSelection: LegendData[],
        _clicked?: number,
        event?: React.MouseEvent<HTMLLIElement>
    ): void => {
        event && event.preventDefault();

        const selection = currentSelection
            .filter((item: LegendData): boolean => item.selected)
            .map((item: LegendData): string => item.name as string);

        const filteredData = !selection.length
            ? basicData
            : basicData.map(
                  ({ name, data, ...rest }: PlotData): PlotData => ({
                      name,
                      ...rest,
                      data: selection.includes(name) ? data : []
                  })
              );
        setData([...filteredData]);
        setLegendData(currentSelection);
    };

    const simulateServerCall = (): void => {
        setTimeout((): void => {
            setLoading(false);
            filterByLegend(legendData || basicData);
        }, 1000);
    };

    const refreshChart = (): void => {
        setLoading(true);
        simulateServerCall();
    };

    return (
        <>
            <p className="mb-5">
                Filtering data when clicking on legend and keeping legend
                selection after refreshing
            </p>
            <Button className="mb-5" onClick={refreshChart}>
                Refresh chart
            </Button>
            <StackedAreaChart
                autoWidth
                data={data}
                isLoading={loading}
                legendData={legendData}
                onLegendClick={filterByLegend}
            />
        </>
    );
};

export const StackedAreaChartToggableLegendExample: React.FC = (): React.ReactElement => (
    <section className="mt-5">
        <h4>Legend Interaction</h4>
        <p className="mt-2 mb-5">
            Callback to perform an action after clicking on a legend. The
            legendData property could be used to set the initial selection
            state.
        </p>

        <h5 className="mt-5 mb-2">* Example 1:</h5>
        <ToggableLegendFilterExample />

        <h5 className="mt-5 mb-2">* Example 2:</h5>
        <ToggableLegendKeepLegendSelectionExample />
    </section>
);

export default StackedAreaChartToggableLegendExample;
