import React from 'react';

import { cloneDeep, get, set } from 'lodash';
import {
    PlotData,
    DataDomain,
    STACKEDAREACHART_DEFAULT_DOMAIN,
    StackedAreaChart
} from '@preamp/waveform';

import { TextField, TextFieldType, Toggle } from '@preamp/core';

const basicData: PlotData[] = [
    {
        name: 'Cats',
        data: [
            [new Date(2018, 0, 1), 20],
            [new Date(2018, 1, 1), -25], // bad value: it will be internally filtered out
            [new Date(2018, 2, 1), -40], // bad value: it will be internally filtered out
            [new Date(2018, 3, 1), -47], // bad value: it will be internally filtered out
            [null, 50], // bad value: it will be internally filtered out
            [new Date(2018, 5, 1), 48]
        ]
    },
    {
        name: 'Dogs',
        data: [
            [new Date(2018, 0, 1), 12],
            [new Date(2018, 1, 1), 10],
            [new Date(2018, 2, 1), 9],
            [new Date(2018, 3, 1), 8],
            [new Date(2018, 4, 1), null], // bad value: it will be internally filtered out
            [new Date(2018, 5, 1), 12]
        ]
    },
    {
        name: 'Birds',
        data: [
            [new Date(2018, 0, 1), 40],
            [new Date(2018, 1, 1), -50], // bad value: it will be internally filtered out
            [new Date(2018, 2, 1), 0],
            [new Date(2018, 3, 1), 50],
            [new Date(2018, 4, 1), 46],
            [new Date(2018, 5, 1), 45]
        ]
    }
];

export const DataDomainsStackedAreaChartExample: React.FC = (): React.ReactElement => {
    const [isCustomDomain, setIsCustomDomain] = React.useState<boolean>();
    const [domain, setDomain] = React.useState<DataDomain>(
        cloneDeep(STACKEDAREACHART_DEFAULT_DOMAIN)
    );

    function changeDomainProperty(prop: string, value: number | boolean): void {
        setDomain(
            (prevDomain: DataDomain): DataDomain => {
                const newDomain = cloneDeep(prevDomain);
                set(newDomain, ['y', 0, prop], value);
                return newDomain;
            }
        );
    }

    function onChange(
        prop: string
    ): (_: React.ChangeEvent<HTMLInputElement>) => void {
        return (e: React.ChangeEvent<HTMLInputElement>): void => {
            changeDomainProperty(prop, Number(e.target.value));
        };
    }

    function onToggleCustomDomain(value: boolean): void {
        setDomain(cloneDeep(STACKEDAREACHART_DEFAULT_DOMAIN));
        setIsCustomDomain(value);
    }

    return (
        <section className="mt-5">
            <h4>Plot Data Domains</h4>
            <p className="mt-2 mb-5">
                Values out of range or not allowed by the chart definition will
                be filtered out from data.
            </p>

            <Toggle
                checked={isCustomDomain}
                label="Set a custom domain"
                name="custom-domain"
                onChange={onToggleCustomDomain}
            />

            <div className="flex items-end mb-4">
                <div className="flex-1 text-right pr-4 pb-3">Y:</div>
                <div className="flex-1 pr-4">
                    <TextField
                        disabled={!isCustomDomain}
                        label="min"
                        onChange={onChange('min')}
                        textFieldType={TextFieldType.Number}
                        value={`${get(domain, ['y', 0, 'min'], -50)}`}
                    />
                </div>
                <div className="flex-1 pr-4">
                    <TextField
                        disabled={!isCustomDomain}
                        label="max"
                        onChange={onChange('max')}
                        textFieldType={TextFieldType.Number}
                        value={`${get(domain, ['y', 0, 'max'], 50)}`}
                    />
                </div>
                <div className="flex-1 u-body-2 mb-3">Nulls not allowed</div>
            </div>

            <StackedAreaChart autoWidth data={basicData} dataDomain={domain} />
        </section>
    );
};

export default DataDomainsStackedAreaChartExample;
