import React, { useState } from 'react';

import { Button } from '@preamp/core';
import { TornadoChart, PlotData } from '@preamp/waveform';

const basicData: PlotData[][] = [
    [
        {
            name: 'Cats',
            data: [
                ['Adam Molano', 152343, { id: 0 }],
                ['Amy Gaudioso', 155838, { id: 1 }],
                ['Ben Behrens', 142747, { id: 2 }],
                ['Bob Samuelson', 120301, { id: 3 }],
                ['Daniel Raynes', 143255, { id: 4 }],
                ['Doug Ung', 131998, { id: 5 }],
                ['Helen Kim', 153558, { id: 6 }],
                ['Juan Giuffrida', 123020, { id: 7 }],
                ['Vera Carrillo-Marquez', 152321, { id: 8 }]
            ]
        },
        {
            name: 'Dogs',
            data: [
                ['Adam Molano', 155838, { id: 0 }],
                ['Amy Gaudioso', 142747, { id: 1 }],
                ['Ben Behrens', 120301, { id: 2 }],
                ['Bob Samuelson', 143255, { id: 3 }],
                ['Daniel Raynes', 131998, { id: 4 }],
                ['Doug Ung', 153558, { id: 5 }],
                ['Helen Kim', 123020, { id: 6 }],
                ['Juan Giuffrida', 152321, { id: 7 }],
                ['Vera Carrillo-Marquez', 155843, { id: 8 }]
            ]
        }
    ],
    [
        {
            name: 'Cats',
            data: [
                ['Adam Molano', 142747, { id: 0 }],
                ['Amy Gaudioso', 155838, { id: 1 }],
                ['Ben Behrens', 142747, { id: 2 }],
                ['Bob Samuelson', 120301, { id: 3 }],
                ['Daniel Raynes', 143255, { id: 4 }],
                ['Doug Ung', 131998, { id: 5 }],
                ['Helen Kim', 153558, { id: 6 }],
                ['Juan Giuffrida', 123020, { id: 7 }],
                ['Vera Carrillo-Marquez', 152221, { id: 8 }]
            ]
        },
        {
            name: 'Dogs',
            data: [
                ['Adam Molano', 154343, { id: 0 }],
                ['Amy Gaudioso', 165838, { id: 1 }],
                ['Ben Behrens', 142947, { id: 2 }],
                ['Bob Samuelson', 125301, { id: 3 }],
                ['Daniel Raynes', 143155, { id: 4 }],
                ['Doug Ung', 131798, { id: 5 }],
                ['Helen Kim', 153358, { id: 6 }],
                ['Juan Giuffrida', 123920, { id: 7 }],
                ['Vera Carrillo-Marquez', 152329, { id: 8 }]
            ]
        }
    ]
];

const singleData: PlotData[][] = [
    [
        {
            name: 'Cats',
            data: [
                ['Adam Molano', 102343, { id: 0 }],
                ['Amy Gaudioso', 95838, { id: 1 }],
                ['Ben Behrens', 14274, { id: 2 }],
                ['Bob Samuelson', 120301, { id: 3 }],
                ['Daniel Raynes', 143200, { id: 4 }],
                ['Doug Ung', 131998, { id: 5 }],
                ['Helen Kim', 153002, { id: 6 }],
                ['Juan Giuffrida', 123020, { id: 7 }],
                ['Vera Carrillo-Marquez', 152321, { id: 8 }]
            ]
        }
    ]
];

const smallData: PlotData[][] = [
    [
        {
            name: 'Frequency1',
            data: [
                [' 1x', 5],
                [' 2x', 3.5],
                [' 3x', 6.5],
                [' 4x', 2.5],
                [' 5x', 0],
                [' 6x', 7.1],
                [' 8x', 6],
                [' 9x', 7.2]
            ]
        },
        {
            name: 'Frequency2',
            data: [
                [' 1x', 3],
                [' 2x', 2],
                [' 3x', 1.5],
                [' 4x', 4.5],
                [' 5x', 2],
                [' 6x', 4.1],
                [' 8x', 3],
                [' 9x', 6.2]
            ]
        }
    ],
    [
        {
            name: 'Frequency1',
            data: [
                [' 1x', 5],
                [' 2x', 3.5],
                [' 3x', 6.5],
                [' 4x', 2.5],
                [' 5x', 0],
                [' 6x', 7.1],
                [' 8x', 6],
                [' 9x', 7.2]
            ]
        },
        {
            name: 'Frequency2',
            data: [
                [' 1x', 3],
                [' 2x', 2],
                [' 3x', 1.5],
                [' 4x', 4.5],
                [' 5x', 2],
                [' 6x', 4.1],
                [' 8x', 3],
                [' 9x', 6.2]
            ]
        }
    ]
];

/**
 * A TornadoChart with no data.
 */
export const TornadoChartStates: React.FC = (): React.ReactElement => {
    const [showMetricLine, setMetricLine] = useState<boolean>(false);
    const [groupTitles, setGroupTitles] = useState<string[]>(['']);
    const [data, setData] = useState<PlotData[][]>(basicData);
    return (
        <section className="mt-8">
            <h2>Tornado Chart States Display</h2>
            <p className="max-w-sm mt-2">
                This is a example where you can look a the diffrent ststes of
                the Chart.
            </p>
            <p className="mt-2">
                <Button
                    onClick={(): void => {
                        setGroupTitles(['GROUP NAME 1', 'GROUP NAME 2']);
                        setData(basicData);
                    }}
                >
                    Show Mock Data
                </Button>
                <Button
                    onClick={(): void => {
                        setGroupTitles(['GROUP NAME 1']);
                        setData(singleData);
                    }}
                >
                    Single Wing Data
                </Button>
                <Button
                    onClick={(): void => {
                        setGroupTitles(['GROUP NAME 1', 'GROUP NAME 2']);
                        setMetricLine(true);
                        setData(smallData);
                    }}
                >
                    YAxis Not width fixed
                </Button>
                <Button
                    onClick={(): void => {
                        setGroupTitles(['GROUP NAME 1', 'GROUP NAME 2']);
                        setMetricLine(true);
                        setData(basicData);
                    }}
                >
                    Show Metric Line
                </Button>
                <Button
                    onClick={(): void => {
                        setGroupTitles(['']);
                        setData([]);
                    }}
                >
                    Clear Data
                </Button>
            </p>
            <TornadoChart
                data={data}
                groupTitles={groupTitles}
                showMetricLine={showMetricLine}
                xAxisTitle="Team Members"
            />
        </section>
    );
};

export default TornadoChartStates;
