import React from 'react';

import {
    OptionsType,
    OptionType,
    Select,
    SelectType,
    ValueType
} from '@preamp/select';
import { AlertTriangle, Signal } from '@preamp/signal';
import { NullIndicators, PlotData, TrendLineChart } from '@preamp/waveform';

const DATA: PlotData[] = [
    {
        name: 'Cats',
        data: [
            [new Date(2018, 0, 1), 20000],
            [new Date(2018, 1, 1), 25000],
            [new Date(2018, 2, 1), null],
            [new Date(2018, 3, 1), 35000],
            [new Date(2018, 4, 1), 50000],
            [new Date(2018, 5, 1), null],
            [new Date(2018, 6, 1), null],
            [new Date(2018, 7, 1), null],
            [new Date(2018, 8, 1), null],
            [new Date(2018, 9, 1), 10000],
            [new Date(2018, 10, 1), 8000],
            [new Date(2018, 11, 1), 18000]
        ]
    },
    {
        name: 'Dogs',
        data: [
            [new Date(2018, 0, 1), 12000],
            [new Date(2018, 1, 1), 10000],
            [new Date(2018, 2, 1), null],
            [new Date(2018, 3, 1), 8000],
            [new Date(2018, 4, 1), 9000],
            [new Date(2018, 5, 1), null],
            [new Date(2018, 6, 1), 20000],
            [new Date(2018, 7, 1), 30000],
            [new Date(2018, 8, 1), 40000],
            [new Date(2018, 9, 1), 60000],
            [new Date(2018, 10, 1), 80000],
            [new Date(2018, 11, 1), 82334]
        ]
    },
    {
        name: 'Birds',
        data: [
            [new Date(2018, 0, 1), null],
            [new Date(2018, 1, 1), 45000],
            [new Date(2018, 2, 1), null],
            [new Date(2018, 3, 1), 50023],
            [new Date(2018, 4, 1), 46000],
            [new Date(2018, 5, 1), null],
            [new Date(2018, 6, 1), 33045],
            [new Date(2018, 7, 1), 26000],
            [new Date(2018, 8, 1), 19500],
            [new Date(2018, 9, 1), 12000],
            [new Date(2018, 10, 1), 23000],
            [new Date(2018, 11, 1), 40000]
        ]
    }
];

const nullOptions: OptionsType<OptionType> = [
    { value: NullIndicators.All, label: 'All' },
    { value: NullIndicators.Some, label: 'Some' },
    { value: NullIndicators.None, label: 'None' }
];

export const NullDataPointsExample: React.FC = (): React.ReactElement => {
    const [nullIndicators, setNullIndicators] = React.useState<NullIndicators>(
        NullIndicators.All
    );

    return (
        <div className="mt-3">
            <p className="mt-2 mb-3">
                If all data points for a sepecifc date are null indicator bars
                are shown. This can be changed to show the bars when some data
                points are null for a specific date or to hide the bars
                completely.
            </p>
            <Select
                defaultValue={nullOptions[0]}
                isOptional={false}
                label="Null Indicators"
                labelDescription="Select when to show null indicators"
                onChange={(option: ValueType<NullIndicators>): void => {
                    setNullIndicators(option.value);
                }}
                options={nullOptions}
                selectType={SelectType.Compact}
                style={{ width: '18rem' }}
            />
            <TrendLineChart
                data={DATA}
                dataUI="null-data-points"
                nullIndicators={nullIndicators}
                tooltipNullContent={
                    <span className="va-grey-900--text normal-case">
                        <Signal
                            className="align-middle mr-1"
                            color="var(--va-grey-600)"
                            icon={AlertTriangle}
                            size=".65rem"
                        />
                        Data Unavailable
                    </span>
                }
            />
        </div>
    );
};

export default NullDataPointsExample;
