import React, { ReactElement } from 'react';

import {
    CurveFunction,
    TrendLineChart,
    TrendLineChartPlotData
} from '@preamp/waveform';

const basicData: TrendLineChartPlotData[] = [
    {
        name: 'y-axis #1',
        data: [
            [new Date(2018, 0, 1), 13],
            [new Date(2018, 1, 1), 6],
            [new Date(2018, 2, 1), 9],
            [new Date(2018, 3, 1), 8],
            [new Date(2018, 4, 1), 10],
            [new Date(2018, 5, 1), 12],
            [new Date(2018, 6, 1), 13],
            [new Date(2018, 7, 1), 11],
            [new Date(2018, 8, 1), 10],
            [new Date(2018, 9, 1), 9],
            [new Date(2018, 10, 1), 8],
            [new Date(2018, 11, 1), 7]
        ]
    },
    {
        name: 'y-axis #2',
        data: [
            [new Date(2018, 0, 1), 1],
            [new Date(2018, 1, 1), 8],
            [new Date(2018, 2, 1), 2],
            [new Date(2018, 3, 1), 5],
            [new Date(2018, 4, 1), 1],
            [new Date(2018, 5, 1), 10],
            [new Date(2018, 6, 1), 9],
            [new Date(2018, 7, 1), 9],
            [new Date(2018, 8, 1), 10],
            [new Date(2018, 9, 1), 4],
            [new Date(2018, 10, 1), 9],
            [new Date(2018, 11, 1), 2]
        ],
        curve: CurveFunction.CatmullRom
    }
];

const forecastData: TrendLineChartPlotData[] = [
    {
        name: 'y-axis #1',
        data: [
            [new Date(2019, 0, 1), 10],
            [new Date(2019, 1, 1), 9],
            [new Date(2019, 2, 1), 8],
            [new Date(2019, 3, 1), 7],
            [new Date(2019, 4, 1), 9],
            [new Date(2019, 5, 1), 10]
        ]
    },
    {
        name: 'y-axis #2',
        data: [
            [new Date(2019, 0, 1), 1],
            [new Date(2019, 1, 1), 5],
            [new Date(2019, 2, 1), 7],
            [new Date(2019, 3, 1), 3],
            [new Date(2019, 4, 1), 7],
            [new Date(2019, 5, 1), 6]
        ],
        curve: CurveFunction.CatmullRom
    }
];

export const CurvedLinesTrendLineChartExample: React.FC = (): React.ReactElement => {
    return (
        <section className="mt-5">
            <h4>Curved Lines</h4>
            <p className="mt-2 mb-5">
                Support values of <code>curve</code> include:
            </p>
            <ul>
                {Object.keys(CurveFunction).map(
                    (curve: string): ReactElement => (
                        <li key={curve}>
                            <code>{curve}</code>
                        </li>
                    )
                )}
            </ul>
            <TrendLineChart
                autoWidth
                data={basicData}
                dataUI="curved-lines-example"
                forecastData={forecastData}
            />
        </section>
    );
};

export default CurvedLinesTrendLineChartExample;
