import { TimeValue, TrendLineChartPlotData } from '@preamp/waveform';

export const TODAY = new Date();
const MAX_Y_VALUE = 100;

export interface MaximumYAxisValues {
    [idx: number]: number;
}

export function getDefaultMaxYValue(axis: number): number {
    return MAX_Y_VALUE * axis || 1;
}

function generateAllAxisData(
    yAxisNr: number,
    dates: Date[],
    yAxisMaxValues: MaximumYAxisValues
): TrendLineChartPlotData[] {
    return [...new Array(yAxisNr)].map(
        (_, index: number): TrendLineChartPlotData => ({
            name: `y-axis #${index + 1}`,
            data: [
                ...dates.map(
                    (d: Date): TimeValue => [
                        d,
                        Math.random() *
                            (yAxisMaxValues[index] ||
                                getDefaultMaxYValue(index))
                    ]
                )
            ],
            maxY: yAxisMaxValues[index]
        })
    );
}

function generateDates(
    dataPoints: number,
    startDate: Date,
    endDate: Date,
    addStartDate: boolean
): Date[] {
    const points = dataPoints > 0 ? dataPoints : 1;
    const dateInterval = (endDate.getTime() - startDate.getTime()) / points;
    const sDate = addStartDate
        ? startDate
        : new Date(startDate.getTime() + dateInterval);
    return [
        ...[...new Array(points - (addStartDate ? 0 : 1))].map(
            (_, idx: number): Date =>
                new Date(sDate.getTime() + idx * dateInterval)
        ),
        endDate
    ];
}

export function generateAxisData(
    yAxisNr: number,
    points: number,
    startDate: Date,
    endDate: Date,
    yAxisMaxValues: MaximumYAxisValues,
    isForecastData = false
): TrendLineChartPlotData[] {
    const dates = generateDates(points, startDate, endDate, !isForecastData);
    return generateAllAxisData(yAxisNr, dates, yAxisMaxValues || {});
}
