import React from 'react';

import { TextField, TextFieldType } from '@preamp/core';
import { SetValue, VennDiagram } from '@preamp/waveform';

/**
 * A Basic VennDiagram.
 */
export const BasicVennDiagram: React.FC = (): React.ReactElement => {
    const [a, setA] = React.useState<number>(60);
    const [b, setB] = React.useState<number>(30);
    const [ab, setAB] = React.useState<number>(15);

    const data: SetValue[] = [
        [['A'], a],
        [['B'], b],
        [['A', 'B'], ab]
    ];

    return (
        <section>
            <VennDiagram data={data} />
            <div className="flex">
                <div>
                    <TextField
                        id="basic-a"
                        label="A"
                        max="100"
                        min="1"
                        onChange={(
                            e: React.FormEvent<HTMLInputElement>
                        ): void => {
                            const value = Number(e.currentTarget.value);
                            const maxOverlap = Math.min(value, b);

                            setA(value);

                            if (ab > maxOverlap) {
                                setAB(maxOverlap);
                            }
                        }}
                        textFieldType={TextFieldType.Number}
                        value={String(a)}
                    />
                </div>
                <div className="ml-4">
                    <TextField
                        id="basic-b"
                        label="B"
                        max="100"
                        min="1"
                        onChange={(
                            e: React.FormEvent<HTMLInputElement>
                        ): void => {
                            const value = Number(e.currentTarget.value);
                            const maxOverlap = Math.min(a, value);

                            setB(value);

                            if (ab > maxOverlap) {
                                setAB(maxOverlap);
                            }
                        }}
                        textFieldType={TextFieldType.Number}
                        value={String(b)}
                    />
                </div>
                <div className="ml-4">
                    <TextField
                        id="basic-ab"
                        label="A ∩ B"
                        max={String(Math.min(a, b))}
                        min="1"
                        onChange={(
                            e: React.FormEvent<HTMLInputElement>
                        ): void => {
                            const value = Number(e.currentTarget.value);

                            setAB(value);
                        }}
                        textFieldType={TextFieldType.Number}
                        value={String(ab)}
                    />
                </div>
            </div>
        </section>
    );
};

export default BasicVennDiagram;
