import React from 'react';

import { Button } from '@preamp/core';
import { SetValue, VennDiagram } from '@preamp/waveform';

const DATA: SetValue[] = [
    [['A'], 60],
    [['B'], 30],
    [['A', 'B'], 15]
];

let timeoutID: ReturnType<typeof setTimeout>;

/**
 * VennDiagram empty and loading states.
 */
export const EmptyLoadingVennDiagram: React.FC = (): React.ReactElement => {
    const [data, setData] = React.useState<SetValue[]>([]);
    const [isLoading, setIsLoading] = React.useState<boolean>(false);

    function simulateLoading(): void {
        setIsLoading(true);

        timeoutID = setTimeout((): void => {
            setData(DATA);
            setIsLoading(false);

            timeoutID = null;
        }, 3000);
    }

    function triggerData(): void {
        setData((prevState: SetValue[]): SetValue[] =>
            prevState === DATA ? [] : DATA
        );
    }

    React.useEffect((): (() => void) => {
        simulateLoading();

        return (): void => {
            if (timeoutID) {
                clearTimeout(timeoutID);
            }
        };
    }, []);

    return (
        <section>
            <VennDiagram data={data} isLoading={isLoading} />
            <div className="mt-4">
                <Button onClick={simulateLoading}>Simulate Loading</Button>
                <Button onClick={triggerData}>
                    {data.length ? 'Empty Data' : 'Reset Data'}
                </Button>
            </div>
        </section>
    );
};

export default EmptyLoadingVennDiagram;
