import React from 'react';

import { cloneDeep, get, set } from 'lodash';
import {
    DataDomain,
    VENNDIAGRAM_DEFAULT_DOMAIN,
    VennDiagram,
    SetValue
} from '@preamp/waveform';

import { TextField, TextFieldType, Toggle } from '@preamp/core';

const basicData: SetValue[] = [
    [['A'], 30],
    [['B'], 35],
    [['C'], 20],
    [['D'], 25],
    [['E'], null], // bad value: it will be internally filtered out
    [['A', 'B'], 15],
    [['B', 'C'], 10],
    [['C', 'D'], 3],
    [['A', 'E'], 12], // internally filtered out because E is a bad value
    [['A', 'B', 'C'], 10],
    [['A', 'C', 'D'], -10] // bad value: it will be internally filtered out
];

export const DataDomainsVennDiagramChartExample: React.FC = (): React.ReactElement => {
    const [isCustomDomain, setIsCustomDomain] = React.useState<boolean>();
    const [domain, setDomain] = React.useState<DataDomain>(
        cloneDeep(VENNDIAGRAM_DEFAULT_DOMAIN)
    );

    function changeDomainProperty(prop: string, value: number | boolean): void {
        setDomain(
            (prevDomain: DataDomain): DataDomain => {
                const newDomain = cloneDeep(prevDomain);
                set(newDomain, ['y', 0, prop], value);
                return newDomain;
            }
        );
    }

    function onChange(
        prop: string
    ): (_: React.ChangeEvent<HTMLInputElement>) => void {
        return (e: React.ChangeEvent<HTMLInputElement>): void => {
            changeDomainProperty(prop, Number(e.target.value));
        };
    }

    function onToggleCustomDomain(value: boolean): void {
        setDomain(VENNDIAGRAM_DEFAULT_DOMAIN);
        setIsCustomDomain(value);
    }

    return (
        <section className="mt-5">
            <h4>Plot Data Domains</h4>
            <p className="mt-2 mb-5">
                Values out of range or not allowed by the chart definition will
                be filtered out from data.
            </p>

            <Toggle
                checked={isCustomDomain}
                label="Set a custom domain"
                name="custom-domain"
                onChange={onToggleCustomDomain}
            />

            <div className="flex items-end mb-4">
                <div className="flex-1 text-right pr-4 pb-3">Values:</div>
                <div className="flex-1 pr-4">
                    <TextField
                        disabled={!isCustomDomain}
                        label="min"
                        onChange={onChange('min')}
                        textFieldType={TextFieldType.Number}
                        value={`${get(domain, ['y', 0, 'min'], -10)}`}
                    />
                </div>
                <div className="flex-1 pr-4">
                    <TextField
                        disabled={!isCustomDomain}
                        label="max"
                        onChange={onChange('max')}
                        textFieldType={TextFieldType.Number}
                        value={`${get(domain, ['y', 0, 'max'], 30)}`}
                    />
                </div>
                <div className="flex-1 u-body-2 mb-3">Nulls not allowed</div>
            </div>

            <VennDiagram autoWidth data={basicData} dataDomain={domain} />
        </section>
    );
};

export default DataDomainsVennDiagramChartExample;
